package SmotifCS::StatisticalPotential;

use 5.10.1 ;
use strict;
use warnings;

=head1 NAME

StatisticalPotential - 

=head1 VERSION

Version 0.05

=cut

our $VERSION = '0.05';

=head1 SYNOPSIS

Perhaps a little code snippet.

    use StatisticalPotential;

    my $foo = StatisticalPotential->new();
    ...


=head1 SUBROUTINES/METHODS

=head2 potential_hash

Function that returns a hash containing
Weight of the parameters in the statistical potentials.

=cut

sub potential_hash {
    my %statpot;
    $statpot{'p3AA'}=-0.839;
    $statpot{'p3AR'}=0.328;
    $statpot{'p3AN'}=-0.247;
    $statpot{'p3AD'}=-0.748;
    $statpot{'p3AC'}=-0.996;
    $statpot{'p3AQ'}=0.511;
    $statpot{'p3AE'}=0.242;
    $statpot{'p3AG'}=-0.971;
    $statpot{'p3AH'}=0.277;
    $statpot{'p3AI'}=0.244;
    $statpot{'p3AL'}=-0.074;
    $statpot{'p3AK'}=0.528;
    $statpot{'p3AM'}=-0.017;
    $statpot{'p3AF'}=-0.465;
    $statpot{'p3AP'}=0.072;
    $statpot{'p3AS'}=-0.389;
    $statpot{'p3AT'}=0.270;
    $statpot{'p3AW'}=-0.669;
    $statpot{'p3AY'}=-0.614;
    $statpot{'p3AV'}=0.252;
    $statpot{'p3RA'}=0.328;
    $statpot{'p3RR'}=1.392;
    $statpot{'p3RN'}=0.758;
    $statpot{'p3RD'}=-0.659;
    $statpot{'p3RC'}=1.733;
    $statpot{'p3RQ'}=0.812;
    $statpot{'p3RE'}=0.307;
    $statpot{'p3RG'}=-0.604;
    $statpot{'p3RH'}=-0.124;
    $statpot{'p3RI'}=1.504;
    $statpot{'p3RL'}=0.856;
    $statpot{'p3RK'}=2.308;
    $statpot{'p3RM'}=2.129;
    $statpot{'p3RF'}=0.837;
    $statpot{'p3RP'}=1.130;
    $statpot{'p3RS'}=0.113;
    $statpot{'p3RT'}=0.681;
    $statpot{'p3RW'}=0.233;
    $statpot{'p3RY'}=-0.602;
    $statpot{'p3RV'}=1.394;
    $statpot{'p3NA'}=-0.247;
    $statpot{'p3NR'}=0.758;
    $statpot{'p3NN'}=0.207;
    $statpot{'p3ND'}=0.886;
    $statpot{'p3NC'}=1.795;
    $statpot{'p3NQ'}=0.289;
    $statpot{'p3NE'}=0.128;
    $statpot{'p3NG'}=-0.441;
    $statpot{'p3NH'}=0.453;
    $statpot{'p3NI'}=1.447;
    $statpot{'p3NL'}=0.636;
    $statpot{'p3NK'}=0.043;
    $statpot{'p3NM'}=0.773;
    $statpot{'p3NF'}=2.457;
    $statpot{'p3NP'}=0.471;
    $statpot{'p3NS'}=0.305;
    $statpot{'p3NT'}=1.215;
    $statpot{'p3NW'}=0.377;
    $statpot{'p3NY'}=1.907;
    $statpot{'p3NV'}=0.527;
    $statpot{'p3DA'}=-0.748;
    $statpot{'p3DR'}=-0.659;
    $statpot{'p3DN'}=0.886;
    $statpot{'p3DD'}=0.379;
    $statpot{'p3DC'}=-0.021;
    $statpot{'p3DQ'}=0.318;
    $statpot{'p3DE'}=0.898;
    $statpot{'p3DG'}=-0.736;
    $statpot{'p3DH'}=0.789;
    $statpot{'p3DI'}=0.946;
    $statpot{'p3DL'}=0.597;
    $statpot{'p3DK'}=-0.293;
    $statpot{'p3DM'}=2.251;
    $statpot{'p3DF'}=0.485;
    $statpot{'p3DP'}=0.438;
    $statpot{'p3DS'}=-0.366;
    $statpot{'p3DT'}=0.751;
    $statpot{'p3DW'}=0.240;
    $statpot{'p3DY'}=0.496;
    $statpot{'p3DV'}=0.862;
    $statpot{'p3CA'}=-0.996;
    $statpot{'p3CR'}=1.733;
    $statpot{'p3CN'}=1.795;
    $statpot{'p3CD'}=-0.021;
    $statpot{'p3CC'}=-3.422;
    $statpot{'p3CQ'}=0.320;
    $statpot{'p3CE'}=1.364;
    $statpot{'p3CG'}=0.063;
    $statpot{'p3CH'}=0.012;
    $statpot{'p3CI'}=0.375;
    $statpot{'p3CL'}=0.170;
    $statpot{'p3CK'}=1.336;
    $statpot{'p3CM'}=-0.894;
    $statpot{'p3CF'}=-0.174;
    $statpot{'p3CP'}=-0.198;
    $statpot{'p3CS'}=-0.624;
    $statpot{'p3CT'}=0.419;
    $statpot{'p3CW'}=-0.388;
    $statpot{'p3CY'}=-0.031;
    $statpot{'p3CV'}=-0.604;
    $statpot{'p3QA'}=0.511;
    $statpot{'p3QR'}=0.812;
    $statpot{'p3QN'}=0.289;
    $statpot{'p3QD'}=0.318;
    $statpot{'p3QC'}=0.320;
    $statpot{'p3QQ'}=0.387;
    $statpot{'p3QE'}=1.418;
    $statpot{'p3QG'}=-0.491;
    $statpot{'p3QH'}=0.000;
    $statpot{'p3QI'}=2.162;
    $statpot{'p3QL'}=0.842;
    $statpot{'p3QK'}=-0.043;
    $statpot{'p3QM'}=1.351;
    $statpot{'p3QF'}=0.182;
    $statpot{'p3QP'}=1.003;
    $statpot{'p3QS'}=-0.064;
    $statpot{'p3QT'}=0.897;
    $statpot{'p3QW'}=0.000;
    $statpot{'p3QY'}=-0.236;
    $statpot{'p3QV'}=0.930;
    $statpot{'p3EA'}=0.242;
    $statpot{'p3ER'}=0.307;
    $statpot{'p3EN'}=0.128;
    $statpot{'p3ED'}=0.898;
    $statpot{'p3EC'}=1.364;
    $statpot{'p3EQ'}=1.418;
    $statpot{'p3EE'}=1.624;
    $statpot{'p3EG'}=0.004;
    $statpot{'p3EH'}=1.139;
    $statpot{'p3EI'}=1.862;
    $statpot{'p3EL'}=1.575;
    $statpot{'p3EK'}=0.102;
    $statpot{'p3EM'}=2.396;
    $statpot{'p3EF'}=1.688;
    $statpot{'p3EP'}=0.930;
    $statpot{'p3ES'}=-0.050;
    $statpot{'p3ET'}=0.972;
    $statpot{'p3EW'}=0.907;
    $statpot{'p3EY'}=1.383;
    $statpot{'p3EV'}=0.561;
    $statpot{'p3GA'}=-0.971;
    $statpot{'p3GR'}=-0.604;
    $statpot{'p3GN'}=-0.441;
    $statpot{'p3GD'}=-0.736;
    $statpot{'p3GC'}=0.063;
    $statpot{'p3GQ'}=-0.491;
    $statpot{'p3GE'}=0.004;
    $statpot{'p3GG'}=-0.462;
    $statpot{'p3GH'}=-0.596;
    $statpot{'p3GI'}=-0.375;
    $statpot{'p3GL'}=-0.446;
    $statpot{'p3GK'}=-0.371;
    $statpot{'p3GM'}=-0.728;
    $statpot{'p3GF'}=-0.793;
    $statpot{'p3GP'}=-0.644;
    $statpot{'p3GS'}=-0.916;
    $statpot{'p3GT'}=-0.799;
    $statpot{'p3GW'}=-0.543;
    $statpot{'p3GY'}=-0.681;
    $statpot{'p3GV'}=-0.678;
    $statpot{'p3HA'}=0.277;
    $statpot{'p3HR'}=-0.124;
    $statpot{'p3HN'}=0.453;
    $statpot{'p3HD'}=0.789;
    $statpot{'p3HC'}=0.012;
    $statpot{'p3HQ'}=0.000;
    $statpot{'p3HE'}=1.139;
    $statpot{'p3HG'}=-0.596;
    $statpot{'p3HH'}=-0.267;
    $statpot{'p3HI'}=2.168;
    $statpot{'p3HL'}=-0.031;
    $statpot{'p3HK'}=1.650;
    $statpot{'p3HM'}=-1.171;
    $statpot{'p3HF'}=0.405;
    $statpot{'p3HP'}=0.624;
    $statpot{'p3HS'}=-0.421;
    $statpot{'p3HT'}=0.295;
    $statpot{'p3HW'}=0.340;
    $statpot{'p3HY'}=-0.205;
    $statpot{'p3HV'}=0.152;
    $statpot{'p3IA'}=0.244;
    $statpot{'p3IR'}=1.504;
    $statpot{'p3IN'}=1.447;
    $statpot{'p3ID'}=0.946;
    $statpot{'p3IC'}=0.375;
    $statpot{'p3IQ'}=2.162;
    $statpot{'p3IE'}=1.862;
    $statpot{'p3IG'}=-0.375;
    $statpot{'p3IH'}=2.168;
    $statpot{'p3II'}=2.007;
    $statpot{'p3IL'}=0.171;
    $statpot{'p3IK'}=2.966;
    $statpot{'p3IM'}=0.178;
    $statpot{'p3IF'}=0.234;
    $statpot{'p3IP'}=0.859;
    $statpot{'p3IS'}=1.128;
    $statpot{'p3IT'}=1.422;
    $statpot{'p3IW'}=0.518;
    $statpot{'p3IY'}=0.132;
    $statpot{'p3IV'}=0.948;
    $statpot{'p3LA'}=-0.074;
    $statpot{'p3LR'}=0.856;
    $statpot{'p3LN'}=0.636;
    $statpot{'p3LD'}=0.597;
    $statpot{'p3LC'}=0.170;
    $statpot{'p3LQ'}=0.842;
    $statpot{'p3LE'}=1.575;
    $statpot{'p3LG'}=-0.446;
    $statpot{'p3LH'}=-0.031;
    $statpot{'p3LI'}=0.171;
    $statpot{'p3LL'}=0.677;
    $statpot{'p3LK'}=1.534;
    $statpot{'p3LM'}=1.136;
    $statpot{'p3LF'}=-0.222;
    $statpot{'p3LP'}=1.318;
    $statpot{'p3LS'}=0.030;
    $statpot{'p3LT'}=1.281;
    $statpot{'p3LW'}=-0.051;
    $statpot{'p3LY'}=-0.547;
    $statpot{'p3LV'}=0.472;
    $statpot{'p3KA'}=0.528;
    $statpot{'p3KR'}=2.308;
    $statpot{'p3KN'}=0.043;
    $statpot{'p3KD'}=-0.293;
    $statpot{'p3KC'}=1.336;
    $statpot{'p3KQ'}=-0.043;
    $statpot{'p3KE'}=0.102;
    $statpot{'p3KG'}=-0.371;
    $statpot{'p3KH'}=1.650;
    $statpot{'p3KI'}=2.966;
    $statpot{'p3KL'}=1.534;
    $statpot{'p3KK'}=1.211;
    $statpot{'p3KM'}=1.735;
    $statpot{'p3KF'}=0.899;
    $statpot{'p3KP'}=0.504;
    $statpot{'p3KS'}=0.199;
    $statpot{'p3KT'}=1.172;
    $statpot{'p3KW'}=0.527;
    $statpot{'p3KY'}=0.941;
    $statpot{'p3KV'}=1.145;
    $statpot{'p3MA'}=-0.017;
    $statpot{'p3MR'}=2.129;
    $statpot{'p3MN'}=0.773;
    $statpot{'p3MD'}=2.251;
    $statpot{'p3MC'}=-0.894;
    $statpot{'p3MQ'}=1.351;
    $statpot{'p3ME'}=2.396;
    $statpot{'p3MG'}=-0.728;
    $statpot{'p3MH'}=-1.171;
    $statpot{'p3MI'}=0.178;
    $statpot{'p3ML'}=1.136;
    $statpot{'p3MK'}=1.735;
    $statpot{'p3MM'}=0.378;
    $statpot{'p3MF'}=0.122;
    $statpot{'p3MP'}=1.154;
    $statpot{'p3MS'}=0.592;
    $statpot{'p3MT'}=0.831;
    $statpot{'p3MW'}=-0.765;
    $statpot{'p3MY'}=-0.793;
    $statpot{'p3MV'}=0.101;
    $statpot{'p3FA'}=-0.465;
    $statpot{'p3FR'}=0.837;
    $statpot{'p3FN'}=2.457;
    $statpot{'p3FD'}=0.485;
    $statpot{'p3FC'}=-0.174;
    $statpot{'p3FQ'}=0.182;
    $statpot{'p3FE'}=1.688;
    $statpot{'p3FG'}=-0.793;
    $statpot{'p3FH'}=0.405;
    $statpot{'p3FI'}=0.234;
    $statpot{'p3FL'}=-0.222;
    $statpot{'p3FK'}=0.899;
    $statpot{'p3FM'}=0.122;
    $statpot{'p3FF'}=-0.631;
    $statpot{'p3FP'}=0.242;
    $statpot{'p3FS'}=0.985;
    $statpot{'p3FT'}=1.017;
    $statpot{'p3FW'}=-1.140;
    $statpot{'p3FY'}=-0.133;
    $statpot{'p3FV'}=0.741;
    $statpot{'p3PA'}=0.072;
    $statpot{'p3PR'}=1.130;
    $statpot{'p3PN'}=0.471;
    $statpot{'p3PD'}=0.438;
    $statpot{'p3PC'}=-0.198;
    $statpot{'p3PQ'}=1.003;
    $statpot{'p3PE'}=0.930;
    $statpot{'p3PG'}=-0.644;
    $statpot{'p3PH'}=0.624;
    $statpot{'p3PI'}=0.859;
    $statpot{'p3PL'}=1.318;
    $statpot{'p3PK'}=0.504;
    $statpot{'p3PM'}=1.154;
    $statpot{'p3PF'}=0.242;
    $statpot{'p3PP'}=0.641;
    $statpot{'p3PS'}=0.791;
    $statpot{'p3PT'}=1.416;
    $statpot{'p3PW'}=1.172;
    $statpot{'p3PY'}=0.237;
    $statpot{'p3PV'}=1.857;
    $statpot{'p3SA'}=-0.389;
    $statpot{'p3SR'}=0.113;
    $statpot{'p3SN'}=0.305;
    $statpot{'p3SD'}=-0.366;
    $statpot{'p3SC'}=-0.624;
    $statpot{'p3SQ'}=-0.064;
    $statpot{'p3SE'}=-0.050;
    $statpot{'p3SG'}=-0.916;
    $statpot{'p3SH'}=-0.421;
    $statpot{'p3SI'}=1.128;
    $statpot{'p3SL'}=0.030;
    $statpot{'p3SK'}=0.199;
    $statpot{'p3SM'}=0.592;
    $statpot{'p3SF'}=0.985;
    $statpot{'p3SP'}=0.791;
    $statpot{'p3SS'}=-0.343;
    $statpot{'p3ST'}=0.045;
    $statpot{'p3SW'}=1.026;
    $statpot{'p3SY'}=0.007;
    $statpot{'p3SV'}=0.849;
    $statpot{'p3TA'}=0.270;
    $statpot{'p3TR'}=0.681;
    $statpot{'p3TN'}=1.215;
    $statpot{'p3TD'}=0.751;
    $statpot{'p3TC'}=0.419;
    $statpot{'p3TQ'}=0.897;
    $statpot{'p3TE'}=0.972;
    $statpot{'p3TG'}=-0.799;
    $statpot{'p3TH'}=0.295;
    $statpot{'p3TI'}=1.422;
    $statpot{'p3TL'}=1.281;
    $statpot{'p3TK'}=1.172;
    $statpot{'p3TM'}=0.831;
    $statpot{'p3TF'}=1.017;
    $statpot{'p3TP'}=1.416;
    $statpot{'p3TS'}=0.045;
    $statpot{'p3TT'}=1.031;
    $statpot{'p3TW'}=1.905;
    $statpot{'p3TY'}=0.358;
    $statpot{'p3TV'}=2.241;
    $statpot{'p3WA'}=-0.669;
    $statpot{'p3WR'}=0.233;
    $statpot{'p3WN'}=0.377;
    $statpot{'p3WD'}=0.240;
    $statpot{'p3WC'}=-0.388;
    $statpot{'p3WQ'}=0.000;
    $statpot{'p3WE'}=0.907;
    $statpot{'p3WG'}=-0.543;
    $statpot{'p3WH'}=0.340;
    $statpot{'p3WI'}=0.518;
    $statpot{'p3WL'}=-0.051;
    $statpot{'p3WK'}=0.527;
    $statpot{'p3WM'}=-0.765;
    $statpot{'p3WF'}=-1.140;
    $statpot{'p3WP'}=1.172;
    $statpot{'p3WS'}=1.026;
    $statpot{'p3WT'}=1.905;
    $statpot{'p3WW'}=0.000;
    $statpot{'p3WY'}=-0.799;
    $statpot{'p3WV'}=-0.517;
    $statpot{'p3YA'}=-0.614;
    $statpot{'p3YR'}=-0.602;
    $statpot{'p3YN'}=1.907;
    $statpot{'p3YD'}=0.496;
    $statpot{'p3YC'}=-0.031;
    $statpot{'p3YQ'}=-0.236;
    $statpot{'p3YE'}=1.383;
    $statpot{'p3YG'}=-0.681;
    $statpot{'p3YH'}=-0.205;
    $statpot{'p3YI'}=0.132;
    $statpot{'p3YL'}=-0.547;
    $statpot{'p3YK'}=0.941;
    $statpot{'p3YM'}=-0.793;
    $statpot{'p3YF'}=-0.133;
    $statpot{'p3YP'}=0.237;
    $statpot{'p3YS'}=0.007;
    $statpot{'p3YT'}=0.358;
    $statpot{'p3YW'}=-0.799;
    $statpot{'p3YY'}=-0.878;
    $statpot{'p3YV'}=0.166;
    $statpot{'p3VA'}=0.252;
    $statpot{'p3VR'}=1.394;
    $statpot{'p3VN'}=0.527;
    $statpot{'p3VD'}=0.862;
    $statpot{'p3VC'}=-0.604;
    $statpot{'p3VQ'}=0.930;
    $statpot{'p3VE'}=0.561;
    $statpot{'p3VG'}=-0.678;
    $statpot{'p3VH'}=0.152;
    $statpot{'p3VI'}=0.948;
    $statpot{'p3VL'}=0.472;
    $statpot{'p3VK'}=1.145;
    $statpot{'p3VM'}=0.101;
    $statpot{'p3VF'}=0.741;
    $statpot{'p3VP'}=1.857;
    $statpot{'p3VS'}=0.849;
    $statpot{'p3VT'}=2.241;
    $statpot{'p3VW'}=-0.517;
    $statpot{'p3VY'}=0.166;
    $statpot{'p3VV'}=0.458;
    $statpot{'f3AA'}=-1.616;
    $statpot{'f3AR'}=0.040;
    $statpot{'f3AN'}=-0.191;
    $statpot{'f3AD'}=-0.288;
    $statpot{'f3AC'}=-1.023;
    $statpot{'f3AQ'}=-0.101;
    $statpot{'f3AE'}=0.287;
    $statpot{'f3AG'}=-1.054;
    $statpot{'f3AH'}=-0.548;
    $statpot{'f3AI'}=0.570;
    $statpot{'f3AL'}=-0.355;
    $statpot{'f3AK'}=0.062;
    $statpot{'f3AM'}=-0.918;
    $statpot{'f3AF'}=-0.716;
    $statpot{'f3AP'}=-0.910;
    $statpot{'f3AS'}=-0.654;
    $statpot{'f3AT'}=-0.154;
    $statpot{'f3AW'}=-0.566;
    $statpot{'f3AY'}=-0.936;
    $statpot{'f3AV'}=-0.090;
    $statpot{'f3RA'}=0.041;
    $statpot{'f3RR'}=0.000;
    $statpot{'f3RN'}=1.583;
    $statpot{'f3RD'}=0.998;
    $statpot{'f3RC'}=-0.037;
    $statpot{'f3RQ'}=1.989;
    $statpot{'f3RE'}=2.571;
    $statpot{'f3RG'}=-0.321;
    $statpot{'f3RH'}=0.271;
    $statpot{'f3RI'}=2.098;
    $statpot{'f3RL'}=1.724;
    $statpot{'f3RK'}=2.334;
    $statpot{'f3RM'}=1.545;
    $statpot{'f3RF'}=0.781;
    $statpot{'f3RP'}=0.416;
    $statpot{'f3RS'}=0.273;
    $statpot{'f3RT'}=1.930;
    $statpot{'f3RW'}=0.457;
    $statpot{'f3RY'}=0.410;
    $statpot{'f3RV'}=2.240;
    $statpot{'f3NA'}=-0.175;
    $statpot{'f3NR'}=1.584;
    $statpot{'f3NN'}=0.705;
    $statpot{'f3ND'}=1.652;
    $statpot{'f3NC'}=-0.278;
    $statpot{'f3NQ'}=1.927;
    $statpot{'f3NE'}=1.209;
    $statpot{'f3NG'}=-0.625;
    $statpot{'f3NH'}=0.661;
    $statpot{'f3NI'}=1.671;
    $statpot{'f3NL'}=1.161;
    $statpot{'f3NK'}=1.006;
    $statpot{'f3NM'}=1.100;
    $statpot{'f3NF'}=0.991;
    $statpot{'f3NP'}=0.498;
    $statpot{'f3NS'}=-0.200;
    $statpot{'f3NT'}=1.007;
    $statpot{'f3NW'}=0.358;
    $statpot{'f3NY'}=0.847;
    $statpot{'f3NV'}=1.267;
    $statpot{'f3DA'}=-0.288;
    $statpot{'f3DR'}=0.998;
    $statpot{'f3DN'}=1.652;
    $statpot{'f3DD'}=0.860;
    $statpot{'f3DC'}=0.413;
    $statpot{'f3DQ'}=1.239;
    $statpot{'f3DE'}=1.900;
    $statpot{'f3DG'}=-0.514;
    $statpot{'f3DH'}=0.712;
    $statpot{'f3DI'}=1.417;
    $statpot{'f3DL'}=1.132;
    $statpot{'f3DK'}=0.633;
    $statpot{'f3DM'}=0.604;
    $statpot{'f3DF'}=1.261;
    $statpot{'f3DP'}=-0.076;
    $statpot{'f3DS'}=-0.016;
    $statpot{'f3DT'}=0.890;
    $statpot{'f3DW'}=0.974;
    $statpot{'f3DY'}=0.515;
    $statpot{'f3DV'}=1.041;
    $statpot{'f3CA'}=-1.023;
    $statpot{'f3CR'}=-0.037;
    $statpot{'f3CN'}=-0.278;
    $statpot{'f3CD'}=0.413;
    $statpot{'f3CC'}=-4.024;
    $statpot{'f3CQ'}=0.538;
    $statpot{'f3CE'}=0.453;
    $statpot{'f3CG'}=-1.079;
    $statpot{'f3CH'}=1.494;
    $statpot{'f3CI'}=1.335;
    $statpot{'f3CL'}=-0.125;
    $statpot{'f3CK'}=0.736;
    $statpot{'f3CM'}=0.847;
    $statpot{'f3CF'}=-0.682;
    $statpot{'f3CP'}=-0.828;
    $statpot{'f3CS'}=-0.703;
    $statpot{'f3CT'}=1.352;
    $statpot{'f3CW'}=0.073;
    $statpot{'f3CY'}=-0.279;
    $statpot{'f3CV'}=1.277;
    $statpot{'f3QA'}=-0.101;
    $statpot{'f3QR'}=1.989;
    $statpot{'f3QN'}=1.926;
    $statpot{'f3QD'}=1.239;
    $statpot{'f3QC'}=0.537;
    $statpot{'f3QQ'}=0.968;
    $statpot{'f3QE'}=2.582;
    $statpot{'f3QG'}=-0.326;
    $statpot{'f3QH'}=1.657;
    $statpot{'f3QI'}=2.887;
    $statpot{'f3QL'}=0.835;
    $statpot{'f3QK'}=2.512;
    $statpot{'f3QM'}=1.024;
    $statpot{'f3QF'}=0.300;
    $statpot{'f3QP'}=0.253;
    $statpot{'f3QS'}=0.465;
    $statpot{'f3QT'}=1.076;
    $statpot{'f3QW'}=-0.101;
    $statpot{'f3QY'}=0.217;
    $statpot{'f3QV'}=2.412;
    $statpot{'f3EA'}=0.286;
    $statpot{'f3ER'}=2.571;
    $statpot{'f3EN'}=1.209;
    $statpot{'f3ED'}=1.900;
    $statpot{'f3EC'}=0.453;
    $statpot{'f3EQ'}=2.582;
    $statpot{'f3EE'}=1.782;
    $statpot{'f3EG'}=0.043;
    $statpot{'f3EH'}=1.506;
    $statpot{'f3EI'}=1.569;
    $statpot{'f3EL'}=1.658;
    $statpot{'f3EK'}=0.739;
    $statpot{'f3EM'}=1.373;
    $statpot{'f3EF'}=0.592;
    $statpot{'f3EP'}=0.346;
    $statpot{'f3ES'}=0.016;
    $statpot{'f3ET'}=1.359;
    $statpot{'f3EW'}=0.646;
    $statpot{'f3EY'}=1.313;
    $statpot{'f3EV'}=1.263;
    $statpot{'f3GA'}=-1.057;
    $statpot{'f3GR'}=-0.331;
    $statpot{'f3GN'}=-0.624;
    $statpot{'f3GD'}=-0.532;
    $statpot{'f3GC'}=-1.108;
    $statpot{'f3GQ'}=-0.365;
    $statpot{'f3GE'}=-0.010;
    $statpot{'f3GG'}=-1.060;
    $statpot{'f3GH'}=-0.983;
    $statpot{'f3GI'}=-0.621;
    $statpot{'f3GL'}=-0.415;
    $statpot{'f3GK'}=-0.314;
    $statpot{'f3GM'}=-1.131;
    $statpot{'f3GF'}=-0.915;
    $statpot{'f3GP'}=-1.072;
    $statpot{'f3GS'}=-1.127;
    $statpot{'f3GT'}=-0.780;
    $statpot{'f3GW'}=-0.608;
    $statpot{'f3GY'}=-0.928;
    $statpot{'f3GV'}=-0.885;
    $statpot{'f3HA'}=-0.526;
    $statpot{'f3HR'}=0.271;
    $statpot{'f3HN'}=0.661;
    $statpot{'f3HD'}=0.712;
    $statpot{'f3HC'}=1.494;
    $statpot{'f3HQ'}=1.657;
    $statpot{'f3HE'}=1.505;
    $statpot{'f3HG'}=-0.839;
    $statpot{'f3HH'}=0.560;
    $statpot{'f3HI'}=0.782;
    $statpot{'f3HL'}=1.087;
    $statpot{'f3HK'}=0.945;
    $statpot{'f3HM'}=-0.055;
    $statpot{'f3HF'}=0.091;
    $statpot{'f3HP'}=-0.237;
    $statpot{'f3HS'}=-0.040;
    $statpot{'f3HT'}=0.132;
    $statpot{'f3HW'}=-0.845;
    $statpot{'f3HY'}=-0.280;
    $statpot{'f3HV'}=0.370;
    $statpot{'f3IA'}=0.570;
    $statpot{'f3IR'}=2.098;
    $statpot{'f3IN'}=1.670;
    $statpot{'f3ID'}=1.418;
    $statpot{'f3IC'}=1.335;
    $statpot{'f3IQ'}=2.887;
    $statpot{'f3IE'}=1.569;
    $statpot{'f3IG'}=-0.603;
    $statpot{'f3IH'}=0.782;
    $statpot{'f3II'}=0.814;
    $statpot{'f3IL'}=3.368;
    $statpot{'f3IK'}=1.844;
    $statpot{'f3IM'}=2.075;
    $statpot{'f3IF'}=1.362;
    $statpot{'f3IP'}=2.409;
    $statpot{'f3IS'}=1.416;
    $statpot{'f3IT'}=2.880;
    $statpot{'f3IW'}=0.000;
    $statpot{'f3IY'}=1.292;
    $statpot{'f3IV'}=3.265;
    $statpot{'f3LA'}=-0.356;
    $statpot{'f3LR'}=1.724;
    $statpot{'f3LN'}=1.161;
    $statpot{'f3LD'}=1.132;
    $statpot{'f3LC'}=-0.124;
    $statpot{'f3LQ'}=0.835;
    $statpot{'f3LE'}=1.658;
    $statpot{'f3LG'}=-0.405;
    $statpot{'f3LH'}=1.088;
    $statpot{'f3LI'}=3.368;
    $statpot{'f3LL'}=1.508;
    $statpot{'f3LK'}=1.892;
    $statpot{'f3LM'}=1.101;
    $statpot{'f3LF'}=0.983;
    $statpot{'f3LP'}=0.490;
    $statpot{'f3LS'}=0.240;
    $statpot{'f3LT'}=1.653;
    $statpot{'f3LW'}=0.427;
    $statpot{'f3LY'}=0.428;
    $statpot{'f3LV'}=1.789;
    $statpot{'f3KA'}=0.062;
    $statpot{'f3KR'}=2.334;
    $statpot{'f3KN'}=1.006;
    $statpot{'f3KD'}=0.633;
    $statpot{'f3KC'}=0.736;
    $statpot{'f3KQ'}=2.512;
    $statpot{'f3KE'}=0.739;
    $statpot{'f3KG'}=-0.250;
    $statpot{'f3KH'}=0.946;
    $statpot{'f3KI'}=1.844;
    $statpot{'f3KL'}=1.892;
    $statpot{'f3KK'}=1.404;
    $statpot{'f3KM'}=1.216;
    $statpot{'f3KF'}=1.399;
    $statpot{'f3KP'}=0.842;
    $statpot{'f3KS'}=0.688;
    $statpot{'f3KT'}=1.823;
    $statpot{'f3KW'}=1.582;
    $statpot{'f3KY'}=0.562;
    $statpot{'f3KV'}=2.342;
    $statpot{'f3MA'}=-0.918;
    $statpot{'f3MR'}=1.546;
    $statpot{'f3MN'}=1.099;
    $statpot{'f3MD'}=0.604;
    $statpot{'f3MC'}=0.848;
    $statpot{'f3MQ'}=1.024;
    $statpot{'f3ME'}=1.373;
    $statpot{'f3MG'}=-1.083;
    $statpot{'f3MH'}=-0.054;
    $statpot{'f3MI'}=2.075;
    $statpot{'f3ML'}=1.101;
    $statpot{'f3MK'}=1.216;
    $statpot{'f3MM'}=0.286;
    $statpot{'f3MF'}=0.120;
    $statpot{'f3MP'}=0.613;
    $statpot{'f3MS'}=-0.342;
    $statpot{'f3MT'}=1.407;
    $statpot{'f3MW'}=0.289;
    $statpot{'f3MY'}=0.532;
    $statpot{'f3MV'}=1.940;
    $statpot{'f3FA'}=-0.716;
    $statpot{'f3FR'}=0.781;
    $statpot{'f3FN'}=0.991;
    $statpot{'f3FD'}=1.262;
    $statpot{'f3FC'}=-0.681;
    $statpot{'f3FQ'}=0.301;
    $statpot{'f3FE'}=0.593;
    $statpot{'f3FG'}=-0.854;
    $statpot{'f3FH'}=0.090;
    $statpot{'f3FI'}=1.362;
    $statpot{'f3FL'}=0.983;
    $statpot{'f3FK'}=1.399;
    $statpot{'f3FM'}=0.120;
    $statpot{'f3FF'}=-0.574;
    $statpot{'f3FP'}=-0.218;
    $statpot{'f3FS'}=-0.134;
    $statpot{'f3FT'}=0.871;
    $statpot{'f3FW'}=0.064;
    $statpot{'f3FY'}=0.257;
    $statpot{'f3FV'}=0.616;
    $statpot{'f3PA'}=-0.910;
    $statpot{'f3PR'}=0.416;
    $statpot{'f3PN'}=0.498;
    $statpot{'f3PD'}=-0.050;
    $statpot{'f3PC'}=-0.828;
    $statpot{'f3PQ'}=0.253;
    $statpot{'f3PE'}=0.345;
    $statpot{'f3PG'}=-1.052;
    $statpot{'f3PH'}=-0.237;
    $statpot{'f3PI'}=2.409;
    $statpot{'f3PL'}=0.490;
    $statpot{'f3PK'}=0.843;
    $statpot{'f3PM'}=0.614;
    $statpot{'f3PF'}=-0.218;
    $statpot{'f3PP'}=0.143;
    $statpot{'f3PS'}=-0.074;
    $statpot{'f3PT'}=0.496;
    $statpot{'f3PW'}=-0.598;
    $statpot{'f3PY'}=-0.451;
    $statpot{'f3PV'}=1.171;
    $statpot{'f3SA'}=-0.655;
    $statpot{'f3SR'}=0.273;
    $statpot{'f3SN'}=-0.200;
    $statpot{'f3SD'}=-0.016;
    $statpot{'f3SC'}=-0.703;
    $statpot{'f3SQ'}=0.465;
    $statpot{'f3SE'}=0.016;
    $statpot{'f3SG'}=-1.138;
    $statpot{'f3SH'}=-0.041;
    $statpot{'f3SI'}=1.416;
    $statpot{'f3SL'}=0.240;
    $statpot{'f3SK'}=0.688;
    $statpot{'f3SM'}=-0.343;
    $statpot{'f3SF'}=-0.134;
    $statpot{'f3SP'}=-0.074;
    $statpot{'f3SS'}=-0.446;
    $statpot{'f3ST'}=0.513;
    $statpot{'f3SW'}=-0.153;
    $statpot{'f3SY'}=-0.099;
    $statpot{'f3SV'}=0.908;
    $statpot{'f3TA'}=-0.154;
    $statpot{'f3TR'}=1.930;
    $statpot{'f3TN'}=1.007;
    $statpot{'f3TD'}=0.948;
    $statpot{'f3TC'}=1.352;
    $statpot{'f3TQ'}=1.076;
    $statpot{'f3TE'}=1.359;
    $statpot{'f3TG'}=-0.750;
    $statpot{'f3TH'}=0.132;
    $statpot{'f3TI'}=2.881;
    $statpot{'f3TL'}=1.653;
    $statpot{'f3TK'}=1.823;
    $statpot{'f3TM'}=1.407;
    $statpot{'f3TF'}=0.871;
    $statpot{'f3TP'}=0.496;
    $statpot{'f3TS'}=0.513;
    $statpot{'f3TT'}=0.869;
    $statpot{'f3TW'}=1.674;
    $statpot{'f3TY'}=1.247;
    $statpot{'f3TV'}=1.827;
    $statpot{'f3WA'}=-0.566;
    $statpot{'f3WR'}=0.457;
    $statpot{'f3WN'}=0.358;
    $statpot{'f3WD'}=0.974;
    $statpot{'f3WC'}=0.073;
    $statpot{'f3WQ'}=-0.100;
    $statpot{'f3WE'}=0.646;
    $statpot{'f3WG'}=-0.541;
    $statpot{'f3WH'}=-0.846;
    $statpot{'f3WI'}=0.000;
    $statpot{'f3WL'}=0.428;
    $statpot{'f3WK'}=1.581;
    $statpot{'f3WM'}=0.289;
    $statpot{'f3WF'}=0.063;
    $statpot{'f3WP'}=-0.599;
    $statpot{'f3WS'}=-0.153;
    $statpot{'f3WT'}=1.674;
    $statpot{'f3WW'}=-1.256;
    $statpot{'f3WY'}=-0.174;
    $statpot{'f3WV'}=1.453;
    $statpot{'f3YA'}=-0.936;
    $statpot{'f3YR'}=0.411;
    $statpot{'f3YN'}=0.848;
    $statpot{'f3YD'}=0.515;
    $statpot{'f3YC'}=-0.279;
    $statpot{'f3YQ'}=0.217;
    $statpot{'f3YE'}=1.313;
    $statpot{'f3YG'}=-0.921;
    $statpot{'f3YH'}=-0.279;
    $statpot{'f3YI'}=1.292;
    $statpot{'f3YL'}=0.428;
    $statpot{'f3YK'}=0.562;
    $statpot{'f3YM'}=0.532;
    $statpot{'f3YF'}=0.257;
    $statpot{'f3YP'}=-0.450;
    $statpot{'f3YS'}=-0.099;
    $statpot{'f3YT'}=1.248;
    $statpot{'f3YW'}=-0.175;
    $statpot{'f3YY'}=-0.425;
    $statpot{'f3YV'}=0.606;
    $statpot{'f3VA'}=-0.090;
    $statpot{'f3VR'}=2.240;
    $statpot{'f3VN'}=1.267;
    $statpot{'f3VD'}=1.042;
    $statpot{'f3VC'}=1.278;
    $statpot{'f3VQ'}=2.412;
    $statpot{'f3VE'}=1.263;
    $statpot{'f3VG'}=-0.876;
    $statpot{'f3VH'}=0.370;
    $statpot{'f3VI'}=3.265;
    $statpot{'f3VL'}=1.789;
    $statpot{'f3VK'}=2.342;
    $statpot{'f3VM'}=1.940;
    $statpot{'f3VF'}=0.616;
    $statpot{'f3VP'}=1.171;
    $statpot{'f3VS'}=0.908;
    $statpot{'f3VT'}=1.827;
    $statpot{'f3VW'}=1.453;
    $statpot{'f3VY'}=0.606;
    $statpot{'f3VV'}=1.822;
    $statpot{'a3AA'}=-2.899;
    $statpot{'a3AR'}=0.000;
    $statpot{'a3AN'}=0.000;
    $statpot{'a3AD'}=0.000;
    $statpot{'a3AC'}=0.000;
    $statpot{'a3AQ'}=0.000;
    $statpot{'a3AE'}=0.000;
    $statpot{'a3AG'}=-1.437;
    $statpot{'a3AH'}=0.000;
    $statpot{'a3AI'}=0.000;
    $statpot{'a3AL'}=0.000;
    $statpot{'a3AK'}=0.000;
    $statpot{'a3AM'}=0.000;
    $statpot{'a3AF'}=0.000;
    $statpot{'a3AP'}=0.000;
    $statpot{'a3AS'}=0.000;
    $statpot{'a3AT'}=0.000;
    $statpot{'a3AW'}=0.000;
    $statpot{'a3AY'}=0.000;
    $statpot{'a3AV'}=0.000;
    $statpot{'a3RA'}=0.000;
    $statpot{'a3RR'}=0.000;
    $statpot{'a3RN'}=0.000;
    $statpot{'a3RD'}=0.000;
    $statpot{'a3RC'}=0.000;
    $statpot{'a3RQ'}=0.000;
    $statpot{'a3RE'}=0.000;
    $statpot{'a3RG'}=-1.023;
    $statpot{'a3RH'}=0.000;
    $statpot{'a3RI'}=0.000;
    $statpot{'a3RL'}=0.000;
    $statpot{'a3RK'}=0.000;
    $statpot{'a3RM'}=0.000;
    $statpot{'a3RF'}=0.000;
    $statpot{'a3RP'}=0.000;
    $statpot{'a3RS'}=0.000;
    $statpot{'a3RT'}=0.000;
    $statpot{'a3RW'}=0.000;
    $statpot{'a3RY'}=0.000;
    $statpot{'a3RV'}=0.000;
    $statpot{'a3NA'}=-3.687;
    $statpot{'a3NR'}=0.000;
    $statpot{'a3NN'}=0.000;
    $statpot{'a3ND'}=0.000;
    $statpot{'a3NC'}=0.000;
    $statpot{'a3NQ'}=0.000;
    $statpot{'a3NE'}=0.000;
    $statpot{'a3NG'}=-0.517;
    $statpot{'a3NH'}=0.000;
    $statpot{'a3NI'}=0.000;
    $statpot{'a3NL'}=0.000;
    $statpot{'a3NK'}=0.000;
    $statpot{'a3NM'}=0.000;
    $statpot{'a3NF'}=0.000;
    $statpot{'a3NP'}=0.000;
    $statpot{'a3NS'}=0.000;
    $statpot{'a3NT'}=0.000;
    $statpot{'a3NW'}=0.000;
    $statpot{'a3NY'}=0.000;
    $statpot{'a3NV'}=0.000;
    $statpot{'a3DA'}=0.000;
    $statpot{'a3DR'}=0.000;
    $statpot{'a3DN'}=0.000;
    $statpot{'a3DD'}=0.000;
    $statpot{'a3DC'}=0.000;
    $statpot{'a3DQ'}=0.000;
    $statpot{'a3DE'}=0.000;
    $statpot{'a3DG'}=-1.478;
    $statpot{'a3DH'}=0.000;
    $statpot{'a3DI'}=0.000;
    $statpot{'a3DL'}=0.000;
    $statpot{'a3DK'}=0.000;
    $statpot{'a3DM'}=0.000;
    $statpot{'a3DF'}=0.000;
    $statpot{'a3DP'}=0.000;
    $statpot{'a3DS'}=0.000;
    $statpot{'a3DT'}=0.000;
    $statpot{'a3DW'}=0.000;
    $statpot{'a3DY'}=0.000;
    $statpot{'a3DV'}=0.000;
    $statpot{'a3CA'}=0.000;
    $statpot{'a3CR'}=0.000;
    $statpot{'a3CN'}=0.000;
    $statpot{'a3CD'}=0.000;
    $statpot{'a3CC'}=0.000;
    $statpot{'a3CQ'}=0.000;
    $statpot{'a3CE'}=0.000;
    $statpot{'a3CG'}=-2.419;
    $statpot{'a3CH'}=0.000;
    $statpot{'a3CI'}=0.000;
    $statpot{'a3CL'}=0.000;
    $statpot{'a3CK'}=0.000;
    $statpot{'a3CM'}=0.000;
    $statpot{'a3CF'}=0.000;
    $statpot{'a3CP'}=0.000;
    $statpot{'a3CS'}=0.000;
    $statpot{'a3CT'}=0.000;
    $statpot{'a3CW'}=0.000;
    $statpot{'a3CY'}=0.000;
    $statpot{'a3CV'}=0.000;
    $statpot{'a3QA'}=0.000;
    $statpot{'a3QR'}=0.000;
    $statpot{'a3QN'}=0.000;
    $statpot{'a3QD'}=0.000;
    $statpot{'a3QC'}=0.000;
    $statpot{'a3QQ'}=0.000;
    $statpot{'a3QE'}=0.000;
    $statpot{'a3QG'}=-1.771;
    $statpot{'a3QH'}=0.000;
    $statpot{'a3QI'}=0.000;
    $statpot{'a3QL'}=0.000;
    $statpot{'a3QK'}=0.000;
    $statpot{'a3QM'}=0.000;
    $statpot{'a3QF'}=0.000;
    $statpot{'a3QP'}=0.000;
    $statpot{'a3QS'}=0.000;
    $statpot{'a3QT'}=0.000;
    $statpot{'a3QW'}=0.000;
    $statpot{'a3QY'}=0.000;
    $statpot{'a3QV'}=0.000;
    $statpot{'a3EA'}=0.000;
    $statpot{'a3ER'}=0.000;
    $statpot{'a3EN'}=0.000;
    $statpot{'a3ED'}=0.000;
    $statpot{'a3EC'}=0.000;
    $statpot{'a3EQ'}=0.000;
    $statpot{'a3EE'}=0.000;
    $statpot{'a3EG'}=-1.745;
    $statpot{'a3EH'}=0.000;
    $statpot{'a3EI'}=0.000;
    $statpot{'a3EL'}=0.000;
    $statpot{'a3EK'}=0.000;
    $statpot{'a3EM'}=0.000;
    $statpot{'a3EF'}=0.000;
    $statpot{'a3EP'}=0.000;
    $statpot{'a3ES'}=0.000;
    $statpot{'a3ET'}=0.000;
    $statpot{'a3EW'}=0.000;
    $statpot{'a3EY'}=0.000;
    $statpot{'a3EV'}=0.000;
    $statpot{'a3GA'}=-2.546;
    $statpot{'a3GR'}=0.000;
    $statpot{'a3GN'}=0.000;
    $statpot{'a3GD'}=0.000;
    $statpot{'a3GC'}=0.000;
    $statpot{'a3GQ'}=0.000;
    $statpot{'a3GE'}=0.000;
    $statpot{'a3GG'}=-1.409;
    $statpot{'a3GH'}=0.000;
    $statpot{'a3GI'}=0.000;
    $statpot{'a3GL'}=0.000;
    $statpot{'a3GK'}=0.000;
    $statpot{'a3GM'}=0.000;
    $statpot{'a3GF'}=0.000;
    $statpot{'a3GP'}=0.000;
    $statpot{'a3GS'}=0.000;
    $statpot{'a3GT'}=0.000;
    $statpot{'a3GW'}=0.000;
    $statpot{'a3GY'}=0.000;
    $statpot{'a3GV'}=0.000;
    $statpot{'a3HA'}=-3.910;
    $statpot{'a3HR'}=0.000;
    $statpot{'a3HN'}=0.000;
    $statpot{'a3HD'}=0.000;
    $statpot{'a3HC'}=0.000;
    $statpot{'a3HQ'}=0.000;
    $statpot{'a3HE'}=0.000;
    $statpot{'a3HG'}=-3.413;
    $statpot{'a3HH'}=0.000;
    $statpot{'a3HI'}=0.000;
    $statpot{'a3HL'}=0.000;
    $statpot{'a3HK'}=0.000;
    $statpot{'a3HM'}=0.000;
    $statpot{'a3HF'}=0.000;
    $statpot{'a3HP'}=0.000;
    $statpot{'a3HS'}=0.000;
    $statpot{'a3HT'}=0.000;
    $statpot{'a3HW'}=0.000;
    $statpot{'a3HY'}=0.000;
    $statpot{'a3HV'}=0.000;
    $statpot{'a3IA'}=0.000;
    $statpot{'a3IR'}=0.000;
    $statpot{'a3IN'}=0.000;
    $statpot{'a3ID'}=0.000;
    $statpot{'a3IC'}=0.000;
    $statpot{'a3IQ'}=0.000;
    $statpot{'a3IE'}=0.000;
    $statpot{'a3IG'}=-1.749;
    $statpot{'a3IH'}=0.000;
    $statpot{'a3II'}=0.000;
    $statpot{'a3IL'}=0.000;
    $statpot{'a3IK'}=0.000;
    $statpot{'a3IM'}=0.000;
    $statpot{'a3IF'}=0.000;
    $statpot{'a3IP'}=0.000;
    $statpot{'a3IS'}=0.000;
    $statpot{'a3IT'}=0.000;
    $statpot{'a3IW'}=0.000;
    $statpot{'a3IY'}=0.000;
    $statpot{'a3IV'}=0.000;
    $statpot{'a3LA'}=0.000;
    $statpot{'a3LR'}=0.000;
    $statpot{'a3LN'}=0.000;
    $statpot{'a3LD'}=0.000;
    $statpot{'a3LC'}=0.000;
    $statpot{'a3LQ'}=0.000;
    $statpot{'a3LE'}=0.000;
    $statpot{'a3LG'}=-1.115;
    $statpot{'a3LH'}=0.000;
    $statpot{'a3LI'}=0.000;
    $statpot{'a3LL'}=0.000;
    $statpot{'a3LK'}=0.000;
    $statpot{'a3LM'}=0.000;
    $statpot{'a3LF'}=0.000;
    $statpot{'a3LP'}=0.000;
    $statpot{'a3LS'}=0.000;
    $statpot{'a3LT'}=0.000;
    $statpot{'a3LW'}=0.000;
    $statpot{'a3LY'}=0.000;
    $statpot{'a3LV'}=0.000;
    $statpot{'a3KA'}=0.000;
    $statpot{'a3KR'}=0.000;
    $statpot{'a3KN'}=0.000;
    $statpot{'a3KD'}=0.000;
    $statpot{'a3KC'}=0.000;
    $statpot{'a3KQ'}=0.000;
    $statpot{'a3KE'}=0.000;
    $statpot{'a3KG'}=-2.382;
    $statpot{'a3KH'}=0.000;
    $statpot{'a3KI'}=0.000;
    $statpot{'a3KL'}=0.000;
    $statpot{'a3KK'}=0.000;
    $statpot{'a3KM'}=0.000;
    $statpot{'a3KF'}=0.000;
    $statpot{'a3KP'}=0.000;
    $statpot{'a3KS'}=0.000;
    $statpot{'a3KT'}=0.000;
    $statpot{'a3KW'}=0.000;
    $statpot{'a3KY'}=0.000;
    $statpot{'a3KV'}=0.000;
    $statpot{'a3MA'}=0.000;
    $statpot{'a3MR'}=0.000;
    $statpot{'a3MN'}=0.000;
    $statpot{'a3MD'}=0.000;
    $statpot{'a3MC'}=0.000;
    $statpot{'a3MQ'}=0.000;
    $statpot{'a3ME'}=0.000;
    $statpot{'a3MG'}=-2.739;
    $statpot{'a3MH'}=0.000;
    $statpot{'a3MI'}=0.000;
    $statpot{'a3ML'}=0.000;
    $statpot{'a3MK'}=0.000;
    $statpot{'a3MM'}=0.000;
    $statpot{'a3MF'}=0.000;
    $statpot{'a3MP'}=0.000;
    $statpot{'a3MS'}=0.000;
    $statpot{'a3MT'}=0.000;
    $statpot{'a3MW'}=0.000;
    $statpot{'a3MY'}=0.000;
    $statpot{'a3MV'}=0.000;
    $statpot{'a3FA'}=0.000;
    $statpot{'a3FR'}=0.000;
    $statpot{'a3FN'}=0.000;
    $statpot{'a3FD'}=0.000;
    $statpot{'a3FC'}=0.000;
    $statpot{'a3FQ'}=0.000;
    $statpot{'a3FE'}=0.000;
    $statpot{'a3FG'}=-2.785;
    $statpot{'a3FH'}=0.000;
    $statpot{'a3FI'}=0.000;
    $statpot{'a3FL'}=0.000;
    $statpot{'a3FK'}=0.000;
    $statpot{'a3FM'}=0.000;
    $statpot{'a3FF'}=0.000;
    $statpot{'a3FP'}=0.000;
    $statpot{'a3FS'}=0.000;
    $statpot{'a3FT'}=0.000;
    $statpot{'a3FW'}=0.000;
    $statpot{'a3FY'}=0.000;
    $statpot{'a3FV'}=0.000;
    $statpot{'a3PA'}=0.000;
    $statpot{'a3PR'}=0.000;
    $statpot{'a3PN'}=0.000;
    $statpot{'a3PD'}=-3.830;
    $statpot{'a3PC'}=0.000;
    $statpot{'a3PQ'}=0.000;
    $statpot{'a3PE'}=0.000;
    $statpot{'a3PG'}=-2.209;
    $statpot{'a3PH'}=0.000;
    $statpot{'a3PI'}=0.000;
    $statpot{'a3PL'}=0.000;
    $statpot{'a3PK'}=0.000;
    $statpot{'a3PM'}=0.000;
    $statpot{'a3PF'}=0.000;
    $statpot{'a3PP'}=0.000;
    $statpot{'a3PS'}=0.000;
    $statpot{'a3PT'}=0.000;
    $statpot{'a3PW'}=0.000;
    $statpot{'a3PY'}=0.000;
    $statpot{'a3PV'}=0.000;
    $statpot{'a3SA'}=0.000;
    $statpot{'a3SR'}=0.000;
    $statpot{'a3SN'}=0.000;
    $statpot{'a3SD'}=0.000;
    $statpot{'a3SC'}=0.000;
    $statpot{'a3SQ'}=0.000;
    $statpot{'a3SE'}=0.000;
    $statpot{'a3SG'}=0.000;
    $statpot{'a3SH'}=0.000;
    $statpot{'a3SI'}=0.000;
    $statpot{'a3SL'}=0.000;
    $statpot{'a3SK'}=0.000;
    $statpot{'a3SM'}=0.000;
    $statpot{'a3SF'}=0.000;
    $statpot{'a3SP'}=0.000;
    $statpot{'a3SS'}=0.000;
    $statpot{'a3ST'}=0.000;
    $statpot{'a3SW'}=0.000;
    $statpot{'a3SY'}=0.000;
    $statpot{'a3SV'}=0.000;
    $statpot{'a3TA'}=0.000;
    $statpot{'a3TR'}=0.000;
    $statpot{'a3TN'}=0.000;
    $statpot{'a3TD'}=-3.562;
    $statpot{'a3TC'}=0.000;
    $statpot{'a3TQ'}=0.000;
    $statpot{'a3TE'}=0.000;
    $statpot{'a3TG'}=-2.171;
    $statpot{'a3TH'}=0.000;
    $statpot{'a3TI'}=0.000;
    $statpot{'a3TL'}=0.000;
    $statpot{'a3TK'}=0.000;
    $statpot{'a3TM'}=0.000;
    $statpot{'a3TF'}=0.000;
    $statpot{'a3TP'}=0.000;
    $statpot{'a3TS'}=0.000;
    $statpot{'a3TT'}=0.000;
    $statpot{'a3TW'}=0.000;
    $statpot{'a3TY'}=0.000;
    $statpot{'a3TV'}=0.000;
    $statpot{'a3WA'}=0.000;
    $statpot{'a3WR'}=0.000;
    $statpot{'a3WN'}=0.000;
    $statpot{'a3WD'}=0.000;
    $statpot{'a3WC'}=0.000;
    $statpot{'a3WQ'}=0.000;
    $statpot{'a3WE'}=0.000;
    $statpot{'a3WG'}=-2.753;
    $statpot{'a3WH'}=0.000;
    $statpot{'a3WI'}=0.000;
    $statpot{'a3WL'}=0.000;
    $statpot{'a3WK'}=0.000;
    $statpot{'a3WM'}=0.000;
    $statpot{'a3WF'}=0.000;
    $statpot{'a3WP'}=0.000;
    $statpot{'a3WS'}=0.000;
    $statpot{'a3WT'}=0.000;
    $statpot{'a3WW'}=0.000;
    $statpot{'a3WY'}=0.000;
    $statpot{'a3WV'}=0.000;
    $statpot{'a3YA'}=0.000;
    $statpot{'a3YR'}=0.000;
    $statpot{'a3YN'}=0.000;
    $statpot{'a3YD'}=0.000;
    $statpot{'a3YC'}=0.000;
    $statpot{'a3YQ'}=0.000;
    $statpot{'a3YE'}=0.000;
    $statpot{'a3YG'}=-1.472;
    $statpot{'a3YH'}=0.000;
    $statpot{'a3YI'}=0.000;
    $statpot{'a3YL'}=0.000;
    $statpot{'a3YK'}=0.000;
    $statpot{'a3YM'}=0.000;
    $statpot{'a3YF'}=0.000;
    $statpot{'a3YP'}=0.000;
    $statpot{'a3YS'}=0.000;
    $statpot{'a3YT'}=0.000;
    $statpot{'a3YW'}=0.000;
    $statpot{'a3YY'}=0.000;
    $statpot{'a3YV'}=0.000;
    $statpot{'a3VA'}=0.000;
    $statpot{'a3VR'}=0.000;
    $statpot{'a3VN'}=0.000;
    $statpot{'a3VD'}=0.000;
    $statpot{'a3VC'}=0.000;
    $statpot{'a3VQ'}=0.000;
    $statpot{'a3VE'}=0.000;
    $statpot{'a3VG'}=-1.421;
    $statpot{'a3VH'}=0.000;
    $statpot{'a3VI'}=0.000;
    $statpot{'a3VL'}=0.000;
    $statpot{'a3VK'}=0.000;
    $statpot{'a3VM'}=0.000;
    $statpot{'a3VF'}=0.000;
    $statpot{'a3VP'}=0.000;
    $statpot{'a3VS'}=0.000;
    $statpot{'a3VT'}=0.000;
    $statpot{'a3VW'}=0.000;
    $statpot{'a3VY'}=0.000;
    $statpot{'a3VV'}=0.000;
    $statpot{'p4AA'}=-0.210;
    $statpot{'p4AR'}=0.258;
    $statpot{'p4AN'}=0.066;
    $statpot{'p4AD'}=0.132;
    $statpot{'p4AC'}=-0.617;
    $statpot{'p4AQ'}=0.458;
    $statpot{'p4AE'}=0.652;
    $statpot{'p4AG'}=-0.037;
    $statpot{'p4AH'}=-0.042;
    $statpot{'p4AI'}=-0.185;
    $statpot{'p4AL'}=-0.079;
    $statpot{'p4AK'}=0.503;
    $statpot{'p4AM'}=-0.153;
    $statpot{'p4AF'}=-0.354;
    $statpot{'p4AP'}=0.182;
    $statpot{'p4AS'}=-0.242;
    $statpot{'p4AT'}=-0.236;
    $statpot{'p4AW'}=-0.061;
    $statpot{'p4AY'}=-0.000;
    $statpot{'p4AV'}=-0.337;
    $statpot{'p4RA'}=0.258;
    $statpot{'p4RR'}=0.699;
    $statpot{'p4RN'}=-0.036;
    $statpot{'p4RD'}=-0.371;
    $statpot{'p4RC'}=0.306;
    $statpot{'p4RQ'}=0.283;
    $statpot{'p4RE'}=-0.056;
    $statpot{'p4RG'}=0.024;
    $statpot{'p4RH'}=-0.164;
    $statpot{'p4RI'}=0.726;
    $statpot{'p4RL'}=0.415;
    $statpot{'p4RK'}=0.883;
    $statpot{'p4RM'}=0.505;
    $statpot{'p4RF'}=0.196;
    $statpot{'p4RP'}=0.461;
    $statpot{'p4RS'}=-0.290;
    $statpot{'p4RT'}=-0.211;
    $statpot{'p4RW'}=-0.028;
    $statpot{'p4RY'}=-0.053;
    $statpot{'p4RV'}=0.487;
    $statpot{'p4NA'}=0.066;
    $statpot{'p4NR'}=-0.036;
    $statpot{'p4NN'}=-0.247;
    $statpot{'p4ND'}=-0.419;
    $statpot{'p4NC'}=0.144;
    $statpot{'p4NQ'}=-0.018;
    $statpot{'p4NE'}=-0.157;
    $statpot{'p4NG'}=-0.227;
    $statpot{'p4NH'}=-0.569;
    $statpot{'p4NI'}=0.450;
    $statpot{'p4NL'}=0.332;
    $statpot{'p4NK'}=-0.008;
    $statpot{'p4NM'}=0.366;
    $statpot{'p4NF'}=0.225;
    $statpot{'p4NP'}=0.268;
    $statpot{'p4NS'}=-0.356;
    $statpot{'p4NT'}=-0.249;
    $statpot{'p4NW'}=0.226;
    $statpot{'p4NY'}=0.009;
    $statpot{'p4NV'}=0.203;
    $statpot{'p4DA'}=0.132;
    $statpot{'p4DR'}=-0.371;
    $statpot{'p4DN'}=-0.419;
    $statpot{'p4DD'}=-0.052;
    $statpot{'p4DC'}=-0.125;
    $statpot{'p4DQ'}=0.095;
    $statpot{'p4DE'}=0.412;
    $statpot{'p4DG'}=-0.184;
    $statpot{'p4DH'}=-0.331;
    $statpot{'p4DI'}=0.240;
    $statpot{'p4DL'}=0.398;
    $statpot{'p4DK'}=-0.542;
    $statpot{'p4DM'}=0.481;
    $statpot{'p4DF'}=0.370;
    $statpot{'p4DP'}=0.328;
    $statpot{'p4DS'}=-0.475;
    $statpot{'p4DT'}=-0.362;
    $statpot{'p4DW'}=0.360;
    $statpot{'p4DY'}=0.141;
    $statpot{'p4DV'}=0.234;
    $statpot{'p4CA'}=-0.617;
    $statpot{'p4CR'}=0.306;
    $statpot{'p4CN'}=0.144;
    $statpot{'p4CD'}=-0.125;
    $statpot{'p4CC'}=-1.602;
    $statpot{'p4CQ'}=0.310;
    $statpot{'p4CE'}=0.812;
    $statpot{'p4CG'}=-0.125;
    $statpot{'p4CH'}=-0.031;
    $statpot{'p4CI'}=-0.434;
    $statpot{'p4CL'}=-0.158;
    $statpot{'p4CK'}=0.606;
    $statpot{'p4CM'}=-0.509;
    $statpot{'p4CF'}=-0.332;
    $statpot{'p4CP'}=0.279;
    $statpot{'p4CS'}=-0.092;
    $statpot{'p4CT'}=-0.171;
    $statpot{'p4CW'}=0.202;
    $statpot{'p4CY'}=-0.219;
    $statpot{'p4CV'}=-0.352;
    $statpot{'p4QA'}=0.458;
    $statpot{'p4QR'}=0.283;
    $statpot{'p4QN'}=-0.018;
    $statpot{'p4QD'}=0.095;
    $statpot{'p4QC'}=0.310;
    $statpot{'p4QQ'}=0.109;
    $statpot{'p4QE'}=0.421;
    $statpot{'p4QG'}=-0.027;
    $statpot{'p4QH'}=0.073;
    $statpot{'p4QI'}=0.886;
    $statpot{'p4QL'}=0.625;
    $statpot{'p4QK'}=0.189;
    $statpot{'p4QM'}=0.709;
    $statpot{'p4QF'}=0.103;
    $statpot{'p4QP'}=0.368;
    $statpot{'p4QS'}=-0.108;
    $statpot{'p4QT'}=-0.118;
    $statpot{'p4QW'}=0.284;
    $statpot{'p4QY'}=0.218;
    $statpot{'p4QV'}=0.447;
    $statpot{'p4EA'}=0.652;
    $statpot{'p4ER'}=-0.056;
    $statpot{'p4EN'}=-0.157;
    $statpot{'p4ED'}=0.412;
    $statpot{'p4EC'}=0.812;
    $statpot{'p4EQ'}=0.421;
    $statpot{'p4EE'}=0.554;
    $statpot{'p4EG'}=-0.051;
    $statpot{'p4EH'}=-0.124;
    $statpot{'p4EI'}=0.787;
    $statpot{'p4EL'}=0.828;
    $statpot{'p4EK'}=-0.306;
    $statpot{'p4EM'}=0.622;
    $statpot{'p4EF'}=0.579;
    $statpot{'p4EP'}=0.221;
    $statpot{'p4ES'}=-0.411;
    $statpot{'p4ET'}=-0.415;
    $statpot{'p4EW'}=0.244;
    $statpot{'p4EY'}=0.105;
    $statpot{'p4EV'}=0.692;
    $statpot{'p4GA'}=-0.037;
    $statpot{'p4GR'}=0.024;
    $statpot{'p4GN'}=-0.227;
    $statpot{'p4GD'}=-0.184;
    $statpot{'p4GC'}=-0.125;
    $statpot{'p4GQ'}=-0.027;
    $statpot{'p4GE'}=-0.051;
    $statpot{'p4GG'}=-0.128;
    $statpot{'p4GH'}=-0.245;
    $statpot{'p4GI'}=-0.223;
    $statpot{'p4GL'}=0.162;
    $statpot{'p4GK'}=0.108;
    $statpot{'p4GM'}=-0.217;
    $statpot{'p4GF'}=-0.058;
    $statpot{'p4GP'}=-0.544;
    $statpot{'p4GS'}=-0.327;
    $statpot{'p4GT'}=-0.234;
    $statpot{'p4GW'}=0.284;
    $statpot{'p4GY'}=-0.127;
    $statpot{'p4GV'}=-0.153;
    $statpot{'p4HA'}=-0.042;
    $statpot{'p4HR'}=-0.164;
    $statpot{'p4HN'}=-0.569;
    $statpot{'p4HD'}=-0.331;
    $statpot{'p4HC'}=-0.031;
    $statpot{'p4HQ'}=0.073;
    $statpot{'p4HE'}=-0.124;
    $statpot{'p4HG'}=-0.245;
    $statpot{'p4HH'}=-0.107;
    $statpot{'p4HI'}=0.096;
    $statpot{'p4HL'}=0.085;
    $statpot{'p4HK'}=0.136;
    $statpot{'p4HM'}=-0.248;
    $statpot{'p4HF'}=-0.174;
    $statpot{'p4HP'}=0.325;
    $statpot{'p4HS'}=-0.372;
    $statpot{'p4HT'}=-0.305;
    $statpot{'p4HW'}=0.038;
    $statpot{'p4HY'}=-0.231;
    $statpot{'p4HV'}=0.053;
    $statpot{'p4IA'}=-0.185;
    $statpot{'p4IR'}=0.726;
    $statpot{'p4IN'}=0.450;
    $statpot{'p4ID'}=0.240;
    $statpot{'p4IC'}=-0.434;
    $statpot{'p4IQ'}=0.886;
    $statpot{'p4IE'}=0.787;
    $statpot{'p4IG'}=-0.223;
    $statpot{'p4IH'}=0.096;
    $statpot{'p4II'}=-0.271;
    $statpot{'p4IL'}=-0.385;
    $statpot{'p4IK'}=0.611;
    $statpot{'p4IM'}=-0.101;
    $statpot{'p4IF'}=-0.527;
    $statpot{'p4IP'}=0.838;
    $statpot{'p4IS'}=0.182;
    $statpot{'p4IT'}=0.539;
    $statpot{'p4IW'}=-0.261;
    $statpot{'p4IY'}=-0.561;
    $statpot{'p4IV'}=-0.225;
    $statpot{'p4LA'}=-0.079;
    $statpot{'p4LR'}=0.415;
    $statpot{'p4LN'}=0.332;
    $statpot{'p4LD'}=0.398;
    $statpot{'p4LC'}=-0.158;
    $statpot{'p4LQ'}=0.625;
    $statpot{'p4LE'}=0.828;
    $statpot{'p4LG'}=0.162;
    $statpot{'p4LH'}=0.085;
    $statpot{'p4LI'}=-0.385;
    $statpot{'p4LL'}=-0.173;
    $statpot{'p4LK'}=0.549;
    $statpot{'p4LM'}=0.194;
    $statpot{'p4LF'}=-0.311;
    $statpot{'p4LP'}=0.513;
    $statpot{'p4LS'}=0.177;
    $statpot{'p4LT'}=0.119;
    $statpot{'p4LW'}=-0.082;
    $statpot{'p4LY'}=-0.270;
    $statpot{'p4LV'}=-0.320;
    $statpot{'p4KA'}=0.503;
    $statpot{'p4KR'}=0.883;
    $statpot{'p4KN'}=-0.008;
    $statpot{'p4KD'}=-0.542;
    $statpot{'p4KC'}=0.606;
    $statpot{'p4KQ'}=0.189;
    $statpot{'p4KE'}=-0.306;
    $statpot{'p4KG'}=0.108;
    $statpot{'p4KH'}=0.136;
    $statpot{'p4KI'}=0.611;
    $statpot{'p4KL'}=0.549;
    $statpot{'p4KK'}=0.484;
    $statpot{'p4KM'}=0.694;
    $statpot{'p4KF'}=0.405;
    $statpot{'p4KP'}=0.518;
    $statpot{'p4KS'}=-0.078;
    $statpot{'p4KT'}=-0.088;
    $statpot{'p4KW'}=0.012;
    $statpot{'p4KY'}=0.151;
    $statpot{'p4KV'}=0.586;
    $statpot{'p4MA'}=-0.153;
    $statpot{'p4MR'}=0.505;
    $statpot{'p4MN'}=0.366;
    $statpot{'p4MD'}=0.481;
    $statpot{'p4MC'}=-0.509;
    $statpot{'p4MQ'}=0.709;
    $statpot{'p4ME'}=0.622;
    $statpot{'p4MG'}=-0.217;
    $statpot{'p4MH'}=-0.248;
    $statpot{'p4MI'}=-0.101;
    $statpot{'p4ML'}=0.194;
    $statpot{'p4MK'}=0.694;
    $statpot{'p4MM'}=-0.292;
    $statpot{'p4MF'}=-0.385;
    $statpot{'p4MP'}=0.580;
    $statpot{'p4MS'}=0.146;
    $statpot{'p4MT'}=0.157;
    $statpot{'p4MW'}=-0.435;
    $statpot{'p4MY'}=-0.056;
    $statpot{'p4MV'}=-0.451;
    $statpot{'p4FA'}=-0.354;
    $statpot{'p4FR'}=0.196;
    $statpot{'p4FN'}=0.225;
    $statpot{'p4FD'}=0.370;
    $statpot{'p4FC'}=-0.332;
    $statpot{'p4FQ'}=0.103;
    $statpot{'p4FE'}=0.579;
    $statpot{'p4FG'}=-0.058;
    $statpot{'p4FH'}=-0.174;
    $statpot{'p4FI'}=-0.527;
    $statpot{'p4FL'}=-0.311;
    $statpot{'p4FK'}=0.405;
    $statpot{'p4FM'}=-0.385;
    $statpot{'p4FF'}=-0.712;
    $statpot{'p4FP'}=0.004;
    $statpot{'p4FS'}=-0.198;
    $statpot{'p4FT'}=-0.192;
    $statpot{'p4FW'}=-0.502;
    $statpot{'p4FY'}=-0.240;
    $statpot{'p4FV'}=-0.260;
    $statpot{'p4PA'}=0.182;
    $statpot{'p4PR'}=0.461;
    $statpot{'p4PN'}=0.268;
    $statpot{'p4PD'}=0.328;
    $statpot{'p4PC'}=0.279;
    $statpot{'p4PQ'}=0.368;
    $statpot{'p4PE'}=0.221;
    $statpot{'p4PG'}=-0.544;
    $statpot{'p4PH'}=0.325;
    $statpot{'p4PI'}=0.838;
    $statpot{'p4PL'}=0.513;
    $statpot{'p4PK'}=0.518;
    $statpot{'p4PM'}=0.580;
    $statpot{'p4PF'}=0.004;
    $statpot{'p4PP'}=0.473;
    $statpot{'p4PS'}=0.102;
    $statpot{'p4PT'}=0.171;
    $statpot{'p4PW'}=-0.006;
    $statpot{'p4PY'}=0.105;
    $statpot{'p4PV'}=0.167;
    $statpot{'p4SA'}=-0.242;
    $statpot{'p4SR'}=-0.290;
    $statpot{'p4SN'}=-0.356;
    $statpot{'p4SD'}=-0.475;
    $statpot{'p4SC'}=-0.092;
    $statpot{'p4SQ'}=-0.108;
    $statpot{'p4SE'}=-0.411;
    $statpot{'p4SG'}=-0.327;
    $statpot{'p4SH'}=-0.372;
    $statpot{'p4SI'}=0.182;
    $statpot{'p4SL'}=0.177;
    $statpot{'p4SK'}=-0.078;
    $statpot{'p4SM'}=0.146;
    $statpot{'p4SF'}=-0.198;
    $statpot{'p4SP'}=0.102;
    $statpot{'p4SS'}=-0.578;
    $statpot{'p4ST'}=-0.397;
    $statpot{'p4SW'}=-0.172;
    $statpot{'p4SY'}=-0.247;
    $statpot{'p4SV'}=0.138;
    $statpot{'p4TA'}=-0.236;
    $statpot{'p4TR'}=-0.211;
    $statpot{'p4TN'}=-0.249;
    $statpot{'p4TD'}=-0.362;
    $statpot{'p4TC'}=-0.171;
    $statpot{'p4TQ'}=-0.118;
    $statpot{'p4TE'}=-0.415;
    $statpot{'p4TG'}=-0.234;
    $statpot{'p4TH'}=-0.305;
    $statpot{'p4TI'}=0.539;
    $statpot{'p4TL'}=0.119;
    $statpot{'p4TK'}=-0.088;
    $statpot{'p4TM'}=0.157;
    $statpot{'p4TF'}=-0.192;
    $statpot{'p4TP'}=0.171;
    $statpot{'p4TS'}=-0.397;
    $statpot{'p4TT'}=-0.451;
    $statpot{'p4TW'}=0.288;
    $statpot{'p4TY'}=0.014;
    $statpot{'p4TV'}=0.266;
    $statpot{'p4WA'}=-0.061;
    $statpot{'p4WR'}=-0.028;
    $statpot{'p4WN'}=0.226;
    $statpot{'p4WD'}=0.360;
    $statpot{'p4WC'}=0.202;
    $statpot{'p4WQ'}=0.284;
    $statpot{'p4WE'}=0.244;
    $statpot{'p4WG'}=0.284;
    $statpot{'p4WH'}=0.038;
    $statpot{'p4WI'}=-0.261;
    $statpot{'p4WL'}=-0.082;
    $statpot{'p4WK'}=0.012;
    $statpot{'p4WM'}=-0.435;
    $statpot{'p4WF'}=-0.502;
    $statpot{'p4WP'}=-0.006;
    $statpot{'p4WS'}=-0.172;
    $statpot{'p4WT'}=0.288;
    $statpot{'p4WW'}=-0.468;
    $statpot{'p4WY'}=-0.207;
    $statpot{'p4WV'}=-0.144;
    $statpot{'p4YA'}=-0.000;
    $statpot{'p4YR'}=-0.053;
    $statpot{'p4YN'}=0.009;
    $statpot{'p4YD'}=0.141;
    $statpot{'p4YC'}=-0.219;
    $statpot{'p4YQ'}=0.218;
    $statpot{'p4YE'}=0.105;
    $statpot{'p4YG'}=-0.127;
    $statpot{'p4YH'}=-0.231;
    $statpot{'p4YI'}=-0.561;
    $statpot{'p4YL'}=-0.270;
    $statpot{'p4YK'}=0.151;
    $statpot{'p4YM'}=-0.056;
    $statpot{'p4YF'}=-0.240;
    $statpot{'p4YP'}=0.105;
    $statpot{'p4YS'}=-0.247;
    $statpot{'p4YT'}=0.014;
    $statpot{'p4YW'}=-0.207;
    $statpot{'p4YY'}=-0.401;
    $statpot{'p4YV'}=-0.371;
    $statpot{'p4VA'}=-0.337;
    $statpot{'p4VR'}=0.487;
    $statpot{'p4VN'}=0.203;
    $statpot{'p4VD'}=0.234;
    $statpot{'p4VC'}=-0.352;
    $statpot{'p4VQ'}=0.447;
    $statpot{'p4VE'}=0.692;
    $statpot{'p4VG'}=-0.153;
    $statpot{'p4VH'}=0.053;
    $statpot{'p4VI'}=-0.225;
    $statpot{'p4VL'}=-0.320;
    $statpot{'p4VK'}=0.586;
    $statpot{'p4VM'}=-0.451;
    $statpot{'p4VF'}=-0.260;
    $statpot{'p4VP'}=0.167;
    $statpot{'p4VS'}=0.138;
    $statpot{'p4VT'}=0.266;
    $statpot{'p4VW'}=-0.144;
    $statpot{'p4VY'}=-0.371;
    $statpot{'p4VV'}=-0.291;
    $statpot{'f4AA'}=-0.796;
    $statpot{'f4AR'}=0.090;
    $statpot{'f4AN'}=-0.046;
    $statpot{'f4AD'}=0.041;
    $statpot{'f4AC'}=-0.953;
    $statpot{'f4AQ'}=0.111;
    $statpot{'f4AE'}=0.209;
    $statpot{'f4AG'}=0.380;
    $statpot{'f4AH'}=-0.456;
    $statpot{'f4AI'}=-0.641;
    $statpot{'f4AL'}=-0.505;
    $statpot{'f4AK'}=0.115;
    $statpot{'f4AM'}=-0.683;
    $statpot{'f4AF'}=-0.454;
    $statpot{'f4AP'}=-0.325;
    $statpot{'f4AS'}=-0.345;
    $statpot{'f4AT'}=-0.615;
    $statpot{'f4AW'}=-0.570;
    $statpot{'f4AY'}=-0.487;
    $statpot{'f4AV'}=-1.082;
    $statpot{'f4RA'}=0.111;
    $statpot{'f4RR'}=1.146;
    $statpot{'f4RN'}=0.610;
    $statpot{'f4RD'}=0.254;
    $statpot{'f4RC'}=0.113;
    $statpot{'f4RQ'}=0.356;
    $statpot{'f4RE'}=1.074;
    $statpot{'f4RG'}=0.682;
    $statpot{'f4RH'}=0.053;
    $statpot{'f4RI'}=0.591;
    $statpot{'f4RL'}=0.354;
    $statpot{'f4RK'}=1.745;
    $statpot{'f4RM'}=0.532;
    $statpot{'f4RF'}=0.403;
    $statpot{'f4RP'}=0.325;
    $statpot{'f4RS'}=0.100;
    $statpot{'f4RT'}=0.476;
    $statpot{'f4RW'}=0.264;
    $statpot{'f4RY'}=0.150;
    $statpot{'f4RV'}=0.355;
    $statpot{'f4NA'}=-0.063;
    $statpot{'f4NR'}=0.632;
    $statpot{'f4NN'}=0.236;
    $statpot{'f4ND'}=0.344;
    $statpot{'f4NC'}=-0.589;
    $statpot{'f4NQ'}=0.436;
    $statpot{'f4NE'}=0.878;
    $statpot{'f4NG'}=0.197;
    $statpot{'f4NH'}=0.359;
    $statpot{'f4NI'}=0.561;
    $statpot{'f4NL'}=0.612;
    $statpot{'f4NK'}=0.301;
    $statpot{'f4NM'}=0.156;
    $statpot{'f4NF'}=0.030;
    $statpot{'f4NP'}=-0.004;
    $statpot{'f4NS'}=0.058;
    $statpot{'f4NT'}=-0.109;
    $statpot{'f4NW'}=-0.173;
    $statpot{'f4NY'}=-0.108;
    $statpot{'f4NV'}=0.296;
    $statpot{'f4DA'}=0.076;
    $statpot{'f4DR'}=0.275;
    $statpot{'f4DN'}=0.357;
    $statpot{'f4DD'}=0.604;
    $statpot{'f4DC'}=0.024;
    $statpot{'f4DQ'}=0.542;
    $statpot{'f4DE'}=1.039;
    $statpot{'f4DG'}=0.635;
    $statpot{'f4DH'}=-0.192;
    $statpot{'f4DI'}=0.657;
    $statpot{'f4DL'}=0.458;
    $statpot{'f4DK'}=0.400;
    $statpot{'f4DM'}=0.121;
    $statpot{'f4DF'}=0.479;
    $statpot{'f4DP'}=0.323;
    $statpot{'f4DS'}=-0.300;
    $statpot{'f4DT'}=-0.398;
    $statpot{'f4DW'}=0.586;
    $statpot{'f4DY'}=0.235;
    $statpot{'f4DV'}=0.389;
    $statpot{'f4CA'}=-0.913;
    $statpot{'f4CR'}=0.191;
    $statpot{'f4CN'}=-0.571;
    $statpot{'f4CD'}=0.111;
    $statpot{'f4CC'}=-2.001;
    $statpot{'f4CQ'}=0.300;
    $statpot{'f4CE'}=0.293;
    $statpot{'f4CG'}=-0.152;
    $statpot{'f4CH'}=-0.259;
    $statpot{'f4CI'}=-0.379;
    $statpot{'f4CL'}=-0.143;
    $statpot{'f4CK'}=0.768;
    $statpot{'f4CM'}=-0.805;
    $statpot{'f4CF'}=-0.838;
    $statpot{'f4CP'}=-0.569;
    $statpot{'f4CS'}=-0.691;
    $statpot{'f4CT'}=-0.300;
    $statpot{'f4CW'}=-0.209;
    $statpot{'f4CY'}=-0.599;
    $statpot{'f4CV'}=-0.817;
    $statpot{'f4QA'}=0.139;
    $statpot{'f4QR'}=0.322;
    $statpot{'f4QN'}=0.481;
    $statpot{'f4QD'}=0.598;
    $statpot{'f4QC'}=0.299;
    $statpot{'f4QQ'}=0.675;
    $statpot{'f4QE'}=1.061;
    $statpot{'f4QG'}=0.357;
    $statpot{'f4QH'}=0.090;
    $statpot{'f4QI'}=0.455;
    $statpot{'f4QL'}=0.414;
    $statpot{'f4QK'}=0.763;
    $statpot{'f4QM'}=-0.019;
    $statpot{'f4QF'}=0.013;
    $statpot{'f4QP'}=0.126;
    $statpot{'f4QS'}=0.089;
    $statpot{'f4QT'}=-0.206;
    $statpot{'f4QW'}=0.248;
    $statpot{'f4QY'}=0.169;
    $statpot{'f4QV'}=0.148;
    $statpot{'f4EA'}=0.257;
    $statpot{'f4ER'}=1.035;
    $statpot{'f4EN'}=0.857;
    $statpot{'f4ED'}=1.039;
    $statpot{'f4EC'}=0.324;
    $statpot{'f4EQ'}=1.034;
    $statpot{'f4EE'}=2.125;
    $statpot{'f4EG'}=0.894;
    $statpot{'f4EH'}=0.742;
    $statpot{'f4EI'}=0.687;
    $statpot{'f4EL'}=0.911;
    $statpot{'f4EK'}=1.007;
    $statpot{'f4EM'}=0.730;
    $statpot{'f4EF'}=0.387;
    $statpot{'f4EP'}=0.474;
    $statpot{'f4ES'}=-0.156;
    $statpot{'f4ET'}=-0.002;
    $statpot{'f4EW'}=1.083;
    $statpot{'f4EY'}=0.419;
    $statpot{'f4EV'}=0.349;
    $statpot{'f4GA'}=0.277;
    $statpot{'f4GR'}=0.520;
    $statpot{'f4GN'}=0.041;
    $statpot{'f4GD'}=0.519;
    $statpot{'f4GC'}=-0.335;
    $statpot{'f4GQ'}=0.265;
    $statpot{'f4GE'}=0.788;
    $statpot{'f4GG'}=-0.076;
    $statpot{'f4GH'}=-0.065;
    $statpot{'f4GI'}=-0.032;
    $statpot{'f4GL'}=-0.036;
    $statpot{'f4GK'}=0.928;
    $statpot{'f4GM'}=-0.123;
    $statpot{'f4GF'}=0.007;
    $statpot{'f4GP'}=0.150;
    $statpot{'f4GS'}=0.055;
    $statpot{'f4GT'}=0.003;
    $statpot{'f4GW'}=0.225;
    $statpot{'f4GY'}=0.509;
    $statpot{'f4GV'}=-0.121;
    $statpot{'f4HA'}=-0.413;
    $statpot{'f4HR'}=0.076;
    $statpot{'f4HN'}=0.322;
    $statpot{'f4HD'}=-0.095;
    $statpot{'f4HC'}=-0.303;
    $statpot{'f4HQ'}=0.093;
    $statpot{'f4HE'}=0.677;
    $statpot{'f4HG'}=-0.001;
    $statpot{'f4HH'}=-0.405;
    $statpot{'f4HI'}=0.177;
    $statpot{'f4HL'}=0.346;
    $statpot{'f4HK'}=0.976;
    $statpot{'f4HM'}=-0.074;
    $statpot{'f4HF'}=-0.570;
    $statpot{'f4HP'}=-0.022;
    $statpot{'f4HS'}=-0.297;
    $statpot{'f4HT'}=-0.220;
    $statpot{'f4HW'}=-0.150;
    $statpot{'f4HY'}=-0.021;
    $statpot{'f4HV'}=0.147;
    $statpot{'f4IA'}=-0.610;
    $statpot{'f4IR'}=0.503;
    $statpot{'f4IN'}=0.593;
    $statpot{'f4ID'}=0.726;
    $statpot{'f4IC'}=-0.358;
    $statpot{'f4IQ'}=0.507;
    $statpot{'f4IE'}=0.710;
    $statpot{'f4IG'}=0.068;
    $statpot{'f4IH'}=0.177;
    $statpot{'f4II'}=0.745;
    $statpot{'f4IL'}=0.375;
    $statpot{'f4IK'}=1.167;
    $statpot{'f4IM'}=0.193;
    $statpot{'f4IF'}=-0.226;
    $statpot{'f4IP'}=0.253;
    $statpot{'f4IS'}=0.108;
    $statpot{'f4IT'}=0.456;
    $statpot{'f4IW'}=-0.082;
    $statpot{'f4IY'}=-0.145;
    $statpot{'f4IV'}=0.259;
    $statpot{'f4LA'}=-0.484;
    $statpot{'f4LR'}=0.380;
    $statpot{'f4LN'}=0.602;
    $statpot{'f4LD'}=0.438;
    $statpot{'f4LC'}=-0.128;
    $statpot{'f4LQ'}=0.436;
    $statpot{'f4LE'}=0.911;
    $statpot{'f4LG'}=-0.004;
    $statpot{'f4LH'}=0.332;
    $statpot{'f4LI'}=0.344;
    $statpot{'f4LL'}=0.177;
    $statpot{'f4LK'}=0.808;
    $statpot{'f4LM'}=0.179;
    $statpot{'f4LF'}=-0.239;
    $statpot{'f4LP'}=0.100;
    $statpot{'f4LS'}=0.122;
    $statpot{'f4LT'}=0.311;
    $statpot{'f4LW'}=-0.135;
    $statpot{'f4LY'}=-0.202;
    $statpot{'f4LV'}=-0.127;
    $statpot{'f4KA'}=0.129;
    $statpot{'f4KR'}=1.906;
    $statpot{'f4KN'}=0.312;
    $statpot{'f4KD'}=0.381;
    $statpot{'f4KC'}=0.615;
    $statpot{'f4KQ'}=0.719;
    $statpot{'f4KE'}=1.024;
    $statpot{'f4KG'}=1.051;
    $statpot{'f4KH'}=1.080;
    $statpot{'f4KI'}=1.146;
    $statpot{'f4KL'}=0.779;
    $statpot{'f4KK'}=1.393;
    $statpot{'f4KM'}=1.067;
    $statpot{'f4KF'}=0.597;
    $statpot{'f4KP'}=0.480;
    $statpot{'f4KS'}=0.537;
    $statpot{'f4KT'}=0.389;
    $statpot{'f4KW'}=0.542;
    $statpot{'f4KY'}=0.296;
    $statpot{'f4KV'}=0.413;
    $statpot{'f4MA'}=-0.570;
    $statpot{'f4MR'}=0.601;
    $statpot{'f4MN'}=0.104;
    $statpot{'f4MD'}=0.161;
    $statpot{'f4MC'}=-0.807;
    $statpot{'f4MQ'}=0.007;
    $statpot{'f4ME'}=0.701;
    $statpot{'f4MG'}=-0.009;
    $statpot{'f4MH'}=-0.073;
    $statpot{'f4MI'}=0.192;
    $statpot{'f4ML'}=0.105;
    $statpot{'f4MK'}=1.115;
    $statpot{'f4MM'}=0.015;
    $statpot{'f4MF'}=-0.129;
    $statpot{'f4MP'}=-0.235;
    $statpot{'f4MS'}=-0.138;
    $statpot{'f4MT'}=0.227;
    $statpot{'f4MW'}=0.086;
    $statpot{'f4MY'}=-0.297;
    $statpot{'f4MV'}=-0.021;
    $statpot{'f4FA'}=-0.409;
    $statpot{'f4FR'}=0.404;
    $statpot{'f4FN'}=0.104;
    $statpot{'f4FD'}=0.477;
    $statpot{'f4FC'}=-0.762;
    $statpot{'f4FQ'}=0.012;
    $statpot{'f4FE'}=0.386;
    $statpot{'f4FG'}=0.153;
    $statpot{'f4FH'}=-0.585;
    $statpot{'f4FI'}=-0.258;
    $statpot{'f4FL'}=-0.214;
    $statpot{'f4FK'}=0.546;
    $statpot{'f4FM'}=-0.130;
    $statpot{'f4FF'}=-0.651;
    $statpot{'f4FP'}=-0.329;
    $statpot{'f4FS'}=-0.017;
    $statpot{'f4FT'}=-0.072;
    $statpot{'f4FW'}=-0.339;
    $statpot{'f4FY'}=-0.288;
    $statpot{'f4FV'}=-0.316;
    $statpot{'f4PA'}=-0.308;
    $statpot{'f4PR'}=0.362;
    $statpot{'f4PN'}=0.066;
    $statpot{'f4PD'}=0.247;
    $statpot{'f4PC'}=-0.570;
    $statpot{'f4PQ'}=0.154;
    $statpot{'f4PE'}=0.497;
    $statpot{'f4PG'}=0.324;
    $statpot{'f4PH'}=-0.082;
    $statpot{'f4PI'}=0.264;
    $statpot{'f4PL'}=0.100;
    $statpot{'f4PK'}=0.579;
    $statpot{'f4PM'}=-0.185;
    $statpot{'f4PF'}=-0.320;
    $statpot{'f4PP'}=-0.194;
    $statpot{'f4PS'}=-0.210;
    $statpot{'f4PT'}=-0.103;
    $statpot{'f4PW'}=-0.618;
    $statpot{'f4PY'}=-0.155;
    $statpot{'f4PV'}=-0.031;
    $statpot{'f4SA'}=-0.340;
    $statpot{'f4SR'}=0.092;
    $statpot{'f4SN'}=0.033;
    $statpot{'f4SD'}=-0.338;
    $statpot{'f4SC'}=-0.693;
    $statpot{'f4SQ'}=0.088;
    $statpot{'f4SE'}=-0.175;
    $statpot{'f4SG'}=0.091;
    $statpot{'f4SH'}=-0.297;
    $statpot{'f4SI'}=0.067;
    $statpot{'f4SL'}=0.126;
    $statpot{'f4SK'}=0.442;
    $statpot{'f4SM'}=-0.153;
    $statpot{'f4SF'}=-0.046;
    $statpot{'f4SP'}=-0.235;
    $statpot{'f4SS'}=-0.468;
    $statpot{'f4ST'}=-0.494;
    $statpot{'f4SW'}=0.200;
    $statpot{'f4SY'}=-0.153;
    $statpot{'f4SV'}=-0.244;
    $statpot{'f4TA'}=-0.625;
    $statpot{'f4TR'}=0.463;
    $statpot{'f4TN'}=-0.125;
    $statpot{'f4TD'}=-0.390;
    $statpot{'f4TC'}=-0.246;
    $statpot{'f4TQ'}=-0.207;
    $statpot{'f4TE'}=-0.014;
    $statpot{'f4TG'}=0.066;
    $statpot{'f4TH'}=-0.219;
    $statpot{'f4TI'}=0.434;
    $statpot{'f4TL'}=0.299;
    $statpot{'f4TK'}=0.388;
    $statpot{'f4TM'}=0.205;
    $statpot{'f4TF'}=-0.072;
    $statpot{'f4TP'}=-0.104;
    $statpot{'f4TS'}=-0.495;
    $statpot{'f4TT'}=-0.229;
    $statpot{'f4TW'}=0.153;
    $statpot{'f4TY'}=0.106;
    $statpot{'f4TV'}=0.227;
    $statpot{'f4WA'}=-0.562;
    $statpot{'f4WR'}=0.223;
    $statpot{'f4WN'}=-0.144;
    $statpot{'f4WD'}=0.587;
    $statpot{'f4WC'}=-0.208;
    $statpot{'f4WQ'}=0.196;
    $statpot{'f4WE'}=1.082;
    $statpot{'f4WG'}=0.351;
    $statpot{'f4WH'}=-0.269;
    $statpot{'f4WI'}=-0.137;
    $statpot{'f4WL'}=-0.136;
    $statpot{'f4WK'}=0.541;
    $statpot{'f4WM'}=0.088;
    $statpot{'f4WF'}=-0.340;
    $statpot{'f4WP'}=-0.564;
    $statpot{'f4WS'}=0.200;
    $statpot{'f4WT'}=0.153;
    $statpot{'f4WW'}=-0.252;
    $statpot{'f4WY'}=-0.295;
    $statpot{'f4WV'}=-0.364;
    $statpot{'f4YA'}=-0.452;
    $statpot{'f4YR'}=0.137;
    $statpot{'f4YN'}=-0.028;
    $statpot{'f4YD'}=0.250;
    $statpot{'f4YC'}=-0.646;
    $statpot{'f4YQ'}=0.210;
    $statpot{'f4YE'}=0.389;
    $statpot{'f4YG'}=0.512;
    $statpot{'f4YH'}=-0.020;
    $statpot{'f4YI'}=-0.166;
    $statpot{'f4YL'}=-0.230;
    $statpot{'f4YK'}=0.326;
    $statpot{'f4YM'}=-0.299;
    $statpot{'f4YF'}=-0.311;
    $statpot{'f4YP'}=-0.083;
    $statpot{'f4YS'}=-0.126;
    $statpot{'f4YT'}=0.132;
    $statpot{'f4YW'}=-0.323;
    $statpot{'f4YY'}=-0.701;
    $statpot{'f4YV'}=-0.334;
    $statpot{'f4VA'}=-1.061;
    $statpot{'f4VR'}=0.381;
    $statpot{'f4VN'}=0.297;
    $statpot{'f4VD'}=0.381;
    $statpot{'f4VC'}=-0.797;
    $statpot{'f4VQ'}=0.148;
    $statpot{'f4VE'}=0.331;
    $statpot{'f4VG'}=-0.064;
    $statpot{'f4VH'}=0.146;
    $statpot{'f4VI'}=0.281;
    $statpot{'f4VL'}=-0.122;
    $statpot{'f4VK'}=0.421;
    $statpot{'f4VM'}=-0.007;
    $statpot{'f4VF'}=-0.321;
    $statpot{'f4VP'}=-0.049;
    $statpot{'f4VS'}=-0.240;
    $statpot{'f4VT'}=0.221;
    $statpot{'f4VW'}=-0.378;
    $statpot{'f4VY'}=-0.320;
    $statpot{'f4VV'}=-0.065;
    $statpot{'a4AA'}=-0.559;
    $statpot{'a4AR'}=-0.002;
    $statpot{'a4AN'}=-0.595;
    $statpot{'a4AD'}=0.316;
    $statpot{'a4AC'}=-0.178;
    $statpot{'a4AQ'}=0.104;
    $statpot{'a4AE'}=0.664;
    $statpot{'a4AG'}=-1.383;
    $statpot{'a4AH'}=0.879;
    $statpot{'a4AI'}=0.321;
    $statpot{'a4AL'}=0.339;
    $statpot{'a4AK'}=-0.037;
    $statpot{'a4AM'}=0.000;
    $statpot{'a4AF'}=0.104;
    $statpot{'a4AP'}=-0.973;
    $statpot{'a4AS'}=-0.618;
    $statpot{'a4AT'}=-0.605;
    $statpot{'a4AW'}=-0.237;
    $statpot{'a4AY'}=0.021;
    $statpot{'a4AV'}=-0.075;
    $statpot{'a4RA'}=-0.538;
    $statpot{'a4RR'}=-0.193;
    $statpot{'a4RN'}=0.000;
    $statpot{'a4RD'}=0.000;
    $statpot{'a4RC'}=-0.039;
    $statpot{'a4RQ'}=0.095;
    $statpot{'a4RE'}=0.686;
    $statpot{'a4RG'}=-1.434;
    $statpot{'a4RH'}=0.000;
    $statpot{'a4RI'}=-0.737;
    $statpot{'a4RL'}=1.045;
    $statpot{'a4RK'}=1.147;
    $statpot{'a4RM'}=0.000;
    $statpot{'a4RF'}=0.825;
    $statpot{'a4RP'}=-0.807;
    $statpot{'a4RS'}=0.641;
    $statpot{'a4RT'}=-0.355;
    $statpot{'a4RW'}=-0.848;
    $statpot{'a4RY'}=0.734;
    $statpot{'a4RV'}=0.825;
    $statpot{'a4NA'}=-0.170;
    $statpot{'a4NR'}=0.892;
    $statpot{'a4NN'}=-0.362;
    $statpot{'a4ND'}=0.062;
    $statpot{'a4NC'}=0.000;
    $statpot{'a4NQ'}=0.725;
    $statpot{'a4NE'}=1.177;
    $statpot{'a4NG'}=-1.512;
    $statpot{'a4NH'}=0.200;
    $statpot{'a4NI'}=0.000;
    $statpot{'a4NL'}=0.232;
    $statpot{'a4NK'}=-0.163;
    $statpot{'a4NM'}=-0.822;
    $statpot{'a4NF'}=0.000;
    $statpot{'a4NP'}=0.242;
    $statpot{'a4NS'}=-0.449;
    $statpot{'a4NT'}=-0.393;
    $statpot{'a4NW'}=0.000;
    $statpot{'a4NY'}=0.000;
    $statpot{'a4NV'}=0.000;
    $statpot{'a4DA'}=-0.640;
    $statpot{'a4DR'}=0.543;
    $statpot{'a4DN'}=-0.212;
    $statpot{'a4DD'}=0.000;
    $statpot{'a4DC'}=0.122;
    $statpot{'a4DQ'}=0.939;
    $statpot{'a4DE'}=0.000;
    $statpot{'a4DG'}=-1.282;
    $statpot{'a4DH'}=-0.157;
    $statpot{'a4DI'}=1.346;
    $statpot{'a4DL'}=0.496;
    $statpot{'a4DK'}=-0.141;
    $statpot{'a4DM'}=0.000;
    $statpot{'a4DF'}=-0.086;
    $statpot{'a4DP'}=-0.806;
    $statpot{'a4DS'}=-0.773;
    $statpot{'a4DT'}=-0.188;
    $statpot{'a4DW'}=0.000;
    $statpot{'a4DY'}=0.286;
    $statpot{'a4DV'}=1.611;
    $statpot{'a4CA'}=-1.581;
    $statpot{'a4CR'}=-1.180;
    $statpot{'a4CN'}=-0.114;
    $statpot{'a4CD'}=-1.288;
    $statpot{'a4CC'}=-0.597;
    $statpot{'a4CQ'}=0.000;
    $statpot{'a4CE'}=0.000;
    $statpot{'a4CG'}=-1.977;
    $statpot{'a4CH'}=-1.379;
    $statpot{'a4CI'}=0.000;
    $statpot{'a4CL'}=0.000;
    $statpot{'a4CK'}=-1.208;
    $statpot{'a4CM'}=0.000;
    $statpot{'a4CF'}=0.000;
    $statpot{'a4CP'}=-1.170;
    $statpot{'a4CS'}=0.000;
    $statpot{'a4CT'}=-0.909;
    $statpot{'a4CW'}=0.000;
    $statpot{'a4CY'}=-1.101;
    $statpot{'a4CV'}=0.000;
    $statpot{'a4QA'}=-0.570;
    $statpot{'a4QR'}=0.000;
    $statpot{'a4QN'}=-0.354;
    $statpot{'a4QD'}=-0.380;
    $statpot{'a4QC'}=0.000;
    $statpot{'a4QQ'}=0.007;
    $statpot{'a4QE'}=0.362;
    $statpot{'a4QG'}=-1.642;
    $statpot{'a4QH'}=0.000;
    $statpot{'a4QI'}=0.280;
    $statpot{'a4QL'}=1.434;
    $statpot{'a4QK'}=-0.919;
    $statpot{'a4QM'}=0.000;
    $statpot{'a4QF'}=0.000;
    $statpot{'a4QP'}=0.000;
    $statpot{'a4QS'}=0.421;
    $statpot{'a4QT'}=0.993;
    $statpot{'a4QW'}=-0.278;
    $statpot{'a4QY'}=0.493;
    $statpot{'a4QV'}=0.173;
    $statpot{'a4EA'}=-0.662;
    $statpot{'a4ER'}=0.000;
    $statpot{'a4EN'}=0.000;
    $statpot{'a4ED'}=0.000;
    $statpot{'a4EC'}=0.192;
    $statpot{'a4EQ'}=1.036;
    $statpot{'a4EE'}=1.630;
    $statpot{'a4EG'}=-0.947;
    $statpot{'a4EH'}=-0.133;
    $statpot{'a4EI'}=0.000;
    $statpot{'a4EL'}=1.291;
    $statpot{'a4EK'}=0.000;
    $statpot{'a4EM'}=0.652;
    $statpot{'a4EF'}=1.081;
    $statpot{'a4EP'}=0.692;
    $statpot{'a4ES'}=0.010;
    $statpot{'a4ET'}=0.152;
    $statpot{'a4EW'}=0.000;
    $statpot{'a4EY'}=0.338;
    $statpot{'a4EV'}=0.435;
    $statpot{'a4GA'}=-0.938;
    $statpot{'a4GR'}=-0.890;
    $statpot{'a4GN'}=-0.568;
    $statpot{'a4GD'}=-0.877;
    $statpot{'a4GC'}=-0.923;
    $statpot{'a4GQ'}=-1.481;
    $statpot{'a4GE'}=-0.547;
    $statpot{'a4GG'}=-2.135;
    $statpot{'a4GH'}=-1.446;
    $statpot{'a4GI'}=-0.226;
    $statpot{'a4GL'}=-0.860;
    $statpot{'a4GK'}=-0.641;
    $statpot{'a4GM'}=0.068;
    $statpot{'a4GF'}=-0.872;
    $statpot{'a4GP'}=-0.021;
    $statpot{'a4GS'}=-1.555;
    $statpot{'a4GT'}=-1.216;
    $statpot{'a4GW'}=-1.622;
    $statpot{'a4GY'}=-1.013;
    $statpot{'a4GV'}=-0.361;
    $statpot{'a4HA'}=-1.020;
    $statpot{'a4HR'}=0.324;
    $statpot{'a4HN'}=0.000;
    $statpot{'a4HD'}=-1.628;
    $statpot{'a4HC'}=-0.910;
    $statpot{'a4HQ'}=0.000;
    $statpot{'a4HE'}=0.000;
    $statpot{'a4HG'}=-1.690;
    $statpot{'a4HH'}=0.000;
    $statpot{'a4HI'}=0.000;
    $statpot{'a4HL'}=0.930;
    $statpot{'a4HK'}=0.000;
    $statpot{'a4HM'}=0.000;
    $statpot{'a4HF'}=0.097;
    $statpot{'a4HP'}=-0.794;
    $statpot{'a4HS'}=-0.126;
    $statpot{'a4HT'}=-0.636;
    $statpot{'a4HW'}=-1.644;
    $statpot{'a4HY'}=-0.005;
    $statpot{'a4HV'}=0.000;
    $statpot{'a4IA'}=-1.019;
    $statpot{'a4IR'}=1.170;
    $statpot{'a4IN'}=0.504;
    $statpot{'a4ID'}=-0.366;
    $statpot{'a4IC'}=0.102;
    $statpot{'a4IQ'}=-0.631;
    $statpot{'a4IE'}=0.875;
    $statpot{'a4IG'}=-1.232;
    $statpot{'a4IH'}=0.000;
    $statpot{'a4II'}=1.434;
    $statpot{'a4IL'}=0.270;
    $statpot{'a4IK'}=0.425;
    $statpot{'a4IM'}=0.000;
    $statpot{'a4IF'}=-0.348;
    $statpot{'a4IP'}=-1.034;
    $statpot{'a4IS'}=-0.530;
    $statpot{'a4IT'}=0.368;
    $statpot{'a4IW'}=-0.728;
    $statpot{'a4IY'}=0.217;
    $statpot{'a4IV'}=0.971;
    $statpot{'a4LA'}=-0.679;
    $statpot{'a4LR'}=-0.035;
    $statpot{'a4LN'}=0.491;
    $statpot{'a4LD'}=1.773;
    $statpot{'a4LC'}=0.552;
    $statpot{'a4LQ'}=0.342;
    $statpot{'a4LE'}=1.285;
    $statpot{'a4LG'}=-1.051;
    $statpot{'a4LH'}=0.000;
    $statpot{'a4LI'}=0.000;
    $statpot{'a4LL'}=0.319;
    $statpot{'a4LK'}=0.289;
    $statpot{'a4LM'}=-0.828;
    $statpot{'a4LF'}=1.416;
    $statpot{'a4LP'}=-0.723;
    $statpot{'a4LS'}=0.339;
    $statpot{'a4LT'}=-0.418;
    $statpot{'a4LW'}=0.000;
    $statpot{'a4LY'}=-0.444;
    $statpot{'a4LV'}=0.000;
    $statpot{'a4KA'}=-0.388;
    $statpot{'a4KR'}=-0.210;
    $statpot{'a4KN'}=-0.369;
    $statpot{'a4KD'}=0.353;
    $statpot{'a4KC'}=0.141;
    $statpot{'a4KQ'}=-0.611;
    $statpot{'a4KE'}=1.505;
    $statpot{'a4KG'}=-0.977;
    $statpot{'a4KH'}=-0.214;
    $statpot{'a4KI'}=0.813;
    $statpot{'a4KL'}=1.186;
    $statpot{'a4KK'}=0.000;
    $statpot{'a4KM'}=0.541;
    $statpot{'a4KF'}=-0.830;
    $statpot{'a4KP'}=0.148;
    $statpot{'a4KS'}=-0.781;
    $statpot{'a4KT'}=1.382;
    $statpot{'a4KW'}=0.000;
    $statpot{'a4KY'}=0.918;
    $statpot{'a4KV'}=0.336;
    $statpot{'a4MA'}=-2.008;
    $statpot{'a4MR'}=-0.341;
    $statpot{'a4MN'}=0.244;
    $statpot{'a4MD'}=-0.167;
    $statpot{'a4MC'}=0.000;
    $statpot{'a4MQ'}=0.108;
    $statpot{'a4ME'}=0.000;
    $statpot{'a4MG'}=-1.335;
    $statpot{'a4MH'}=0.000;
    $statpot{'a4MI'}=0.000;
    $statpot{'a4ML'}=0.000;
    $statpot{'a4MK'}=-0.133;
    $statpot{'a4MM'}=0.000;
    $statpot{'a4MF'}=0.000;
    $statpot{'a4MP'}=-0.330;
    $statpot{'a4MS'}=0.594;
    $statpot{'a4MT'}=-0.169;
    $statpot{'a4MW'}=0.000;
    $statpot{'a4MY'}=0.000;
    $statpot{'a4MV'}=0.000;
    $statpot{'a4FA'}=-1.229;
    $statpot{'a4FR'}=0.798;
    $statpot{'a4FN'}=-0.877;
    $statpot{'a4FD'}=-0.038;
    $statpot{'a4FC'}=-1.771;
    $statpot{'a4FQ'}=0.000;
    $statpot{'a4FE'}=1.108;
    $statpot{'a4FG'}=-1.641;
    $statpot{'a4FH'}=0.000;
    $statpot{'a4FI'}=0.000;
    $statpot{'a4FL'}=-0.301;
    $statpot{'a4FK'}=-0.313;
    $statpot{'a4FM'}=0.000;
    $statpot{'a4FF'}=0.013;
    $statpot{'a4FP'}=0.195;
    $statpot{'a4FS'}=-0.799;
    $statpot{'a4FT'}=0.975;
    $statpot{'a4FW'}=0.000;
    $statpot{'a4FY'}=-0.124;
    $statpot{'a4FV'}=1.218;
    $statpot{'a4PA'}=-1.260;
    $statpot{'a4PR'}=-1.145;
    $statpot{'a4PN'}=-1.113;
    $statpot{'a4PD'}=1.216;
    $statpot{'a4PC'}=-1.127;
    $statpot{'a4PQ'}=0.113;
    $statpot{'a4PE'}=-0.012;
    $statpot{'a4PG'}=-1.435;
    $statpot{'a4PH'}=0.000;
    $statpot{'a4PI'}=-1.141;
    $statpot{'a4PL'}=-0.731;
    $statpot{'a4PK'}=-1.049;
    $statpot{'a4PM'}=-1.260;
    $statpot{'a4PF'}=-0.211;
    $statpot{'a4PP'}=-0.961;
    $statpot{'a4PS'}=-1.121;
    $statpot{'a4PT'}=-0.522;
    $statpot{'a4PW'}=-0.010;
    $statpot{'a4PY'}=0.000;
    $statpot{'a4PV'}=-0.062;
    $statpot{'a4SA'}=-0.737;
    $statpot{'a4SR'}=1.286;
    $statpot{'a4SN'}=0.256;
    $statpot{'a4SD'}=0.840;
    $statpot{'a4SC'}=0.000;
    $statpot{'a4SQ'}=0.444;
    $statpot{'a4SE'}=1.526;
    $statpot{'a4SG'}=-1.541;
    $statpot{'a4SH'}=-0.131;
    $statpot{'a4SI'}=0.829;
    $statpot{'a4SL'}=0.184;
    $statpot{'a4SK'}=1.494;
    $statpot{'a4SM'}=0.000;
    $statpot{'a4SF'}=-0.199;
    $statpot{'a4SP'}=-0.682;
    $statpot{'a4SS'}=-0.727;
    $statpot{'a4ST'}=0.912;
    $statpot{'a4SW'}=0.000;
    $statpot{'a4SY'}=-0.012;
    $statpot{'a4SV'}=-0.350;
    $statpot{'a4TA'}=-0.122;
    $statpot{'a4TR'}=-0.159;
    $statpot{'a4TN'}=0.143;
    $statpot{'a4TD'}=-0.482;
    $statpot{'a4TC'}=-1.581;
    $statpot{'a4TQ'}=1.027;
    $statpot{'a4TE'}=0.829;
    $statpot{'a4TG'}=-1.437;
    $statpot{'a4TH'}=-0.650;
    $statpot{'a4TI'}=1.401;
    $statpot{'a4TL'}=-0.173;
    $statpot{'a4TK'}=1.417;
    $statpot{'a4TM'}=0.512;
    $statpot{'a4TF'}=0.969;
    $statpot{'a4TP'}=-0.508;
    $statpot{'a4TS'}=0.940;
    $statpot{'a4TT'}=0.178;
    $statpot{'a4TW'}=0.000;
    $statpot{'a4TY'}=0.300;
    $statpot{'a4TV'}=0.630;
    $statpot{'a4WA'}=-0.575;
    $statpot{'a4WR'}=-0.162;
    $statpot{'a4WN'}=-0.207;
    $statpot{'a4WD'}=0.000;
    $statpot{'a4WC'}=0.000;
    $statpot{'a4WQ'}=0.000;
    $statpot{'a4WE'}=0.000;
    $statpot{'a4WG'}=-1.809;
    $statpot{'a4WH'}=0.000;
    $statpot{'a4WI'}=0.000;
    $statpot{'a4WL'}=0.000;
    $statpot{'a4WK'}=0.000;
    $statpot{'a4WM'}=0.000;
    $statpot{'a4WF'}=0.000;
    $statpot{'a4WP'}=-1.473;
    $statpot{'a4WS'}=0.000;
    $statpot{'a4WT'}=0.000;
    $statpot{'a4WW'}=0.000;
    $statpot{'a4WY'}=-0.378;
    $statpot{'a4WV'}=-0.383;
    $statpot{'a4YA'}=-1.087;
    $statpot{'a4YR'}=0.000;
    $statpot{'a4YN'}=-1.074;
    $statpot{'a4YD'}=-0.144;
    $statpot{'a4YC'}=0.000;
    $statpot{'a4YQ'}=-0.555;
    $statpot{'a4YE'}=0.000;
    $statpot{'a4YG'}=-0.857;
    $statpot{'a4YH'}=-0.031;
    $statpot{'a4YI'}=0.000;
    $statpot{'a4YL'}=1.266;
    $statpot{'a4YK'}=-0.116;
    $statpot{'a4YM'}=0.000;
    $statpot{'a4YF'}=0.000;
    $statpot{'a4YP'}=-1.004;
    $statpot{'a4YS'}=-0.717;
    $statpot{'a4YT'}=-0.407;
    $statpot{'a4YW'}=0.000;
    $statpot{'a4YY'}=0.000;
    $statpot{'a4YV'}=0.000;
    $statpot{'a4VA'}=-1.224;
    $statpot{'a4VR'}=-0.070;
    $statpot{'a4VN'}=0.000;
    $statpot{'a4VD'}=0.000;
    $statpot{'a4VC'}=-0.364;
    $statpot{'a4VQ'}=0.190;
    $statpot{'a4VE'}=1.704;
    $statpot{'a4VG'}=-1.028;
    $statpot{'a4VH'}=0.000;
    $statpot{'a4VI'}=0.053;
    $statpot{'a4VL'}=1.457;
    $statpot{'a4VK'}=0.106;
    $statpot{'a4VM'}=0.778;
    $statpot{'a4VF'}=0.000;
    $statpot{'a4VP'}=0.835;
    $statpot{'a4VS'}=-0.459;
    $statpot{'a4VT'}=1.015;
    $statpot{'a4VW'}=0.245;
    $statpot{'a4VY'}=0.446;
    $statpot{'a4VV'}=0.000;
    $statpot{'p5AA'}=-0.303;
    $statpot{'p5AR'}=-0.135;
    $statpot{'p5AN'}=-0.067;
    $statpot{'p5AD'}=-0.028;
    $statpot{'p5AC'}=-0.159;
    $statpot{'p5AQ'}=-0.173;
    $statpot{'p5AE'}=-0.243;
    $statpot{'p5AG'}=0.398;
    $statpot{'p5AH'}=0.016;
    $statpot{'p5AI'}=-0.385;
    $statpot{'p5AL'}=-0.432;
    $statpot{'p5AK'}=-0.058;
    $statpot{'p5AM'}=-0.357;
    $statpot{'p5AF'}=-0.082;
    $statpot{'p5AP'}=0.382;
    $statpot{'p5AS'}=0.002;
    $statpot{'p5AT'}=0.012;
    $statpot{'p5AW'}=-0.238;
    $statpot{'p5AY'}=-0.047;
    $statpot{'p5AV'}=-0.354;
    $statpot{'p5RA'}=-0.135;
    $statpot{'p5RR'}=0.262;
    $statpot{'p5RN'}=-0.140;
    $statpot{'p5RD'}=-0.310;
    $statpot{'p5RC'}=0.180;
    $statpot{'p5RQ'}=-0.111;
    $statpot{'p5RE'}=-0.417;
    $statpot{'p5RG'}=0.363;
    $statpot{'p5RH'}=0.216;
    $statpot{'p5RI'}=0.010;
    $statpot{'p5RL'}=-0.044;
    $statpot{'p5RK'}=0.118;
    $statpot{'p5RM'}=-0.180;
    $statpot{'p5RF'}=0.136;
    $statpot{'p5RP'}=0.470;
    $statpot{'p5RS'}=0.002;
    $statpot{'p5RT'}=0.058;
    $statpot{'p5RW'}=-0.183;
    $statpot{'p5RY'}=-0.084;
    $statpot{'p5RV'}=0.037;
    $statpot{'p5NA'}=-0.067;
    $statpot{'p5NR'}=-0.140;
    $statpot{'p5NN'}=-0.325;
    $statpot{'p5ND'}=-0.240;
    $statpot{'p5NC'}=0.194;
    $statpot{'p5NQ'}=-0.185;
    $statpot{'p5NE'}=-0.039;
    $statpot{'p5NG'}=0.351;
    $statpot{'p5NH'}=0.019;
    $statpot{'p5NI'}=0.253;
    $statpot{'p5NL'}=0.193;
    $statpot{'p5NK'}=-0.026;
    $statpot{'p5NM'}=0.022;
    $statpot{'p5NF'}=0.165;
    $statpot{'p5NP'}=0.325;
    $statpot{'p5NS'}=-0.022;
    $statpot{'p5NT'}=0.031;
    $statpot{'p5NW'}=-0.141;
    $statpot{'p5NY'}=0.048;
    $statpot{'p5NV'}=0.114;
    $statpot{'p5DA'}=-0.028;
    $statpot{'p5DR'}=-0.310;
    $statpot{'p5DN'}=-0.240;
    $statpot{'p5DD'}=0.037;
    $statpot{'p5DC'}=0.216;
    $statpot{'p5DQ'}=-0.114;
    $statpot{'p5DE'}=-0.010;
    $statpot{'p5DG'}=0.435;
    $statpot{'p5DH'}=-0.116;
    $statpot{'p5DI'}=0.289;
    $statpot{'p5DL'}=0.275;
    $statpot{'p5DK'}=-0.251;
    $statpot{'p5DM'}=0.166;
    $statpot{'p5DF'}=0.350;
    $statpot{'p5DP'}=0.227;
    $statpot{'p5DS'}=-0.136;
    $statpot{'p5DT'}=-0.122;
    $statpot{'p5DW'}=0.107;
    $statpot{'p5DY'}=0.164;
    $statpot{'p5DV'}=0.315;
    $statpot{'p5CA'}=-0.159;
    $statpot{'p5CR'}=0.180;
    $statpot{'p5CN'}=0.194;
    $statpot{'p5CD'}=0.216;
    $statpot{'p5CC'}=-0.312;
    $statpot{'p5CQ'}=-0.016;
    $statpot{'p5CE'}=0.401;
    $statpot{'p5CG'}=0.294;
    $statpot{'p5CH'}=-0.234;
    $statpot{'p5CI'}=-0.161;
    $statpot{'p5CL'}=-0.308;
    $statpot{'p5CK'}=0.553;
    $statpot{'p5CM'}=-0.231;
    $statpot{'p5CF'}=-0.322;
    $statpot{'p5CP'}=0.378;
    $statpot{'p5CS'}=0.135;
    $statpot{'p5CT'}=0.004;
    $statpot{'p5CW'}=-0.262;
    $statpot{'p5CY'}=0.119;
    $statpot{'p5CV'}=-0.285;
    $statpot{'p5QA'}=-0.173;
    $statpot{'p5QR'}=-0.111;
    $statpot{'p5QN'}=-0.185;
    $statpot{'p5QD'}=-0.114;
    $statpot{'p5QC'}=-0.016;
    $statpot{'p5QQ'}=-0.210;
    $statpot{'p5QE'}=-0.114;
    $statpot{'p5QG'}=0.204;
    $statpot{'p5QH'}=-0.054;
    $statpot{'p5QI'}=0.028;
    $statpot{'p5QL'}=-0.113;
    $statpot{'p5QK'}=-0.154;
    $statpot{'p5QM'}=0.199;
    $statpot{'p5QF'}=0.121;
    $statpot{'p5QP'}=0.171;
    $statpot{'p5QS'}=0.003;
    $statpot{'p5QT'}=0.009;
    $statpot{'p5QW'}=-0.114;
    $statpot{'p5QY'}=-0.105;
    $statpot{'p5QV'}=0.120;
    $statpot{'p5EA'}=-0.243;
    $statpot{'p5ER'}=-0.417;
    $statpot{'p5EN'}=-0.039;
    $statpot{'p5ED'}=-0.010;
    $statpot{'p5EC'}=0.401;
    $statpot{'p5EQ'}=-0.114;
    $statpot{'p5EE'}=-0.171;
    $statpot{'p5EG'}=0.525;
    $statpot{'p5EH'}=0.086;
    $statpot{'p5EI'}=0.090;
    $statpot{'p5EL'}=0.004;
    $statpot{'p5EK'}=-0.488;
    $statpot{'p5EM'}=0.061;
    $statpot{'p5EF'}=0.273;
    $statpot{'p5EP'}=0.138;
    $statpot{'p5ES'}=0.152;
    $statpot{'p5ET'}=-0.047;
    $statpot{'p5EW'}=-0.139;
    $statpot{'p5EY'}=0.120;
    $statpot{'p5EV'}=0.063;
    $statpot{'p5GA'}=0.398;
    $statpot{'p5GR'}=0.363;
    $statpot{'p5GN'}=0.351;
    $statpot{'p5GD'}=0.435;
    $statpot{'p5GC'}=0.294;
    $statpot{'p5GQ'}=0.204;
    $statpot{'p5GE'}=0.525;
    $statpot{'p5GG'}=0.479;
    $statpot{'p5GH'}=0.354;
    $statpot{'p5GI'}=0.401;
    $statpot{'p5GL'}=0.404;
    $statpot{'p5GK'}=0.369;
    $statpot{'p5GM'}=0.232;
    $statpot{'p5GF'}=0.336;
    $statpot{'p5GP'}=0.511;
    $statpot{'p5GS'}=0.366;
    $statpot{'p5GT'}=0.423;
    $statpot{'p5GW'}=0.282;
    $statpot{'p5GY'}=0.227;
    $statpot{'p5GV'}=0.541;
    $statpot{'p5HA'}=0.016;
    $statpot{'p5HR'}=0.216;
    $statpot{'p5HN'}=0.019;
    $statpot{'p5HD'}=-0.116;
    $statpot{'p5HC'}=-0.234;
    $statpot{'p5HQ'}=-0.054;
    $statpot{'p5HE'}=0.086;
    $statpot{'p5HG'}=0.354;
    $statpot{'p5HH'}=-0.060;
    $statpot{'p5HI'}=0.084;
    $statpot{'p5HL'}=0.044;
    $statpot{'p5HK'}=0.335;
    $statpot{'p5HM'}=-0.108;
    $statpot{'p5HF'}=0.200;
    $statpot{'p5HP'}=0.194;
    $statpot{'p5HS'}=0.108;
    $statpot{'p5HT'}=-0.011;
    $statpot{'p5HW'}=0.133;
    $statpot{'p5HY'}=0.040;
    $statpot{'p5HV'}=0.207;
    $statpot{'p5IA'}=-0.385;
    $statpot{'p5IR'}=0.010;
    $statpot{'p5IN'}=0.253;
    $statpot{'p5ID'}=0.289;
    $statpot{'p5IC'}=-0.161;
    $statpot{'p5IQ'}=0.028;
    $statpot{'p5IE'}=0.090;
    $statpot{'p5IG'}=0.401;
    $statpot{'p5IH'}=0.084;
    $statpot{'p5II'}=-0.314;
    $statpot{'p5IL'}=-0.310;
    $statpot{'p5IK'}=0.215;
    $statpot{'p5IM'}=-0.321;
    $statpot{'p5IF'}=-0.275;
    $statpot{'p5IP'}=0.311;
    $statpot{'p5IS'}=0.064;
    $statpot{'p5IT'}=0.105;
    $statpot{'p5IW'}=-0.314;
    $statpot{'p5IY'}=-0.119;
    $statpot{'p5IV'}=-0.401;
    $statpot{'p5LA'}=-0.432;
    $statpot{'p5LR'}=-0.044;
    $statpot{'p5LN'}=0.193;
    $statpot{'p5LD'}=0.275;
    $statpot{'p5LC'}=-0.308;
    $statpot{'p5LQ'}=-0.113;
    $statpot{'p5LE'}=0.004;
    $statpot{'p5LG'}=0.404;
    $statpot{'p5LH'}=0.044;
    $statpot{'p5LI'}=-0.310;
    $statpot{'p5LL'}=-0.467;
    $statpot{'p5LK'}=0.095;
    $statpot{'p5LM'}=-0.298;
    $statpot{'p5LF'}=-0.244;
    $statpot{'p5LP'}=0.324;
    $statpot{'p5LS'}=0.088;
    $statpot{'p5LT'}=0.104;
    $statpot{'p5LW'}=-0.297;
    $statpot{'p5LY'}=-0.150;
    $statpot{'p5LV'}=-0.316;
    $statpot{'p5KA'}=-0.058;
    $statpot{'p5KR'}=0.118;
    $statpot{'p5KN'}=-0.026;
    $statpot{'p5KD'}=-0.251;
    $statpot{'p5KC'}=0.553;
    $statpot{'p5KQ'}=-0.154;
    $statpot{'p5KE'}=-0.488;
    $statpot{'p5KG'}=0.369;
    $statpot{'p5KH'}=0.335;
    $statpot{'p5KI'}=0.215;
    $statpot{'p5KL'}=0.095;
    $statpot{'p5KK'}=0.124;
    $statpot{'p5KM'}=0.107;
    $statpot{'p5KF'}=0.287;
    $statpot{'p5KP'}=0.465;
    $statpot{'p5KS'}=0.079;
    $statpot{'p5KT'}=0.112;
    $statpot{'p5KW'}=-0.017;
    $statpot{'p5KY'}=0.018;
    $statpot{'p5KV'}=0.141;
    $statpot{'p5MA'}=-0.357;
    $statpot{'p5MR'}=-0.180;
    $statpot{'p5MN'}=0.022;
    $statpot{'p5MD'}=0.166;
    $statpot{'p5MC'}=-0.231;
    $statpot{'p5MQ'}=0.199;
    $statpot{'p5ME'}=0.061;
    $statpot{'p5MG'}=0.232;
    $statpot{'p5MH'}=-0.108;
    $statpot{'p5MI'}=-0.321;
    $statpot{'p5ML'}=-0.298;
    $statpot{'p5MK'}=0.107;
    $statpot{'p5MM'}=-0.474;
    $statpot{'p5MF'}=-0.176;
    $statpot{'p5MP'}=0.528;
    $statpot{'p5MS'}=0.251;
    $statpot{'p5MT'}=0.038;
    $statpot{'p5MW'}=0.090;
    $statpot{'p5MY'}=-0.041;
    $statpot{'p5MV'}=-0.341;
    $statpot{'p5FA'}=-0.082;
    $statpot{'p5FR'}=0.136;
    $statpot{'p5FN'}=0.165;
    $statpot{'p5FD'}=0.350;
    $statpot{'p5FC'}=-0.322;
    $statpot{'p5FQ'}=0.121;
    $statpot{'p5FE'}=0.273;
    $statpot{'p5FG'}=0.336;
    $statpot{'p5FH'}=0.200;
    $statpot{'p5FI'}=-0.275;
    $statpot{'p5FL'}=-0.244;
    $statpot{'p5FK'}=0.287;
    $statpot{'p5FM'}=-0.176;
    $statpot{'p5FF'}=-0.425;
    $statpot{'p5FP'}=0.285;
    $statpot{'p5FS'}=0.082;
    $statpot{'p5FT'}=0.134;
    $statpot{'p5FW'}=-0.241;
    $statpot{'p5FY'}=-0.193;
    $statpot{'p5FV'}=-0.239;
    $statpot{'p5PA'}=0.382;
    $statpot{'p5PR'}=0.470;
    $statpot{'p5PN'}=0.325;
    $statpot{'p5PD'}=0.227;
    $statpot{'p5PC'}=0.378;
    $statpot{'p5PQ'}=0.171;
    $statpot{'p5PE'}=0.138;
    $statpot{'p5PG'}=0.511;
    $statpot{'p5PH'}=0.194;
    $statpot{'p5PI'}=0.311;
    $statpot{'p5PL'}=0.324;
    $statpot{'p5PK'}=0.465;
    $statpot{'p5PM'}=0.528;
    $statpot{'p5PF'}=0.285;
    $statpot{'p5PP'}=0.617;
    $statpot{'p5PS'}=0.337;
    $statpot{'p5PT'}=0.134;
    $statpot{'p5PW'}=0.281;
    $statpot{'p5PY'}=0.174;
    $statpot{'p5PV'}=0.291;
    $statpot{'p5SA'}=0.002;
    $statpot{'p5SR'}=0.002;
    $statpot{'p5SN'}=-0.022;
    $statpot{'p5SD'}=-0.136;
    $statpot{'p5SC'}=0.135;
    $statpot{'p5SQ'}=0.003;
    $statpot{'p5SE'}=0.152;
    $statpot{'p5SG'}=0.366;
    $statpot{'p5SH'}=0.108;
    $statpot{'p5SI'}=0.064;
    $statpot{'p5SL'}=0.088;
    $statpot{'p5SK'}=0.079;
    $statpot{'p5SM'}=0.251;
    $statpot{'p5SF'}=0.082;
    $statpot{'p5SP'}=0.337;
    $statpot{'p5SS'}=0.036;
    $statpot{'p5ST'}=0.099;
    $statpot{'p5SW'}=0.020;
    $statpot{'p5SY'}=0.087;
    $statpot{'p5SV'}=0.103;
    $statpot{'p5TA'}=0.012;
    $statpot{'p5TR'}=0.058;
    $statpot{'p5TN'}=0.031;
    $statpot{'p5TD'}=-0.122;
    $statpot{'p5TC'}=0.004;
    $statpot{'p5TQ'}=0.009;
    $statpot{'p5TE'}=-0.047;
    $statpot{'p5TG'}=0.423;
    $statpot{'p5TH'}=-0.011;
    $statpot{'p5TI'}=0.105;
    $statpot{'p5TL'}=0.104;
    $statpot{'p5TK'}=0.112;
    $statpot{'p5TM'}=0.038;
    $statpot{'p5TF'}=0.134;
    $statpot{'p5TP'}=0.134;
    $statpot{'p5TS'}=0.099;
    $statpot{'p5TT'}=0.024;
    $statpot{'p5TW'}=0.045;
    $statpot{'p5TY'}=0.329;
    $statpot{'p5TV'}=0.024;
    $statpot{'p5WA'}=-0.238;
    $statpot{'p5WR'}=-0.183;
    $statpot{'p5WN'}=-0.141;
    $statpot{'p5WD'}=0.107;
    $statpot{'p5WC'}=-0.262;
    $statpot{'p5WQ'}=-0.114;
    $statpot{'p5WE'}=-0.139;
    $statpot{'p5WG'}=0.282;
    $statpot{'p5WH'}=0.133;
    $statpot{'p5WI'}=-0.314;
    $statpot{'p5WL'}=-0.297;
    $statpot{'p5WK'}=-0.017;
    $statpot{'p5WM'}=0.090;
    $statpot{'p5WF'}=-0.241;
    $statpot{'p5WP'}=0.281;
    $statpot{'p5WS'}=0.020;
    $statpot{'p5WT'}=0.045;
    $statpot{'p5WW'}=-0.253;
    $statpot{'p5WY'}=-0.213;
    $statpot{'p5WV'}=-0.208;
    $statpot{'p5YA'}=-0.047;
    $statpot{'p5YR'}=-0.084;
    $statpot{'p5YN'}=0.048;
    $statpot{'p5YD'}=0.164;
    $statpot{'p5YC'}=0.119;
    $statpot{'p5YQ'}=-0.105;
    $statpot{'p5YE'}=0.120;
    $statpot{'p5YG'}=0.227;
    $statpot{'p5YH'}=0.040;
    $statpot{'p5YI'}=-0.119;
    $statpot{'p5YL'}=-0.150;
    $statpot{'p5YK'}=0.018;
    $statpot{'p5YM'}=-0.041;
    $statpot{'p5YF'}=-0.193;
    $statpot{'p5YP'}=0.174;
    $statpot{'p5YS'}=0.087;
    $statpot{'p5YT'}=0.329;
    $statpot{'p5YW'}=-0.213;
    $statpot{'p5YY'}=0.024;
    $statpot{'p5YV'}=-0.126;
    $statpot{'p5VA'}=-0.354;
    $statpot{'p5VR'}=0.037;
    $statpot{'p5VN'}=0.114;
    $statpot{'p5VD'}=0.315;
    $statpot{'p5VC'}=-0.285;
    $statpot{'p5VQ'}=0.120;
    $statpot{'p5VE'}=0.063;
    $statpot{'p5VG'}=0.541;
    $statpot{'p5VH'}=0.207;
    $statpot{'p5VI'}=-0.401;
    $statpot{'p5VL'}=-0.316;
    $statpot{'p5VK'}=0.141;
    $statpot{'p5VM'}=-0.341;
    $statpot{'p5VF'}=-0.239;
    $statpot{'p5VP'}=0.291;
    $statpot{'p5VS'}=0.103;
    $statpot{'p5VT'}=0.024;
    $statpot{'p5VW'}=-0.208;
    $statpot{'p5VY'}=-0.126;
    $statpot{'p5VV'}=-0.488;
    $statpot{'f5AA'}=0.353;
    $statpot{'f5AR'}=0.542;
    $statpot{'f5AN'}=0.287;
    $statpot{'f5AD'}=0.680;
    $statpot{'f5AC'}=-0.245;
    $statpot{'f5AQ'}=0.568;
    $statpot{'f5AE'}=0.696;
    $statpot{'f5AG'}=0.172;
    $statpot{'f5AH'}=0.203;
    $statpot{'f5AI'}=-0.868;
    $statpot{'f5AL'}=-0.761;
    $statpot{'f5AK'}=0.715;
    $statpot{'f5AM'}=-0.177;
    $statpot{'f5AF'}=-0.232;
    $statpot{'f5AP'}=0.286;
    $statpot{'f5AS'}=0.415;
    $statpot{'f5AT'}=-0.109;
    $statpot{'f5AW'}=-0.280;
    $statpot{'f5AY'}=-0.085;
    $statpot{'f5AV'}=-0.785;
    $statpot{'f5RA'}=0.625;
    $statpot{'f5RR'}=1.122;
    $statpot{'f5RN'}=0.491;
    $statpot{'f5RD'}=0.347;
    $statpot{'f5RC'}=-0.090;
    $statpot{'f5RQ'}=0.763;
    $statpot{'f5RE'}=0.642;
    $statpot{'f5RG'}=0.651;
    $statpot{'f5RH'}=0.354;
    $statpot{'f5RI'}=-0.125;
    $statpot{'f5RL'}=0.056;
    $statpot{'f5RK'}=1.290;
    $statpot{'f5RM'}=0.448;
    $statpot{'f5RF'}=0.702;
    $statpot{'f5RP'}=0.401;
    $statpot{'f5RS'}=0.677;
    $statpot{'f5RT'}=0.530;
    $statpot{'f5RW'}=-0.236;
    $statpot{'f5RY'}=0.054;
    $statpot{'f5RV'}=0.161;
    $statpot{'f5NA'}=0.270;
    $statpot{'f5NR'}=0.391;
    $statpot{'f5NN'}=0.135;
    $statpot{'f5ND'}=0.197;
    $statpot{'f5NC'}=-0.168;
    $statpot{'f5NQ'}=0.078;
    $statpot{'f5NE'}=0.543;
    $statpot{'f5NG'}=0.295;
    $statpot{'f5NH'}=0.024;
    $statpot{'f5NI'}=0.015;
    $statpot{'f5NL'}=-0.033;
    $statpot{'f5NK'}=0.698;
    $statpot{'f5NM'}=0.149;
    $statpot{'f5NF'}=0.337;
    $statpot{'f5NP'}=0.091;
    $statpot{'f5NS'}=0.201;
    $statpot{'f5NT'}=-0.121;
    $statpot{'f5NW'}=0.220;
    $statpot{'f5NY'}=0.313;
    $statpot{'f5NV'}=-0.056;
    $statpot{'f5DA'}=0.833;
    $statpot{'f5DR'}=0.283;
    $statpot{'f5DN'}=0.173;
    $statpot{'f5DD'}=0.818;
    $statpot{'f5DC'}=0.165;
    $statpot{'f5DQ'}=0.595;
    $statpot{'f5DE'}=1.500;
    $statpot{'f5DG'}=0.602;
    $statpot{'f5DH'}=-0.082;
    $statpot{'f5DI'}=0.358;
    $statpot{'f5DL'}=0.428;
    $statpot{'f5DK'}=0.449;
    $statpot{'f5DM'}=0.443;
    $statpot{'f5DF'}=0.439;
    $statpot{'f5DP'}=0.615;
    $statpot{'f5DS'}=0.070;
    $statpot{'f5DT'}=0.049;
    $statpot{'f5DW'}=0.936;
    $statpot{'f5DY'}=0.508;
    $statpot{'f5DV'}=0.397;
    $statpot{'f5CA'}=-0.301;
    $statpot{'f5CR'}=0.203;
    $statpot{'f5CN'}=-0.188;
    $statpot{'f5CD'}=0.167;
    $statpot{'f5CC'}=-1.170;
    $statpot{'f5CQ'}=-0.153;
    $statpot{'f5CE'}=0.783;
    $statpot{'f5CG'}=-0.035;
    $statpot{'f5CH'}=-0.316;
    $statpot{'f5CI'}=-0.884;
    $statpot{'f5CL'}=-0.612;
    $statpot{'f5CK'}=0.460;
    $statpot{'f5CM'}=-0.566;
    $statpot{'f5CF'}=-0.661;
    $statpot{'f5CP'}=-0.650;
    $statpot{'f5CS'}=-0.356;
    $statpot{'f5CT'}=-0.346;
    $statpot{'f5CW'}=0.230;
    $statpot{'f5CY'}=-0.647;
    $statpot{'f5CV'}=-0.812;
    $statpot{'f5QA'}=0.618;
    $statpot{'f5QR'}=0.745;
    $statpot{'f5QN'}=0.057;
    $statpot{'f5QD'}=0.581;
    $statpot{'f5QC'}=-0.153;
    $statpot{'f5QQ'}=0.613;
    $statpot{'f5QE'}=1.334;
    $statpot{'f5QG'}=0.395;
    $statpot{'f5QH'}=0.201;
    $statpot{'f5QI'}=0.016;
    $statpot{'f5QL'}=0.189;
    $statpot{'f5QK'}=0.995;
    $statpot{'f5QM'}=0.645;
    $statpot{'f5QF'}=0.036;
    $statpot{'f5QP'}=0.044;
    $statpot{'f5QS'}=0.567;
    $statpot{'f5QT'}=0.121;
    $statpot{'f5QW'}=0.563;
    $statpot{'f5QY'}=0.232;
    $statpot{'f5QV'}=-0.098;
    $statpot{'f5EA'}=0.883;
    $statpot{'f5ER'}=0.744;
    $statpot{'f5EN'}=0.674;
    $statpot{'f5ED'}=1.621;
    $statpot{'f5EC'}=0.824;
    $statpot{'f5EQ'}=1.306;
    $statpot{'f5EE'}=1.782;
    $statpot{'f5EG'}=1.119;
    $statpot{'f5EH'}=0.673;
    $statpot{'f5EI'}=0.314;
    $statpot{'f5EL'}=0.347;
    $statpot{'f5EK'}=0.969;
    $statpot{'f5EM'}=0.423;
    $statpot{'f5EF'}=0.873;
    $statpot{'f5EP'}=0.926;
    $statpot{'f5ES'}=0.518;
    $statpot{'f5ET'}=0.436;
    $statpot{'f5EW'}=0.863;
    $statpot{'f5EY'}=0.803;
    $statpot{'f5EV'}=0.272;
    $statpot{'f5GA'}=0.228;
    $statpot{'f5GR'}=0.521;
    $statpot{'f5GN'}=0.276;
    $statpot{'f5GD'}=0.618;
    $statpot{'f5GC'}=-0.006;
    $statpot{'f5GQ'}=0.336;
    $statpot{'f5GE'}=0.981;
    $statpot{'f5GG'}=0.176;
    $statpot{'f5GH'}=0.070;
    $statpot{'f5GI'}=0.176;
    $statpot{'f5GL'}=0.187;
    $statpot{'f5GK'}=0.780;
    $statpot{'f5GM'}=0.047;
    $statpot{'f5GF'}=-0.033;
    $statpot{'f5GP'}=0.340;
    $statpot{'f5GS'}=0.235;
    $statpot{'f5GT'}=0.195;
    $statpot{'f5GW'}=0.133;
    $statpot{'f5GY'}=-0.052;
    $statpot{'f5GV'}=0.227;
    $statpot{'f5HA'}=0.276;
    $statpot{'f5HR'}=0.171;
    $statpot{'f5HN'}=-0.111;
    $statpot{'f5HD'}=0.057;
    $statpot{'f5HC'}=-0.282;
    $statpot{'f5HQ'}=0.295;
    $statpot{'f5HE'}=0.653;
    $statpot{'f5HG'}=0.143;
    $statpot{'f5HH'}=0.843;
    $statpot{'f5HI'}=-0.292;
    $statpot{'f5HL'}=-0.103;
    $statpot{'f5HK'}=0.727;
    $statpot{'f5HM'}=-0.289;
    $statpot{'f5HF'}=0.210;
    $statpot{'f5HP'}=0.469;
    $statpot{'f5HS'}=-0.004;
    $statpot{'f5HT'}=0.117;
    $statpot{'f5HW'}=0.117;
    $statpot{'f5HY'}=0.067;
    $statpot{'f5HV'}=-0.224;
    $statpot{'f5IA'}=-0.883;
    $statpot{'f5IR'}=-0.176;
    $statpot{'f5IN'}=0.015;
    $statpot{'f5ID'}=0.336;
    $statpot{'f5IC'}=-0.878;
    $statpot{'f5IQ'}=0.009;
    $statpot{'f5IE'}=0.240;
    $statpot{'f5IG'}=0.230;
    $statpot{'f5IH'}=-0.320;
    $statpot{'f5II'}=-0.963;
    $statpot{'f5IL'}=-0.828;
    $statpot{'f5IK'}=0.135;
    $statpot{'f5IM'}=-0.748;
    $statpot{'f5IF'}=-0.810;
    $statpot{'f5IP'}=-0.298;
    $statpot{'f5IS'}=-0.272;
    $statpot{'f5IT'}=-0.387;
    $statpot{'f5IW'}=-0.781;
    $statpot{'f5IY'}=-0.841;
    $statpot{'f5IV'}=-1.021;
    $statpot{'f5LA'}=-0.732;
    $statpot{'f5LR'}=0.090;
    $statpot{'f5LN'}=0.047;
    $statpot{'f5LD'}=0.508;
    $statpot{'f5LC'}=-0.559;
    $statpot{'f5LQ'}=0.210;
    $statpot{'f5LE'}=0.344;
    $statpot{'f5LG'}=0.281;
    $statpot{'f5LH'}=-0.098;
    $statpot{'f5LI'}=-0.819;
    $statpot{'f5LL'}=-0.540;
    $statpot{'f5LK'}=0.498;
    $statpot{'f5LM'}=-0.327;
    $statpot{'f5LF'}=-0.667;
    $statpot{'f5LP'}=-0.201;
    $statpot{'f5LS'}=-0.037;
    $statpot{'f5LT'}=-0.099;
    $statpot{'f5LW'}=-0.453;
    $statpot{'f5LY'}=-0.562;
    $statpot{'f5LV'}=-0.743;
    $statpot{'f5KA'}=0.787;
    $statpot{'f5KR'}=1.187;
    $statpot{'f5KN'}=0.548;
    $statpot{'f5KD'}=0.356;
    $statpot{'f5KC'}=0.729;
    $statpot{'f5KQ'}=0.954;
    $statpot{'f5KE'}=0.879;
    $statpot{'f5KG'}=0.967;
    $statpot{'f5KH'}=0.699;
    $statpot{'f5KI'}=0.141;
    $statpot{'f5KL'}=0.490;
    $statpot{'f5KK'}=1.278;
    $statpot{'f5KM'}=0.370;
    $statpot{'f5KF'}=0.466;
    $statpot{'f5KP'}=0.848;
    $statpot{'f5KS'}=0.814;
    $statpot{'f5KT'}=0.402;
    $statpot{'f5KW'}=0.748;
    $statpot{'f5KY'}=0.191;
    $statpot{'f5KV'}=0.416;
    $statpot{'f5MA'}=-0.171;
    $statpot{'f5MR'}=0.493;
    $statpot{'f5MN'}=0.248;
    $statpot{'f5MD'}=0.542;
    $statpot{'f5MC'}=-0.567;
    $statpot{'f5MQ'}=0.490;
    $statpot{'f5ME'}=0.437;
    $statpot{'f5MG'}=0.177;
    $statpot{'f5MH'}=-0.268;
    $statpot{'f5MI'}=-0.760;
    $statpot{'f5ML'}=-0.309;
    $statpot{'f5MK'}=0.275;
    $statpot{'f5MM'}=-0.138;
    $statpot{'f5MF'}=-0.597;
    $statpot{'f5MP'}=-0.289;
    $statpot{'f5MS'}=0.097;
    $statpot{'f5MT'}=0.076;
    $statpot{'f5MW'}=-0.411;
    $statpot{'f5MY'}=-0.347;
    $statpot{'f5MV'}=-0.727;
    $statpot{'f5FA'}=-0.143;
    $statpot{'f5FR'}=0.635;
    $statpot{'f5FN'}=0.362;
    $statpot{'f5FD'}=0.428;
    $statpot{'f5FC'}=-0.628;
    $statpot{'f5FQ'}=0.070;
    $statpot{'f5FE'}=0.774;
    $statpot{'f5FG'}=0.071;
    $statpot{'f5FH'}=0.164;
    $statpot{'f5FI'}=-0.786;
    $statpot{'f5FL'}=-0.644;
    $statpot{'f5FK'}=0.511;
    $statpot{'f5FM'}=-0.524;
    $statpot{'f5FF'}=-0.510;
    $statpot{'f5FP'}=-0.384;
    $statpot{'f5FS'}=0.372;
    $statpot{'f5FT'}=0.025;
    $statpot{'f5FW'}=-0.546;
    $statpot{'f5FY'}=-0.301;
    $statpot{'f5FV'}=-0.615;
    $statpot{'f5PA'}=0.328;
    $statpot{'f5PR'}=0.459;
    $statpot{'f5PN'}=0.189;
    $statpot{'f5PD'}=0.705;
    $statpot{'f5PC'}=-0.556;
    $statpot{'f5PQ'}=-0.042;
    $statpot{'f5PE'}=0.833;
    $statpot{'f5PG'}=0.416;
    $statpot{'f5PH'}=0.449;
    $statpot{'f5PI'}=-0.343;
    $statpot{'f5PL'}=-0.276;
    $statpot{'f5PK'}=0.861;
    $statpot{'f5PM'}=-0.318;
    $statpot{'f5PF'}=-0.396;
    $statpot{'f5PP'}=-0.176;
    $statpot{'f5PS'}=0.153;
    $statpot{'f5PT'}=-0.070;
    $statpot{'f5PW'}=-0.414;
    $statpot{'f5PY'}=-0.222;
    $statpot{'f5PV'}=-0.438;
    $statpot{'f5SA'}=0.415;
    $statpot{'f5SR'}=0.557;
    $statpot{'f5SN'}=0.194;
    $statpot{'f5SD'}=0.041;
    $statpot{'f5SC'}=-0.435;
    $statpot{'f5SQ'}=0.566;
    $statpot{'f5SE'}=0.362;
    $statpot{'f5SG'}=0.157;
    $statpot{'f5SH'}=-0.048;
    $statpot{'f5SI'}=-0.333;
    $statpot{'f5SL'}=-0.052;
    $statpot{'f5SK'}=0.782;
    $statpot{'f5SM'}=0.150;
    $statpot{'f5SF'}=0.257;
    $statpot{'f5SP'}=0.077;
    $statpot{'f5SS'}=0.483;
    $statpot{'f5ST'}=0.231;
    $statpot{'f5SW'}=0.398;
    $statpot{'f5SY'}=0.143;
    $statpot{'f5SV'}=-0.126;
    $statpot{'f5TA'}=-0.149;
    $statpot{'f5TR'}=0.455;
    $statpot{'f5TN'}=-0.158;
    $statpot{'f5TD'}=0.045;
    $statpot{'f5TC'}=-0.248;
    $statpot{'f5TQ'}=0.137;
    $statpot{'f5TE'}=0.347;
    $statpot{'f5TG'}=0.308;
    $statpot{'f5TH'}=0.104;
    $statpot{'f5TI'}=-0.407;
    $statpot{'f5TL'}=-0.117;
    $statpot{'f5TK'}=0.439;
    $statpot{'f5TM'}=0.115;
    $statpot{'f5TF'}=-0.097;
    $statpot{'f5TP'}=-0.106;
    $statpot{'f5TS'}=0.285;
    $statpot{'f5TT'}=0.071;
    $statpot{'f5TW'}=-0.133;
    $statpot{'f5TY'}=-0.002;
    $statpot{'f5TV'}=-0.455;
    $statpot{'f5WA'}=-0.240;
    $statpot{'f5WR'}=-0.235;
    $statpot{'f5WN'}=0.317;
    $statpot{'f5WD'}=0.711;
    $statpot{'f5WC'}=0.544;
    $statpot{'f5WQ'}=0.615;
    $statpot{'f5WE'}=0.782;
    $statpot{'f5WG'}=0.116;
    $statpot{'f5WH'}=0.055;
    $statpot{'f5WI'}=-0.753;
    $statpot{'f5WL'}=-0.484;
    $statpot{'f5WK'}=0.792;
    $statpot{'f5WM'}=-0.508;
    $statpot{'f5WF'}=-0.562;
    $statpot{'f5WP'}=-0.319;
    $statpot{'f5WS'}=0.426;
    $statpot{'f5WT'}=-0.131;
    $statpot{'f5WW'}=0.563;
    $statpot{'f5WY'}=-0.171;
    $statpot{'f5WV'}=-0.188;
    $statpot{'f5YA'}=-0.052;
    $statpot{'f5YR'}=0.104;
    $statpot{'f5YN'}=0.428;
    $statpot{'f5YD'}=0.525;
    $statpot{'f5YC'}=-0.564;
    $statpot{'f5YQ'}=0.218;
    $statpot{'f5YE'}=0.882;
    $statpot{'f5YG'}=0.067;
    $statpot{'f5YH'}=0.114;
    $statpot{'f5YI'}=-0.894;
    $statpot{'f5YL'}=-0.561;
    $statpot{'f5YK'}=0.249;
    $statpot{'f5YM'}=-0.306;
    $statpot{'f5YF'}=-0.405;
    $statpot{'f5YP'}=-0.266;
    $statpot{'f5YS'}=0.126;
    $statpot{'f5YT'}=0.070;
    $statpot{'f5YW'}=-0.286;
    $statpot{'f5YY'}=-0.341;
    $statpot{'f5YV'}=-0.643;
    $statpot{'f5VA'}=-0.808;
    $statpot{'f5VR'}=0.093;
    $statpot{'f5VN'}=-0.006;
    $statpot{'f5VD'}=0.376;
    $statpot{'f5VC'}=-0.853;
    $statpot{'f5VQ'}=-0.149;
    $statpot{'f5VE'}=0.193;
    $statpot{'f5VG'}=0.325;
    $statpot{'f5VH'}=-0.225;
    $statpot{'f5VI'}=-1.040;
    $statpot{'f5VL'}=-0.777;
    $statpot{'f5VK'}=0.265;
    $statpot{'f5VM'}=-0.745;
    $statpot{'f5VF'}=-0.655;
    $statpot{'f5VP'}=-0.484;
    $statpot{'f5VS'}=-0.126;
    $statpot{'f5VT'}=-0.458;
    $statpot{'f5VW'}=-0.228;
    $statpot{'f5VY'}=-0.618;
    $statpot{'f5VV'}=-1.222;
    $statpot{'a5AA'}=0.461;
    $statpot{'a5AR'}=0.244;
    $statpot{'a5AN'}=0.167;
    $statpot{'a5AD'}=0.106;
    $statpot{'a5AC'}=-0.083;
    $statpot{'a5AQ'}=0.128;
    $statpot{'a5AE'}=0.333;
    $statpot{'a5AG'}=-0.006;
    $statpot{'a5AH'}=0.154;
    $statpot{'a5AI'}=-0.020;
    $statpot{'a5AL'}=0.238;
    $statpot{'a5AK'}=0.133;
    $statpot{'a5AM'}=0.150;
    $statpot{'a5AF'}=0.101;
    $statpot{'a5AP'}=-0.058;
    $statpot{'a5AS'}=-0.020;
    $statpot{'a5AT'}=-0.019;
    $statpot{'a5AW'}=0.083;
    $statpot{'a5AY'}=0.134;
    $statpot{'a5AV'}=-0.104;
    $statpot{'a5RA'}=0.210;
    $statpot{'a5RR'}=0.296;
    $statpot{'a5RN'}=0.059;
    $statpot{'a5RD'}=0.173;
    $statpot{'a5RC'}=-0.024;
    $statpot{'a5RQ'}=0.236;
    $statpot{'a5RE'}=0.431;
    $statpot{'a5RG'}=-0.035;
    $statpot{'a5RH'}=-0.015;
    $statpot{'a5RI'}=-0.421;
    $statpot{'a5RL'}=-0.023;
    $statpot{'a5RK'}=0.176;
    $statpot{'a5RM'}=0.075;
    $statpot{'a5RF'}=-0.071;
    $statpot{'a5RP'}=0.031;
    $statpot{'a5RS'}=0.095;
    $statpot{'a5RT'}=0.052;
    $statpot{'a5RW'}=-0.017;
    $statpot{'a5RY'}=-0.153;
    $statpot{'a5RV'}=-0.267;
    $statpot{'a5NA'}=0.176;
    $statpot{'a5NR'}=0.094;
    $statpot{'a5NN'}=-0.004;
    $statpot{'a5ND'}=0.442;
    $statpot{'a5NC'}=-0.142;
    $statpot{'a5NQ'}=0.300;
    $statpot{'a5NE'}=0.616;
    $statpot{'a5NG'}=0.171;
    $statpot{'a5NH'}=0.135;
    $statpot{'a5NI'}=-0.151;
    $statpot{'a5NL'}=-0.043;
    $statpot{'a5NK'}=0.141;
    $statpot{'a5NM'}=-0.032;
    $statpot{'a5NF'}=-0.160;
    $statpot{'a5NP'}=-0.112;
    $statpot{'a5NS'}=0.221;
    $statpot{'a5NT'}=-0.011;
    $statpot{'a5NW'}=0.103;
    $statpot{'a5NY'}=-0.154;
    $statpot{'a5NV'}=-0.161;
    $statpot{'a5DA'}=0.062;
    $statpot{'a5DR'}=0.203;
    $statpot{'a5DN'}=0.457;
    $statpot{'a5DD'}=0.446;
    $statpot{'a5DC'}=-0.093;
    $statpot{'a5DQ'}=0.381;
    $statpot{'a5DE'}=0.296;
    $statpot{'a5DG'}=0.139;
    $statpot{'a5DH'}=0.208;
    $statpot{'a5DI'}=-0.161;
    $statpot{'a5DL'}=-0.023;
    $statpot{'a5DK'}=0.217;
    $statpot{'a5DM'}=0.066;
    $statpot{'a5DF'}=-0.301;
    $statpot{'a5DP'}=-0.281;
    $statpot{'a5DS'}=0.042;
    $statpot{'a5DT'}=0.130;
    $statpot{'a5DW'}=0.133;
    $statpot{'a5DY'}=-0.213;
    $statpot{'a5DV'}=-0.008;
    $statpot{'a5CA'}=-0.046;
    $statpot{'a5CR'}=-0.151;
    $statpot{'a5CN'}=-0.131;
    $statpot{'a5CD'}=-0.093;
    $statpot{'a5CC'}=0.382;
    $statpot{'a5CQ'}=-0.111;
    $statpot{'a5CE'}=-0.157;
    $statpot{'a5CG'}=-0.315;
    $statpot{'a5CH'}=-0.569;
    $statpot{'a5CI'}=-0.022;
    $statpot{'a5CL'}=-0.153;
    $statpot{'a5CK'}=0.335;
    $statpot{'a5CM'}=-0.166;
    $statpot{'a5CF'}=-0.049;
    $statpot{'a5CP'}=-0.488;
    $statpot{'a5CS'}=-0.497;
    $statpot{'a5CT'}=-0.309;
    $statpot{'a5CW'}=-0.124;
    $statpot{'a5CY'}=-0.160;
    $statpot{'a5CV'}=-0.359;
    $statpot{'a5QA'}=0.110;
    $statpot{'a5QR'}=0.242;
    $statpot{'a5QN'}=0.313;
    $statpot{'a5QD'}=0.387;
    $statpot{'a5QC'}=-0.111;
    $statpot{'a5QQ'}=0.246;
    $statpot{'a5QE'}=0.393;
    $statpot{'a5QG'}=0.071;
    $statpot{'a5QH'}=-0.018;
    $statpot{'a5QI'}=0.044;
    $statpot{'a5QL'}=-0.042;
    $statpot{'a5QK'}=0.250;
    $statpot{'a5QM'}=-0.071;
    $statpot{'a5QF'}=-0.083;
    $statpot{'a5QP'}=-0.115;
    $statpot{'a5QS'}=0.225;
    $statpot{'a5QT'}=0.131;
    $statpot{'a5QW'}=-0.144;
    $statpot{'a5QY'}=-0.166;
    $statpot{'a5QV'}=-0.115;
    $statpot{'a5EA'}=0.266;
    $statpot{'a5ER'}=0.388;
    $statpot{'a5EN'}=0.550;
    $statpot{'a5ED'}=0.278;
    $statpot{'a5EC'}=-0.165;
    $statpot{'a5EQ'}=0.400;
    $statpot{'a5EE'}=0.341;
    $statpot{'a5EG'}=0.314;
    $statpot{'a5EH'}=0.469;
    $statpot{'a5EI'}=0.042;
    $statpot{'a5EL'}=0.034;
    $statpot{'a5EK'}=0.279;
    $statpot{'a5EM'}=-0.128;
    $statpot{'a5EF'}=0.053;
    $statpot{'a5EP'}=0.169;
    $statpot{'a5ES'}=0.323;
    $statpot{'a5ET'}=0.163;
    $statpot{'a5EW'}=-0.163;
    $statpot{'a5EY'}=0.066;
    $statpot{'a5EV'}=-0.130;
    $statpot{'a5GA'}=-0.031;
    $statpot{'a5GR'}=0.001;
    $statpot{'a5GN'}=0.179;
    $statpot{'a5GD'}=0.133;
    $statpot{'a5GC'}=-0.326;
    $statpot{'a5GQ'}=0.093;
    $statpot{'a5GE'}=0.349;
    $statpot{'a5GG'}=0.243;
    $statpot{'a5GH'}=0.073;
    $statpot{'a5GI'}=-0.089;
    $statpot{'a5GL'}=0.044;
    $statpot{'a5GK'}=0.220;
    $statpot{'a5GM'}=-0.150;
    $statpot{'a5GF'}=-0.222;
    $statpot{'a5GP'}=0.688;
    $statpot{'a5GS'}=-0.072;
    $statpot{'a5GT'}=-0.175;
    $statpot{'a5GW'}=-0.206;
    $statpot{'a5GY'}=-0.113;
    $statpot{'a5GV'}=0.037;
    $statpot{'a5HA'}=0.117;
    $statpot{'a5HR'}=0.063;
    $statpot{'a5HN'}=0.222;
    $statpot{'a5HD'}=0.121;
    $statpot{'a5HC'}=-0.582;
    $statpot{'a5HQ'}=-0.055;
    $statpot{'a5HE'}=0.478;
    $statpot{'a5HG'}=0.037;
    $statpot{'a5HH'}=-0.292;
    $statpot{'a5HI'}=-0.244;
    $statpot{'a5HL'}=-0.079;
    $statpot{'a5HK'}=0.085;
    $statpot{'a5HM'}=-0.157;
    $statpot{'a5HF'}=-0.267;
    $statpot{'a5HP'}=-0.363;
    $statpot{'a5HS'}=-0.201;
    $statpot{'a5HT'}=-0.188;
    $statpot{'a5HW'}=0.125;
    $statpot{'a5HY'}=-0.188;
    $statpot{'a5HV'}=-0.119;
    $statpot{'a5IA'}=-0.000;
    $statpot{'a5IR'}=-0.400;
    $statpot{'a5IN'}=-0.150;
    $statpot{'a5ID'}=-0.154;
    $statpot{'a5IC'}=-0.031;
    $statpot{'a5IQ'}=0.048;
    $statpot{'a5IE'}=0.075;
    $statpot{'a5IG'}=-0.110;
    $statpot{'a5IH'}=-0.229;
    $statpot{'a5II'}=-0.109;
    $statpot{'a5IL'}=0.081;
    $statpot{'a5IK'}=-0.163;
    $statpot{'a5IM'}=-0.026;
    $statpot{'a5IF'}=-0.077;
    $statpot{'a5IP'}=-0.463;
    $statpot{'a5IS'}=-0.420;
    $statpot{'a5IT'}=-0.316;
    $statpot{'a5IW'}=0.012;
    $statpot{'a5IY'}=-0.332;
    $statpot{'a5IV'}=-0.331;
    $statpot{'a5LA'}=0.192;
    $statpot{'a5LR'}=-0.040;
    $statpot{'a5LN'}=-0.082;
    $statpot{'a5LD'}=-0.048;
    $statpot{'a5LC'}=-0.195;
    $statpot{'a5LQ'}=-0.051;
    $statpot{'a5LE'}=0.035;
    $statpot{'a5LG'}=0.004;
    $statpot{'a5LH'}=-0.082;
    $statpot{'a5LI'}=0.069;
    $statpot{'a5LL'}=0.193;
    $statpot{'a5LK'}=-0.112;
    $statpot{'a5LM'}=0.091;
    $statpot{'a5LF'}=0.046;
    $statpot{'a5LP'}=-0.290;
    $statpot{'a5LS'}=-0.215;
    $statpot{'a5LT'}=-0.316;
    $statpot{'a5LW'}=0.147;
    $statpot{'a5LY'}=-0.019;
    $statpot{'a5LV'}=-0.210;
    $statpot{'a5KA'}=0.111;
    $statpot{'a5KR'}=0.195;
    $statpot{'a5KN'}=0.189;
    $statpot{'a5KD'}=0.258;
    $statpot{'a5KC'}=0.236;
    $statpot{'a5KQ'}=0.261;
    $statpot{'a5KE'}=0.304;
    $statpot{'a5KG'}=0.172;
    $statpot{'a5KH'}=0.094;
    $statpot{'a5KI'}=-0.165;
    $statpot{'a5KL'}=-0.110;
    $statpot{'a5KK'}=0.403;
    $statpot{'a5KM'}=-0.109;
    $statpot{'a5KF'}=-0.089;
    $statpot{'a5KP'}=-0.119;
    $statpot{'a5KS'}=0.193;
    $statpot{'a5KT'}=0.207;
    $statpot{'a5KW'}=-0.004;
    $statpot{'a5KY'}=0.030;
    $statpot{'a5KV'}=-0.299;
    $statpot{'a5MA'}=0.145;
    $statpot{'a5MR'}=0.058;
    $statpot{'a5MN'}=-0.072;
    $statpot{'a5MD'}=0.031;
    $statpot{'a5MC'}=-0.165;
    $statpot{'a5MQ'}=-0.025;
    $statpot{'a5ME'}=-0.132;
    $statpot{'a5MG'}=-0.202;
    $statpot{'a5MH'}=-0.170;
    $statpot{'a5MI'}=-0.013;
    $statpot{'a5ML'}=0.076;
    $statpot{'a5MK'}=-0.075;
    $statpot{'a5MM'}=0.291;
    $statpot{'a5MF'}=0.080;
    $statpot{'a5MP'}=-0.130;
    $statpot{'a5MS'}=-0.076;
    $statpot{'a5MT'}=-0.177;
    $statpot{'a5MW'}=0.157;
    $statpot{'a5MY'}=0.454;
    $statpot{'a5MV'}=-0.076;
    $statpot{'a5FA'}=0.038;
    $statpot{'a5FR'}=-0.054;
    $statpot{'a5FN'}=-0.166;
    $statpot{'a5FD'}=-0.298;
    $statpot{'a5FC'}=-0.077;
    $statpot{'a5FQ'}=-0.098;
    $statpot{'a5FE'}=0.077;
    $statpot{'a5FG'}=-0.262;
    $statpot{'a5FH'}=-0.252;
    $statpot{'a5FI'}=-0.103;
    $statpot{'a5FL'}=0.022;
    $statpot{'a5FK'}=-0.102;
    $statpot{'a5FM'}=0.011;
    $statpot{'a5FF'}=0.062;
    $statpot{'a5FP'}=-0.275;
    $statpot{'a5FS'}=-0.412;
    $statpot{'a5FT'}=-0.427;
    $statpot{'a5FW'}=0.133;
    $statpot{'a5FY'}=-0.102;
    $statpot{'a5FV'}=-0.239;
    $statpot{'a5PA'}=-0.075;
    $statpot{'a5PR'}=0.010;
    $statpot{'a5PN'}=-0.149;
    $statpot{'a5PD'}=-0.299;
    $statpot{'a5PC'}=-0.539;
    $statpot{'a5PQ'}=-0.074;
    $statpot{'a5PE'}=0.193;
    $statpot{'a5PG'}=0.635;
    $statpot{'a5PH'}=-0.359;
    $statpot{'a5PI'}=-0.443;
    $statpot{'a5PL'}=-0.251;
    $statpot{'a5PK'}=-0.121;
    $statpot{'a5PM'}=-0.111;
    $statpot{'a5PF'}=-0.268;
    $statpot{'a5PP'}=-0.096;
    $statpot{'a5PS'}=-0.271;
    $statpot{'a5PT'}=-0.258;
    $statpot{'a5PW'}=0.107;
    $statpot{'a5PY'}=-0.115;
    $statpot{'a5PV'}=-0.508;
    $statpot{'a5SA'}=-0.020;
    $statpot{'a5SR'}=0.133;
    $statpot{'a5SN'}=0.225;
    $statpot{'a5SD'}=0.056;
    $statpot{'a5SC'}=-0.462;
    $statpot{'a5SQ'}=0.225;
    $statpot{'a5SE'}=0.399;
    $statpot{'a5SG'}=-0.041;
    $statpot{'a5SH'}=-0.182;
    $statpot{'a5SI'}=-0.391;
    $statpot{'a5SL'}=-0.208;
    $statpot{'a5SK'}=0.203;
    $statpot{'a5SM'}=-0.099;
    $statpot{'a5SF'}=-0.384;
    $statpot{'a5SP'}=-0.244;
    $statpot{'a5SS'}=-0.093;
    $statpot{'a5ST'}=-0.112;
    $statpot{'a5SW'}=-0.299;
    $statpot{'a5SY'}=-0.313;
    $statpot{'a5SV'}=-0.112;
    $statpot{'a5TA'}=0.006;
    $statpot{'a5TR'}=0.078;
    $statpot{'a5TN'}=0.009;
    $statpot{'a5TD'}=0.133;
    $statpot{'a5TC'}=-0.355;
    $statpot{'a5TQ'}=0.123;
    $statpot{'a5TE'}=0.202;
    $statpot{'a5TG'}=-0.210;
    $statpot{'a5TH'}=-0.184;
    $statpot{'a5TI'}=-0.305;
    $statpot{'a5TL'}=-0.309;
    $statpot{'a5TK'}=0.191;
    $statpot{'a5TM'}=-0.193;
    $statpot{'a5TF'}=-0.385;
    $statpot{'a5TP'}=-0.243;
    $statpot{'a5TS'}=-0.130;
    $statpot{'a5TT'}=-0.193;
    $statpot{'a5TW'}=-0.457;
    $statpot{'a5TY'}=-0.328;
    $statpot{'a5TV'}=-0.528;
    $statpot{'a5WA'}=0.054;
    $statpot{'a5WR'}=-0.017;
    $statpot{'a5WN'}=0.065;
    $statpot{'a5WD'}=0.192;
    $statpot{'a5WC'}=-0.210;
    $statpot{'a5WQ'}=-0.156;
    $statpot{'a5WE'}=-0.148;
    $statpot{'a5WG'}=-0.200;
    $statpot{'a5WH'}=0.158;
    $statpot{'a5WI'}=-0.019;
    $statpot{'a5WL'}=0.177;
    $statpot{'a5WK'}=-0.014;
    $statpot{'a5WM'}=0.253;
    $statpot{'a5WF'}=0.149;
    $statpot{'a5WP'}=0.035;
    $statpot{'a5WS'}=-0.306;
    $statpot{'a5WT'}=-0.458;
    $statpot{'a5WW'}=0.570;
    $statpot{'a5WY'}=-0.014;
    $statpot{'a5WV'}=-0.245;
    $statpot{'a5YA'}=0.112;
    $statpot{'a5YR'}=-0.173;
    $statpot{'a5YN'}=-0.188;
    $statpot{'a5YD'}=-0.218;
    $statpot{'a5YC'}=-0.222;
    $statpot{'a5YQ'}=-0.161;
    $statpot{'a5YE'}=0.047;
    $statpot{'a5YG'}=-0.164;
    $statpot{'a5YH'}=-0.206;
    $statpot{'a5YI'}=-0.283;
    $statpot{'a5YL'}=-0.019;
    $statpot{'a5YK'}=0.005;
    $statpot{'a5YM'}=0.406;
    $statpot{'a5YF'}=-0.033;
    $statpot{'a5YP'}=-0.088;
    $statpot{'a5YS'}=-0.307;
    $statpot{'a5YT'}=-0.353;
    $statpot{'a5YW'}=0.058;
    $statpot{'a5YY'}=-0.088;
    $statpot{'a5YV'}=-0.360;
    $statpot{'a5VA'}=-0.076;
    $statpot{'a5VR'}=-0.242;
    $statpot{'a5VN'}=-0.183;
    $statpot{'a5VD'}=-0.001;
    $statpot{'a5VC'}=-0.326;
    $statpot{'a5VQ'}=-0.088;
    $statpot{'a5VE'}=-0.099;
    $statpot{'a5VG'}=-0.002;
    $statpot{'a5VH'}=-0.119;
    $statpot{'a5VI'}=-0.310;
    $statpot{'a5VL'}=-0.177;
    $statpot{'a5VK'}=-0.256;
    $statpot{'a5VM'}=-0.057;
    $statpot{'a5VF'}=-0.208;
    $statpot{'a5VP'}=-0.484;
    $statpot{'a5VS'}=-0.113;
    $statpot{'a5VT'}=-0.527;
    $statpot{'a5VW'}=-0.225;
    $statpot{'a5VY'}=-0.376;
    $statpot{'a5VV'}=-0.451;
    $statpot{'p6AA'}=-0.325;
    $statpot{'p6AR'}=0.035;
    $statpot{'p6AN'}=0.307;
    $statpot{'p6AD'}=0.343;
    $statpot{'p6AC'}=-0.157;
    $statpot{'p6AQ'}=0.060;
    $statpot{'p6AE'}=0.109;
    $statpot{'p6AG'}=0.205;
    $statpot{'p6AH'}=0.113;
    $statpot{'p6AI'}=-0.194;
    $statpot{'p6AL'}=-0.307;
    $statpot{'p6AK'}=0.132;
    $statpot{'p6AM'}=-0.292;
    $statpot{'p6AF'}=-0.132;
    $statpot{'p6AP'}=0.256;
    $statpot{'p6AS'}=0.125;
    $statpot{'p6AT'}=0.098;
    $statpot{'p6AW'}=0.090;
    $statpot{'p6AY'}=-0.174;
    $statpot{'p6AV'}=-0.061;
    $statpot{'p6RA'}=0.035;
    $statpot{'p6RR'}=-0.032;
    $statpot{'p6RN'}=0.054;
    $statpot{'p6RD'}=-0.200;
    $statpot{'p6RC'}=0.202;
    $statpot{'p6RQ'}=-0.121;
    $statpot{'p6RE'}=-0.341;
    $statpot{'p6RG'}=0.243;
    $statpot{'p6RH'}=0.227;
    $statpot{'p6RI'}=-0.194;
    $statpot{'p6RL'}=-0.064;
    $statpot{'p6RK'}=0.263;
    $statpot{'p6RM'}=0.140;
    $statpot{'p6RF'}=0.089;
    $statpot{'p6RP'}=0.318;
    $statpot{'p6RS'}=0.104;
    $statpot{'p6RT'}=0.131;
    $statpot{'p6RW'}=-0.195;
    $statpot{'p6RY'}=-0.111;
    $statpot{'p6RV'}=-0.017;
    $statpot{'p6NA'}=0.307;
    $statpot{'p6NR'}=0.054;
    $statpot{'p6NN'}=0.020;
    $statpot{'p6ND'}=0.225;
    $statpot{'p6NC'}=0.107;
    $statpot{'p6NQ'}=0.069;
    $statpot{'p6NE'}=0.028;
    $statpot{'p6NG'}=0.161;
    $statpot{'p6NH'}=0.203;
    $statpot{'p6NI'}=0.231;
    $statpot{'p6NL'}=0.252;
    $statpot{'p6NK'}=0.088;
    $statpot{'p6NM'}=0.096;
    $statpot{'p6NF'}=0.211;
    $statpot{'p6NP'}=0.225;
    $statpot{'p6NS'}=0.303;
    $statpot{'p6NT'}=-0.027;
    $statpot{'p6NW'}=0.254;
    $statpot{'p6NY'}=0.066;
    $statpot{'p6NV'}=0.103;
    $statpot{'p6DA'}=0.343;
    $statpot{'p6DR'}=-0.200;
    $statpot{'p6DN'}=0.225;
    $statpot{'p6DD'}=0.394;
    $statpot{'p6DC'}=0.626;
    $statpot{'p6DQ'}=0.034;
    $statpot{'p6DE'}=0.443;
    $statpot{'p6DG'}=0.447;
    $statpot{'p6DH'}=0.178;
    $statpot{'p6DI'}=0.512;
    $statpot{'p6DL'}=0.500;
    $statpot{'p6DK'}=-0.081;
    $statpot{'p6DM'}=0.343;
    $statpot{'p6DF'}=0.405;
    $statpot{'p6DP'}=0.633;
    $statpot{'p6DS'}=0.369;
    $statpot{'p6DT'}=0.518;
    $statpot{'p6DW'}=0.122;
    $statpot{'p6DY'}=0.117;
    $statpot{'p6DV'}=0.500;
    $statpot{'p6CA'}=-0.157;
    $statpot{'p6CR'}=0.202;
    $statpot{'p6CN'}=0.107;
    $statpot{'p6CD'}=0.626;
    $statpot{'p6CC'}=0.168;
    $statpot{'p6CQ'}=-0.119;
    $statpot{'p6CE'}=0.212;
    $statpot{'p6CG'}=-0.101;
    $statpot{'p6CH'}=-0.314;
    $statpot{'p6CI'}=-0.511;
    $statpot{'p6CL'}=-0.390;
    $statpot{'p6CK'}=0.552;
    $statpot{'p6CM'}=-0.461;
    $statpot{'p6CF'}=-0.099;
    $statpot{'p6CP'}=0.048;
    $statpot{'p6CS'}=0.133;
    $statpot{'p6CT'}=-0.098;
    $statpot{'p6CW'}=-0.430;
    $statpot{'p6CY'}=-0.333;
    $statpot{'p6CV'}=-0.491;
    $statpot{'p6QA'}=0.060;
    $statpot{'p6QR'}=-0.121;
    $statpot{'p6QN'}=0.069;
    $statpot{'p6QD'}=0.034;
    $statpot{'p6QC'}=-0.119;
    $statpot{'p6QQ'}=-0.143;
    $statpot{'p6QE'}=-0.090;
    $statpot{'p6QG'}=0.224;
    $statpot{'p6QH'}=0.161;
    $statpot{'p6QI'}=0.056;
    $statpot{'p6QL'}=-0.030;
    $statpot{'p6QK'}=0.041;
    $statpot{'p6QM'}=0.027;
    $statpot{'p6QF'}=0.233;
    $statpot{'p6QP'}=0.359;
    $statpot{'p6QS'}=0.064;
    $statpot{'p6QT'}=-0.003;
    $statpot{'p6QW'}=-0.291;
    $statpot{'p6QY'}=-0.049;
    $statpot{'p6QV'}=0.184;
    $statpot{'p6EA'}=0.109;
    $statpot{'p6ER'}=-0.341;
    $statpot{'p6EN'}=0.028;
    $statpot{'p6ED'}=0.443;
    $statpot{'p6EC'}=0.212;
    $statpot{'p6EQ'}=-0.090;
    $statpot{'p6EE'}=0.062;
    $statpot{'p6EG'}=0.549;
    $statpot{'p6EH'}=0.170;
    $statpot{'p6EI'}=0.215;
    $statpot{'p6EL'}=0.155;
    $statpot{'p6EK'}=-0.431;
    $statpot{'p6EM'}=0.250;
    $statpot{'p6EF'}=0.378;
    $statpot{'p6EP'}=0.380;
    $statpot{'p6ES'}=0.255;
    $statpot{'p6ET'}=0.315;
    $statpot{'p6EW'}=0.018;
    $statpot{'p6EY'}=0.212;
    $statpot{'p6EV'}=0.326;
    $statpot{'p6GA'}=0.205;
    $statpot{'p6GR'}=0.243;
    $statpot{'p6GN'}=0.161;
    $statpot{'p6GD'}=0.447;
    $statpot{'p6GC'}=-0.101;
    $statpot{'p6GQ'}=0.224;
    $statpot{'p6GE'}=0.549;
    $statpot{'p6GG'}=0.157;
    $statpot{'p6GH'}=0.205;
    $statpot{'p6GI'}=0.198;
    $statpot{'p6GL'}=0.343;
    $statpot{'p6GK'}=0.410;
    $statpot{'p6GM'}=0.192;
    $statpot{'p6GF'}=0.078;
    $statpot{'p6GP'}=0.447;
    $statpot{'p6GS'}=0.160;
    $statpot{'p6GT'}=0.089;
    $statpot{'p6GW'}=0.010;
    $statpot{'p6GY'}=0.115;
    $statpot{'p6GV'}=0.165;
    $statpot{'p6HA'}=0.113;
    $statpot{'p6HR'}=0.227;
    $statpot{'p6HN'}=0.203;
    $statpot{'p6HD'}=0.178;
    $statpot{'p6HC'}=-0.314;
    $statpot{'p6HQ'}=0.161;
    $statpot{'p6HE'}=0.170;
    $statpot{'p6HG'}=0.205;
    $statpot{'p6HH'}=-0.326;
    $statpot{'p6HI'}=0.044;
    $statpot{'p6HL'}=-0.130;
    $statpot{'p6HK'}=0.155;
    $statpot{'p6HM'}=0.140;
    $statpot{'p6HF'}=-0.200;
    $statpot{'p6HP'}=0.475;
    $statpot{'p6HS'}=-0.053;
    $statpot{'p6HT'}=0.019;
    $statpot{'p6HW'}=0.002;
    $statpot{'p6HY'}=-0.192;
    $statpot{'p6HV'}=-0.105;
    $statpot{'p6IA'}=-0.194;
    $statpot{'p6IR'}=-0.194;
    $statpot{'p6IN'}=0.231;
    $statpot{'p6ID'}=0.512;
    $statpot{'p6IC'}=-0.511;
    $statpot{'p6IQ'}=0.056;
    $statpot{'p6IE'}=0.215;
    $statpot{'p6IG'}=0.198;
    $statpot{'p6IH'}=0.044;
    $statpot{'p6II'}=-0.947;
    $statpot{'p6IL'}=-0.720;
    $statpot{'p6IK'}=0.158;
    $statpot{'p6IM'}=-0.461;
    $statpot{'p6IF'}=-0.495;
    $statpot{'p6IP'}=0.213;
    $statpot{'p6IS'}=0.273;
    $statpot{'p6IT'}=-0.333;
    $statpot{'p6IW'}=-0.033;
    $statpot{'p6IY'}=-0.335;
    $statpot{'p6IV'}=-0.907;
    $statpot{'p6LA'}=-0.307;
    $statpot{'p6LR'}=-0.064;
    $statpot{'p6LN'}=0.252;
    $statpot{'p6LD'}=0.500;
    $statpot{'p6LC'}=-0.390;
    $statpot{'p6LQ'}=-0.030;
    $statpot{'p6LE'}=0.155;
    $statpot{'p6LG'}=0.343;
    $statpot{'p6LH'}=-0.130;
    $statpot{'p6LI'}=-0.720;
    $statpot{'p6LL'}=-0.745;
    $statpot{'p6LK'}=0.158;
    $statpot{'p6LM'}=-0.566;
    $statpot{'p6LF'}=-0.496;
    $statpot{'p6LP'}=0.291;
    $statpot{'p6LS'}=0.183;
    $statpot{'p6LT'}=-0.067;
    $statpot{'p6LW'}=-0.235;
    $statpot{'p6LY'}=-0.269;
    $statpot{'p6LV'}=-0.736;
    $statpot{'p6KA'}=0.132;
    $statpot{'p6KR'}=0.263;
    $statpot{'p6KN'}=0.088;
    $statpot{'p6KD'}=-0.081;
    $statpot{'p6KC'}=0.552;
    $statpot{'p6KQ'}=0.041;
    $statpot{'p6KE'}=-0.431;
    $statpot{'p6KG'}=0.410;
    $statpot{'p6KH'}=0.155;
    $statpot{'p6KI'}=0.158;
    $statpot{'p6KL'}=0.158;
    $statpot{'p6KK'}=0.364;
    $statpot{'p6KM'}=0.257;
    $statpot{'p6KF'}=0.253;
    $statpot{'p6KP'}=0.419;
    $statpot{'p6KS'}=0.301;
    $statpot{'p6KT'}=0.167;
    $statpot{'p6KW'}=0.028;
    $statpot{'p6KY'}=-0.005;
    $statpot{'p6KV'}=0.159;
    $statpot{'p6MA'}=-0.292;
    $statpot{'p6MR'}=0.140;
    $statpot{'p6MN'}=0.096;
    $statpot{'p6MD'}=0.343;
    $statpot{'p6MC'}=-0.461;
    $statpot{'p6MQ'}=0.027;
    $statpot{'p6ME'}=0.250;
    $statpot{'p6MG'}=0.192;
    $statpot{'p6MH'}=0.140;
    $statpot{'p6MI'}=-0.461;
    $statpot{'p6ML'}=-0.566;
    $statpot{'p6MK'}=0.257;
    $statpot{'p6MM'}=-0.366;
    $statpot{'p6MF'}=-0.389;
    $statpot{'p6MP'}=0.319;
    $statpot{'p6MS'}=0.139;
    $statpot{'p6MT'}=-0.082;
    $statpot{'p6MW'}=-0.226;
    $statpot{'p6MY'}=-0.271;
    $statpot{'p6MV'}=-0.555;
    $statpot{'p6FA'}=-0.132;
    $statpot{'p6FR'}=0.089;
    $statpot{'p6FN'}=0.211;
    $statpot{'p6FD'}=0.405;
    $statpot{'p6FC'}=-0.099;
    $statpot{'p6FQ'}=0.233;
    $statpot{'p6FE'}=0.378;
    $statpot{'p6FG'}=0.078;
    $statpot{'p6FH'}=-0.200;
    $statpot{'p6FI'}=-0.495;
    $statpot{'p6FL'}=-0.496;
    $statpot{'p6FK'}=0.253;
    $statpot{'p6FM'}=-0.389;
    $statpot{'p6FF'}=-0.323;
    $statpot{'p6FP'}=-0.045;
    $statpot{'p6FS'}=0.023;
    $statpot{'p6FT'}=0.102;
    $statpot{'p6FW'}=-0.561;
    $statpot{'p6FY'}=-0.227;
    $statpot{'p6FV'}=-0.469;
    $statpot{'p6PA'}=0.256;
    $statpot{'p6PR'}=0.318;
    $statpot{'p6PN'}=0.225;
    $statpot{'p6PD'}=0.633;
    $statpot{'p6PC'}=0.048;
    $statpot{'p6PQ'}=0.359;
    $statpot{'p6PE'}=0.380;
    $statpot{'p6PG'}=0.447;
    $statpot{'p6PH'}=0.475;
    $statpot{'p6PI'}=0.213;
    $statpot{'p6PL'}=0.291;
    $statpot{'p6PK'}=0.419;
    $statpot{'p6PM'}=0.319;
    $statpot{'p6PF'}=-0.045;
    $statpot{'p6PP'}=0.434;
    $statpot{'p6PS'}=0.380;
    $statpot{'p6PT'}=0.244;
    $statpot{'p6PW'}=0.161;
    $statpot{'p6PY'}=0.126;
    $statpot{'p6PV'}=0.240;
    $statpot{'p6SA'}=0.125;
    $statpot{'p6SR'}=0.104;
    $statpot{'p6SN'}=0.303;
    $statpot{'p6SD'}=0.369;
    $statpot{'p6SC'}=0.133;
    $statpot{'p6SQ'}=0.064;
    $statpot{'p6SE'}=0.255;
    $statpot{'p6SG'}=0.160;
    $statpot{'p6SH'}=-0.053;
    $statpot{'p6SI'}=0.273;
    $statpot{'p6SL'}=0.183;
    $statpot{'p6SK'}=0.301;
    $statpot{'p6SM'}=0.139;
    $statpot{'p6SF'}=0.023;
    $statpot{'p6SP'}=0.380;
    $statpot{'p6SS'}=-0.015;
    $statpot{'p6ST'}=0.039;
    $statpot{'p6SW'}=0.163;
    $statpot{'p6SY'}=0.005;
    $statpot{'p6SV'}=0.267;
    $statpot{'p6TA'}=0.098;
    $statpot{'p6TR'}=0.131;
    $statpot{'p6TN'}=-0.027;
    $statpot{'p6TD'}=0.518;
    $statpot{'p6TC'}=-0.098;
    $statpot{'p6TQ'}=-0.003;
    $statpot{'p6TE'}=0.315;
    $statpot{'p6TG'}=0.089;
    $statpot{'p6TH'}=0.019;
    $statpot{'p6TI'}=-0.333;
    $statpot{'p6TL'}=-0.067;
    $statpot{'p6TK'}=0.167;
    $statpot{'p6TM'}=-0.082;
    $statpot{'p6TF'}=0.102;
    $statpot{'p6TP'}=0.244;
    $statpot{'p6TS'}=0.039;
    $statpot{'p6TT'}=-0.065;
    $statpot{'p6TW'}=-0.058;
    $statpot{'p6TY'}=0.046;
    $statpot{'p6TV'}=-0.247;
    $statpot{'p6WA'}=0.090;
    $statpot{'p6WR'}=-0.195;
    $statpot{'p6WN'}=0.254;
    $statpot{'p6WD'}=0.122;
    $statpot{'p6WC'}=-0.430;
    $statpot{'p6WQ'}=-0.291;
    $statpot{'p6WE'}=0.018;
    $statpot{'p6WG'}=0.010;
    $statpot{'p6WH'}=0.002;
    $statpot{'p6WI'}=-0.033;
    $statpot{'p6WL'}=-0.235;
    $statpot{'p6WK'}=0.028;
    $statpot{'p6WM'}=-0.226;
    $statpot{'p6WF'}=-0.561;
    $statpot{'p6WP'}=0.161;
    $statpot{'p6WS'}=0.163;
    $statpot{'p6WT'}=-0.058;
    $statpot{'p6WW'}=-0.249;
    $statpot{'p6WY'}=-0.259;
    $statpot{'p6WV'}=-0.237;
    $statpot{'p6YA'}=-0.174;
    $statpot{'p6YR'}=-0.111;
    $statpot{'p6YN'}=0.066;
    $statpot{'p6YD'}=0.117;
    $statpot{'p6YC'}=-0.333;
    $statpot{'p6YQ'}=-0.049;
    $statpot{'p6YE'}=0.212;
    $statpot{'p6YG'}=0.115;
    $statpot{'p6YH'}=-0.192;
    $statpot{'p6YI'}=-0.335;
    $statpot{'p6YL'}=-0.269;
    $statpot{'p6YK'}=-0.005;
    $statpot{'p6YM'}=-0.271;
    $statpot{'p6YF'}=-0.227;
    $statpot{'p6YP'}=0.126;
    $statpot{'p6YS'}=0.005;
    $statpot{'p6YT'}=0.046;
    $statpot{'p6YW'}=-0.259;
    $statpot{'p6YY'}=-0.305;
    $statpot{'p6YV'}=-0.360;
    $statpot{'p6VA'}=-0.061;
    $statpot{'p6VR'}=-0.017;
    $statpot{'p6VN'}=0.103;
    $statpot{'p6VD'}=0.500;
    $statpot{'p6VC'}=-0.491;
    $statpot{'p6VQ'}=0.184;
    $statpot{'p6VE'}=0.326;
    $statpot{'p6VG'}=0.165;
    $statpot{'p6VH'}=-0.105;
    $statpot{'p6VI'}=-0.907;
    $statpot{'p6VL'}=-0.736;
    $statpot{'p6VK'}=0.159;
    $statpot{'p6VM'}=-0.555;
    $statpot{'p6VF'}=-0.469;
    $statpot{'p6VP'}=0.240;
    $statpot{'p6VS'}=0.267;
    $statpot{'p6VT'}=-0.247;
    $statpot{'p6VW'}=-0.237;
    $statpot{'p6VY'}=-0.360;
    $statpot{'p6VV'}=-0.919;
    $statpot{'f6AA'}=0.384;
    $statpot{'f6AR'}=0.366;
    $statpot{'f6AN'}=0.237;
    $statpot{'f6AD'}=0.394;
    $statpot{'f6AC'}=-0.179;
    $statpot{'f6AQ'}=0.621;
    $statpot{'f6AE'}=0.540;
    $statpot{'f6AG'}=0.171;
    $statpot{'f6AH'}=0.125;
    $statpot{'f6AI'}=-0.410;
    $statpot{'f6AL'}=-0.584;
    $statpot{'f6AK'}=0.683;
    $statpot{'f6AM'}=-0.427;
    $statpot{'f6AF'}=-0.278;
    $statpot{'f6AP'}=0.250;
    $statpot{'f6AS'}=0.270;
    $statpot{'f6AT'}=0.279;
    $statpot{'f6AW'}=-0.162;
    $statpot{'f6AY'}=-0.161;
    $statpot{'f6AV'}=-0.002;
    $statpot{'f6RA'}=0.438;
    $statpot{'f6RR'}=1.020;
    $statpot{'f6RN'}=0.449;
    $statpot{'f6RD'}=0.158;
    $statpot{'f6RC'}=-0.011;
    $statpot{'f6RQ'}=0.374;
    $statpot{'f6RE'}=0.362;
    $statpot{'f6RG'}=0.320;
    $statpot{'f6RH'}=0.301;
    $statpot{'f6RI'}=0.007;
    $statpot{'f6RL'}=-0.108;
    $statpot{'f6RK'}=1.047;
    $statpot{'f6RM'}=0.034;
    $statpot{'f6RF'}=-0.097;
    $statpot{'f6RP'}=0.382;
    $statpot{'f6RS'}=0.382;
    $statpot{'f6RT'}=0.266;
    $statpot{'f6RW'}=0.478;
    $statpot{'f6RY'}=0.156;
    $statpot{'f6RV'}=0.351;
    $statpot{'f6NA'}=0.245;
    $statpot{'f6NR'}=0.540;
    $statpot{'f6NN'}=0.134;
    $statpot{'f6ND'}=0.322;
    $statpot{'f6NC'}=-0.187;
    $statpot{'f6NQ'}=0.532;
    $statpot{'f6NE'}=0.578;
    $statpot{'f6NG'}=0.225;
    $statpot{'f6NH'}=0.325;
    $statpot{'f6NI'}=0.080;
    $statpot{'f6NL'}=0.154;
    $statpot{'f6NK'}=0.674;
    $statpot{'f6NM'}=-0.060;
    $statpot{'f6NF'}=-0.034;
    $statpot{'f6NP'}=0.321;
    $statpot{'f6NS'}=0.337;
    $statpot{'f6NT'}=0.235;
    $statpot{'f6NW'}=0.356;
    $statpot{'f6NY'}=0.067;
    $statpot{'f6NV'}=0.258;
    $statpot{'f6DA'}=0.755;
    $statpot{'f6DR'}=0.264;
    $statpot{'f6DN'}=0.572;
    $statpot{'f6DD'}=0.915;
    $statpot{'f6DC'}=0.505;
    $statpot{'f6DQ'}=0.799;
    $statpot{'f6DE'}=1.222;
    $statpot{'f6DG'}=0.544;
    $statpot{'f6DH'}=0.494;
    $statpot{'f6DI'}=0.376;
    $statpot{'f6DL'}=0.334;
    $statpot{'f6DK'}=0.690;
    $statpot{'f6DM'}=0.374;
    $statpot{'f6DF'}=0.439;
    $statpot{'f6DP'}=0.374;
    $statpot{'f6DS'}=0.845;
    $statpot{'f6DT'}=0.694;
    $statpot{'f6DW'}=0.301;
    $statpot{'f6DY'}=0.245;
    $statpot{'f6DV'}=0.833;
    $statpot{'f6CA'}=-0.149;
    $statpot{'f6CR'}=-0.257;
    $statpot{'f6CN'}=-0.133;
    $statpot{'f6CD'}=0.322;
    $statpot{'f6CC'}=-0.386;
    $statpot{'f6CQ'}=-0.080;
    $statpot{'f6CE'}=0.059;
    $statpot{'f6CG'}=-0.030;
    $statpot{'f6CH'}=-0.469;
    $statpot{'f6CI'}=-0.897;
    $statpot{'f6CL'}=-0.808;
    $statpot{'f6CK'}=0.105;
    $statpot{'f6CM'}=-0.678;
    $statpot{'f6CF'}=-0.589;
    $statpot{'f6CP'}=-0.361;
    $statpot{'f6CS'}=-0.071;
    $statpot{'f6CT'}=-0.539;
    $statpot{'f6CW'}=-0.445;
    $statpot{'f6CY'}=-0.412;
    $statpot{'f6CV'}=-0.761;
    $statpot{'f6QA'}=0.752;
    $statpot{'f6QR'}=0.432;
    $statpot{'f6QN'}=0.553;
    $statpot{'f6QD'}=0.723;
    $statpot{'f6QC'}=0.614;
    $statpot{'f6QQ'}=0.587;
    $statpot{'f6QE'}=0.933;
    $statpot{'f6QG'}=0.302;
    $statpot{'f6QH'}=0.620;
    $statpot{'f6QI'}=0.027;
    $statpot{'f6QL'}=0.017;
    $statpot{'f6QK'}=0.825;
    $statpot{'f6QM'}=0.046;
    $statpot{'f6QF'}=0.064;
    $statpot{'f6QP'}=0.448;
    $statpot{'f6QS'}=0.229;
    $statpot{'f6QT'}=0.109;
    $statpot{'f6QW'}=0.230;
    $statpot{'f6QY'}=0.030;
    $statpot{'f6QV'}=0.151;
    $statpot{'f6EA'}=0.681;
    $statpot{'f6ER'}=0.465;
    $statpot{'f6EN'}=0.630;
    $statpot{'f6ED'}=1.329;
    $statpot{'f6EC'}=0.360;
    $statpot{'f6EQ'}=0.663;
    $statpot{'f6EE'}=1.690;
    $statpot{'f6EG'}=0.731;
    $statpot{'f6EH'}=-0.002;
    $statpot{'f6EI'}=0.486;
    $statpot{'f6EL'}=0.337;
    $statpot{'f6EK'}=0.863;
    $statpot{'f6EM'}=0.296;
    $statpot{'f6EF'}=0.450;
    $statpot{'f6EP'}=0.881;
    $statpot{'f6ES'}=0.502;
    $statpot{'f6ET'}=0.471;
    $statpot{'f6EW'}=0.635;
    $statpot{'f6EY'}=0.568;
    $statpot{'f6EV'}=0.606;
    $statpot{'f6GA'}=0.182;
    $statpot{'f6GR'}=0.271;
    $statpot{'f6GN'}=0.348;
    $statpot{'f6GD'}=0.562;
    $statpot{'f6GC'}=0.135;
    $statpot{'f6GQ'}=0.344;
    $statpot{'f6GE'}=0.664;
    $statpot{'f6GG'}=0.011;
    $statpot{'f6GH'}=-0.048;
    $statpot{'f6GI'}=0.391;
    $statpot{'f6GL'}=0.324;
    $statpot{'f6GK'}=0.552;
    $statpot{'f6GM'}=0.168;
    $statpot{'f6GF'}=-0.193;
    $statpot{'f6GP'}=0.337;
    $statpot{'f6GS'}=0.139;
    $statpot{'f6GT'}=0.189;
    $statpot{'f6GW'}=0.161;
    $statpot{'f6GY'}=-0.283;
    $statpot{'f6GV'}=0.219;
    $statpot{'f6HA'}=0.235;
    $statpot{'f6HR'}=0.442;
    $statpot{'f6HN'}=0.252;
    $statpot{'f6HD'}=0.450;
    $statpot{'f6HC'}=-0.438;
    $statpot{'f6HQ'}=0.426;
    $statpot{'f6HE'}=0.081;
    $statpot{'f6HG'}=-0.040;
    $statpot{'f6HH'}=-0.137;
    $statpot{'f6HI'}=-0.065;
    $statpot{'f6HL'}=-0.377;
    $statpot{'f6HK'}=0.823;
    $statpot{'f6HM'}=-0.411;
    $statpot{'f6HF'}=-0.267;
    $statpot{'f6HP'}=0.238;
    $statpot{'f6HS'}=-0.237;
    $statpot{'f6HT'}=0.417;
    $statpot{'f6HW'}=-0.579;
    $statpot{'f6HY'}=-0.147;
    $statpot{'f6HV'}=0.011;
    $statpot{'f6IA'}=-0.400;
    $statpot{'f6IR'}=-0.109;
    $statpot{'f6IN'}=0.065;
    $statpot{'f6ID'}=0.278;
    $statpot{'f6IC'}=-0.883;
    $statpot{'f6IQ'}=-0.038;
    $statpot{'f6IE'}=0.285;
    $statpot{'f6IG'}=0.197;
    $statpot{'f6IH'}=-0.147;
    $statpot{'f6II'}=-1.292;
    $statpot{'f6IL'}=-1.019;
    $statpot{'f6IK'}=0.176;
    $statpot{'f6IM'}=-0.756;
    $statpot{'f6IF'}=-0.871;
    $statpot{'f6IP'}=0.036;
    $statpot{'f6IS'}=-0.113;
    $statpot{'f6IT'}=-0.367;
    $statpot{'f6IW'}=-0.459;
    $statpot{'f6IY'}=-0.730;
    $statpot{'f6IV'}=-1.193;
    $statpot{'f6LA'}=-0.556;
    $statpot{'f6LR'}=-0.151;
    $statpot{'f6LN'}=0.175;
    $statpot{'f6LD'}=0.336;
    $statpot{'f6LC'}=-0.757;
    $statpot{'f6LQ'}=-0.056;
    $statpot{'f6LE'}=0.204;
    $statpot{'f6LG'}=0.182;
    $statpot{'f6LH'}=-0.404;
    $statpot{'f6LI'}=-1.010;
    $statpot{'f6LL'}=-1.060;
    $statpot{'f6LK'}=0.151;
    $statpot{'f6LM'}=-0.780;
    $statpot{'f6LF'}=-0.829;
    $statpot{'f6LP'}=0.014;
    $statpot{'f6LS'}=-0.138;
    $statpot{'f6LT'}=-0.378;
    $statpot{'f6LW'}=-0.736;
    $statpot{'f6LY'}=-0.693;
    $statpot{'f6LV'}=-1.192;
    $statpot{'f6KA'}=0.683;
    $statpot{'f6KR'}=0.867;
    $statpot{'f6KN'}=0.622;
    $statpot{'f6KD'}=0.544;
    $statpot{'f6KC'}=0.501;
    $statpot{'f6KQ'}=0.799;
    $statpot{'f6KE'}=0.841;
    $statpot{'f6KG'}=0.625;
    $statpot{'f6KH'}=0.722;
    $statpot{'f6KI'}=0.288;
    $statpot{'f6KL'}=0.204;
    $statpot{'f6KK'}=1.409;
    $statpot{'f6KM'}=0.404;
    $statpot{'f6KF'}=0.534;
    $statpot{'f6KP'}=0.776;
    $statpot{'f6KS'}=0.615;
    $statpot{'f6KT'}=0.766;
    $statpot{'f6KW'}=0.238;
    $statpot{'f6KY'}=0.219;
    $statpot{'f6KV'}=0.321;
    $statpot{'f6MA'}=-0.412;
    $statpot{'f6MR'}=0.137;
    $statpot{'f6MN'}=-0.060;
    $statpot{'f6MD'}=0.400;
    $statpot{'f6MC'}=-0.520;
    $statpot{'f6MQ'}=-0.028;
    $statpot{'f6ME'}=0.304;
    $statpot{'f6MG'}=0.099;
    $statpot{'f6MH'}=-0.427;
    $statpot{'f6MI'}=-0.756;
    $statpot{'f6ML'}=-0.781;
    $statpot{'f6MK'}=0.214;
    $statpot{'f6MM'}=-0.757;
    $statpot{'f6MF'}=-0.749;
    $statpot{'f6MP'}=-0.375;
    $statpot{'f6MS'}=-0.057;
    $statpot{'f6MT'}=-0.305;
    $statpot{'f6MW'}=-0.772;
    $statpot{'f6MY'}=-0.627;
    $statpot{'f6MV'}=-0.609;
    $statpot{'f6FA'}=-0.201;
    $statpot{'f6FR'}=-0.079;
    $statpot{'f6FN'}=0.104;
    $statpot{'f6FD'}=0.534;
    $statpot{'f6FC'}=-0.563;
    $statpot{'f6FQ'}=-0.098;
    $statpot{'f6FE'}=0.371;
    $statpot{'f6FG'}=-0.200;
    $statpot{'f6FH'}=-0.211;
    $statpot{'f6FI'}=-0.795;
    $statpot{'f6FL'}=-0.830;
    $statpot{'f6FK'}=0.324;
    $statpot{'f6FM'}=-0.769;
    $statpot{'f6FF'}=-0.692;
    $statpot{'f6FP'}=-0.174;
    $statpot{'f6FS'}=-0.230;
    $statpot{'f6FT'}=-0.269;
    $statpot{'f6FW'}=-0.691;
    $statpot{'f6FY'}=-0.545;
    $statpot{'f6FV'}=-0.506;
    $statpot{'f6PA'}=0.351;
    $statpot{'f6PR'}=0.381;
    $statpot{'f6PN'}=0.407;
    $statpot{'f6PD'}=0.553;
    $statpot{'f6PC'}=-0.199;
    $statpot{'f6PQ'}=0.371;
    $statpot{'f6PE'}=0.836;
    $statpot{'f6PG'}=0.373;
    $statpot{'f6PH'}=0.426;
    $statpot{'f6PI'}=0.038;
    $statpot{'f6PL'}=0.025;
    $statpot{'f6PK'}=0.724;
    $statpot{'f6PM'}=-0.310;
    $statpot{'f6PF'}=-0.127;
    $statpot{'f6PP'}=0.290;
    $statpot{'f6PS'}=0.394;
    $statpot{'f6PT'}=0.417;
    $statpot{'f6PW'}=-0.137;
    $statpot{'f6PY'}=-0.366;
    $statpot{'f6PV'}=0.072;
    $statpot{'f6SA'}=0.377;
    $statpot{'f6SR'}=0.467;
    $statpot{'f6SN'}=0.405;
    $statpot{'f6SD'}=0.671;
    $statpot{'f6SC'}=0.173;
    $statpot{'f6SQ'}=0.257;
    $statpot{'f6SE'}=0.487;
    $statpot{'f6SG'}=0.043;
    $statpot{'f6SH'}=-0.031;
    $statpot{'f6SI'}=0.112;
    $statpot{'f6SL'}=0.061;
    $statpot{'f6SK'}=0.734;
    $statpot{'f6SM'}=0.066;
    $statpot{'f6SF'}=-0.042;
    $statpot{'f6SP'}=0.321;
    $statpot{'f6SS'}=0.308;
    $statpot{'f6ST'}=0.369;
    $statpot{'f6SW'}=0.424;
    $statpot{'f6SY'}=0.038;
    $statpot{'f6SV'}=0.407;
    $statpot{'f6TA'}=0.380;
    $statpot{'f6TR'}=0.321;
    $statpot{'f6TN'}=0.312;
    $statpot{'f6TD'}=0.696;
    $statpot{'f6TC'}=-0.261;
    $statpot{'f6TQ'}=0.141;
    $statpot{'f6TE'}=0.600;
    $statpot{'f6TG'}=0.125;
    $statpot{'f6TH'}=0.241;
    $statpot{'f6TI'}=-0.327;
    $statpot{'f6TL'}=-0.276;
    $statpot{'f6TK'}=0.854;
    $statpot{'f6TM'}=-0.021;
    $statpot{'f6TF'}=-0.051;
    $statpot{'f6TP'}=0.292;
    $statpot{'f6TS'}=0.418;
    $statpot{'f6TT'}=-0.020;
    $statpot{'f6TW'}=0.012;
    $statpot{'f6TY'}=-0.075;
    $statpot{'f6TV'}=-0.202;
    $statpot{'f6WA'}=-0.185;
    $statpot{'f6WR'}=0.134;
    $statpot{'f6WN'}=0.434;
    $statpot{'f6WD'}=0.140;
    $statpot{'f6WC'}=0.066;
    $statpot{'f6WQ'}=0.057;
    $statpot{'f6WE'}=0.689;
    $statpot{'f6WG'}=0.054;
    $statpot{'f6WH'}=-0.392;
    $statpot{'f6WI'}=-0.316;
    $statpot{'f6WL'}=-0.757;
    $statpot{'f6WK'}=0.364;
    $statpot{'f6WM'}=-0.619;
    $statpot{'f6WF'}=-0.621;
    $statpot{'f6WP'}=-0.193;
    $statpot{'f6WS'}=0.100;
    $statpot{'f6WT'}=-0.214;
    $statpot{'f6WW'}=-0.328;
    $statpot{'f6WY'}=-0.109;
    $statpot{'f6WV'}=-0.562;
    $statpot{'f6YA'}=-0.170;
    $statpot{'f6YR'}=-0.104;
    $statpot{'f6YN'}=0.034;
    $statpot{'f6YD'}=0.158;
    $statpot{'f6YC'}=-0.514;
    $statpot{'f6YQ'}=0.066;
    $statpot{'f6YE'}=0.503;
    $statpot{'f6YG'}=-0.311;
    $statpot{'f6YH'}=-0.122;
    $statpot{'f6YI'}=-0.702;
    $statpot{'f6YL'}=-0.680;
    $statpot{'f6YK'}=0.114;
    $statpot{'f6YM'}=-0.646;
    $statpot{'f6YF'}=-0.494;
    $statpot{'f6YP'}=-0.341;
    $statpot{'f6YS'}=-0.176;
    $statpot{'f6YT'}=-0.063;
    $statpot{'f6YW'}=-0.127;
    $statpot{'f6YY'}=-0.321;
    $statpot{'f6YV'}=-0.406;
    $statpot{'f6VA'}=0.041;
    $statpot{'f6VR'}=0.204;
    $statpot{'f6VN'}=0.274;
    $statpot{'f6VD'}=0.692;
    $statpot{'f6VC'}=-0.623;
    $statpot{'f6VQ'}=0.090;
    $statpot{'f6VE'}=0.501;
    $statpot{'f6VG'}=0.174;
    $statpot{'f6VH'}=0.056;
    $statpot{'f6VI'}=-1.205;
    $statpot{'f6VL'}=-1.180;
    $statpot{'f6VK'}=0.193;
    $statpot{'f6VM'}=-0.552;
    $statpot{'f6VF'}=-0.498;
    $statpot{'f6VP'}=0.031;
    $statpot{'f6VS'}=0.401;
    $statpot{'f6VT'}=-0.337;
    $statpot{'f6VW'}=-0.546;
    $statpot{'f6VY'}=-0.299;
    $statpot{'f6VV'}=-1.012;
    $statpot{'a6AA'}=0.269;
    $statpot{'a6AR'}=0.164;
    $statpot{'a6AN'}=-0.132;
    $statpot{'a6AD'}=0.287;
    $statpot{'a6AC'}=0.168;
    $statpot{'a6AQ'}=0.582;
    $statpot{'a6AE'}=0.504;
    $statpot{'a6AG'}=0.098;
    $statpot{'a6AH'}=0.044;
    $statpot{'a6AI'}=0.021;
    $statpot{'a6AL'}=0.197;
    $statpot{'a6AK'}=0.377;
    $statpot{'a6AM'}=-0.068;
    $statpot{'a6AF'}=-0.017;
    $statpot{'a6AP'}=0.155;
    $statpot{'a6AS'}=0.139;
    $statpot{'a6AT'}=0.242;
    $statpot{'a6AW'}=-0.005;
    $statpot{'a6AY'}=-0.028;
    $statpot{'a6AV'}=0.026;
    $statpot{'a6RA'}=0.055;
    $statpot{'a6RR'}=0.587;
    $statpot{'a6RN'}=0.135;
    $statpot{'a6RD'}=0.155;
    $statpot{'a6RC'}=-0.518;
    $statpot{'a6RQ'}=0.464;
    $statpot{'a6RE'}=0.806;
    $statpot{'a6RG'}=0.266;
    $statpot{'a6RH'}=0.234;
    $statpot{'a6RI'}=-0.254;
    $statpot{'a6RL'}=-0.108;
    $statpot{'a6RK'}=0.106;
    $statpot{'a6RM'}=0.151;
    $statpot{'a6RF'}=-0.291;
    $statpot{'a6RP'}=0.036;
    $statpot{'a6RS'}=0.198;
    $statpot{'a6RT'}=0.324;
    $statpot{'a6RW'}=-0.160;
    $statpot{'a6RY'}=-0.481;
    $statpot{'a6RV'}=-0.175;
    $statpot{'a6NA'}=-0.143;
    $statpot{'a6NR'}=0.024;
    $statpot{'a6NN'}=-0.101;
    $statpot{'a6ND'}=0.200;
    $statpot{'a6NC'}=-0.553;
    $statpot{'a6NQ'}=0.416;
    $statpot{'a6NE'}=0.396;
    $statpot{'a6NG'}=0.272;
    $statpot{'a6NH'}=0.203;
    $statpot{'a6NI'}=-0.468;
    $statpot{'a6NL'}=-0.290;
    $statpot{'a6NK'}=0.243;
    $statpot{'a6NM'}=-0.306;
    $statpot{'a6NF'}=-0.383;
    $statpot{'a6NP'}=-0.415;
    $statpot{'a6NS'}=0.023;
    $statpot{'a6NT'}=0.127;
    $statpot{'a6NW'}=-0.600;
    $statpot{'a6NY'}=-0.247;
    $statpot{'a6NV'}=-0.220;
    $statpot{'a6DA'}=-0.140;
    $statpot{'a6DR'}=-0.018;
    $statpot{'a6DN'}=-0.103;
    $statpot{'a6DD'}=0.247;
    $statpot{'a6DC'}=-0.439;
    $statpot{'a6DQ'}=0.543;
    $statpot{'a6DE'}=0.721;
    $statpot{'a6DG'}=0.388;
    $statpot{'a6DH'}=-0.037;
    $statpot{'a6DI'}=-0.316;
    $statpot{'a6DL'}=-0.162;
    $statpot{'a6DK'}=0.334;
    $statpot{'a6DM'}=-0.080;
    $statpot{'a6DF'}=-0.361;
    $statpot{'a6DP'}=0.246;
    $statpot{'a6DS'}=0.101;
    $statpot{'a6DT'}=0.172;
    $statpot{'a6DW'}=-0.465;
    $statpot{'a6DY'}=-0.383;
    $statpot{'a6DV'}=-0.123;
    $statpot{'a6CA'}=0.091;
    $statpot{'a6CR'}=-0.159;
    $statpot{'a6CN'}=-0.612;
    $statpot{'a6CD'}=-0.288;
    $statpot{'a6CC'}=0.877;
    $statpot{'a6CQ'}=0.216;
    $statpot{'a6CE'}=0.254;
    $statpot{'a6CG'}=0.001;
    $statpot{'a6CH'}=-0.075;
    $statpot{'a6CI'}=-0.431;
    $statpot{'a6CL'}=-0.163;
    $statpot{'a6CK'}=-0.133;
    $statpot{'a6CM'}=0.868;
    $statpot{'a6CF'}=-0.409;
    $statpot{'a6CP'}=-0.303;
    $statpot{'a6CS'}=-0.242;
    $statpot{'a6CT'}=-0.477;
    $statpot{'a6CW'}=0.991;
    $statpot{'a6CY'}=-0.757;
    $statpot{'a6CV'}=-0.444;
    $statpot{'a6QA'}=0.372;
    $statpot{'a6QR'}=0.352;
    $statpot{'a6QN'}=0.383;
    $statpot{'a6QD'}=0.663;
    $statpot{'a6QC'}=-0.566;
    $statpot{'a6QQ'}=0.536;
    $statpot{'a6QE'}=0.230;
    $statpot{'a6QG'}=0.352;
    $statpot{'a6QH'}=-0.081;
    $statpot{'a6QI'}=-0.195;
    $statpot{'a6QL'}=-0.056;
    $statpot{'a6QK'}=0.541;
    $statpot{'a6QM'}=0.017;
    $statpot{'a6QF'}=-0.307;
    $statpot{'a6QP'}=0.243;
    $statpot{'a6QS'}=0.260;
    $statpot{'a6QT'}=0.110;
    $statpot{'a6QW'}=-0.357;
    $statpot{'a6QY'}=-0.186;
    $statpot{'a6QV'}=-0.182;
    $statpot{'a6EA'}=0.273;
    $statpot{'a6ER'}=0.541;
    $statpot{'a6EN'}=0.319;
    $statpot{'a6ED'}=0.610;
    $statpot{'a6EC'}=-0.209;
    $statpot{'a6EQ'}=0.578;
    $statpot{'a6EE'}=0.871;
    $statpot{'a6EG'}=0.660;
    $statpot{'a6EH'}=0.307;
    $statpot{'a6EI'}=-0.180;
    $statpot{'a6EL'}=0.092;
    $statpot{'a6EK'}=0.674;
    $statpot{'a6EM'}=0.054;
    $statpot{'a6EF'}=0.023;
    $statpot{'a6EP'}=0.513;
    $statpot{'a6ES'}=0.769;
    $statpot{'a6ET'}=0.669;
    $statpot{'a6EW'}=0.112;
    $statpot{'a6EY'}=0.105;
    $statpot{'a6EV'}=-0.101;
    $statpot{'a6GA'}=0.078;
    $statpot{'a6GR'}=0.362;
    $statpot{'a6GN'}=0.073;
    $statpot{'a6GD'}=0.362;
    $statpot{'a6GC'}=-0.243;
    $statpot{'a6GQ'}=0.275;
    $statpot{'a6GE'}=0.794;
    $statpot{'a6GG'}=-0.010;
    $statpot{'a6GH'}=0.032;
    $statpot{'a6GI'}=-0.097;
    $statpot{'a6GL'}=0.019;
    $statpot{'a6GK'}=0.471;
    $statpot{'a6GM'}=-0.039;
    $statpot{'a6GF'}=0.115;
    $statpot{'a6GP'}=0.481;
    $statpot{'a6GS'}=-0.071;
    $statpot{'a6GT'}=0.059;
    $statpot{'a6GW'}=-0.072;
    $statpot{'a6GY'}=0.098;
    $statpot{'a6GV'}=0.102;
    $statpot{'a6HA'}=-0.129;
    $statpot{'a6HR'}=0.022;
    $statpot{'a6HN'}=0.335;
    $statpot{'a6HD'}=0.012;
    $statpot{'a6HC'}=-0.147;
    $statpot{'a6HQ'}=0.140;
    $statpot{'a6HE'}=0.117;
    $statpot{'a6HG'}=0.016;
    $statpot{'a6HH'}=-0.642;
    $statpot{'a6HI'}=-0.306;
    $statpot{'a6HL'}=-0.452;
    $statpot{'a6HK'}=0.105;
    $statpot{'a6HM'}=-0.323;
    $statpot{'a6HF'}=-0.499;
    $statpot{'a6HP'}=-0.206;
    $statpot{'a6HS'}=-0.052;
    $statpot{'a6HT'}=-0.206;
    $statpot{'a6HW'}=-0.385;
    $statpot{'a6HY'}=-0.230;
    $statpot{'a6HV'}=-0.171;
    $statpot{'a6IA'}=-0.008;
    $statpot{'a6IR'}=-0.049;
    $statpot{'a6IN'}=-0.450;
    $statpot{'a6ID'}=-0.213;
    $statpot{'a6IC'}=-0.470;
    $statpot{'a6IQ'}=-0.087;
    $statpot{'a6IE'}=0.077;
    $statpot{'a6IG'}=0.193;
    $statpot{'a6IH'}=-0.168;
    $statpot{'a6II'}=-0.074;
    $statpot{'a6IL'}=-0.094;
    $statpot{'a6IK'}=0.068;
    $statpot{'a6IM'}=-0.344;
    $statpot{'a6IF'}=-0.059;
    $statpot{'a6IP'}=0.291;
    $statpot{'a6IS'}=-0.196;
    $statpot{'a6IT'}=-0.264;
    $statpot{'a6IW'}=0.022;
    $statpot{'a6IY'}=-0.465;
    $statpot{'a6IV'}=-0.415;
    $statpot{'a6LA'}=0.078;
    $statpot{'a6LR'}=-0.020;
    $statpot{'a6LN'}=-0.316;
    $statpot{'a6LD'}=-0.164;
    $statpot{'a6LC'}=-0.323;
    $statpot{'a6LQ'}=0.089;
    $statpot{'a6LE'}=0.343;
    $statpot{'a6LG'}=0.262;
    $statpot{'a6LH'}=-0.403;
    $statpot{'a6LI'}=-0.140;
    $statpot{'a6LL'}=0.129;
    $statpot{'a6LK'}=-0.005;
    $statpot{'a6LM'}=-0.060;
    $statpot{'a6LF'}=-0.141;
    $statpot{'a6LP'}=-0.025;
    $statpot{'a6LS'}=0.207;
    $statpot{'a6LT'}=-0.265;
    $statpot{'a6LW'}=-0.383;
    $statpot{'a6LY'}=-0.133;
    $statpot{'a6LV'}=-0.276;
    $statpot{'a6KA'}=0.376;
    $statpot{'a6KR'}=0.265;
    $statpot{'a6KN'}=0.308;
    $statpot{'a6KD'}=0.565;
    $statpot{'a6KC'}=-0.513;
    $statpot{'a6KQ'}=0.580;
    $statpot{'a6KE'}=0.711;
    $statpot{'a6KG'}=0.355;
    $statpot{'a6KH'}=0.203;
    $statpot{'a6KI'}=-0.101;
    $statpot{'a6KL'}=-0.088;
    $statpot{'a6KK'}=0.648;
    $statpot{'a6KM'}=-0.024;
    $statpot{'a6KF'}=-0.262;
    $statpot{'a6KP'}=0.203;
    $statpot{'a6KS'}=0.519;
    $statpot{'a6KT'}=0.529;
    $statpot{'a6KW'}=-0.285;
    $statpot{'a6KY'}=-0.346;
    $statpot{'a6KV'}=-0.321;
    $statpot{'a6MA'}=-0.111;
    $statpot{'a6MR'}=-0.050;
    $statpot{'a6MN'}=-0.307;
    $statpot{'a6MD'}=-0.112;
    $statpot{'a6MC'}=0.029;
    $statpot{'a6MQ'}=0.172;
    $statpot{'a6ME'}=0.043;
    $statpot{'a6MG'}=0.082;
    $statpot{'a6MH'}=-0.288;
    $statpot{'a6MI'}=-0.348;
    $statpot{'a6ML'}=-0.052;
    $statpot{'a6MK'}=0.291;
    $statpot{'a6MM'}=-0.442;
    $statpot{'a6MF'}=-0.144;
    $statpot{'a6MP'}=0.415;
    $statpot{'a6MS'}=-0.122;
    $statpot{'a6MT'}=-0.071;
    $statpot{'a6MW'}=0.689;
    $statpot{'a6MY'}=-0.272;
    $statpot{'a6MV'}=0.264;
    $statpot{'a6FA'}=-0.189;
    $statpot{'a6FR'}=-0.319;
    $statpot{'a6FN'}=-0.536;
    $statpot{'a6FD'}=-0.433;
    $statpot{'a6FC'}=-0.461;
    $statpot{'a6FQ'}=-0.053;
    $statpot{'a6FE'}=0.134;
    $statpot{'a6FG'}=0.134;
    $statpot{'a6FH'}=-0.576;
    $statpot{'a6FI'}=-0.336;
    $statpot{'a6FL'}=-0.136;
    $statpot{'a6FK'}=-0.043;
    $statpot{'a6FM'}=-0.071;
    $statpot{'a6FF'}=-0.279;
    $statpot{'a6FP'}=-0.371;
    $statpot{'a6FS'}=-0.211;
    $statpot{'a6FT'}=-0.344;
    $statpot{'a6FW'}=-0.161;
    $statpot{'a6FY'}=-0.490;
    $statpot{'a6FV'}=-0.280;
    $statpot{'a6PA'}=-0.007;
    $statpot{'a6PR'}=0.037;
    $statpot{'a6PN'}=-0.485;
    $statpot{'a6PD'}=0.007;
    $statpot{'a6PC'}=-0.549;
    $statpot{'a6PQ'}=0.373;
    $statpot{'a6PE'}=0.577;
    $statpot{'a6PG'}=0.408;
    $statpot{'a6PH'}=-0.395;
    $statpot{'a6PI'}=0.284;
    $statpot{'a6PL'}=-0.045;
    $statpot{'a6PK'}=0.266;
    $statpot{'a6PM'}=0.179;
    $statpot{'a6PF'}=-0.440;
    $statpot{'a6PP'}=0.685;
    $statpot{'a6PS'}=0.161;
    $statpot{'a6PT'}=0.048;
    $statpot{'a6PW'}=-0.205;
    $statpot{'a6PY'}=-0.467;
    $statpot{'a6PV'}=0.025;
    $statpot{'a6SA'}=-0.023;
    $statpot{'a6SR'}=0.076;
    $statpot{'a6SN'}=-0.062;
    $statpot{'a6SD'}=0.282;
    $statpot{'a6SC'}=-0.519;
    $statpot{'a6SQ'}=0.208;
    $statpot{'a6SE'}=0.806;
    $statpot{'a6SG'}=0.091;
    $statpot{'a6SH'}=-0.400;
    $statpot{'a6SI'}=-0.499;
    $statpot{'a6SL'}=-0.188;
    $statpot{'a6SK'}=0.346;
    $statpot{'a6SM'}=-0.316;
    $statpot{'a6SF'}=-0.490;
    $statpot{'a6SP'}=0.280;
    $statpot{'a6SS'}=0.197;
    $statpot{'a6ST'}=0.235;
    $statpot{'a6SW'}=-0.289;
    $statpot{'a6SY'}=-0.499;
    $statpot{'a6SV'}=-0.107;
    $statpot{'a6TA'}=0.076;
    $statpot{'a6TR'}=0.221;
    $statpot{'a6TN'}=0.016;
    $statpot{'a6TD'}=0.169;
    $statpot{'a6TC'}=-0.841;
    $statpot{'a6TQ'}=0.055;
    $statpot{'a6TE'}=0.417;
    $statpot{'a6TG'}=0.172;
    $statpot{'a6TH'}=0.007;
    $statpot{'a6TI'}=-0.343;
    $statpot{'a6TL'}=-0.453;
    $statpot{'a6TK'}=0.412;
    $statpot{'a6TM'}=-0.554;
    $statpot{'a6TF'}=-0.631;
    $statpot{'a6TP'}=0.238;
    $statpot{'a6TS'}=0.162;
    $statpot{'a6TT'}=0.067;
    $statpot{'a6TW'}=-0.417;
    $statpot{'a6TY'}=-0.196;
    $statpot{'a6TV'}=-0.511;
    $statpot{'a6WA'}=0.047;
    $statpot{'a6WR'}=0.353;
    $statpot{'a6WN'}=-0.646;
    $statpot{'a6WD'}=-0.313;
    $statpot{'a6WC'}=-0.342;
    $statpot{'a6WQ'}=-0.147;
    $statpot{'a6WE'}=0.054;
    $statpot{'a6WG'}=0.103;
    $statpot{'a6WH'}=-0.709;
    $statpot{'a6WI'}=-0.314;
    $statpot{'a6WL'}=-0.323;
    $statpot{'a6WK'}=-0.404;
    $statpot{'a6WM'}=-0.074;
    $statpot{'a6WF'}=-0.345;
    $statpot{'a6WP'}=-0.101;
    $statpot{'a6WS'}=0.113;
    $statpot{'a6WT'}=-0.076;
    $statpot{'a6WW'}=0.035;
    $statpot{'a6WY'}=-0.382;
    $statpot{'a6WV'}=-0.438;
    $statpot{'a6YA'}=-0.008;
    $statpot{'a6YR'}=-0.129;
    $statpot{'a6YN'}=-0.202;
    $statpot{'a6YD'}=-0.291;
    $statpot{'a6YC'}=-0.614;
    $statpot{'a6YQ'}=-0.237;
    $statpot{'a6YE'}=0.191;
    $statpot{'a6YG'}=0.185;
    $statpot{'a6YH'}=-0.270;
    $statpot{'a6YI'}=-0.529;
    $statpot{'a6YL'}=-0.175;
    $statpot{'a6YK'}=-0.222;
    $statpot{'a6YM'}=-0.212;
    $statpot{'a6YF'}=-0.583;
    $statpot{'a6YP'}=-0.508;
    $statpot{'a6YS'}=-0.208;
    $statpot{'a6YT'}=-0.214;
    $statpot{'a6YW'}=-0.359;
    $statpot{'a6YY'}=-0.426;
    $statpot{'a6YV'}=-0.259;
    $statpot{'a6VA'}=-0.058;
    $statpot{'a6VR'}=0.027;
    $statpot{'a6VN'}=-0.238;
    $statpot{'a6VD'}=-0.007;
    $statpot{'a6VC'}=-0.723;
    $statpot{'a6VQ'}=-0.095;
    $statpot{'a6VE'}=0.012;
    $statpot{'a6VG'}=0.184;
    $statpot{'a6VH'}=-0.239;
    $statpot{'a6VI'}=-0.356;
    $statpot{'a6VL'}=-0.330;
    $statpot{'a6VK'}=-0.172;
    $statpot{'a6VM'}=0.029;
    $statpot{'a6VF'}=-0.296;
    $statpot{'a6VP'}=0.106;
    $statpot{'a6VS'}=-0.099;
    $statpot{'a6VT'}=-0.288;
    $statpot{'a6VW'}=-0.472;
    $statpot{'a6VY'}=-0.460;
    $statpot{'a6VV'}=-0.494;
    $statpot{'p7AA'}=-0.017;
    $statpot{'p7AR'}=0.099;
    $statpot{'p7AN'}=0.016;
    $statpot{'p7AD'}=0.282;
    $statpot{'p7AC'}=-0.324;
    $statpot{'p7AQ'}=0.193;
    $statpot{'p7AE'}=0.347;
    $statpot{'p7AG'}=-0.006;
    $statpot{'p7AH'}=0.152;
    $statpot{'p7AI'}=-0.000;
    $statpot{'p7AL'}=-0.006;
    $statpot{'p7AK'}=0.260;
    $statpot{'p7AM'}=-0.015;
    $statpot{'p7AF'}=-0.202;
    $statpot{'p7AP'}=-0.101;
    $statpot{'p7AS'}=-0.031;
    $statpot{'p7AT'}=-0.065;
    $statpot{'p7AW'}=-0.096;
    $statpot{'p7AY'}=-0.141;
    $statpot{'p7AV'}=0.108;
    $statpot{'p7RA'}=0.099;
    $statpot{'p7RR'}=0.118;
    $statpot{'p7RN'}=0.024;
    $statpot{'p7RD'}=-0.255;
    $statpot{'p7RC'}=-0.033;
    $statpot{'p7RQ'}=0.128;
    $statpot{'p7RE'}=-0.053;
    $statpot{'p7RG'}=-0.255;
    $statpot{'p7RH'}=-0.130;
    $statpot{'p7RI'}=0.294;
    $statpot{'p7RL'}=0.152;
    $statpot{'p7RK'}=0.161;
    $statpot{'p7RM'}=-0.081;
    $statpot{'p7RF'}=-0.099;
    $statpot{'p7RP'}=-0.163;
    $statpot{'p7RS'}=-0.103;
    $statpot{'p7RT'}=0.111;
    $statpot{'p7RW'}=-0.237;
    $statpot{'p7RY'}=-0.000;
    $statpot{'p7RV'}=0.293;
    $statpot{'p7NA'}=0.016;
    $statpot{'p7NR'}=0.024;
    $statpot{'p7NN'}=0.096;
    $statpot{'p7ND'}=0.115;
    $statpot{'p7NC'}=-0.190;
    $statpot{'p7NQ'}=-0.125;
    $statpot{'p7NE'}=0.330;
    $statpot{'p7NG'}=-0.087;
    $statpot{'p7NH'}=-0.148;
    $statpot{'p7NI'}=0.193;
    $statpot{'p7NL'}=0.191;
    $statpot{'p7NK'}=0.121;
    $statpot{'p7NM'}=0.013;
    $statpot{'p7NF'}=0.051;
    $statpot{'p7NP'}=-0.257;
    $statpot{'p7NS'}=-0.023;
    $statpot{'p7NT'}=-0.083;
    $statpot{'p7NW'}=0.103;
    $statpot{'p7NY'}=-0.129;
    $statpot{'p7NV'}=0.161;
    $statpot{'p7DA'}=0.282;
    $statpot{'p7DR'}=-0.255;
    $statpot{'p7DN'}=0.115;
    $statpot{'p7DD'}=0.252;
    $statpot{'p7DC'}=0.205;
    $statpot{'p7DQ'}=0.109;
    $statpot{'p7DE'}=0.369;
    $statpot{'p7DG'}=0.005;
    $statpot{'p7DH'}=-0.234;
    $statpot{'p7DI'}=0.386;
    $statpot{'p7DL'}=0.516;
    $statpot{'p7DK'}=-0.101;
    $statpot{'p7DM'}=0.451;
    $statpot{'p7DF'}=0.022;
    $statpot{'p7DP'}=-0.105;
    $statpot{'p7DS'}=0.060;
    $statpot{'p7DT'}=0.218;
    $statpot{'p7DW'}=0.030;
    $statpot{'p7DY'}=-0.043;
    $statpot{'p7DV'}=0.375;
    $statpot{'p7CA'}=-0.324;
    $statpot{'p7CR'}=-0.033;
    $statpot{'p7CN'}=-0.190;
    $statpot{'p7CD'}=0.205;
    $statpot{'p7CC'}=0.049;
    $statpot{'p7CQ'}=0.072;
    $statpot{'p7CE'}=0.235;
    $statpot{'p7CG'}=-0.257;
    $statpot{'p7CH'}=0.310;
    $statpot{'p7CI'}=-0.335;
    $statpot{'p7CL'}=-0.444;
    $statpot{'p7CK'}=0.164;
    $statpot{'p7CM'}=-0.462;
    $statpot{'p7CF'}=-0.289;
    $statpot{'p7CP'}=-0.255;
    $statpot{'p7CS'}=-0.197;
    $statpot{'p7CT'}=-0.114;
    $statpot{'p7CW'}=-0.449;
    $statpot{'p7CY'}=-0.350;
    $statpot{'p7CV'}=-0.335;
    $statpot{'p7QA'}=0.193;
    $statpot{'p7QR'}=0.128;
    $statpot{'p7QN'}=-0.125;
    $statpot{'p7QD'}=0.109;
    $statpot{'p7QC'}=0.072;
    $statpot{'p7QQ'}=-0.042;
    $statpot{'p7QE'}=0.122;
    $statpot{'p7QG'}=-0.148;
    $statpot{'p7QH'}=0.009;
    $statpot{'p7QI'}=0.302;
    $statpot{'p7QL'}=0.287;
    $statpot{'p7QK'}=0.097;
    $statpot{'p7QM'}=-0.070;
    $statpot{'p7QF'}=-0.042;
    $statpot{'p7QP'}=-0.205;
    $statpot{'p7QS'}=0.052;
    $statpot{'p7QT'}=0.114;
    $statpot{'p7QW'}=-0.137;
    $statpot{'p7QY'}=-0.189;
    $statpot{'p7QV'}=0.283;
    $statpot{'p7EA'}=0.347;
    $statpot{'p7ER'}=-0.053;
    $statpot{'p7EN'}=0.330;
    $statpot{'p7ED'}=0.369;
    $statpot{'p7EC'}=0.235;
    $statpot{'p7EQ'}=0.122;
    $statpot{'p7EE'}=0.599;
    $statpot{'p7EG'}=0.091;
    $statpot{'p7EH'}=0.185;
    $statpot{'p7EI'}=0.498;
    $statpot{'p7EL'}=0.481;
    $statpot{'p7EK'}=-0.064;
    $statpot{'p7EM'}=0.512;
    $statpot{'p7EF'}=0.390;
    $statpot{'p7EP'}=-0.041;
    $statpot{'p7ES'}=0.230;
    $statpot{'p7ET'}=0.229;
    $statpot{'p7EW'}=0.366;
    $statpot{'p7EY'}=0.047;
    $statpot{'p7EV'}=0.480;
    $statpot{'p7GA'}=-0.006;
    $statpot{'p7GR'}=-0.255;
    $statpot{'p7GN'}=-0.087;
    $statpot{'p7GD'}=0.005;
    $statpot{'p7GC'}=-0.257;
    $statpot{'p7GQ'}=-0.148;
    $statpot{'p7GE'}=0.091;
    $statpot{'p7GG'}=-0.200;
    $statpot{'p7GH'}=-0.187;
    $statpot{'p7GI'}=-0.041;
    $statpot{'p7GL'}=0.002;
    $statpot{'p7GK'}=0.001;
    $statpot{'p7GM'}=-0.198;
    $statpot{'p7GF'}=0.021;
    $statpot{'p7GP'}=-0.159;
    $statpot{'p7GS'}=-0.124;
    $statpot{'p7GT'}=-0.164;
    $statpot{'p7GW'}=0.038;
    $statpot{'p7GY'}=-0.118;
    $statpot{'p7GV'}=-0.135;
    $statpot{'p7HA'}=0.152;
    $statpot{'p7HR'}=-0.130;
    $statpot{'p7HN'}=-0.148;
    $statpot{'p7HD'}=-0.234;
    $statpot{'p7HC'}=0.310;
    $statpot{'p7HQ'}=0.009;
    $statpot{'p7HE'}=0.185;
    $statpot{'p7HG'}=-0.187;
    $statpot{'p7HH'}=-0.286;
    $statpot{'p7HI'}=0.151;
    $statpot{'p7HL'}=-0.024;
    $statpot{'p7HK'}=0.042;
    $statpot{'p7HM'}=0.048;
    $statpot{'p7HF'}=-0.081;
    $statpot{'p7HP'}=-0.149;
    $statpot{'p7HS'}=-0.027;
    $statpot{'p7HT'}=-0.258;
    $statpot{'p7HW'}=-0.080;
    $statpot{'p7HY'}=-0.231;
    $statpot{'p7HV'}=0.093;
    $statpot{'p7IA'}=-0.000;
    $statpot{'p7IR'}=0.294;
    $statpot{'p7IN'}=0.193;
    $statpot{'p7ID'}=0.386;
    $statpot{'p7IC'}=-0.335;
    $statpot{'p7IQ'}=0.302;
    $statpot{'p7IE'}=0.498;
    $statpot{'p7IG'}=-0.041;
    $statpot{'p7IH'}=0.151;
    $statpot{'p7II'}=-0.589;
    $statpot{'p7IL'}=-0.646;
    $statpot{'p7IK'}=0.500;
    $statpot{'p7IM'}=-0.406;
    $statpot{'p7IF'}=-0.611;
    $statpot{'p7IP'}=-0.046;
    $statpot{'p7IS'}=0.155;
    $statpot{'p7IT'}=-0.063;
    $statpot{'p7IW'}=-0.176;
    $statpot{'p7IY'}=-0.382;
    $statpot{'p7IV'}=-0.321;
    $statpot{'p7LA'}=-0.006;
    $statpot{'p7LR'}=0.152;
    $statpot{'p7LN'}=0.191;
    $statpot{'p7LD'}=0.516;
    $statpot{'p7LC'}=-0.444;
    $statpot{'p7LQ'}=0.287;
    $statpot{'p7LE'}=0.481;
    $statpot{'p7LG'}=0.002;
    $statpot{'p7LH'}=-0.024;
    $statpot{'p7LI'}=-0.646;
    $statpot{'p7LL'}=-0.686;
    $statpot{'p7LK'}=0.346;
    $statpot{'p7LM'}=-0.332;
    $statpot{'p7LF'}=-0.520;
    $statpot{'p7LP'}=-0.092;
    $statpot{'p7LS'}=0.214;
    $statpot{'p7LT'}=-0.002;
    $statpot{'p7LW'}=-0.263;
    $statpot{'p7LY'}=-0.249;
    $statpot{'p7LV'}=-0.503;
    $statpot{'p7KA'}=0.260;
    $statpot{'p7KR'}=0.161;
    $statpot{'p7KN'}=0.121;
    $statpot{'p7KD'}=-0.101;
    $statpot{'p7KC'}=0.164;
    $statpot{'p7KQ'}=0.097;
    $statpot{'p7KE'}=-0.064;
    $statpot{'p7KG'}=0.001;
    $statpot{'p7KH'}=0.042;
    $statpot{'p7KI'}=0.500;
    $statpot{'p7KL'}=0.346;
    $statpot{'p7KK'}=0.468;
    $statpot{'p7KM'}=0.494;
    $statpot{'p7KF'}=0.555;
    $statpot{'p7KP'}=-0.175;
    $statpot{'p7KS'}=0.050;
    $statpot{'p7KT'}=0.019;
    $statpot{'p7KW'}=0.391;
    $statpot{'p7KY'}=0.118;
    $statpot{'p7KV'}=0.438;
    $statpot{'p7MA'}=-0.015;
    $statpot{'p7MR'}=-0.081;
    $statpot{'p7MN'}=0.013;
    $statpot{'p7MD'}=0.451;
    $statpot{'p7MC'}=-0.462;
    $statpot{'p7MQ'}=-0.070;
    $statpot{'p7ME'}=0.512;
    $statpot{'p7MG'}=-0.198;
    $statpot{'p7MH'}=0.048;
    $statpot{'p7MI'}=-0.406;
    $statpot{'p7ML'}=-0.332;
    $statpot{'p7MK'}=0.494;
    $statpot{'p7MM'}=-0.150;
    $statpot{'p7MF'}=-0.397;
    $statpot{'p7MP'}=-0.202;
    $statpot{'p7MS'}=-0.067;
    $statpot{'p7MT'}=-0.166;
    $statpot{'p7MW'}=-0.486;
    $statpot{'p7MY'}=-0.370;
    $statpot{'p7MV'}=-0.247;
    $statpot{'p7FA'}=-0.202;
    $statpot{'p7FR'}=-0.099;
    $statpot{'p7FN'}=0.051;
    $statpot{'p7FD'}=0.022;
    $statpot{'p7FC'}=-0.289;
    $statpot{'p7FQ'}=-0.042;
    $statpot{'p7FE'}=0.390;
    $statpot{'p7FG'}=0.021;
    $statpot{'p7FH'}=-0.081;
    $statpot{'p7FI'}=-0.611;
    $statpot{'p7FL'}=-0.520;
    $statpot{'p7FK'}=0.555;
    $statpot{'p7FM'}=-0.397;
    $statpot{'p7FF'}=-0.627;
    $statpot{'p7FP'}=0.021;
    $statpot{'p7FS'}=-0.156;
    $statpot{'p7FT'}=-0.032;
    $statpot{'p7FW'}=-0.586;
    $statpot{'p7FY'}=-0.364;
    $statpot{'p7FV'}=-0.459;
    $statpot{'p7PA'}=-0.101;
    $statpot{'p7PR'}=-0.163;
    $statpot{'p7PN'}=-0.257;
    $statpot{'p7PD'}=-0.105;
    $statpot{'p7PC'}=-0.255;
    $statpot{'p7PQ'}=-0.205;
    $statpot{'p7PE'}=-0.041;
    $statpot{'p7PG'}=-0.159;
    $statpot{'p7PH'}=-0.149;
    $statpot{'p7PI'}=-0.046;
    $statpot{'p7PL'}=-0.092;
    $statpot{'p7PK'}=-0.175;
    $statpot{'p7PM'}=-0.202;
    $statpot{'p7PF'}=0.021;
    $statpot{'p7PP'}=-0.188;
    $statpot{'p7PS'}=-0.128;
    $statpot{'p7PT'}=-0.090;
    $statpot{'p7PW'}=-0.292;
    $statpot{'p7PY'}=-0.210;
    $statpot{'p7PV'}=0.059;
    $statpot{'p7SA'}=-0.031;
    $statpot{'p7SR'}=-0.103;
    $statpot{'p7SN'}=-0.023;
    $statpot{'p7SD'}=0.060;
    $statpot{'p7SC'}=-0.197;
    $statpot{'p7SQ'}=0.052;
    $statpot{'p7SE'}=0.230;
    $statpot{'p7SG'}=-0.124;
    $statpot{'p7SH'}=-0.027;
    $statpot{'p7SI'}=0.155;
    $statpot{'p7SL'}=0.214;
    $statpot{'p7SK'}=0.050;
    $statpot{'p7SM'}=-0.067;
    $statpot{'p7SF'}=-0.156;
    $statpot{'p7SP'}=-0.128;
    $statpot{'p7SS'}=-0.218;
    $statpot{'p7ST'}=-0.103;
    $statpot{'p7SW'}=0.208;
    $statpot{'p7SY'}=-0.031;
    $statpot{'p7SV'}=0.096;
    $statpot{'p7TA'}=-0.065;
    $statpot{'p7TR'}=0.111;
    $statpot{'p7TN'}=-0.083;
    $statpot{'p7TD'}=0.218;
    $statpot{'p7TC'}=-0.114;
    $statpot{'p7TQ'}=0.114;
    $statpot{'p7TE'}=0.229;
    $statpot{'p7TG'}=-0.164;
    $statpot{'p7TH'}=-0.258;
    $statpot{'p7TI'}=-0.063;
    $statpot{'p7TL'}=-0.002;
    $statpot{'p7TK'}=0.019;
    $statpot{'p7TM'}=-0.166;
    $statpot{'p7TF'}=-0.032;
    $statpot{'p7TP'}=-0.090;
    $statpot{'p7TS'}=-0.103;
    $statpot{'p7TT'}=-0.084;
    $statpot{'p7TW'}=-0.247;
    $statpot{'p7TY'}=-0.264;
    $statpot{'p7TV'}=0.030;
    $statpot{'p7WA'}=-0.096;
    $statpot{'p7WR'}=-0.237;
    $statpot{'p7WN'}=0.103;
    $statpot{'p7WD'}=0.030;
    $statpot{'p7WC'}=-0.449;
    $statpot{'p7WQ'}=-0.137;
    $statpot{'p7WE'}=0.366;
    $statpot{'p7WG'}=0.038;
    $statpot{'p7WH'}=-0.080;
    $statpot{'p7WI'}=-0.176;
    $statpot{'p7WL'}=-0.263;
    $statpot{'p7WK'}=0.391;
    $statpot{'p7WM'}=-0.486;
    $statpot{'p7WF'}=-0.586;
    $statpot{'p7WP'}=-0.292;
    $statpot{'p7WS'}=0.208;
    $statpot{'p7WT'}=-0.247;
    $statpot{'p7WW'}=-0.316;
    $statpot{'p7WY'}=-0.328;
    $statpot{'p7WV'}=-0.101;
    $statpot{'p7YA'}=-0.141;
    $statpot{'p7YR'}=-0.000;
    $statpot{'p7YN'}=-0.129;
    $statpot{'p7YD'}=-0.043;
    $statpot{'p7YC'}=-0.350;
    $statpot{'p7YQ'}=-0.189;
    $statpot{'p7YE'}=0.047;
    $statpot{'p7YG'}=-0.118;
    $statpot{'p7YH'}=-0.231;
    $statpot{'p7YI'}=-0.382;
    $statpot{'p7YL'}=-0.249;
    $statpot{'p7YK'}=0.118;
    $statpot{'p7YM'}=-0.370;
    $statpot{'p7YF'}=-0.364;
    $statpot{'p7YP'}=-0.210;
    $statpot{'p7YS'}=-0.031;
    $statpot{'p7YT'}=-0.264;
    $statpot{'p7YW'}=-0.328;
    $statpot{'p7YY'}=-0.279;
    $statpot{'p7YV'}=-0.187;
    $statpot{'p7VA'}=0.108;
    $statpot{'p7VR'}=0.293;
    $statpot{'p7VN'}=0.161;
    $statpot{'p7VD'}=0.375;
    $statpot{'p7VC'}=-0.335;
    $statpot{'p7VQ'}=0.283;
    $statpot{'p7VE'}=0.480;
    $statpot{'p7VG'}=-0.135;
    $statpot{'p7VH'}=0.093;
    $statpot{'p7VI'}=-0.321;
    $statpot{'p7VL'}=-0.503;
    $statpot{'p7VK'}=0.438;
    $statpot{'p7VM'}=-0.247;
    $statpot{'p7VF'}=-0.459;
    $statpot{'p7VP'}=0.059;
    $statpot{'p7VS'}=0.096;
    $statpot{'p7VT'}=0.030;
    $statpot{'p7VW'}=-0.101;
    $statpot{'p7VY'}=-0.187;
    $statpot{'p7VV'}=-0.146;
    $statpot{'f7AA'}=-0.181;
    $statpot{'f7AR'}=0.157;
    $statpot{'f7AN'}=0.144;
    $statpot{'f7AD'}=0.338;
    $statpot{'f7AC'}=-0.237;
    $statpot{'f7AQ'}=0.240;
    $statpot{'f7AE'}=0.201;
    $statpot{'f7AG'}=0.003;
    $statpot{'f7AH'}=-0.006;
    $statpot{'f7AI'}=-0.040;
    $statpot{'f7AL'}=-0.077;
    $statpot{'f7AK'}=0.338;
    $statpot{'f7AM'}=-0.108;
    $statpot{'f7AF'}=-0.536;
    $statpot{'f7AP'}=-0.100;
    $statpot{'f7AS'}=-0.047;
    $statpot{'f7AT'}=0.035;
    $statpot{'f7AW'}=-0.145;
    $statpot{'f7AY'}=-0.294;
    $statpot{'f7AV'}=-0.090;
    $statpot{'f7RA'}=0.153;
    $statpot{'f7RR'}=0.589;
    $statpot{'f7RN'}=0.300;
    $statpot{'f7RD'}=0.244;
    $statpot{'f7RC'}=0.017;
    $statpot{'f7RQ'}=0.278;
    $statpot{'f7RE'}=0.306;
    $statpot{'f7RG'}=0.268;
    $statpot{'f7RH'}=0.251;
    $statpot{'f7RI'}=0.216;
    $statpot{'f7RL'}=0.082;
    $statpot{'f7RK'}=1.010;
    $statpot{'f7RM'}=0.119;
    $statpot{'f7RF'}=-0.063;
    $statpot{'f7RP'}=0.053;
    $statpot{'f7RS'}=0.210;
    $statpot{'f7RT'}=0.318;
    $statpot{'f7RW'}=0.099;
    $statpot{'f7RY'}=0.020;
    $statpot{'f7RV'}=0.145;
    $statpot{'f7NA'}=0.186;
    $statpot{'f7NR'}=0.346;
    $statpot{'f7NN'}=0.501;
    $statpot{'f7ND'}=0.472;
    $statpot{'f7NC'}=0.055;
    $statpot{'f7NQ'}=0.464;
    $statpot{'f7NE'}=0.650;
    $statpot{'f7NG'}=0.392;
    $statpot{'f7NH'}=0.145;
    $statpot{'f7NI'}=0.340;
    $statpot{'f7NL'}=0.406;
    $statpot{'f7NK'}=0.827;
    $statpot{'f7NM'}=0.016;
    $statpot{'f7NF'}=0.122;
    $statpot{'f7NP'}=0.348;
    $statpot{'f7NS'}=0.278;
    $statpot{'f7NT'}=0.192;
    $statpot{'f7NW'}=0.315;
    $statpot{'f7NY'}=0.265;
    $statpot{'f7NV'}=0.271;
    $statpot{'f7DA'}=0.561;
    $statpot{'f7DR'}=0.272;
    $statpot{'f7DN'}=0.409;
    $statpot{'f7DD'}=0.915;
    $statpot{'f7DC'}=0.147;
    $statpot{'f7DQ'}=0.678;
    $statpot{'f7DE'}=0.986;
    $statpot{'f7DG'}=0.481;
    $statpot{'f7DH'}=0.081;
    $statpot{'f7DI'}=0.406;
    $statpot{'f7DL'}=0.627;
    $statpot{'f7DK'}=0.414;
    $statpot{'f7DM'}=0.433;
    $statpot{'f7DF'}=0.316;
    $statpot{'f7DP'}=0.337;
    $statpot{'f7DS'}=0.510;
    $statpot{'f7DT'}=0.284;
    $statpot{'f7DW'}=0.291;
    $statpot{'f7DY'}=0.168;
    $statpot{'f7DV'}=0.466;
    $statpot{'f7CA'}=-0.299;
    $statpot{'f7CR'}=0.027;
    $statpot{'f7CN'}=0.002;
    $statpot{'f7CD'}=-0.096;
    $statpot{'f7CC'}=-0.521;
    $statpot{'f7CQ'}=0.078;
    $statpot{'f7CE'}=0.407;
    $statpot{'f7CG'}=-0.378;
    $statpot{'f7CH'}=-0.278;
    $statpot{'f7CI'}=-0.505;
    $statpot{'f7CL'}=-0.461;
    $statpot{'f7CK'}=0.067;
    $statpot{'f7CM'}=-0.367;
    $statpot{'f7CF'}=-0.814;
    $statpot{'f7CP'}=-0.311;
    $statpot{'f7CS'}=-0.255;
    $statpot{'f7CT'}=-0.391;
    $statpot{'f7CW'}=-0.669;
    $statpot{'f7CY'}=-0.409;
    $statpot{'f7CV'}=-0.543;
    $statpot{'f7QA'}=0.290;
    $statpot{'f7QR'}=0.213;
    $statpot{'f7QN'}=0.396;
    $statpot{'f7QD'}=0.549;
    $statpot{'f7QC'}=-0.158;
    $statpot{'f7QQ'}=0.302;
    $statpot{'f7QE'}=0.648;
    $statpot{'f7QG'}=0.192;
    $statpot{'f7QH'}=0.033;
    $statpot{'f7QI'}=0.288;
    $statpot{'f7QL'}=0.258;
    $statpot{'f7QK'}=0.409;
    $statpot{'f7QM'}=-0.226;
    $statpot{'f7QF'}=-0.054;
    $statpot{'f7QP'}=0.033;
    $statpot{'f7QS'}=0.436;
    $statpot{'f7QT'}=0.175;
    $statpot{'f7QW'}=-0.022;
    $statpot{'f7QY'}=0.314;
    $statpot{'f7QV'}=0.254;
    $statpot{'f7EA'}=0.433;
    $statpot{'f7ER'}=0.431;
    $statpot{'f7EN'}=0.700;
    $statpot{'f7ED'}=0.958;
    $statpot{'f7EC'}=0.584;
    $statpot{'f7EQ'}=0.634;
    $statpot{'f7EE'}=0.870;
    $statpot{'f7EG'}=0.600;
    $statpot{'f7EH'}=0.417;
    $statpot{'f7EI'}=0.567;
    $statpot{'f7EL'}=0.433;
    $statpot{'f7EK'}=0.400;
    $statpot{'f7EM'}=0.211;
    $statpot{'f7EF'}=0.232;
    $statpot{'f7EP'}=0.294;
    $statpot{'f7ES'}=0.654;
    $statpot{'f7ET'}=0.761;
    $statpot{'f7EW'}=0.363;
    $statpot{'f7EY'}=0.196;
    $statpot{'f7EV'}=0.875;
    $statpot{'f7GA'}=-0.002;
    $statpot{'f7GR'}=0.275;
    $statpot{'f7GN'}=0.311;
    $statpot{'f7GD'}=0.483;
    $statpot{'f7GC'}=-0.367;
    $statpot{'f7GQ'}=0.291;
    $statpot{'f7GE'}=0.484;
    $statpot{'f7GG'}=0.086;
    $statpot{'f7GH'}=-0.100;
    $statpot{'f7GI'}=-0.091;
    $statpot{'f7GL'}=-0.030;
    $statpot{'f7GK'}=0.428;
    $statpot{'f7GM'}=-0.044;
    $statpot{'f7GF'}=-0.066;
    $statpot{'f7GP'}=-0.010;
    $statpot{'f7GS'}=0.042;
    $statpot{'f7GT'}=0.085;
    $statpot{'f7GW'}=-0.228;
    $statpot{'f7GY'}=-0.156;
    $statpot{'f7GV'}=0.032;
    $statpot{'f7HA'}=-0.087;
    $statpot{'f7HR'}=0.254;
    $statpot{'f7HN'}=-0.113;
    $statpot{'f7HD'}=-0.040;
    $statpot{'f7HC'}=-0.357;
    $statpot{'f7HQ'}=0.202;
    $statpot{'f7HE'}=0.386;
    $statpot{'f7HG'}=0.036;
    $statpot{'f7HH'}=-0.353;
    $statpot{'f7HI'}=0.013;
    $statpot{'f7HL'}=-0.017;
    $statpot{'f7HK'}=0.368;
    $statpot{'f7HM'}=-0.212;
    $statpot{'f7HF'}=-0.447;
    $statpot{'f7HP'}=-0.074;
    $statpot{'f7HS'}=-0.172;
    $statpot{'f7HT'}=-0.131;
    $statpot{'f7HW'}=-0.247;
    $statpot{'f7HY'}=-0.311;
    $statpot{'f7HV'}=-0.021;
    $statpot{'f7IA'}=-0.079;
    $statpot{'f7IR'}=0.102;
    $statpot{'f7IN'}=0.225;
    $statpot{'f7ID'}=0.344;
    $statpot{'f7IC'}=-0.422;
    $statpot{'f7IQ'}=0.199;
    $statpot{'f7IE'}=0.252;
    $statpot{'f7IG'}=-0.112;
    $statpot{'f7IH'}=-0.083;
    $statpot{'f7II'}=-0.904;
    $statpot{'f7IL'}=-0.983;
    $statpot{'f7IK'}=0.298;
    $statpot{'f7IM'}=-0.708;
    $statpot{'f7IF'}=-0.648;
    $statpot{'f7IP'}=-0.319;
    $statpot{'f7IS'}=0.000;
    $statpot{'f7IT'}=-0.168;
    $statpot{'f7IW'}=-0.514;
    $statpot{'f7IY'}=-0.446;
    $statpot{'f7IV'}=-0.674;
    $statpot{'f7LA'}=-0.089;
    $statpot{'f7LR'}=-0.090;
    $statpot{'f7LN'}=0.227;
    $statpot{'f7LD'}=0.272;
    $statpot{'f7LC'}=-0.512;
    $statpot{'f7LQ'}=0.063;
    $statpot{'f7LE'}=0.301;
    $statpot{'f7LG'}=0.003;
    $statpot{'f7LH'}=-0.078;
    $statpot{'f7LI'}=-0.990;
    $statpot{'f7LL'}=-0.920;
    $statpot{'f7LK'}=0.191;
    $statpot{'f7LM'}=-0.609;
    $statpot{'f7LF'}=-0.759;
    $statpot{'f7LP'}=-0.279;
    $statpot{'f7LS'}=0.075;
    $statpot{'f7LT'}=-0.198;
    $statpot{'f7LW'}=-0.443;
    $statpot{'f7LY'}=-0.389;
    $statpot{'f7LV'}=-0.801;
    $statpot{'f7KA'}=0.338;
    $statpot{'f7KR'}=1.039;
    $statpot{'f7KN'}=0.794;
    $statpot{'f7KD'}=0.276;
    $statpot{'f7KC'}=0.239;
    $statpot{'f7KQ'}=0.578;
    $statpot{'f7KE'}=0.321;
    $statpot{'f7KG'}=0.562;
    $statpot{'f7KH'}=0.524;
    $statpot{'f7KI'}=0.399;
    $statpot{'f7KL'}=0.372;
    $statpot{'f7KK'}=1.147;
    $statpot{'f7KM'}=0.366;
    $statpot{'f7KF'}=0.112;
    $statpot{'f7KP'}=0.379;
    $statpot{'f7KS'}=0.384;
    $statpot{'f7KT'}=0.606;
    $statpot{'f7KW'}=0.274;
    $statpot{'f7KY'}=0.086;
    $statpot{'f7KV'}=0.523;
    $statpot{'f7MA'}=-0.117;
    $statpot{'f7MR'}=-0.005;
    $statpot{'f7MN'}=-0.096;
    $statpot{'f7MD'}=0.343;
    $statpot{'f7MC'}=-0.329;
    $statpot{'f7MQ'}=-0.070;
    $statpot{'f7ME'}=0.065;
    $statpot{'f7MG'}=0.119;
    $statpot{'f7MH'}=-0.277;
    $statpot{'f7MI'}=-0.827;
    $statpot{'f7ML'}=-0.637;
    $statpot{'f7MK'}=0.289;
    $statpot{'f7MM'}=-0.573;
    $statpot{'f7MF'}=-0.727;
    $statpot{'f7MP'}=-0.196;
    $statpot{'f7MS'}=0.119;
    $statpot{'f7MT'}=-0.290;
    $statpot{'f7MW'}=-0.396;
    $statpot{'f7MY'}=-0.443;
    $statpot{'f7MV'}=-0.647;
    $statpot{'f7FA'}=-0.596;
    $statpot{'f7FR'}=-0.247;
    $statpot{'f7FN'}=-0.123;
    $statpot{'f7FD'}=0.007;
    $statpot{'f7FC'}=-0.771;
    $statpot{'f7FQ'}=-0.145;
    $statpot{'f7FE'}=0.052;
    $statpot{'f7FG'}=-0.164;
    $statpot{'f7FH'}=-0.478;
    $statpot{'f7FI'}=-0.669;
    $statpot{'f7FL'}=-0.764;
    $statpot{'f7FK'}=-0.104;
    $statpot{'f7FM'}=-0.775;
    $statpot{'f7FF'}=-0.967;
    $statpot{'f7FP'}=-0.448;
    $statpot{'f7FS'}=-0.130;
    $statpot{'f7FT'}=-0.260;
    $statpot{'f7FW'}=-0.727;
    $statpot{'f7FY'}=-0.694;
    $statpot{'f7FV'}=-0.629;
    $statpot{'f7PA'}=0.144;
    $statpot{'f7PR'}=0.335;
    $statpot{'f7PN'}=0.342;
    $statpot{'f7PD'}=0.343;
    $statpot{'f7PC'}=0.135;
    $statpot{'f7PQ'}=0.265;
    $statpot{'f7PE'}=0.561;
    $statpot{'f7PG'}=0.228;
    $statpot{'f7PH'}=0.190;
    $statpot{'f7PI'}=0.065;
    $statpot{'f7PL'}=-0.003;
    $statpot{'f7PK'}=0.428;
    $statpot{'f7PM'}=0.006;
    $statpot{'f7PF'}=-0.259;
    $statpot{'f7PP'}=0.012;
    $statpot{'f7PS'}=0.322;
    $statpot{'f7PT'}=0.382;
    $statpot{'f7PW'}=-0.314;
    $statpot{'f7PY'}=-0.226;
    $statpot{'f7PV'}=0.197;
    $statpot{'f7SA'}=0.035;
    $statpot{'f7SR'}=0.244;
    $statpot{'f7SN'}=0.362;
    $statpot{'f7SD'}=0.364;
    $statpot{'f7SC'}=-0.198;
    $statpot{'f7SQ'}=0.487;
    $statpot{'f7SE'}=0.677;
    $statpot{'f7SG'}=0.107;
    $statpot{'f7SH'}=-0.134;
    $statpot{'f7SI'}=0.147;
    $statpot{'f7SL'}=0.367;
    $statpot{'f7SK'}=0.485;
    $statpot{'f7SM'}=0.083;
    $statpot{'f7SF'}=-0.006;
    $statpot{'f7SP'}=0.123;
    $statpot{'f7SS'}=0.226;
    $statpot{'f7ST'}=0.191;
    $statpot{'f7SW'}=-0.162;
    $statpot{'f7SY'}=0.090;
    $statpot{'f7SV'}=0.191;
    $statpot{'f7TA'}=0.048;
    $statpot{'f7TR'}=0.451;
    $statpot{'f7TN'}=0.291;
    $statpot{'f7TD'}=0.253;
    $statpot{'f7TC'}=-0.030;
    $statpot{'f7TQ'}=0.130;
    $statpot{'f7TE'}=0.715;
    $statpot{'f7TG'}=0.059;
    $statpot{'f7TH'}=-0.045;
    $statpot{'f7TI'}=-0.018;
    $statpot{'f7TL'}=-0.064;
    $statpot{'f7TK'}=0.520;
    $statpot{'f7TM'}=-0.250;
    $statpot{'f7TF'}=-0.153;
    $statpot{'f7TP'}=0.091;
    $statpot{'f7TS'}=0.086;
    $statpot{'f7TT'}=0.365;
    $statpot{'f7TW'}=-0.107;
    $statpot{'f7TY'}=-0.177;
    $statpot{'f7TV'}=0.050;
    $statpot{'f7WA'}=-0.167;
    $statpot{'f7WR'}=-0.113;
    $statpot{'f7WN'}=0.169;
    $statpot{'f7WD'}=-0.004;
    $statpot{'f7WC'}=-0.644;
    $statpot{'f7WQ'}=0.084;
    $statpot{'f7WE'}=0.182;
    $statpot{'f7WG'}=-0.171;
    $statpot{'f7WH'}=-0.254;
    $statpot{'f7WI'}=-0.471;
    $statpot{'f7WL'}=-0.430;
    $statpot{'f7WK'}=0.343;
    $statpot{'f7WM'}=-0.278;
    $statpot{'f7WF'}=-0.669;
    $statpot{'f7WP'}=-0.500;
    $statpot{'f7WS'}=-0.146;
    $statpot{'f7WT'}=-0.218;
    $statpot{'f7WW'}=-0.379;
    $statpot{'f7WY'}=-0.207;
    $statpot{'f7WV'}=-0.405;
    $statpot{'f7YA'}=-0.357;
    $statpot{'f7YR'}=-0.131;
    $statpot{'f7YN'}=0.007;
    $statpot{'f7YD'}=0.057;
    $statpot{'f7YC'}=-0.642;
    $statpot{'f7YQ'}=0.072;
    $statpot{'f7YE'}=-0.002;
    $statpot{'f7YG'}=-0.095;
    $statpot{'f7YH'}=-0.439;
    $statpot{'f7YI'}=-0.522;
    $statpot{'f7YL'}=-0.424;
    $statpot{'f7YK'}=0.137;
    $statpot{'f7YM'}=-0.437;
    $statpot{'f7YF'}=-0.716;
    $statpot{'f7YP'}=-0.348;
    $statpot{'f7YS'}=-0.065;
    $statpot{'f7YT'}=-0.364;
    $statpot{'f7YW'}=-0.300;
    $statpot{'f7YY'}=-0.405;
    $statpot{'f7YV'}=-0.454;
    $statpot{'f7VA'}=-0.073;
    $statpot{'f7VR'}=0.007;
    $statpot{'f7VN'}=0.175;
    $statpot{'f7VD'}=0.315;
    $statpot{'f7VC'}=-0.621;
    $statpot{'f7VQ'}=0.209;
    $statpot{'f7VE'}=0.541;
    $statpot{'f7VG'}=-0.049;
    $statpot{'f7VH'}=-0.038;
    $statpot{'f7VI'}=-0.633;
    $statpot{'f7VL'}=-0.780;
    $statpot{'f7VK'}=0.204;
    $statpot{'f7VM'}=-0.621;
    $statpot{'f7VF'}=-0.625;
    $statpot{'f7VP'}=-0.077;
    $statpot{'f7VS'}=0.008;
    $statpot{'f7VT'}=-0.020;
    $statpot{'f7VW'}=-0.379;
    $statpot{'f7VY'}=-0.405;
    $statpot{'f7VV'}=-0.304;
    $statpot{'a7AA'}=-0.270;
    $statpot{'a7AR'}=-0.233;
    $statpot{'a7AN'}=0.144;
    $statpot{'a7AD'}=0.224;
    $statpot{'a7AC'}=-0.172;
    $statpot{'a7AQ'}=-0.190;
    $statpot{'a7AE'}=-0.188;
    $statpot{'a7AG'}=-0.016;
    $statpot{'a7AH'}=-0.064;
    $statpot{'a7AI'}=-0.139;
    $statpot{'a7AL'}=-0.245;
    $statpot{'a7AK'}=-0.241;
    $statpot{'a7AM'}=-0.087;
    $statpot{'a7AF'}=-0.133;
    $statpot{'a7AP'}=0.517;
    $statpot{'a7AS'}=0.170;
    $statpot{'a7AT'}=0.075;
    $statpot{'a7AW'}=-0.133;
    $statpot{'a7AY'}=-0.206;
    $statpot{'a7AV'}=-0.156;
    $statpot{'a7RA'}=-0.231;
    $statpot{'a7RR'}=0.104;
    $statpot{'a7RN'}=0.367;
    $statpot{'a7RD'}=0.539;
    $statpot{'a7RC'}=-0.194;
    $statpot{'a7RQ'}=-0.007;
    $statpot{'a7RE'}=0.227;
    $statpot{'a7RG'}=0.159;
    $statpot{'a7RH'}=0.393;
    $statpot{'a7RI'}=-0.284;
    $statpot{'a7RL'}=-0.396;
    $statpot{'a7RK'}=0.110;
    $statpot{'a7RM'}=-0.275;
    $statpot{'a7RF'}=-0.260;
    $statpot{'a7RP'}=0.527;
    $statpot{'a7RS'}=0.464;
    $statpot{'a7RT'}=0.147;
    $statpot{'a7RW'}=-0.336;
    $statpot{'a7RY'}=-0.120;
    $statpot{'a7RV'}=-0.310;
    $statpot{'a7NA'}=0.116;
    $statpot{'a7NR'}=0.335;
    $statpot{'a7NN'}=0.463;
    $statpot{'a7ND'}=0.556;
    $statpot{'a7NC'}=-0.100;
    $statpot{'a7NQ'}=0.403;
    $statpot{'a7NE'}=0.504;
    $statpot{'a7NG'}=0.230;
    $statpot{'a7NH'}=0.239;
    $statpot{'a7NI'}=-0.212;
    $statpot{'a7NL'}=-0.070;
    $statpot{'a7NK'}=0.302;
    $statpot{'a7NM'}=-0.220;
    $statpot{'a7NF'}=-0.132;
    $statpot{'a7NP'}=0.587;
    $statpot{'a7NS'}=0.474;
    $statpot{'a7NT'}=0.539;
    $statpot{'a7NW'}=-0.085;
    $statpot{'a7NY'}=0.025;
    $statpot{'a7NV'}=-0.125;
    $statpot{'a7DA'}=0.111;
    $statpot{'a7DR'}=0.513;
    $statpot{'a7DN'}=0.606;
    $statpot{'a7DD'}=0.962;
    $statpot{'a7DC'}=0.072;
    $statpot{'a7DQ'}=0.373;
    $statpot{'a7DE'}=0.632;
    $statpot{'a7DG'}=0.379;
    $statpot{'a7DH'}=0.369;
    $statpot{'a7DI'}=-0.253;
    $statpot{'a7DL'}=-0.218;
    $statpot{'a7DK'}=0.749;
    $statpot{'a7DM'}=-0.043;
    $statpot{'a7DF'}=-0.207;
    $statpot{'a7DP'}=0.675;
    $statpot{'a7DS'}=0.559;
    $statpot{'a7DT'}=0.419;
    $statpot{'a7DW'}=0.035;
    $statpot{'a7DY'}=0.180;
    $statpot{'a7DV'}=-0.101;
    $statpot{'a7CA'}=-0.123;
    $statpot{'a7CR'}=-0.199;
    $statpot{'a7CN'}=-0.068;
    $statpot{'a7CD'}=0.267;
    $statpot{'a7CC'}=0.852;
    $statpot{'a7CQ'}=-0.267;
    $statpot{'a7CE'}=-0.123;
    $statpot{'a7CG'}=0.103;
    $statpot{'a7CH'}=-0.362;
    $statpot{'a7CI'}=0.047;
    $statpot{'a7CL'}=-0.129;
    $statpot{'a7CK'}=-0.039;
    $statpot{'a7CM'}=0.090;
    $statpot{'a7CF'}=-0.068;
    $statpot{'a7CP'}=0.436;
    $statpot{'a7CS'}=-0.157;
    $statpot{'a7CT'}=-0.077;
    $statpot{'a7CW'}=0.003;
    $statpot{'a7CY'}=-0.054;
    $statpot{'a7CV'}=-0.172;
    $statpot{'a7QA'}=-0.211;
    $statpot{'a7QR'}=0.027;
    $statpot{'a7QN'}=0.449;
    $statpot{'a7QD'}=0.444;
    $statpot{'a7QC'}=-0.129;
    $statpot{'a7QQ'}=0.203;
    $statpot{'a7QE'}=0.122;
    $statpot{'a7QG'}=0.173;
    $statpot{'a7QH'}=0.121;
    $statpot{'a7QI'}=-0.350;
    $statpot{'a7QL'}=-0.431;
    $statpot{'a7QK'}=0.186;
    $statpot{'a7QM'}=-0.414;
    $statpot{'a7QF'}=-0.282;
    $statpot{'a7QP'}=0.513;
    $statpot{'a7QS'}=0.314;
    $statpot{'a7QT'}=0.233;
    $statpot{'a7QW'}=-0.370;
    $statpot{'a7QY'}=-0.165;
    $statpot{'a7QV'}=-0.235;
    $statpot{'a7EA'}=-0.277;
    $statpot{'a7ER'}=0.157;
    $statpot{'a7EN'}=0.476;
    $statpot{'a7ED'}=0.647;
    $statpot{'a7EC'}=-0.186;
    $statpot{'a7EQ'}=0.127;
    $statpot{'a7EE'}=0.409;
    $statpot{'a7EG'}=0.164;
    $statpot{'a7EH'}=0.289;
    $statpot{'a7EI'}=-0.378;
    $statpot{'a7EL'}=-0.470;
    $statpot{'a7EK'}=0.269;
    $statpot{'a7EM'}=-0.493;
    $statpot{'a7EF'}=-0.277;
    $statpot{'a7EP'}=0.653;
    $statpot{'a7ES'}=0.460;
    $statpot{'a7ET'}=0.388;
    $statpot{'a7EW'}=-0.225;
    $statpot{'a7EY'}=-0.071;
    $statpot{'a7EV'}=-0.352;
    $statpot{'a7GA'}=-0.012;
    $statpot{'a7GR'}=0.155;
    $statpot{'a7GN'}=0.282;
    $statpot{'a7GD'}=0.378;
    $statpot{'a7GC'}=0.089;
    $statpot{'a7GQ'}=0.110;
    $statpot{'a7GE'}=0.220;
    $statpot{'a7GG'}=0.392;
    $statpot{'a7GH'}=0.349;
    $statpot{'a7GI'}=0.025;
    $statpot{'a7GL'}=0.073;
    $statpot{'a7GK'}=0.190;
    $statpot{'a7GM'}=0.000;
    $statpot{'a7GF'}=0.084;
    $statpot{'a7GP'}=0.595;
    $statpot{'a7GS'}=0.244;
    $statpot{'a7GT'}=0.246;
    $statpot{'a7GW'}=0.102;
    $statpot{'a7GY'}=0.208;
    $statpot{'a7GV'}=0.107;
    $statpot{'a7HA'}=-0.009;
    $statpot{'a7HR'}=0.391;
    $statpot{'a7HN'}=0.485;
    $statpot{'a7HD'}=0.495;
    $statpot{'a7HC'}=-0.309;
    $statpot{'a7HQ'}=0.013;
    $statpot{'a7HE'}=0.307;
    $statpot{'a7HG'}=0.219;
    $statpot{'a7HH'}=0.494;
    $statpot{'a7HI'}=-0.289;
    $statpot{'a7HL'}=-0.254;
    $statpot{'a7HK'}=0.269;
    $statpot{'a7HM'}=0.100;
    $statpot{'a7HF'}=-0.106;
    $statpot{'a7HP'}=0.343;
    $statpot{'a7HS'}=0.249;
    $statpot{'a7HT'}=0.209;
    $statpot{'a7HW'}=-0.187;
    $statpot{'a7HY'}=-0.068;
    $statpot{'a7HV'}=-0.163;
    $statpot{'a7IA'}=-0.115;
    $statpot{'a7IR'}=-0.234;
    $statpot{'a7IN'}=-0.164;
    $statpot{'a7ID'}=-0.231;
    $statpot{'a7IC'}=-0.045;
    $statpot{'a7IQ'}=-0.316;
    $statpot{'a7IE'}=-0.279;
    $statpot{'a7IG'}=0.041;
    $statpot{'a7IH'}=-0.238;
    $statpot{'a7II'}=0.091;
    $statpot{'a7IL'}=0.125;
    $statpot{'a7IK'}=-0.303;
    $statpot{'a7IM'}=-0.157;
    $statpot{'a7IF'}=0.153;
    $statpot{'a7IP'}=0.259;
    $statpot{'a7IS'}=-0.175;
    $statpot{'a7IT'}=-0.185;
    $statpot{'a7IW'}=-0.087;
    $statpot{'a7IY'}=-0.194;
    $statpot{'a7IV'}=-0.108;
    $statpot{'a7LA'}=-0.238;
    $statpot{'a7LR'}=-0.314;
    $statpot{'a7LN'}=0.017;
    $statpot{'a7LD'}=-0.085;
    $statpot{'a7LC'}=-0.079;
    $statpot{'a7LQ'}=-0.357;
    $statpot{'a7LE'}=-0.432;
    $statpot{'a7LG'}=0.048;
    $statpot{'a7LH'}=-0.220;
    $statpot{'a7LI'}=0.140;
    $statpot{'a7LL'}=0.064;
    $statpot{'a7LK'}=-0.415;
    $statpot{'a7LM'}=-0.029;
    $statpot{'a7LF'}=0.146;
    $statpot{'a7LP'}=0.313;
    $statpot{'a7LS'}=-0.109;
    $statpot{'a7LT'}=-0.083;
    $statpot{'a7LW'}=-0.042;
    $statpot{'a7LY'}=0.044;
    $statpot{'a7LV'}=-0.071;
    $statpot{'a7KA'}=-0.241;
    $statpot{'a7KR'}=0.102;
    $statpot{'a7KN'}=0.316;
    $statpot{'a7KD'}=0.896;
    $statpot{'a7KC'}=-0.130;
    $statpot{'a7KQ'}=0.108;
    $statpot{'a7KE'}=0.318;
    $statpot{'a7KG'}=0.126;
    $statpot{'a7KH'}=0.185;
    $statpot{'a7KI'}=-0.337;
    $statpot{'a7KL'}=-0.473;
    $statpot{'a7KK'}=0.162;
    $statpot{'a7KM'}=-0.294;
    $statpot{'a7KF'}=-0.323;
    $statpot{'a7KP'}=0.480;
    $statpot{'a7KS'}=0.409;
    $statpot{'a7KT'}=0.305;
    $statpot{'a7KW'}=-0.238;
    $statpot{'a7KY'}=0.011;
    $statpot{'a7KV'}=-0.298;
    $statpot{'a7MA'}=-0.081;
    $statpot{'a7MR'}=-0.215;
    $statpot{'a7MN'}=-0.156;
    $statpot{'a7MD'}=-0.003;
    $statpot{'a7MC'}=0.050;
    $statpot{'a7MQ'}=-0.490;
    $statpot{'a7ME'}=-0.441;
    $statpot{'a7MG'}=-0.102;
    $statpot{'a7MH'}=0.161;
    $statpot{'a7MI'}=-0.002;
    $statpot{'a7ML'}=0.006;
    $statpot{'a7MK'}=-0.266;
    $statpot{'a7MM'}=-0.280;
    $statpot{'a7MF'}=0.096;
    $statpot{'a7MP'}=0.387;
    $statpot{'a7MS'}=0.088;
    $statpot{'a7MT'}=-0.160;
    $statpot{'a7MW'}=-0.028;
    $statpot{'a7MY'}=0.321;
    $statpot{'a7MV'}=-0.027;
    $statpot{'a7FA'}=-0.070;
    $statpot{'a7FR'}=-0.142;
    $statpot{'a7FN'}=0.026;
    $statpot{'a7FD'}=-0.051;
    $statpot{'a7FC'}=-0.123;
    $statpot{'a7FQ'}=-0.229;
    $statpot{'a7FE'}=-0.196;
    $statpot{'a7FG'}=0.170;
    $statpot{'a7FH'}=-0.077;
    $statpot{'a7FI'}=0.184;
    $statpot{'a7FL'}=0.153;
    $statpot{'a7FK'}=-0.213;
    $statpot{'a7FM'}=0.176;
    $statpot{'a7FF'}=0.376;
    $statpot{'a7FP'}=0.143;
    $statpot{'a7FS'}=0.075;
    $statpot{'a7FT'}=-0.026;
    $statpot{'a7FW'}=0.086;
    $statpot{'a7FY'}=0.021;
    $statpot{'a7FV'}=-0.126;
    $statpot{'a7PA'}=0.276;
    $statpot{'a7PR'}=0.289;
    $statpot{'a7PN'}=0.593;
    $statpot{'a7PD'}=0.670;
    $statpot{'a7PC'}=0.005;
    $statpot{'a7PQ'}=0.307;
    $statpot{'a7PE'}=0.449;
    $statpot{'a7PG'}=0.354;
    $statpot{'a7PH'}=0.126;
    $statpot{'a7PI'}=-0.067;
    $statpot{'a7PL'}=0.052;
    $statpot{'a7PK'}=0.445;
    $statpot{'a7PM'}=0.188;
    $statpot{'a7PF'}=-0.050;
    $statpot{'a7PP'}=0.409;
    $statpot{'a7PS'}=0.359;
    $statpot{'a7PT'}=0.195;
    $statpot{'a7PW'}=0.291;
    $statpot{'a7PY'}=0.099;
    $statpot{'a7PV'}=0.030;
    $statpot{'a7SA'}=0.105;
    $statpot{'a7SR'}=0.434;
    $statpot{'a7SN'}=0.408;
    $statpot{'a7SD'}=0.680;
    $statpot{'a7SC'}=-0.199;
    $statpot{'a7SQ'}=0.284;
    $statpot{'a7SE'}=0.447;
    $statpot{'a7SG'}=0.190;
    $statpot{'a7SH'}=0.211;
    $statpot{'a7SI'}=-0.250;
    $statpot{'a7SL'}=-0.244;
    $statpot{'a7SK'}=0.346;
    $statpot{'a7SM'}=0.112;
    $statpot{'a7SF'}=-0.019;
    $statpot{'a7SP'}=0.532;
    $statpot{'a7SS'}=0.462;
    $statpot{'a7ST'}=0.348;
    $statpot{'a7SW'}=-0.041;
    $statpot{'a7SY'}=-0.054;
    $statpot{'a7SV'}=-0.187;
    $statpot{'a7TA'}=0.065;
    $statpot{'a7TR'}=0.077;
    $statpot{'a7TN'}=0.451;
    $statpot{'a7TD'}=0.444;
    $statpot{'a7TC'}=-0.336;
    $statpot{'a7TQ'}=0.266;
    $statpot{'a7TE'}=0.409;
    $statpot{'a7TG'}=0.268;
    $statpot{'a7TH'}=0.133;
    $statpot{'a7TI'}=-0.274;
    $statpot{'a7TL'}=-0.174;
    $statpot{'a7TK'}=0.351;
    $statpot{'a7TM'}=-0.190;
    $statpot{'a7TF'}=-0.111;
    $statpot{'a7TP'}=0.411;
    $statpot{'a7TS'}=0.444;
    $statpot{'a7TT'}=0.384;
    $statpot{'a7TW'}=-0.191;
    $statpot{'a7TY'}=-0.221;
    $statpot{'a7TV'}=-0.150;
    $statpot{'a7WA'}=-0.116;
    $statpot{'a7WR'}=-0.225;
    $statpot{'a7WN'}=-0.009;
    $statpot{'a7WD'}=0.240;
    $statpot{'a7WC'}=-0.029;
    $statpot{'a7WQ'}=-0.419;
    $statpot{'a7WE'}=-0.148;
    $statpot{'a7WG'}=0.049;
    $statpot{'a7WH'}=-0.182;
    $statpot{'a7WI'}=-0.129;
    $statpot{'a7WL'}=-0.054;
    $statpot{'a7WK'}=-0.267;
    $statpot{'a7WM'}=-0.131;
    $statpot{'a7WF'}=0.004;
    $statpot{'a7WP'}=0.601;
    $statpot{'a7WS'}=-0.054;
    $statpot{'a7WT'}=-0.113;
    $statpot{'a7WW'}=0.186;
    $statpot{'a7WY'}=0.260;
    $statpot{'a7WV'}=-0.034;
    $statpot{'a7YA'}=-0.157;
    $statpot{'a7YR'}=-0.019;
    $statpot{'a7YN'}=0.201;
    $statpot{'a7YD'}=0.265;
    $statpot{'a7YC'}=0.251;
    $statpot{'a7YQ'}=-0.042;
    $statpot{'a7YE'}=0.049;
    $statpot{'a7YG'}=0.148;
    $statpot{'a7YH'}=0.060;
    $statpot{'a7YI'}=-0.123;
    $statpot{'a7YL'}=0.082;
    $statpot{'a7YK'}=-0.020;
    $statpot{'a7YM'}=0.312;
    $statpot{'a7YF'}=0.051;
    $statpot{'a7YP'}=0.232;
    $statpot{'a7YS'}=0.053;
    $statpot{'a7YT'}=-0.073;
    $statpot{'a7YW'}=0.375;
    $statpot{'a7YY'}=0.043;
    $statpot{'a7YV'}=-0.028;
    $statpot{'a7VA'}=-0.166;
    $statpot{'a7VR'}=-0.245;
    $statpot{'a7VN'}=-0.077;
    $statpot{'a7VD'}=-0.035;
    $statpot{'a7VC'}=-0.088;
    $statpot{'a7VQ'}=-0.216;
    $statpot{'a7VE'}=-0.271;
    $statpot{'a7VG'}=0.172;
    $statpot{'a7VH'}=-0.153;
    $statpot{'a7VI'}=-0.154;
    $statpot{'a7VL'}=-0.100;
    $statpot{'a7VK'}=-0.180;
    $statpot{'a7VM'}=-0.060;
    $statpot{'a7VF'}=-0.132;
    $statpot{'a7VP'}=0.234;
    $statpot{'a7VS'}=-0.086;
    $statpot{'a7VT'}=-0.108;
    $statpot{'a7VW'}=-0.059;
    $statpot{'a7VY'}=-0.077;
    $statpot{'a7VV'}=-0.256;
    $statpot{'p8AA'}=-0.354;
    $statpot{'p8AR'}=-0.106;
    $statpot{'p8AN'}=-0.042;
    $statpot{'p8AD'}=0.088;
    $statpot{'p8AC'}=-0.401;
    $statpot{'p8AQ'}=-0.039;
    $statpot{'p8AE'}=0.212;
    $statpot{'p8AG'}=-0.098;
    $statpot{'p8AH'}=-0.076;
    $statpot{'p8AI'}=-0.152;
    $statpot{'p8AL'}=-0.103;
    $statpot{'p8AK'}=0.048;
    $statpot{'p8AM'}=-0.186;
    $statpot{'p8AF'}=-0.163;
    $statpot{'p8AP'}=-0.020;
    $statpot{'p8AS'}=-0.214;
    $statpot{'p8AT'}=-0.204;
    $statpot{'p8AW'}=-0.202;
    $statpot{'p8AY'}=-0.199;
    $statpot{'p8AV'}=-0.271;
    $statpot{'p8RA'}=-0.106;
    $statpot{'p8RR'}=0.179;
    $statpot{'p8RN'}=-0.051;
    $statpot{'p8RD'}=-0.165;
    $statpot{'p8RC'}=-0.135;
    $statpot{'p8RQ'}=0.214;
    $statpot{'p8RE'}=0.100;
    $statpot{'p8RG'}=0.074;
    $statpot{'p8RH'}=0.042;
    $statpot{'p8RI'}=0.171;
    $statpot{'p8RL'}=0.276;
    $statpot{'p8RK'}=0.258;
    $statpot{'p8RM'}=0.183;
    $statpot{'p8RF'}=0.126;
    $statpot{'p8RP'}=-0.024;
    $statpot{'p8RS'}=-0.133;
    $statpot{'p8RT'}=0.001;
    $statpot{'p8RW'}=-0.036;
    $statpot{'p8RY'}=0.057;
    $statpot{'p8RV'}=0.139;
    $statpot{'p8NA'}=-0.042;
    $statpot{'p8NR'}=-0.051;
    $statpot{'p8NN'}=-0.083;
    $statpot{'p8ND'}=0.017;
    $statpot{'p8NC'}=-0.063;
    $statpot{'p8NQ'}=0.117;
    $statpot{'p8NE'}=0.211;
    $statpot{'p8NG'}=0.058;
    $statpot{'p8NH'}=-0.116;
    $statpot{'p8NI'}=0.256;
    $statpot{'p8NL'}=0.188;
    $statpot{'p8NK'}=0.034;
    $statpot{'p8NM'}=0.124;
    $statpot{'p8NF'}=0.090;
    $statpot{'p8NP'}=-0.091;
    $statpot{'p8NS'}=-0.158;
    $statpot{'p8NT'}=0.028;
    $statpot{'p8NW'}=-0.082;
    $statpot{'p8NY'}=0.002;
    $statpot{'p8NV'}=0.196;
    $statpot{'p8DA'}=0.088;
    $statpot{'p8DR'}=-0.165;
    $statpot{'p8DN'}=0.017;
    $statpot{'p8DD'}=0.063;
    $statpot{'p8DC'}=-0.123;
    $statpot{'p8DQ'}=0.033;
    $statpot{'p8DE'}=0.229;
    $statpot{'p8DG'}=0.095;
    $statpot{'p8DH'}=-0.097;
    $statpot{'p8DI'}=0.398;
    $statpot{'p8DL'}=0.406;
    $statpot{'p8DK'}=0.072;
    $statpot{'p8DM'}=0.357;
    $statpot{'p8DF'}=0.198;
    $statpot{'p8DP'}=-0.047;
    $statpot{'p8DS'}=-0.008;
    $statpot{'p8DT'}=0.080;
    $statpot{'p8DW'}=-0.023;
    $statpot{'p8DY'}=0.042;
    $statpot{'p8DV'}=0.285;
    $statpot{'p8CA'}=-0.401;
    $statpot{'p8CR'}=-0.135;
    $statpot{'p8CN'}=-0.063;
    $statpot{'p8CD'}=-0.123;
    $statpot{'p8CC'}=-0.268;
    $statpot{'p8CQ'}=-0.012;
    $statpot{'p8CE'}=0.073;
    $statpot{'p8CG'}=-0.395;
    $statpot{'p8CH'}=-0.201;
    $statpot{'p8CI'}=-0.319;
    $statpot{'p8CL'}=-0.353;
    $statpot{'p8CK'}=0.057;
    $statpot{'p8CM'}=-0.720;
    $statpot{'p8CF'}=-0.578;
    $statpot{'p8CP'}=-0.171;
    $statpot{'p8CS'}=-0.391;
    $statpot{'p8CT'}=-0.304;
    $statpot{'p8CW'}=-0.781;
    $statpot{'p8CY'}=-0.559;
    $statpot{'p8CV'}=-0.213;
    $statpot{'p8QA'}=-0.039;
    $statpot{'p8QR'}=0.214;
    $statpot{'p8QN'}=0.117;
    $statpot{'p8QD'}=0.033;
    $statpot{'p8QC'}=-0.012;
    $statpot{'p8QQ'}=-0.092;
    $statpot{'p8QE'}=0.313;
    $statpot{'p8QG'}=0.038;
    $statpot{'p8QH'}=0.068;
    $statpot{'p8QI'}=0.335;
    $statpot{'p8QL'}=0.285;
    $statpot{'p8QK'}=0.254;
    $statpot{'p8QM'}=0.329;
    $statpot{'p8QF'}=0.148;
    $statpot{'p8QP'}=-0.052;
    $statpot{'p8QS'}=-0.052;
    $statpot{'p8QT'}=-0.064;
    $statpot{'p8QW'}=0.050;
    $statpot{'p8QY'}=-0.029;
    $statpot{'p8QV'}=0.173;
    $statpot{'p8EA'}=0.212;
    $statpot{'p8ER'}=0.100;
    $statpot{'p8EN'}=0.211;
    $statpot{'p8ED'}=0.229;
    $statpot{'p8EC'}=0.073;
    $statpot{'p8EQ'}=0.313;
    $statpot{'p8EE'}=0.370;
    $statpot{'p8EG'}=0.175;
    $statpot{'p8EH'}=0.054;
    $statpot{'p8EI'}=0.500;
    $statpot{'p8EL'}=0.457;
    $statpot{'p8EK'}=0.054;
    $statpot{'p8EM'}=0.365;
    $statpot{'p8EF'}=0.388;
    $statpot{'p8EP'}=0.098;
    $statpot{'p8ES'}=0.090;
    $statpot{'p8ET'}=0.213;
    $statpot{'p8EW'}=0.144;
    $statpot{'p8EY'}=0.174;
    $statpot{'p8EV'}=0.338;
    $statpot{'p8GA'}=-0.098;
    $statpot{'p8GR'}=0.074;
    $statpot{'p8GN'}=0.058;
    $statpot{'p8GD'}=0.095;
    $statpot{'p8GC'}=-0.395;
    $statpot{'p8GQ'}=0.038;
    $statpot{'p8GE'}=0.175;
    $statpot{'p8GG'}=-0.029;
    $statpot{'p8GH'}=-0.041;
    $statpot{'p8GI'}=0.062;
    $statpot{'p8GL'}=0.124;
    $statpot{'p8GK'}=0.075;
    $statpot{'p8GM'}=-0.027;
    $statpot{'p8GF'}=0.003;
    $statpot{'p8GP'}=-0.068;
    $statpot{'p8GS'}=-0.139;
    $statpot{'p8GT'}=-0.195;
    $statpot{'p8GW'}=-0.125;
    $statpot{'p8GY'}=-0.094;
    $statpot{'p8GV'}=-0.008;
    $statpot{'p8HA'}=-0.076;
    $statpot{'p8HR'}=0.042;
    $statpot{'p8HN'}=-0.116;
    $statpot{'p8HD'}=-0.097;
    $statpot{'p8HC'}=-0.201;
    $statpot{'p8HQ'}=0.068;
    $statpot{'p8HE'}=0.054;
    $statpot{'p8HG'}=-0.041;
    $statpot{'p8HH'}=-0.217;
    $statpot{'p8HI'}=0.005;
    $statpot{'p8HL'}=0.080;
    $statpot{'p8HK'}=0.355;
    $statpot{'p8HM'}=0.016;
    $statpot{'p8HF'}=-0.017;
    $statpot{'p8HP'}=0.035;
    $statpot{'p8HS'}=-0.081;
    $statpot{'p8HT'}=-0.098;
    $statpot{'p8HW'}=-0.109;
    $statpot{'p8HY'}=-0.274;
    $statpot{'p8HV'}=-0.056;
    $statpot{'p8IA'}=-0.152;
    $statpot{'p8IR'}=0.171;
    $statpot{'p8IN'}=0.256;
    $statpot{'p8ID'}=0.398;
    $statpot{'p8IC'}=-0.319;
    $statpot{'p8IQ'}=0.335;
    $statpot{'p8IE'}=0.500;
    $statpot{'p8IG'}=0.062;
    $statpot{'p8IH'}=0.005;
    $statpot{'p8II'}=-0.233;
    $statpot{'p8IL'}=-0.157;
    $statpot{'p8IK'}=0.474;
    $statpot{'p8IM'}=-0.238;
    $statpot{'p8IF'}=-0.400;
    $statpot{'p8IP'}=-0.001;
    $statpot{'p8IS'}=-0.034;
    $statpot{'p8IT'}=0.136;
    $statpot{'p8IW'}=-0.181;
    $statpot{'p8IY'}=-0.223;
    $statpot{'p8IV'}=-0.134;
    $statpot{'p8LA'}=-0.103;
    $statpot{'p8LR'}=0.276;
    $statpot{'p8LN'}=0.188;
    $statpot{'p8LD'}=0.406;
    $statpot{'p8LC'}=-0.353;
    $statpot{'p8LQ'}=0.285;
    $statpot{'p8LE'}=0.457;
    $statpot{'p8LG'}=0.124;
    $statpot{'p8LH'}=0.080;
    $statpot{'p8LI'}=-0.157;
    $statpot{'p8LL'}=-0.238;
    $statpot{'p8LK'}=0.449;
    $statpot{'p8LM'}=-0.276;
    $statpot{'p8LF'}=-0.323;
    $statpot{'p8LP'}=0.139;
    $statpot{'p8LS'}=0.089;
    $statpot{'p8LT'}=0.117;
    $statpot{'p8LW'}=-0.117;
    $statpot{'p8LY'}=-0.039;
    $statpot{'p8LV'}=-0.069;
    $statpot{'p8KA'}=0.048;
    $statpot{'p8KR'}=0.258;
    $statpot{'p8KN'}=0.034;
    $statpot{'p8KD'}=0.072;
    $statpot{'p8KC'}=0.057;
    $statpot{'p8KQ'}=0.254;
    $statpot{'p8KE'}=0.054;
    $statpot{'p8KG'}=0.075;
    $statpot{'p8KH'}=0.355;
    $statpot{'p8KI'}=0.474;
    $statpot{'p8KL'}=0.449;
    $statpot{'p8KK'}=0.215;
    $statpot{'p8KM'}=0.482;
    $statpot{'p8KF'}=0.291;
    $statpot{'p8KP'}=-0.109;
    $statpot{'p8KS'}=0.034;
    $statpot{'p8KT'}=0.160;
    $statpot{'p8KW'}=0.074;
    $statpot{'p8KY'}=0.207;
    $statpot{'p8KV'}=0.318;
    $statpot{'p8MA'}=-0.186;
    $statpot{'p8MR'}=0.183;
    $statpot{'p8MN'}=0.124;
    $statpot{'p8MD'}=0.357;
    $statpot{'p8MC'}=-0.720;
    $statpot{'p8MQ'}=0.329;
    $statpot{'p8ME'}=0.365;
    $statpot{'p8MG'}=-0.027;
    $statpot{'p8MH'}=0.016;
    $statpot{'p8MI'}=-0.238;
    $statpot{'p8ML'}=-0.276;
    $statpot{'p8MK'}=0.482;
    $statpot{'p8MM'}=-0.108;
    $statpot{'p8MF'}=-0.355;
    $statpot{'p8MP'}=-0.075;
    $statpot{'p8MS'}=-0.074;
    $statpot{'p8MT'}=0.025;
    $statpot{'p8MW'}=-0.013;
    $statpot{'p8MY'}=-0.239;
    $statpot{'p8MV'}=-0.163;
    $statpot{'p8FA'}=-0.163;
    $statpot{'p8FR'}=0.126;
    $statpot{'p8FN'}=0.090;
    $statpot{'p8FD'}=0.198;
    $statpot{'p8FC'}=-0.578;
    $statpot{'p8FQ'}=0.148;
    $statpot{'p8FE'}=0.388;
    $statpot{'p8FG'}=0.003;
    $statpot{'p8FH'}=-0.017;
    $statpot{'p8FI'}=-0.400;
    $statpot{'p8FL'}=-0.323;
    $statpot{'p8FK'}=0.291;
    $statpot{'p8FM'}=-0.355;
    $statpot{'p8FF'}=-0.358;
    $statpot{'p8FP'}=0.211;
    $statpot{'p8FS'}=-0.195;
    $statpot{'p8FT'}=-0.192;
    $statpot{'p8FW'}=-0.291;
    $statpot{'p8FY'}=-0.404;
    $statpot{'p8FV'}=-0.251;
    $statpot{'p8PA'}=-0.020;
    $statpot{'p8PR'}=-0.024;
    $statpot{'p8PN'}=-0.091;
    $statpot{'p8PD'}=-0.047;
    $statpot{'p8PC'}=-0.171;
    $statpot{'p8PQ'}=-0.052;
    $statpot{'p8PE'}=0.098;
    $statpot{'p8PG'}=-0.068;
    $statpot{'p8PH'}=0.035;
    $statpot{'p8PI'}=-0.001;
    $statpot{'p8PL'}=0.139;
    $statpot{'p8PK'}=-0.109;
    $statpot{'p8PM'}=-0.075;
    $statpot{'p8PF'}=0.211;
    $statpot{'p8PP'}=-0.257;
    $statpot{'p8PS'}=-0.125;
    $statpot{'p8PT'}=-0.080;
    $statpot{'p8PW'}=-0.187;
    $statpot{'p8PY'}=-0.140;
    $statpot{'p8PV'}=-0.020;
    $statpot{'p8SA'}=-0.214;
    $statpot{'p8SR'}=-0.133;
    $statpot{'p8SN'}=-0.158;
    $statpot{'p8SD'}=-0.008;
    $statpot{'p8SC'}=-0.391;
    $statpot{'p8SQ'}=-0.052;
    $statpot{'p8SE'}=0.090;
    $statpot{'p8SG'}=-0.139;
    $statpot{'p8SH'}=-0.081;
    $statpot{'p8SI'}=-0.034;
    $statpot{'p8SL'}=0.089;
    $statpot{'p8SK'}=0.034;
    $statpot{'p8SM'}=-0.074;
    $statpot{'p8SF'}=-0.195;
    $statpot{'p8SP'}=-0.125;
    $statpot{'p8SS'}=-0.204;
    $statpot{'p8ST'}=-0.202;
    $statpot{'p8SW'}=-0.062;
    $statpot{'p8SY'}=-0.031;
    $statpot{'p8SV'}=-0.009;
    $statpot{'p8TA'}=-0.204;
    $statpot{'p8TR'}=0.001;
    $statpot{'p8TN'}=0.028;
    $statpot{'p8TD'}=0.080;
    $statpot{'p8TC'}=-0.304;
    $statpot{'p8TQ'}=-0.064;
    $statpot{'p8TE'}=0.213;
    $statpot{'p8TG'}=-0.195;
    $statpot{'p8TH'}=-0.098;
    $statpot{'p8TI'}=0.136;
    $statpot{'p8TL'}=0.117;
    $statpot{'p8TK'}=0.160;
    $statpot{'p8TM'}=0.025;
    $statpot{'p8TF'}=-0.192;
    $statpot{'p8TP'}=-0.080;
    $statpot{'p8TS'}=-0.202;
    $statpot{'p8TT'}=-0.208;
    $statpot{'p8TW'}=-0.235;
    $statpot{'p8TY'}=-0.127;
    $statpot{'p8TV'}=-0.002;
    $statpot{'p8WA'}=-0.202;
    $statpot{'p8WR'}=-0.036;
    $statpot{'p8WN'}=-0.082;
    $statpot{'p8WD'}=-0.023;
    $statpot{'p8WC'}=-0.781;
    $statpot{'p8WQ'}=0.050;
    $statpot{'p8WE'}=0.144;
    $statpot{'p8WG'}=-0.125;
    $statpot{'p8WH'}=-0.109;
    $statpot{'p8WI'}=-0.181;
    $statpot{'p8WL'}=-0.117;
    $statpot{'p8WK'}=0.074;
    $statpot{'p8WM'}=-0.013;
    $statpot{'p8WF'}=-0.291;
    $statpot{'p8WP'}=-0.187;
    $statpot{'p8WS'}=-0.062;
    $statpot{'p8WT'}=-0.235;
    $statpot{'p8WW'}=-0.241;
    $statpot{'p8WY'}=-0.234;
    $statpot{'p8WV'}=-0.219;
    $statpot{'p8YA'}=-0.199;
    $statpot{'p8YR'}=0.057;
    $statpot{'p8YN'}=0.002;
    $statpot{'p8YD'}=0.042;
    $statpot{'p8YC'}=-0.559;
    $statpot{'p8YQ'}=-0.029;
    $statpot{'p8YE'}=0.174;
    $statpot{'p8YG'}=-0.094;
    $statpot{'p8YH'}=-0.274;
    $statpot{'p8YI'}=-0.223;
    $statpot{'p8YL'}=-0.039;
    $statpot{'p8YK'}=0.207;
    $statpot{'p8YM'}=-0.239;
    $statpot{'p8YF'}=-0.404;
    $statpot{'p8YP'}=-0.140;
    $statpot{'p8YS'}=-0.031;
    $statpot{'p8YT'}=-0.127;
    $statpot{'p8YW'}=-0.234;
    $statpot{'p8YY'}=-0.381;
    $statpot{'p8YV'}=-0.178;
    $statpot{'p8VA'}=-0.271;
    $statpot{'p8VR'}=0.139;
    $statpot{'p8VN'}=0.196;
    $statpot{'p8VD'}=0.285;
    $statpot{'p8VC'}=-0.213;
    $statpot{'p8VQ'}=0.173;
    $statpot{'p8VE'}=0.338;
    $statpot{'p8VG'}=-0.008;
    $statpot{'p8VH'}=-0.056;
    $statpot{'p8VI'}=-0.134;
    $statpot{'p8VL'}=-0.069;
    $statpot{'p8VK'}=0.318;
    $statpot{'p8VM'}=-0.163;
    $statpot{'p8VF'}=-0.251;
    $statpot{'p8VP'}=-0.020;
    $statpot{'p8VS'}=-0.009;
    $statpot{'p8VT'}=-0.002;
    $statpot{'p8VW'}=-0.219;
    $statpot{'p8VY'}=-0.178;
    $statpot{'p8VV'}=-0.087;
    $statpot{'f8AA'}=-0.240;
    $statpot{'f8AR'}=0.048;
    $statpot{'f8AN'}=0.084;
    $statpot{'f8AD'}=0.194;
    $statpot{'f8AC'}=-0.261;
    $statpot{'f8AQ'}=0.072;
    $statpot{'f8AE'}=0.180;
    $statpot{'f8AG'}=0.029;
    $statpot{'f8AH'}=0.172;
    $statpot{'f8AI'}=-0.361;
    $statpot{'f8AL'}=-0.163;
    $statpot{'f8AK'}=0.268;
    $statpot{'f8AM'}=-0.286;
    $statpot{'f8AF'}=-0.406;
    $statpot{'f8AP'}=0.120;
    $statpot{'f8AS'}=-0.001;
    $statpot{'f8AT'}=-0.053;
    $statpot{'f8AW'}=-0.320;
    $statpot{'f8AY'}=-0.355;
    $statpot{'f8AV'}=-0.411;
    $statpot{'f8RA'}=0.223;
    $statpot{'f8RR'}=0.421;
    $statpot{'f8RN'}=0.171;
    $statpot{'f8RD'}=0.151;
    $statpot{'f8RC'}=0.147;
    $statpot{'f8RQ'}=0.330;
    $statpot{'f8RE'}=0.108;
    $statpot{'f8RG'}=0.401;
    $statpot{'f8RH'}=0.442;
    $statpot{'f8RI'}=0.123;
    $statpot{'f8RL'}=0.075;
    $statpot{'f8RK'}=0.715;
    $statpot{'f8RM'}=0.283;
    $statpot{'f8RF'}=-0.006;
    $statpot{'f8RP'}=0.145;
    $statpot{'f8RS'}=0.349;
    $statpot{'f8RT'}=0.294;
    $statpot{'f8RW'}=0.313;
    $statpot{'f8RY'}=-0.093;
    $statpot{'f8RV'}=0.198;
    $statpot{'f8NA'}=0.176;
    $statpot{'f8NR'}=0.436;
    $statpot{'f8NN'}=0.649;
    $statpot{'f8ND'}=0.587;
    $statpot{'f8NC'}=0.246;
    $statpot{'f8NQ'}=0.745;
    $statpot{'f8NE'}=0.625;
    $statpot{'f8NG'}=0.393;
    $statpot{'f8NH'}=0.040;
    $statpot{'f8NI'}=0.143;
    $statpot{'f8NL'}=0.269;
    $statpot{'f8NK'}=0.686;
    $statpot{'f8NM'}=-0.031;
    $statpot{'f8NF'}=0.045;
    $statpot{'f8NP'}=0.270;
    $statpot{'f8NS'}=0.358;
    $statpot{'f8NT'}=0.237;
    $statpot{'f8NW'}=-0.078;
    $statpot{'f8NY'}=0.119;
    $statpot{'f8NV'}=0.147;
    $statpot{'f8DA'}=0.417;
    $statpot{'f8DR'}=0.292;
    $statpot{'f8DN'}=0.670;
    $statpot{'f8DD'}=0.754;
    $statpot{'f8DC'}=0.156;
    $statpot{'f8DQ'}=0.677;
    $statpot{'f8DE'}=0.727;
    $statpot{'f8DG'}=0.464;
    $statpot{'f8DH'}=0.341;
    $statpot{'f8DI'}=0.315;
    $statpot{'f8DL'}=0.446;
    $statpot{'f8DK'}=0.353;
    $statpot{'f8DM'}=0.310;
    $statpot{'f8DF'}=0.126;
    $statpot{'f8DP'}=0.504;
    $statpot{'f8DS'}=0.435;
    $statpot{'f8DT'}=0.452;
    $statpot{'f8DW'}=0.229;
    $statpot{'f8DY'}=-0.064;
    $statpot{'f8DV'}=0.191;
    $statpot{'f8CA'}=-0.346;
    $statpot{'f8CR'}=-0.067;
    $statpot{'f8CN'}=-0.038;
    $statpot{'f8CD'}=0.083;
    $statpot{'f8CC'}=-0.224;
    $statpot{'f8CQ'}=-0.041;
    $statpot{'f8CE'}=0.204;
    $statpot{'f8CG'}=-0.357;
    $statpot{'f8CH'}=-0.314;
    $statpot{'f8CI'}=-0.405;
    $statpot{'f8CL'}=-0.311;
    $statpot{'f8CK'}=0.063;
    $statpot{'f8CM'}=-0.391;
    $statpot{'f8CF'}=-0.709;
    $statpot{'f8CP'}=-0.258;
    $statpot{'f8CS'}=-0.120;
    $statpot{'f8CT'}=-0.282;
    $statpot{'f8CW'}=-0.979;
    $statpot{'f8CY'}=-0.427;
    $statpot{'f8CV'}=-0.511;
    $statpot{'f8QA'}=0.215;
    $statpot{'f8QR'}=0.284;
    $statpot{'f8QN'}=0.609;
    $statpot{'f8QD'}=0.537;
    $statpot{'f8QC'}=-0.028;
    $statpot{'f8QQ'}=0.193;
    $statpot{'f8QE'}=0.648;
    $statpot{'f8QG'}=0.364;
    $statpot{'f8QH'}=0.145;
    $statpot{'f8QI'}=0.174;
    $statpot{'f8QL'}=0.166;
    $statpot{'f8QK'}=0.647;
    $statpot{'f8QM'}=0.272;
    $statpot{'f8QF'}=0.017;
    $statpot{'f8QP'}=0.247;
    $statpot{'f8QS'}=0.345;
    $statpot{'f8QT'}=0.529;
    $statpot{'f8QW'}=-0.021;
    $statpot{'f8QY'}=0.052;
    $statpot{'f8QV'}=0.011;
    $statpot{'f8EA'}=0.478;
    $statpot{'f8ER'}=0.200;
    $statpot{'f8EN'}=0.614;
    $statpot{'f8ED'}=0.691;
    $statpot{'f8EC'}=0.417;
    $statpot{'f8EQ'}=0.717;
    $statpot{'f8EE'}=0.762;
    $statpot{'f8EG'}=0.828;
    $statpot{'f8EH'}=0.242;
    $statpot{'f8EI'}=0.348;
    $statpot{'f8EL'}=0.517;
    $statpot{'f8EK'}=0.391;
    $statpot{'f8EM'}=0.322;
    $statpot{'f8EF'}=0.349;
    $statpot{'f8EP'}=0.596;
    $statpot{'f8ES'}=0.472;
    $statpot{'f8ET'}=0.404;
    $statpot{'f8EW'}=0.031;
    $statpot{'f8EY'}=0.056;
    $statpot{'f8EV'}=0.413;
    $statpot{'f8GA'}=0.097;
    $statpot{'f8GR'}=0.274;
    $statpot{'f8GN'}=0.356;
    $statpot{'f8GD'}=0.355;
    $statpot{'f8GC'}=-0.279;
    $statpot{'f8GQ'}=0.223;
    $statpot{'f8GE'}=0.592;
    $statpot{'f8GG'}=0.095;
    $statpot{'f8GH'}=-0.017;
    $statpot{'f8GI'}=-0.043;
    $statpot{'f8GL'}=0.044;
    $statpot{'f8GK'}=0.515;
    $statpot{'f8GM'}=0.001;
    $statpot{'f8GF'}=0.013;
    $statpot{'f8GP'}=0.339;
    $statpot{'f8GS'}=0.142;
    $statpot{'f8GT'}=0.164;
    $statpot{'f8GW'}=-0.026;
    $statpot{'f8GY'}=-0.100;
    $statpot{'f8GV'}=-0.040;
    $statpot{'f8HA'}=0.208;
    $statpot{'f8HR'}=0.413;
    $statpot{'f8HN'}=-0.051;
    $statpot{'f8HD'}=0.073;
    $statpot{'f8HC'}=-0.382;
    $statpot{'f8HQ'}=0.038;
    $statpot{'f8HE'}=-0.041;
    $statpot{'f8HG'}=-0.162;
    $statpot{'f8HH'}=-0.045;
    $statpot{'f8HI'}=-0.050;
    $statpot{'f8HL'}=-0.164;
    $statpot{'f8HK'}=0.282;
    $statpot{'f8HM'}=-0.219;
    $statpot{'f8HF'}=-0.396;
    $statpot{'f8HP'}=-0.073;
    $statpot{'f8HS'}=0.047;
    $statpot{'f8HT'}=0.038;
    $statpot{'f8HW'}=-0.337;
    $statpot{'f8HY'}=-0.213;
    $statpot{'f8HV'}=-0.108;
    $statpot{'f8IA'}=-0.342;
    $statpot{'f8IR'}=0.121;
    $statpot{'f8IN'}=0.098;
    $statpot{'f8ID'}=0.269;
    $statpot{'f8IC'}=-0.422;
    $statpot{'f8IQ'}=0.077;
    $statpot{'f8IE'}=0.277;
    $statpot{'f8IG'}=-0.007;
    $statpot{'f8IH'}=-0.073;
    $statpot{'f8II'}=-0.377;
    $statpot{'f8IL'}=-0.660;
    $statpot{'f8IK'}=0.359;
    $statpot{'f8IM'}=-0.580;
    $statpot{'f8IF'}=-0.679;
    $statpot{'f8IP'}=0.086;
    $statpot{'f8IS'}=-0.016;
    $statpot{'f8IT'}=-0.104;
    $statpot{'f8IW'}=-0.590;
    $statpot{'f8IY'}=-0.339;
    $statpot{'f8IV'}=-0.272;
    $statpot{'f8LA'}=-0.161;
    $statpot{'f8LR'}=-0.015;
    $statpot{'f8LN'}=0.195;
    $statpot{'f8LD'}=0.145;
    $statpot{'f8LC'}=-0.242;
    $statpot{'f8LQ'}=0.066;
    $statpot{'f8LE'}=0.355;
    $statpot{'f8LG'}=0.030;
    $statpot{'f8LH'}=-0.192;
    $statpot{'f8LI'}=-0.662;
    $statpot{'f8LL'}=-0.754;
    $statpot{'f8LK'}=0.266;
    $statpot{'f8LM'}=-0.636;
    $statpot{'f8LF'}=-0.703;
    $statpot{'f8LP'}=0.021;
    $statpot{'f8LS'}=0.005;
    $statpot{'f8LT'}=-0.111;
    $statpot{'f8LW'}=-0.479;
    $statpot{'f8LY'}=-0.430;
    $statpot{'f8LV'}=-0.328;
    $statpot{'f8KA'}=0.517;
    $statpot{'f8KR'}=0.722;
    $statpot{'f8KN'}=0.593;
    $statpot{'f8KD'}=0.274;
    $statpot{'f8KC'}=0.344;
    $statpot{'f8KQ'}=0.709;
    $statpot{'f8KE'}=0.304;
    $statpot{'f8KG'}=0.640;
    $statpot{'f8KH'}=0.407;
    $statpot{'f8KI'}=0.436;
    $statpot{'f8KL'}=0.440;
    $statpot{'f8KK'}=1.107;
    $statpot{'f8KM'}=0.536;
    $statpot{'f8KF'}=0.343;
    $statpot{'f8KP'}=0.496;
    $statpot{'f8KS'}=0.543;
    $statpot{'f8KT'}=0.514;
    $statpot{'f8KW'}=0.082;
    $statpot{'f8KY'}=0.315;
    $statpot{'f8KV'}=0.481;
    $statpot{'f8MA'}=-0.174;
    $statpot{'f8MR'}=0.214;
    $statpot{'f8MN'}=-0.161;
    $statpot{'f8MD'}=0.106;
    $statpot{'f8MC'}=-0.239;
    $statpot{'f8MQ'}=0.261;
    $statpot{'f8ME'}=0.156;
    $statpot{'f8MG'}=0.045;
    $statpot{'f8MH'}=-0.217;
    $statpot{'f8MI'}=-0.623;
    $statpot{'f8ML'}=-0.645;
    $statpot{'f8MK'}=0.376;
    $statpot{'f8MM'}=-0.635;
    $statpot{'f8MF'}=-0.486;
    $statpot{'f8MP'}=-0.075;
    $statpot{'f8MS'}=-0.119;
    $statpot{'f8MT'}=-0.224;
    $statpot{'f8MW'}=-0.459;
    $statpot{'f8MY'}=-0.636;
    $statpot{'f8MV'}=-0.417;
    $statpot{'f8FA'}=-0.399;
    $statpot{'f8FR'}=-0.195;
    $statpot{'f8FN'}=-0.133;
    $statpot{'f8FD'}=-0.087;
    $statpot{'f8FC'}=-0.683;
    $statpot{'f8FQ'}=-0.104;
    $statpot{'f8FE'}=0.077;
    $statpot{'f8FG'}=-0.021;
    $statpot{'f8FH'}=-0.505;
    $statpot{'f8FI'}=-0.700;
    $statpot{'f8FL'}=-0.736;
    $statpot{'f8FK'}=0.054;
    $statpot{'f8FM'}=-0.448;
    $statpot{'f8FF'}=-0.851;
    $statpot{'f8FP'}=-0.114;
    $statpot{'f8FS'}=-0.216;
    $statpot{'f8FT'}=-0.256;
    $statpot{'f8FW'}=-0.859;
    $statpot{'f8FY'}=-0.671;
    $statpot{'f8FV'}=-0.669;
    $statpot{'f8PA'}=0.091;
    $statpot{'f8PR'}=0.333;
    $statpot{'f8PN'}=0.232;
    $statpot{'f8PD'}=0.370;
    $statpot{'f8PC'}=-0.131;
    $statpot{'f8PQ'}=0.211;
    $statpot{'f8PE'}=0.387;
    $statpot{'f8PG'}=0.308;
    $statpot{'f8PH'}=-0.092;
    $statpot{'f8PI'}=0.060;
    $statpot{'f8PL'}=0.076;
    $statpot{'f8PK'}=0.381;
    $statpot{'f8PM'}=-0.069;
    $statpot{'f8PF'}=-0.004;
    $statpot{'f8PP'}=0.218;
    $statpot{'f8PS'}=0.351;
    $statpot{'f8PT'}=0.120;
    $statpot{'f8PW'}=-0.325;
    $statpot{'f8PY'}=-0.091;
    $statpot{'f8PV'}=0.094;
    $statpot{'f8SA'}=0.105;
    $statpot{'f8SR'}=0.364;
    $statpot{'f8SN'}=0.300;
    $statpot{'f8SD'}=0.414;
    $statpot{'f8SC'}=-0.021;
    $statpot{'f8SQ'}=0.339;
    $statpot{'f8SE'}=0.450;
    $statpot{'f8SG'}=0.216;
    $statpot{'f8SH'}=0.216;
    $statpot{'f8SI'}=0.080;
    $statpot{'f8SL'}=0.037;
    $statpot{'f8SK'}=0.568;
    $statpot{'f8SM'}=-0.116;
    $statpot{'f8SF'}=-0.151;
    $statpot{'f8SP'}=0.288;
    $statpot{'f8SS'}=0.188;
    $statpot{'f8ST'}=0.195;
    $statpot{'f8SW'}=0.020;
    $statpot{'f8SY'}=0.012;
    $statpot{'f8SV'}=-0.048;
    $statpot{'f8TA'}=0.031;
    $statpot{'f8TR'}=0.238;
    $statpot{'f8TN'}=0.212;
    $statpot{'f8TD'}=0.437;
    $statpot{'f8TC'}=-0.146;
    $statpot{'f8TQ'}=0.462;
    $statpot{'f8TE'}=0.363;
    $statpot{'f8TG'}=0.134;
    $statpot{'f8TH'}=0.138;
    $statpot{'f8TI'}=-0.073;
    $statpot{'f8TL'}=-0.003;
    $statpot{'f8TK'}=0.482;
    $statpot{'f8TM'}=-0.198;
    $statpot{'f8TF'}=-0.150;
    $statpot{'f8TP'}=0.086;
    $statpot{'f8TS'}=0.171;
    $statpot{'f8TT'}=0.206;
    $statpot{'f8TW'}=-0.036;
    $statpot{'f8TY'}=-0.141;
    $statpot{'f8TV'}=-0.074;
    $statpot{'f8WA'}=-0.275;
    $statpot{'f8WR'}=-0.011;
    $statpot{'f8WN'}=-0.229;
    $statpot{'f8WD'}=-0.073;
    $statpot{'f8WC'}=-0.831;
    $statpot{'f8WQ'}=-0.134;
    $statpot{'f8WE'}=-0.181;
    $statpot{'f8WG'}=-0.031;
    $statpot{'f8WH'}=-0.507;
    $statpot{'f8WI'}=-0.607;
    $statpot{'f8WL'}=-0.507;
    $statpot{'f8WK'}=0.079;
    $statpot{'f8WM'}=-0.455;
    $statpot{'f8WF'}=-0.819;
    $statpot{'f8WP'}=-0.334;
    $statpot{'f8WS'}=-0.011;
    $statpot{'f8WT'}=-0.062;
    $statpot{'f8WW'}=-0.689;
    $statpot{'f8WY'}=-0.558;
    $statpot{'f8WV'}=-0.549;
    $statpot{'f8YA'}=-0.374;
    $statpot{'f8YR'}=-0.257;
    $statpot{'f8YN'}=-0.020;
    $statpot{'f8YD'}=-0.301;
    $statpot{'f8YC'}=-0.446;
    $statpot{'f8YQ'}=-0.046;
    $statpot{'f8YE'}=-0.135;
    $statpot{'f8YG'}=-0.054;
    $statpot{'f8YH'}=-0.235;
    $statpot{'f8YI'}=-0.479;
    $statpot{'f8YL'}=-0.489;
    $statpot{'f8YK'}=0.106;
    $statpot{'f8YM'}=-0.656;
    $statpot{'f8YF'}=-0.655;
    $statpot{'f8YP'}=-0.163;
    $statpot{'f8YS'}=-0.111;
    $statpot{'f8YT'}=-0.099;
    $statpot{'f8YW'}=-0.611;
    $statpot{'f8YY'}=-0.349;
    $statpot{'f8YV'}=-0.468;
    $statpot{'f8VA'}=-0.390;
    $statpot{'f8VR'}=0.057;
    $statpot{'f8VN'}=0.073;
    $statpot{'f8VD'}=0.094;
    $statpot{'f8VC'}=-0.461;
    $statpot{'f8VQ'}=-0.079;
    $statpot{'f8VE'}=0.222;
    $statpot{'f8VG'}=-0.081;
    $statpot{'f8VH'}=-0.272;
    $statpot{'f8VI'}=-0.272;
    $statpot{'f8VL'}=-0.365;
    $statpot{'f8VK'}=0.352;
    $statpot{'f8VM'}=-0.417;
    $statpot{'f8VF'}=-0.643;
    $statpot{'f8VP'}=-0.011;
    $statpot{'f8VS'}=-0.097;
    $statpot{'f8VT'}=-0.098;
    $statpot{'f8VW'}=-0.567;
    $statpot{'f8VY'}=-0.476;
    $statpot{'f8VV'}=-0.415;
    $statpot{'a8AA'}=0.038;
    $statpot{'a8AR'}=0.127;
    $statpot{'a8AN'}=0.064;
    $statpot{'a8AD'}=0.388;
    $statpot{'a8AC'}=-0.051;
    $statpot{'a8AQ'}=0.320;
    $statpot{'a8AE'}=0.415;
    $statpot{'a8AG'}=-0.287;
    $statpot{'a8AH'}=0.065;
    $statpot{'a8AI'}=-0.071;
    $statpot{'a8AL'}=0.101;
    $statpot{'a8AK'}=0.179;
    $statpot{'a8AM'}=0.075;
    $statpot{'a8AF'}=-0.118;
    $statpot{'a8AP'}=-0.206;
    $statpot{'a8AS'}=0.132;
    $statpot{'a8AT'}=-0.030;
    $statpot{'a8AW'}=0.303;
    $statpot{'a8AY'}=-0.100;
    $statpot{'a8AV'}=-0.066;
    $statpot{'a8RA'}=-0.154;
    $statpot{'a8RR'}=0.308;
    $statpot{'a8RN'}=0.083;
    $statpot{'a8RD'}=0.322;
    $statpot{'a8RC'}=-0.347;
    $statpot{'a8RQ'}=0.405;
    $statpot{'a8RE'}=0.631;
    $statpot{'a8RG'}=-0.260;
    $statpot{'a8RH'}=0.454;
    $statpot{'a8RI'}=-0.054;
    $statpot{'a8RL'}=-0.196;
    $statpot{'a8RK'}=0.324;
    $statpot{'a8RM'}=-0.165;
    $statpot{'a8RF'}=-0.359;
    $statpot{'a8RP'}=-0.053;
    $statpot{'a8RS'}=0.177;
    $statpot{'a8RT'}=0.065;
    $statpot{'a8RW'}=-0.254;
    $statpot{'a8RY'}=-0.174;
    $statpot{'a8RV'}=-0.281;
    $statpot{'a8NA'}=-0.077;
    $statpot{'a8NR'}=-0.229;
    $statpot{'a8NN'}=0.032;
    $statpot{'a8ND'}=0.382;
    $statpot{'a8NC'}=-0.583;
    $statpot{'a8NQ'}=0.345;
    $statpot{'a8NE'}=0.460;
    $statpot{'a8NG'}=-0.050;
    $statpot{'a8NH'}=-0.127;
    $statpot{'a8NI'}=-0.333;
    $statpot{'a8NL'}=-0.176;
    $statpot{'a8NK'}=0.347;
    $statpot{'a8NM'}=-0.160;
    $statpot{'a8NF'}=-0.337;
    $statpot{'a8NP'}=-0.146;
    $statpot{'a8NS'}=0.180;
    $statpot{'a8NT'}=0.039;
    $statpot{'a8NW'}=-0.148;
    $statpot{'a8NY'}=-0.211;
    $statpot{'a8NV'}=-0.170;
    $statpot{'a8DA'}=0.021;
    $statpot{'a8DR'}=0.076;
    $statpot{'a8DN'}=0.277;
    $statpot{'a8DD'}=0.627;
    $statpot{'a8DC'}=-0.385;
    $statpot{'a8DQ'}=0.428;
    $statpot{'a8DE'}=0.545;
    $statpot{'a8DG'}=0.062;
    $statpot{'a8DH'}=-0.055;
    $statpot{'a8DI'}=-0.197;
    $statpot{'a8DL'}=-0.336;
    $statpot{'a8DK'}=0.219;
    $statpot{'a8DM'}=-0.097;
    $statpot{'a8DF'}=-0.318;
    $statpot{'a8DP'}=0.015;
    $statpot{'a8DS'}=0.304;
    $statpot{'a8DT'}=0.161;
    $statpot{'a8DW'}=-0.310;
    $statpot{'a8DY'}=-0.344;
    $statpot{'a8DV'}=-0.406;
    $statpot{'a8CA'}=0.161;
    $statpot{'a8CR'}=-0.057;
    $statpot{'a8CN'}=-0.315;
    $statpot{'a8CD'}=-0.310;
    $statpot{'a8CC'}=0.118;
    $statpot{'a8CQ'}=-0.067;
    $statpot{'a8CE'}=0.290;
    $statpot{'a8CG'}=-0.365;
    $statpot{'a8CH'}=-0.293;
    $statpot{'a8CI'}=0.154;
    $statpot{'a8CL'}=0.031;
    $statpot{'a8CK'}=0.087;
    $statpot{'a8CM'}=-0.061;
    $statpot{'a8CF'}=-0.264;
    $statpot{'a8CP'}=-0.350;
    $statpot{'a8CS'}=-0.264;
    $statpot{'a8CT'}=-0.338;
    $statpot{'a8CW'}=0.284;
    $statpot{'a8CY'}=-0.125;
    $statpot{'a8CV'}=0.098;
    $statpot{'a8QA'}=0.049;
    $statpot{'a8QR'}=0.500;
    $statpot{'a8QN'}=0.527;
    $statpot{'a8QD'}=0.657;
    $statpot{'a8QC'}=-0.088;
    $statpot{'a8QQ'}=0.273;
    $statpot{'a8QE'}=0.714;
    $statpot{'a8QG'}=-0.014;
    $statpot{'a8QH'}=-0.054;
    $statpot{'a8QI'}=-0.140;
    $statpot{'a8QL'}=-0.064;
    $statpot{'a8QK'}=0.589;
    $statpot{'a8QM'}=0.132;
    $statpot{'a8QF'}=-0.256;
    $statpot{'a8QP'}=-0.037;
    $statpot{'a8QS'}=0.073;
    $statpot{'a8QT'}=0.232;
    $statpot{'a8QW'}=0.069;
    $statpot{'a8QY'}=0.005;
    $statpot{'a8QV'}=-0.064;
    $statpot{'a8EA'}=-0.061;
    $statpot{'a8ER'}=0.390;
    $statpot{'a8EN'}=0.476;
    $statpot{'a8ED'}=0.600;
    $statpot{'a8EC'}=-0.017;
    $statpot{'a8EQ'}=0.593;
    $statpot{'a8EE'}=0.418;
    $statpot{'a8EG'}=-0.060;
    $statpot{'a8EH'}=0.004;
    $statpot{'a8EI'}=-0.001;
    $statpot{'a8EL'}=-0.002;
    $statpot{'a8EK'}=0.535;
    $statpot{'a8EM'}=-0.093;
    $statpot{'a8EF'}=-0.054;
    $statpot{'a8EP'}=-0.013;
    $statpot{'a8ES'}=0.494;
    $statpot{'a8ET'}=0.302;
    $statpot{'a8EW'}=-0.207;
    $statpot{'a8EY'}=-0.323;
    $statpot{'a8EV'}=-0.125;
    $statpot{'a8GA'}=-0.368;
    $statpot{'a8GR'}=-0.133;
    $statpot{'a8GN'}=-0.011;
    $statpot{'a8GD'}=0.199;
    $statpot{'a8GC'}=-0.477;
    $statpot{'a8GQ'}=0.176;
    $statpot{'a8GE'}=0.149;
    $statpot{'a8GG'}=-0.120;
    $statpot{'a8GH'}=-0.455;
    $statpot{'a8GI'}=-0.240;
    $statpot{'a8GL'}=-0.344;
    $statpot{'a8GK'}=0.088;
    $statpot{'a8GM'}=-0.174;
    $statpot{'a8GF'}=-0.259;
    $statpot{'a8GP'}=-0.254;
    $statpot{'a8GS'}=-0.174;
    $statpot{'a8GT'}=-0.176;
    $statpot{'a8GW'}=-0.373;
    $statpot{'a8GY'}=-0.163;
    $statpot{'a8GV'}=-0.212;
    $statpot{'a8HA'}=0.006;
    $statpot{'a8HR'}=0.509;
    $statpot{'a8HN'}=0.022;
    $statpot{'a8HD'}=0.402;
    $statpot{'a8HC'}=-0.164;
    $statpot{'a8HQ'}=0.125;
    $statpot{'a8HE'}=0.631;
    $statpot{'a8HG'}=-0.266;
    $statpot{'a8HH'}=-0.002;
    $statpot{'a8HI'}=-0.394;
    $statpot{'a8HL'}=-0.108;
    $statpot{'a8HK'}=0.142;
    $statpot{'a8HM'}=-0.432;
    $statpot{'a8HF'}=-0.460;
    $statpot{'a8HP'}=-0.103;
    $statpot{'a8HS'}=0.307;
    $statpot{'a8HT'}=0.137;
    $statpot{'a8HW'}=-0.478;
    $statpot{'a8HY'}=-0.333;
    $statpot{'a8HV'}=-0.313;
    $statpot{'a8IA'}=-0.117;
    $statpot{'a8IR'}=-0.052;
    $statpot{'a8IN'}=-0.282;
    $statpot{'a8ID'}=-0.147;
    $statpot{'a8IC'}=0.208;
    $statpot{'a8IQ'}=0.002;
    $statpot{'a8IE'}=0.097;
    $statpot{'a8IG'}=-0.287;
    $statpot{'a8IH'}=-0.363;
    $statpot{'a8II'}=0.020;
    $statpot{'a8IL'}=0.036;
    $statpot{'a8IK'}=-0.088;
    $statpot{'a8IM'}=0.039;
    $statpot{'a8IF'}=-0.017;
    $statpot{'a8IP'}=-0.499;
    $statpot{'a8IS'}=-0.227;
    $statpot{'a8IT'}=-0.088;
    $statpot{'a8IW'}=-0.110;
    $statpot{'a8IY'}=-0.374;
    $statpot{'a8IV'}=-0.204;
    $statpot{'a8LA'}=0.095;
    $statpot{'a8LR'}=-0.056;
    $statpot{'a8LN'}=-0.085;
    $statpot{'a8LD'}=0.004;
    $statpot{'a8LC'}=-0.122;
    $statpot{'a8LQ'}=0.098;
    $statpot{'a8LE'}=0.212;
    $statpot{'a8LG'}=-0.327;
    $statpot{'a8LH'}=-0.054;
    $statpot{'a8LI'}=0.041;
    $statpot{'a8LL'}=0.156;
    $statpot{'a8LK'}=0.141;
    $statpot{'a8LM'}=0.251;
    $statpot{'a8LF'}=0.055;
    $statpot{'a8LP'}=-0.079;
    $statpot{'a8LS'}=-0.116;
    $statpot{'a8LT'}=0.012;
    $statpot{'a8LW'}=-0.074;
    $statpot{'a8LY'}=-0.138;
    $statpot{'a8LV'}=0.012;
    $statpot{'a8KA'}=-0.134;
    $statpot{'a8KR'}=0.316;
    $statpot{'a8KN'}=0.472;
    $statpot{'a8KD'}=0.353;
    $statpot{'a8KC'}=-0.266;
    $statpot{'a8KQ'}=0.496;
    $statpot{'a8KE'}=0.743;
    $statpot{'a8KG'}=-0.032;
    $statpot{'a8KH'}=-0.024;
    $statpot{'a8KI'}=-0.168;
    $statpot{'a8KL'}=-0.082;
    $statpot{'a8KK'}=0.315;
    $statpot{'a8KM'}=-0.136;
    $statpot{'a8KF'}=-0.311;
    $statpot{'a8KP'}=-0.119;
    $statpot{'a8KS'}=0.235;
    $statpot{'a8KT'}=0.298;
    $statpot{'a8KW'}=-0.102;
    $statpot{'a8KY'}=-0.177;
    $statpot{'a8KV'}=-0.086;
    $statpot{'a8MA'}=-0.174;
    $statpot{'a8MR'}=-0.079;
    $statpot{'a8MN'}=0.082;
    $statpot{'a8MD'}=0.218;
    $statpot{'a8MC'}=-0.359;
    $statpot{'a8MQ'}=0.150;
    $statpot{'a8ME'}=0.151;
    $statpot{'a8MG'}=-0.234;
    $statpot{'a8MH'}=-0.435;
    $statpot{'a8MI'}=0.208;
    $statpot{'a8ML'}=0.281;
    $statpot{'a8MK'}=0.039;
    $statpot{'a8MM'}=-0.037;
    $statpot{'a8MF'}=-0.043;
    $statpot{'a8MP'}=-0.176;
    $statpot{'a8MS'}=0.099;
    $statpot{'a8MT'}=0.041;
    $statpot{'a8MW'}=0.392;
    $statpot{'a8MY'}=0.114;
    $statpot{'a8MV'}=0.010;
    $statpot{'a8FA'}=-0.137;
    $statpot{'a8FR'}=-0.055;
    $statpot{'a8FN'}=-0.083;
    $statpot{'a8FD'}=-0.008;
    $statpot{'a8FC'}=-0.325;
    $statpot{'a8FQ'}=-0.069;
    $statpot{'a8FE'}=0.411;
    $statpot{'a8FG'}=-0.214;
    $statpot{'a8FH'}=-0.251;
    $statpot{'a8FI'}=0.061;
    $statpot{'a8FL'}=0.194;
    $statpot{'a8FK'}=0.050;
    $statpot{'a8FM'}=-0.136;
    $statpot{'a8FF'}=-0.263;
    $statpot{'a8FP'}=0.017;
    $statpot{'a8FS'}=-0.207;
    $statpot{'a8FT'}=-0.143;
    $statpot{'a8FW'}=0.173;
    $statpot{'a8FY'}=-0.109;
    $statpot{'a8FV'}=0.039;
    $statpot{'a8PA'}=-0.168;
    $statpot{'a8PR'}=-0.281;
    $statpot{'a8PN'}=-0.103;
    $statpot{'a8PD'}=0.184;
    $statpot{'a8PC'}=-0.518;
    $statpot{'a8PQ'}=0.013;
    $statpot{'a8PE'}=0.246;
    $statpot{'a8PG'}=-0.223;
    $statpot{'a8PH'}=-0.070;
    $statpot{'a8PI'}=-0.473;
    $statpot{'a8PL'}=-0.164;
    $statpot{'a8PK'}=0.004;
    $statpot{'a8PM'}=-0.185;
    $statpot{'a8PF'}=-0.175;
    $statpot{'a8PP'}=-0.354;
    $statpot{'a8PS'}=-0.161;
    $statpot{'a8PT'}=-0.339;
    $statpot{'a8PW'}=-0.077;
    $statpot{'a8PY'}=-0.123;
    $statpot{'a8PV'}=-0.182;
    $statpot{'a8SA'}=-0.054;
    $statpot{'a8SR'}=0.155;
    $statpot{'a8SN'}=0.268;
    $statpot{'a8SD'}=0.337;
    $statpot{'a8SC'}=-0.391;
    $statpot{'a8SQ'}=0.083;
    $statpot{'a8SE'}=0.535;
    $statpot{'a8SG'}=-0.254;
    $statpot{'a8SH'}=0.007;
    $statpot{'a8SI'}=-0.348;
    $statpot{'a8SL'}=-0.164;
    $statpot{'a8SK'}=0.206;
    $statpot{'a8SM'}=0.092;
    $statpot{'a8SF'}=-0.310;
    $statpot{'a8SP'}=-0.090;
    $statpot{'a8SS'}=0.065;
    $statpot{'a8ST'}=0.081;
    $statpot{'a8SW'}=-0.021;
    $statpot{'a8SY'}=-0.235;
    $statpot{'a8SV'}=-0.167;
    $statpot{'a8TA'}=-0.166;
    $statpot{'a8TR'}=0.151;
    $statpot{'a8TN'}=0.074;
    $statpot{'a8TD'}=0.179;
    $statpot{'a8TC'}=-0.515;
    $statpot{'a8TQ'}=0.324;
    $statpot{'a8TE'}=0.370;
    $statpot{'a8TG'}=-0.140;
    $statpot{'a8TH'}=-0.031;
    $statpot{'a8TI'}=-0.140;
    $statpot{'a8TL'}=-0.173;
    $statpot{'a8TK'}=0.342;
    $statpot{'a8TM'}=-0.015;
    $statpot{'a8TF'}=-0.318;
    $statpot{'a8TP'}=-0.301;
    $statpot{'a8TS'}=0.118;
    $statpot{'a8TT'}=0.009;
    $statpot{'a8TW'}=-0.027;
    $statpot{'a8TY'}=-0.148;
    $statpot{'a8TV'}=-0.188;
    $statpot{'a8WA'}=0.167;
    $statpot{'a8WR'}=0.229;
    $statpot{'a8WN'}=0.146;
    $statpot{'a8WD'}=0.123;
    $statpot{'a8WC'}=-0.293;
    $statpot{'a8WQ'}=0.326;
    $statpot{'a8WE'}=0.189;
    $statpot{'a8WG'}=-0.365;
    $statpot{'a8WH'}=-0.144;
    $statpot{'a8WI'}=-0.062;
    $statpot{'a8WL'}=0.006;
    $statpot{'a8WK'}=-0.097;
    $statpot{'a8WM'}=0.385;
    $statpot{'a8WF'}=-0.000;
    $statpot{'a8WP'}=-0.056;
    $statpot{'a8WS'}=0.030;
    $statpot{'a8WT'}=0.017;
    $statpot{'a8WW'}=0.243;
    $statpot{'a8WY'}=-0.142;
    $statpot{'a8WV'}=0.122;
    $statpot{'a8YA'}=-0.052;
    $statpot{'a8YR'}=0.175;
    $statpot{'a8YN'}=-0.009;
    $statpot{'a8YD'}=0.093;
    $statpot{'a8YC'}=-0.081;
    $statpot{'a8YQ'}=0.194;
    $statpot{'a8YE'}=-0.025;
    $statpot{'a8YG'}=-0.232;
    $statpot{'a8YH'}=-0.299;
    $statpot{'a8YI'}=-0.079;
    $statpot{'a8YL'}=0.023;
    $statpot{'a8YK'}=0.107;
    $statpot{'a8YM'}=0.196;
    $statpot{'a8YF'}=-0.156;
    $statpot{'a8YP'}=0.016;
    $statpot{'a8YS'}=-0.045;
    $statpot{'a8YT'}=-0.216;
    $statpot{'a8YW'}=0.011;
    $statpot{'a8YY'}=0.019;
    $statpot{'a8YV'}=-0.065;
    $statpot{'a8VA'}=-0.117;
    $statpot{'a8VR'}=-0.097;
    $statpot{'a8VN'}=-0.069;
    $statpot{'a8VD'}=-0.301;
    $statpot{'a8VC'}=-0.042;
    $statpot{'a8VQ'}=0.101;
    $statpot{'a8VE'}=0.122;
    $statpot{'a8VG'}=-0.151;
    $statpot{'a8VH'}=-0.017;
    $statpot{'a8VI'}=-0.203;
    $statpot{'a8VL'}=0.112;
    $statpot{'a8VK'}=0.060;
    $statpot{'a8VM'}=0.011;
    $statpot{'a8VF'}=-0.049;
    $statpot{'a8VP'}=-0.020;
    $statpot{'a8VS'}=-0.087;
    $statpot{'a8VT'}=-0.150;
    $statpot{'a8VW'}=0.191;
    $statpot{'a8VY'}=-0.044;
    $statpot{'a8VV'}=-0.101;
    $statpot{'p9AA'}=-0.117;
    $statpot{'p9AR'}=0.034;
    $statpot{'p9AN'}=0.009;
    $statpot{'p9AD'}=0.138;
    $statpot{'p9AC'}=-0.276;
    $statpot{'p9AQ'}=0.192;
    $statpot{'p9AE'}=0.179;
    $statpot{'p9AG'}=0.070;
    $statpot{'p9AH'}=-0.114;
    $statpot{'p9AI'}=-0.312;
    $statpot{'p9AL'}=-0.193;
    $statpot{'p9AK'}=0.176;
    $statpot{'p9AM'}=-0.089;
    $statpot{'p9AF'}=-0.199;
    $statpot{'p9AP'}=0.023;
    $statpot{'p9AS'}=-0.039;
    $statpot{'p9AT'}=-0.085;
    $statpot{'p9AW'}=-0.145;
    $statpot{'p9AY'}=-0.189;
    $statpot{'p9AV'}=-0.368;
    $statpot{'p9RA'}=0.034;
    $statpot{'p9RR'}=0.347;
    $statpot{'p9RN'}=0.089;
    $statpot{'p9RD'}=-0.045;
    $statpot{'p9RC'}=-0.202;
    $statpot{'p9RQ'}=0.161;
    $statpot{'p9RE'}=0.168;
    $statpot{'p9RG'}=0.245;
    $statpot{'p9RH'}=0.076;
    $statpot{'p9RI'}=0.028;
    $statpot{'p9RL'}=0.215;
    $statpot{'p9RK'}=0.232;
    $statpot{'p9RM'}=0.033;
    $statpot{'p9RF'}=0.039;
    $statpot{'p9RP'}=0.140;
    $statpot{'p9RS'}=0.076;
    $statpot{'p9RT'}=0.053;
    $statpot{'p9RW'}=-0.155;
    $statpot{'p9RY'}=0.003;
    $statpot{'p9RV'}=-0.020;
    $statpot{'p9NA'}=0.009;
    $statpot{'p9NR'}=0.089;
    $statpot{'p9NN'}=0.012;
    $statpot{'p9ND'}=0.137;
    $statpot{'p9NC'}=0.039;
    $statpot{'p9NQ'}=0.159;
    $statpot{'p9NE'}=0.172;
    $statpot{'p9NG'}=0.166;
    $statpot{'p9NH'}=0.180;
    $statpot{'p9NI'}=0.065;
    $statpot{'p9NL'}=0.110;
    $statpot{'p9NK'}=0.109;
    $statpot{'p9NM'}=0.020;
    $statpot{'p9NF'}=0.070;
    $statpot{'p9NP'}=0.126;
    $statpot{'p9NS'}=-0.117;
    $statpot{'p9NT'}=0.091;
    $statpot{'p9NW'}=-0.019;
    $statpot{'p9NY'}=0.007;
    $statpot{'p9NV'}=-0.052;
    $statpot{'p9DA'}=0.138;
    $statpot{'p9DR'}=-0.045;
    $statpot{'p9DN'}=0.137;
    $statpot{'p9DD'}=0.026;
    $statpot{'p9DC'}=0.035;
    $statpot{'p9DQ'}=0.103;
    $statpot{'p9DE'}=0.232;
    $statpot{'p9DG'}=0.246;
    $statpot{'p9DH'}=0.090;
    $statpot{'p9DI'}=0.259;
    $statpot{'p9DL'}=0.296;
    $statpot{'p9DK'}=0.098;
    $statpot{'p9DM'}=0.320;
    $statpot{'p9DF'}=0.164;
    $statpot{'p9DP'}=0.118;
    $statpot{'p9DS'}=0.070;
    $statpot{'p9DT'}=0.082;
    $statpot{'p9DW'}=-0.025;
    $statpot{'p9DY'}=0.121;
    $statpot{'p9DV'}=0.107;
    $statpot{'p9CA'}=-0.276;
    $statpot{'p9CR'}=-0.202;
    $statpot{'p9CN'}=0.039;
    $statpot{'p9CD'}=0.035;
    $statpot{'p9CC'}=-0.367;
    $statpot{'p9CQ'}=-0.204;
    $statpot{'p9CE'}=0.180;
    $statpot{'p9CG'}=-0.008;
    $statpot{'p9CH'}=-0.248;
    $statpot{'p9CI'}=-0.400;
    $statpot{'p9CL'}=-0.280;
    $statpot{'p9CK'}=0.166;
    $statpot{'p9CM'}=-0.448;
    $statpot{'p9CF'}=-0.491;
    $statpot{'p9CP'}=-0.038;
    $statpot{'p9CS'}=-0.056;
    $statpot{'p9CT'}=-0.341;
    $statpot{'p9CW'}=-0.390;
    $statpot{'p9CY'}=-0.434;
    $statpot{'p9CV'}=-0.465;
    $statpot{'p9QA'}=0.192;
    $statpot{'p9QR'}=0.161;
    $statpot{'p9QN'}=0.159;
    $statpot{'p9QD'}=0.103;
    $statpot{'p9QC'}=-0.204;
    $statpot{'p9QQ'}=0.136;
    $statpot{'p9QE'}=0.266;
    $statpot{'p9QG'}=0.180;
    $statpot{'p9QH'}=0.164;
    $statpot{'p9QI'}=0.186;
    $statpot{'p9QL'}=0.134;
    $statpot{'p9QK'}=0.283;
    $statpot{'p9QM'}=0.185;
    $statpot{'p9QF'}=0.039;
    $statpot{'p9QP'}=-0.045;
    $statpot{'p9QS'}=-0.053;
    $statpot{'p9QT'}=-0.040;
    $statpot{'p9QW'}=0.072;
    $statpot{'p9QY'}=-0.110;
    $statpot{'p9QV'}=-0.038;
    $statpot{'p9EA'}=0.179;
    $statpot{'p9ER'}=0.168;
    $statpot{'p9EN'}=0.172;
    $statpot{'p9ED'}=0.232;
    $statpot{'p9EC'}=0.180;
    $statpot{'p9EQ'}=0.266;
    $statpot{'p9EE'}=0.239;
    $statpot{'p9EG'}=0.367;
    $statpot{'p9EH'}=0.178;
    $statpot{'p9EI'}=0.230;
    $statpot{'p9EL'}=0.271;
    $statpot{'p9EK'}=0.335;
    $statpot{'p9EM'}=0.409;
    $statpot{'p9EF'}=0.194;
    $statpot{'p9EP'}=0.187;
    $statpot{'p9ES'}=0.146;
    $statpot{'p9ET'}=0.101;
    $statpot{'p9EW'}=0.116;
    $statpot{'p9EY'}=0.107;
    $statpot{'p9EV'}=0.088;
    $statpot{'p9GA'}=0.070;
    $statpot{'p9GR'}=0.245;
    $statpot{'p9GN'}=0.166;
    $statpot{'p9GD'}=0.246;
    $statpot{'p9GC'}=-0.008;
    $statpot{'p9GQ'}=0.180;
    $statpot{'p9GE'}=0.367;
    $statpot{'p9GG'}=0.170;
    $statpot{'p9GH'}=0.094;
    $statpot{'p9GI'}=0.014;
    $statpot{'p9GL'}=0.127;
    $statpot{'p9GK'}=0.342;
    $statpot{'p9GM'}=0.078;
    $statpot{'p9GF'}=0.027;
    $statpot{'p9GP'}=0.106;
    $statpot{'p9GS'}=0.102;
    $statpot{'p9GT'}=0.058;
    $statpot{'p9GW'}=0.153;
    $statpot{'p9GY'}=0.006;
    $statpot{'p9GV'}=0.028;
    $statpot{'p9HA'}=-0.114;
    $statpot{'p9HR'}=0.076;
    $statpot{'p9HN'}=0.180;
    $statpot{'p9HD'}=0.090;
    $statpot{'p9HC'}=-0.248;
    $statpot{'p9HQ'}=0.164;
    $statpot{'p9HE'}=0.178;
    $statpot{'p9HG'}=0.094;
    $statpot{'p9HH'}=-0.213;
    $statpot{'p9HI'}=-0.150;
    $statpot{'p9HL'}=-0.077;
    $statpot{'p9HK'}=0.215;
    $statpot{'p9HM'}=-0.083;
    $statpot{'p9HF'}=-0.172;
    $statpot{'p9HP'}=0.046;
    $statpot{'p9HS'}=-0.039;
    $statpot{'p9HT'}=-0.019;
    $statpot{'p9HW'}=-0.230;
    $statpot{'p9HY'}=-0.183;
    $statpot{'p9HV'}=-0.258;
    $statpot{'p9IA'}=-0.312;
    $statpot{'p9IR'}=0.028;
    $statpot{'p9IN'}=0.065;
    $statpot{'p9ID'}=0.259;
    $statpot{'p9IC'}=-0.400;
    $statpot{'p9IQ'}=0.186;
    $statpot{'p9IE'}=0.230;
    $statpot{'p9IG'}=0.014;
    $statpot{'p9IH'}=-0.150;
    $statpot{'p9II'}=-0.356;
    $statpot{'p9IL'}=-0.275;
    $statpot{'p9IK'}=0.192;
    $statpot{'p9IM'}=-0.353;
    $statpot{'p9IF'}=-0.412;
    $statpot{'p9IP'}=0.031;
    $statpot{'p9IS'}=-0.063;
    $statpot{'p9IT'}=-0.202;
    $statpot{'p9IW'}=-0.316;
    $statpot{'p9IY'}=-0.244;
    $statpot{'p9IV'}=-0.379;
    $statpot{'p9LA'}=-0.193;
    $statpot{'p9LR'}=0.215;
    $statpot{'p9LN'}=0.110;
    $statpot{'p9LD'}=0.296;
    $statpot{'p9LC'}=-0.280;
    $statpot{'p9LQ'}=0.134;
    $statpot{'p9LE'}=0.271;
    $statpot{'p9LG'}=0.127;
    $statpot{'p9LH'}=-0.077;
    $statpot{'p9LI'}=-0.275;
    $statpot{'p9LL'}=-0.267;
    $statpot{'p9LK'}=0.261;
    $statpot{'p9LM'}=-0.128;
    $statpot{'p9LF'}=-0.396;
    $statpot{'p9LP'}=0.118;
    $statpot{'p9LS'}=-0.042;
    $statpot{'p9LT'}=-0.115;
    $statpot{'p9LW'}=-0.237;
    $statpot{'p9LY'}=-0.255;
    $statpot{'p9LV'}=-0.318;
    $statpot{'p9KA'}=0.176;
    $statpot{'p9KR'}=0.232;
    $statpot{'p9KN'}=0.109;
    $statpot{'p9KD'}=0.098;
    $statpot{'p9KC'}=0.166;
    $statpot{'p9KQ'}=0.283;
    $statpot{'p9KE'}=0.335;
    $statpot{'p9KG'}=0.342;
    $statpot{'p9KH'}=0.215;
    $statpot{'p9KI'}=0.192;
    $statpot{'p9KL'}=0.261;
    $statpot{'p9KK'}=0.338;
    $statpot{'p9KM'}=0.281;
    $statpot{'p9KF'}=0.314;
    $statpot{'p9KP'}=0.097;
    $statpot{'p9KS'}=0.165;
    $statpot{'p9KT'}=0.138;
    $statpot{'p9KW'}=0.351;
    $statpot{'p9KY'}=0.265;
    $statpot{'p9KV'}=0.013;
    $statpot{'p9MA'}=-0.089;
    $statpot{'p9MR'}=0.033;
    $statpot{'p9MN'}=0.020;
    $statpot{'p9MD'}=0.320;
    $statpot{'p9MC'}=-0.448;
    $statpot{'p9MQ'}=0.185;
    $statpot{'p9ME'}=0.409;
    $statpot{'p9MG'}=0.078;
    $statpot{'p9MH'}=-0.083;
    $statpot{'p9MI'}=-0.353;
    $statpot{'p9ML'}=-0.128;
    $statpot{'p9MK'}=0.281;
    $statpot{'p9MM'}=-0.472;
    $statpot{'p9MF'}=-0.212;
    $statpot{'p9MP'}=-0.023;
    $statpot{'p9MS'}=-0.011;
    $statpot{'p9MT'}=-0.219;
    $statpot{'p9MW'}=-0.483;
    $statpot{'p9MY'}=-0.327;
    $statpot{'p9MV'}=-0.276;
    $statpot{'p9FA'}=-0.199;
    $statpot{'p9FR'}=0.039;
    $statpot{'p9FN'}=0.070;
    $statpot{'p9FD'}=0.164;
    $statpot{'p9FC'}=-0.491;
    $statpot{'p9FQ'}=0.039;
    $statpot{'p9FE'}=0.194;
    $statpot{'p9FG'}=0.027;
    $statpot{'p9FH'}=-0.172;
    $statpot{'p9FI'}=-0.412;
    $statpot{'p9FL'}=-0.396;
    $statpot{'p9FK'}=0.314;
    $statpot{'p9FM'}=-0.212;
    $statpot{'p9FF'}=-0.485;
    $statpot{'p9FP'}=0.048;
    $statpot{'p9FS'}=0.011;
    $statpot{'p9FT'}=-0.080;
    $statpot{'p9FW'}=-0.302;
    $statpot{'p9FY'}=-0.438;
    $statpot{'p9FV'}=-0.461;
    $statpot{'p9PA'}=0.023;
    $statpot{'p9PR'}=0.140;
    $statpot{'p9PN'}=0.126;
    $statpot{'p9PD'}=0.118;
    $statpot{'p9PC'}=-0.038;
    $statpot{'p9PQ'}=-0.045;
    $statpot{'p9PE'}=0.187;
    $statpot{'p9PG'}=0.106;
    $statpot{'p9PH'}=0.046;
    $statpot{'p9PI'}=0.031;
    $statpot{'p9PL'}=0.118;
    $statpot{'p9PK'}=0.097;
    $statpot{'p9PM'}=-0.023;
    $statpot{'p9PF'}=0.048;
    $statpot{'p9PP'}=-0.078;
    $statpot{'p9PS'}=-0.011;
    $statpot{'p9PT'}=0.023;
    $statpot{'p9PW'}=-0.036;
    $statpot{'p9PY'}=-0.050;
    $statpot{'p9PV'}=-0.014;
    $statpot{'p9SA'}=-0.039;
    $statpot{'p9SR'}=0.076;
    $statpot{'p9SN'}=-0.117;
    $statpot{'p9SD'}=0.070;
    $statpot{'p9SC'}=-0.056;
    $statpot{'p9SQ'}=-0.053;
    $statpot{'p9SE'}=0.146;
    $statpot{'p9SG'}=0.102;
    $statpot{'p9SH'}=-0.039;
    $statpot{'p9SI'}=-0.063;
    $statpot{'p9SL'}=-0.042;
    $statpot{'p9SK'}=0.165;
    $statpot{'p9SM'}=-0.011;
    $statpot{'p9SF'}=0.011;
    $statpot{'p9SP'}=-0.011;
    $statpot{'p9SS'}=-0.044;
    $statpot{'p9ST'}=-0.081;
    $statpot{'p9SW'}=-0.223;
    $statpot{'p9SY'}=-0.085;
    $statpot{'p9SV'}=-0.134;
    $statpot{'p9TA'}=-0.085;
    $statpot{'p9TR'}=0.053;
    $statpot{'p9TN'}=0.091;
    $statpot{'p9TD'}=0.082;
    $statpot{'p9TC'}=-0.341;
    $statpot{'p9TQ'}=-0.040;
    $statpot{'p9TE'}=0.101;
    $statpot{'p9TG'}=0.058;
    $statpot{'p9TH'}=-0.019;
    $statpot{'p9TI'}=-0.202;
    $statpot{'p9TL'}=-0.115;
    $statpot{'p9TK'}=0.138;
    $statpot{'p9TM'}=-0.219;
    $statpot{'p9TF'}=-0.080;
    $statpot{'p9TP'}=0.023;
    $statpot{'p9TS'}=-0.081;
    $statpot{'p9TT'}=-0.160;
    $statpot{'p9TW'}=-0.116;
    $statpot{'p9TY'}=-0.109;
    $statpot{'p9TV'}=-0.168;
    $statpot{'p9WA'}=-0.145;
    $statpot{'p9WR'}=-0.155;
    $statpot{'p9WN'}=-0.019;
    $statpot{'p9WD'}=-0.025;
    $statpot{'p9WC'}=-0.390;
    $statpot{'p9WQ'}=0.072;
    $statpot{'p9WE'}=0.116;
    $statpot{'p9WG'}=0.153;
    $statpot{'p9WH'}=-0.230;
    $statpot{'p9WI'}=-0.316;
    $statpot{'p9WL'}=-0.237;
    $statpot{'p9WK'}=0.351;
    $statpot{'p9WM'}=-0.483;
    $statpot{'p9WF'}=-0.302;
    $statpot{'p9WP'}=-0.036;
    $statpot{'p9WS'}=-0.223;
    $statpot{'p9WT'}=-0.116;
    $statpot{'p9WW'}=-0.463;
    $statpot{'p9WY'}=-0.376;
    $statpot{'p9WV'}=-0.282;
    $statpot{'p9YA'}=-0.189;
    $statpot{'p9YR'}=0.003;
    $statpot{'p9YN'}=0.007;
    $statpot{'p9YD'}=0.121;
    $statpot{'p9YC'}=-0.434;
    $statpot{'p9YQ'}=-0.110;
    $statpot{'p9YE'}=0.107;
    $statpot{'p9YG'}=0.006;
    $statpot{'p9YH'}=-0.183;
    $statpot{'p9YI'}=-0.244;
    $statpot{'p9YL'}=-0.255;
    $statpot{'p9YK'}=0.265;
    $statpot{'p9YM'}=-0.327;
    $statpot{'p9YF'}=-0.438;
    $statpot{'p9YP'}=-0.050;
    $statpot{'p9YS'}=-0.085;
    $statpot{'p9YT'}=-0.109;
    $statpot{'p9YW'}=-0.376;
    $statpot{'p9YY'}=-0.187;
    $statpot{'p9YV'}=-0.333;
    $statpot{'p9VA'}=-0.368;
    $statpot{'p9VR'}=-0.020;
    $statpot{'p9VN'}=-0.052;
    $statpot{'p9VD'}=0.107;
    $statpot{'p9VC'}=-0.465;
    $statpot{'p9VQ'}=-0.038;
    $statpot{'p9VE'}=0.088;
    $statpot{'p9VG'}=0.028;
    $statpot{'p9VH'}=-0.258;
    $statpot{'p9VI'}=-0.379;
    $statpot{'p9VL'}=-0.318;
    $statpot{'p9VK'}=0.013;
    $statpot{'p9VM'}=-0.276;
    $statpot{'p9VF'}=-0.461;
    $statpot{'p9VP'}=-0.014;
    $statpot{'p9VS'}=-0.134;
    $statpot{'p9VT'}=-0.168;
    $statpot{'p9VW'}=-0.282;
    $statpot{'p9VY'}=-0.333;
    $statpot{'p9VV'}=-0.542;
    $statpot{'f9AA'}=-0.126;
    $statpot{'f9AR'}=-0.044;
    $statpot{'f9AN'}=-0.012;
    $statpot{'f9AD'}=0.106;
    $statpot{'f9AC'}=-0.330;
    $statpot{'f9AQ'}=-0.014;
    $statpot{'f9AE'}=0.046;
    $statpot{'f9AG'}=0.156;
    $statpot{'f9AH'}=-0.131;
    $statpot{'f9AI'}=-0.361;
    $statpot{'f9AL'}=-0.369;
    $statpot{'f9AK'}=0.178;
    $statpot{'f9AM'}=-0.290;
    $statpot{'f9AF'}=-0.180;
    $statpot{'f9AP'}=0.043;
    $statpot{'f9AS'}=-0.081;
    $statpot{'f9AT'}=-0.050;
    $statpot{'f9AW'}=-0.280;
    $statpot{'f9AY'}=-0.259;
    $statpot{'f9AV'}=-0.438;
    $statpot{'f9RA'}=0.052;
    $statpot{'f9RR'}=0.317;
    $statpot{'f9RN'}=0.319;
    $statpot{'f9RD'}=0.105;
    $statpot{'f9RC'}=0.169;
    $statpot{'f9RQ'}=0.488;
    $statpot{'f9RE'}=0.323;
    $statpot{'f9RG'}=0.486;
    $statpot{'f9RH'}=0.219;
    $statpot{'f9RI'}=0.017;
    $statpot{'f9RL'}=-0.061;
    $statpot{'f9RK'}=0.584;
    $statpot{'f9RM'}=-0.058;
    $statpot{'f9RF'}=0.039;
    $statpot{'f9RP'}=0.331;
    $statpot{'f9RS'}=0.216;
    $statpot{'f9RT'}=0.236;
    $statpot{'f9RW'}=-0.077;
    $statpot{'f9RY'}=-0.127;
    $statpot{'f9RV'}=-0.036;
    $statpot{'f9NA'}=0.167;
    $statpot{'f9NR'}=0.387;
    $statpot{'f9NN'}=0.429;
    $statpot{'f9ND'}=0.479;
    $statpot{'f9NC'}=0.026;
    $statpot{'f9NQ'}=0.347;
    $statpot{'f9NE'}=0.493;
    $statpot{'f9NG'}=0.424;
    $statpot{'f9NH'}=0.129;
    $statpot{'f9NI'}=-0.019;
    $statpot{'f9NL'}=0.042;
    $statpot{'f9NK'}=0.548;
    $statpot{'f9NM'}=0.258;
    $statpot{'f9NF'}=0.080;
    $statpot{'f9NP'}=0.218;
    $statpot{'f9NS'}=0.333;
    $statpot{'f9NT'}=0.413;
    $statpot{'f9NW'}=-0.112;
    $statpot{'f9NY'}=-0.141;
    $statpot{'f9NV'}=-0.037;
    $statpot{'f9DA'}=0.407;
    $statpot{'f9DR'}=0.208;
    $statpot{'f9DN'}=0.656;
    $statpot{'f9DD'}=0.470;
    $statpot{'f9DC'}=0.194;
    $statpot{'f9DQ'}=0.516;
    $statpot{'f9DE'}=0.602;
    $statpot{'f9DG'}=0.690;
    $statpot{'f9DH'}=0.221;
    $statpot{'f9DI'}=0.119;
    $statpot{'f9DL'}=0.173;
    $statpot{'f9DK'}=0.691;
    $statpot{'f9DM'}=0.216;
    $statpot{'f9DF'}=0.105;
    $statpot{'f9DP'}=0.513;
    $statpot{'f9DS'}=0.370;
    $statpot{'f9DT'}=0.328;
    $statpot{'f9DW'}=-0.110;
    $statpot{'f9DY'}=0.121;
    $statpot{'f9DV'}=0.155;
    $statpot{'f9CA'}=-0.301;
    $statpot{'f9CR'}=-0.099;
    $statpot{'f9CN'}=-0.020;
    $statpot{'f9CD'}=-0.085;
    $statpot{'f9CC'}=-0.566;
    $statpot{'f9CQ'}=-0.088;
    $statpot{'f9CE'}=-0.253;
    $statpot{'f9CG'}=-0.213;
    $statpot{'f9CH'}=-0.358;
    $statpot{'f9CI'}=-0.581;
    $statpot{'f9CL'}=-0.359;
    $statpot{'f9CK'}=0.082;
    $statpot{'f9CM'}=-0.466;
    $statpot{'f9CF'}=-0.460;
    $statpot{'f9CP'}=-0.066;
    $statpot{'f9CS'}=-0.065;
    $statpot{'f9CT'}=-0.307;
    $statpot{'f9CW'}=-0.555;
    $statpot{'f9CY'}=-0.494;
    $statpot{'f9CV'}=-0.510;
    $statpot{'f9QA'}=0.189;
    $statpot{'f9QR'}=0.425;
    $statpot{'f9QN'}=0.346;
    $statpot{'f9QD'}=0.326;
    $statpot{'f9QC'}=0.118;
    $statpot{'f9QQ'}=0.367;
    $statpot{'f9QE'}=0.482;
    $statpot{'f9QG'}=0.368;
    $statpot{'f9QH'}=0.236;
    $statpot{'f9QI'}=0.015;
    $statpot{'f9QL'}=-0.077;
    $statpot{'f9QK'}=0.628;
    $statpot{'f9QM'}=0.141;
    $statpot{'f9QF'}=0.055;
    $statpot{'f9QP'}=0.331;
    $statpot{'f9QS'}=0.249;
    $statpot{'f9QT'}=0.336;
    $statpot{'f9QW'}=-0.058;
    $statpot{'f9QY'}=-0.113;
    $statpot{'f9QV'}=0.038;
    $statpot{'f9EA'}=0.332;
    $statpot{'f9ER'}=0.419;
    $statpot{'f9EN'}=0.576;
    $statpot{'f9ED'}=0.607;
    $statpot{'f9EC'}=-0.142;
    $statpot{'f9EQ'}=0.445;
    $statpot{'f9EE'}=0.686;
    $statpot{'f9EG'}=0.833;
    $statpot{'f9EH'}=0.297;
    $statpot{'f9EI'}=0.060;
    $statpot{'f9EL'}=0.095;
    $statpot{'f9EK'}=0.485;
    $statpot{'f9EM'}=0.253;
    $statpot{'f9EF'}=0.342;
    $statpot{'f9EP'}=0.681;
    $statpot{'f9ES'}=0.512;
    $statpot{'f9ET'}=0.507;
    $statpot{'f9EW'}=-0.085;
    $statpot{'f9EY'}=0.270;
    $statpot{'f9EV'}=0.193;
    $statpot{'f9GA'}=0.346;
    $statpot{'f9GR'}=0.391;
    $statpot{'f9GN'}=0.428;
    $statpot{'f9GD'}=0.637;
    $statpot{'f9GC'}=-0.020;
    $statpot{'f9GQ'}=0.382;
    $statpot{'f9GE'}=0.639;
    $statpot{'f9GG'}=0.456;
    $statpot{'f9GH'}=0.134;
    $statpot{'f9GI'}=-0.054;
    $statpot{'f9GL'}=0.060;
    $statpot{'f9GK'}=0.680;
    $statpot{'f9GM'}=-0.040;
    $statpot{'f9GF'}=0.022;
    $statpot{'f9GP'}=0.468;
    $statpot{'f9GS'}=0.322;
    $statpot{'f9GT'}=0.233;
    $statpot{'f9GW'}=-0.048;
    $statpot{'f9GY'}=0.102;
    $statpot{'f9GV'}=0.084;
    $statpot{'f9HA'}=0.133;
    $statpot{'f9HR'}=0.129;
    $statpot{'f9HN'}=0.219;
    $statpot{'f9HD'}=0.078;
    $statpot{'f9HC'}=-0.321;
    $statpot{'f9HQ'}=0.256;
    $statpot{'f9HE'}=0.176;
    $statpot{'f9HG'}=0.080;
    $statpot{'f9HH'}=0.111;
    $statpot{'f9HI'}=-0.199;
    $statpot{'f9HL'}=-0.132;
    $statpot{'f9HK'}=0.300;
    $statpot{'f9HM'}=-0.224;
    $statpot{'f9HF'}=-0.043;
    $statpot{'f9HP'}=0.199;
    $statpot{'f9HS'}=-0.004;
    $statpot{'f9HT'}=0.090;
    $statpot{'f9HW'}=-0.185;
    $statpot{'f9HY'}=-0.300;
    $statpot{'f9HV'}=-0.076;
    $statpot{'f9IA'}=-0.385;
    $statpot{'f9IR'}=-0.180;
    $statpot{'f9IN'}=-0.113;
    $statpot{'f9ID'}=-0.096;
    $statpot{'f9IC'}=-0.425;
    $statpot{'f9IQ'}=-0.110;
    $statpot{'f9IE'}=-0.093;
    $statpot{'f9IG'}=-0.091;
    $statpot{'f9IH'}=-0.274;
    $statpot{'f9II'}=-0.572;
    $statpot{'f9IL'}=-0.456;
    $statpot{'f9IK'}=0.031;
    $statpot{'f9IM'}=-0.491;
    $statpot{'f9IF'}=-0.559;
    $statpot{'f9IP'}=0.054;
    $statpot{'f9IS'}=-0.211;
    $statpot{'f9IT'}=-0.169;
    $statpot{'f9IW'}=-0.645;
    $statpot{'f9IY'}=-0.353;
    $statpot{'f9IV'}=-0.566;
    $statpot{'f9LA'}=-0.374;
    $statpot{'f9LR'}=-0.204;
    $statpot{'f9LN'}=-0.165;
    $statpot{'f9LD'}=-0.037;
    $statpot{'f9LC'}=-0.408;
    $statpot{'f9LQ'}=-0.207;
    $statpot{'f9LE'}=-0.065;
    $statpot{'f9LG'}=-0.101;
    $statpot{'f9LH'}=-0.113;
    $statpot{'f9LI'}=-0.456;
    $statpot{'f9LL'}=-0.457;
    $statpot{'f9LK'}=-0.007;
    $statpot{'f9LM'}=-0.500;
    $statpot{'f9LF'}=-0.605;
    $statpot{'f9LP'}=0.049;
    $statpot{'f9LS'}=-0.112;
    $statpot{'f9LT'}=-0.164;
    $statpot{'f9LW'}=-0.393;
    $statpot{'f9LY'}=-0.404;
    $statpot{'f9LV'}=-0.480;
    $statpot{'f9KA'}=0.346;
    $statpot{'f9KR'}=0.599;
    $statpot{'f9KN'}=0.552;
    $statpot{'f9KD'}=0.484;
    $statpot{'f9KC'}=0.285;
    $statpot{'f9KQ'}=0.584;
    $statpot{'f9KE'}=0.477;
    $statpot{'f9KG'}=0.679;
    $statpot{'f9KH'}=0.326;
    $statpot{'f9KI'}=0.139;
    $statpot{'f9KL'}=0.071;
    $statpot{'f9KK'}=0.717;
    $statpot{'f9KM'}=0.472;
    $statpot{'f9KF'}=0.176;
    $statpot{'f9KP'}=0.453;
    $statpot{'f9KS'}=0.577;
    $statpot{'f9KT'}=0.546;
    $statpot{'f9KW'}=0.225;
    $statpot{'f9KY'}=0.174;
    $statpot{'f9KV'}=0.116;
    $statpot{'f9MA'}=-0.229;
    $statpot{'f9MR'}=0.025;
    $statpot{'f9MN'}=-0.012;
    $statpot{'f9MD'}=-0.111;
    $statpot{'f9MC'}=-0.544;
    $statpot{'f9MQ'}=-0.082;
    $statpot{'f9ME'}=-0.012;
    $statpot{'f9MG'}=-0.121;
    $statpot{'f9MH'}=-0.282;
    $statpot{'f9MI'}=-0.479;
    $statpot{'f9ML'}=-0.462;
    $statpot{'f9MK'}=0.224;
    $statpot{'f9MM'}=-0.486;
    $statpot{'f9MF'}=-0.469;
    $statpot{'f9MP'}=0.004;
    $statpot{'f9MS'}=-0.086;
    $statpot{'f9MT'}=-0.310;
    $statpot{'f9MW'}=-0.451;
    $statpot{'f9MY'}=-0.522;
    $statpot{'f9MV'}=-0.463;
    $statpot{'f9FA'}=-0.145;
    $statpot{'f9FR'}=-0.026;
    $statpot{'f9FN'}=-0.006;
    $statpot{'f9FD'}=0.009;
    $statpot{'f9FC'}=-0.423;
    $statpot{'f9FQ'}=0.103;
    $statpot{'f9FE'}=0.133;
    $statpot{'f9FG'}=0.039;
    $statpot{'f9FH'}=-0.010;
    $statpot{'f9FI'}=-0.538;
    $statpot{'f9FL'}=-0.635;
    $statpot{'f9FK'}=0.086;
    $statpot{'f9FM'}=-0.454;
    $statpot{'f9FF'}=-0.556;
    $statpot{'f9FP'}=0.118;
    $statpot{'f9FS'}=-0.059;
    $statpot{'f9FT'}=-0.181;
    $statpot{'f9FW'}=-0.568;
    $statpot{'f9FY'}=-0.460;
    $statpot{'f9FV'}=-0.501;
    $statpot{'f9PA'}=0.285;
    $statpot{'f9PR'}=0.393;
    $statpot{'f9PN'}=0.145;
    $statpot{'f9PD'}=0.465;
    $statpot{'f9PC'}=0.105;
    $statpot{'f9PQ'}=0.314;
    $statpot{'f9PE'}=0.656;
    $statpot{'f9PG'}=0.535;
    $statpot{'f9PH'}=0.291;
    $statpot{'f9PI'}=0.076;
    $statpot{'f9PL'}=0.112;
    $statpot{'f9PK'}=0.482;
    $statpot{'f9PM'}=-0.011;
    $statpot{'f9PF'}=0.110;
    $statpot{'f9PP'}=0.306;
    $statpot{'f9PS'}=0.439;
    $statpot{'f9PT'}=0.413;
    $statpot{'f9PW'}=-0.068;
    $statpot{'f9PY'}=0.099;
    $statpot{'f9PV'}=0.229;
    $statpot{'f9SA'}=0.011;
    $statpot{'f9SR'}=0.223;
    $statpot{'f9SN'}=0.214;
    $statpot{'f9SD'}=0.266;
    $statpot{'f9SC'}=0.065;
    $statpot{'f9SQ'}=0.209;
    $statpot{'f9SE'}=0.368;
    $statpot{'f9SG'}=0.341;
    $statpot{'f9SH'}=0.043;
    $statpot{'f9SI'}=-0.141;
    $statpot{'f9SL'}=-0.035;
    $statpot{'f9SK'}=0.523;
    $statpot{'f9SM'}=0.066;
    $statpot{'f9SF'}=-0.062;
    $statpot{'f9SP'}=0.422;
    $statpot{'f9SS'}=0.256;
    $statpot{'f9ST'}=0.236;
    $statpot{'f9SW'}=-0.087;
    $statpot{'f9SY'}=0.041;
    $statpot{'f9SV'}=-0.132;
    $statpot{'f9TA'}=0.036;
    $statpot{'f9TR'}=0.167;
    $statpot{'f9TN'}=0.310;
    $statpot{'f9TD'}=0.206;
    $statpot{'f9TC'}=-0.041;
    $statpot{'f9TQ'}=0.245;
    $statpot{'f9TE'}=0.436;
    $statpot{'f9TG'}=0.225;
    $statpot{'f9TH'}=0.025;
    $statpot{'f9TI'}=-0.162;
    $statpot{'f9TL'}=0.043;
    $statpot{'f9TK'}=0.408;
    $statpot{'f9TM'}=-0.239;
    $statpot{'f9TF'}=-0.175;
    $statpot{'f9TP'}=0.303;
    $statpot{'f9TS'}=0.235;
    $statpot{'f9TT'}=0.196;
    $statpot{'f9TW'}=-0.099;
    $statpot{'f9TY'}=-0.062;
    $statpot{'f9TV'}=-0.072;
    $statpot{'f9WA'}=-0.238;
    $statpot{'f9WR'}=-0.229;
    $statpot{'f9WN'}=-0.343;
    $statpot{'f9WD'}=-0.138;
    $statpot{'f9WC'}=-0.653;
    $statpot{'f9WQ'}=-0.319;
    $statpot{'f9WE'}=-0.147;
    $statpot{'f9WG'}=0.098;
    $statpot{'f9WH'}=-0.248;
    $statpot{'f9WI'}=-0.565;
    $statpot{'f9WL'}=-0.362;
    $statpot{'f9WK'}=-0.051;
    $statpot{'f9WM'}=-0.361;
    $statpot{'f9WF'}=-0.548;
    $statpot{'f9WP'}=-0.292;
    $statpot{'f9WS'}=-0.087;
    $statpot{'f9WT'}=-0.217;
    $statpot{'f9WW'}=-0.362;
    $statpot{'f9WY'}=-0.398;
    $statpot{'f9WV'}=-0.526;
    $statpot{'f9YA'}=-0.260;
    $statpot{'f9YR'}=-0.207;
    $statpot{'f9YN'}=-0.168;
    $statpot{'f9YD'}=-0.054;
    $statpot{'f9YC'}=-0.320;
    $statpot{'f9YQ'}=-0.241;
    $statpot{'f9YE'}=0.088;
    $statpot{'f9YG'}=0.070;
    $statpot{'f9YH'}=-0.380;
    $statpot{'f9YI'}=-0.313;
    $statpot{'f9YL'}=-0.364;
    $statpot{'f9YK'}=0.084;
    $statpot{'f9YM'}=-0.493;
    $statpot{'f9YF'}=-0.388;
    $statpot{'f9YP'}=-0.081;
    $statpot{'f9YS'}=-0.047;
    $statpot{'f9YT'}=-0.133;
    $statpot{'f9YW'}=-0.416;
    $statpot{'f9YY'}=-0.337;
    $statpot{'f9YV'}=-0.318;
    $statpot{'f9VA'}=-0.369;
    $statpot{'f9VR'}=-0.106;
    $statpot{'f9VN'}=-0.090;
    $statpot{'f9VD'}=-0.053;
    $statpot{'f9VC'}=-0.424;
    $statpot{'f9VQ'}=-0.063;
    $statpot{'f9VE'}=0.099;
    $statpot{'f9VG'}=-0.025;
    $statpot{'f9VH'}=-0.152;
    $statpot{'f9VI'}=-0.562;
    $statpot{'f9VL'}=-0.468;
    $statpot{'f9VK'}=0.024;
    $statpot{'f9VM'}=-0.444;
    $statpot{'f9VF'}=-0.544;
    $statpot{'f9VP'}=0.098;
    $statpot{'f9VS'}=-0.145;
    $statpot{'f9VT'}=-0.149;
    $statpot{'f9VW'}=-0.577;
    $statpot{'f9VY'}=-0.308;
    $statpot{'f9VV'}=-0.581;
    $statpot{'a9AA'}=-0.203;
    $statpot{'a9AR'}=-0.097;
    $statpot{'a9AN'}=0.028;
    $statpot{'a9AD'}=0.241;
    $statpot{'a9AC'}=-0.068;
    $statpot{'a9AQ'}=0.136;
    $statpot{'a9AE'}=0.155;
    $statpot{'a9AG'}=0.225;
    $statpot{'a9AH'}=0.334;
    $statpot{'a9AI'}=-0.150;
    $statpot{'a9AL'}=-0.235;
    $statpot{'a9AK'}=0.039;
    $statpot{'a9AM'}=-0.063;
    $statpot{'a9AF'}=-0.015;
    $statpot{'a9AP'}=0.127;
    $statpot{'a9AS'}=-0.041;
    $statpot{'a9AT'}=0.088;
    $statpot{'a9AW'}=-0.061;
    $statpot{'a9AY'}=-0.111;
    $statpot{'a9AV'}=-0.121;
    $statpot{'a9RA'}=-0.243;
    $statpot{'a9RR'}=-0.018;
    $statpot{'a9RN'}=0.170;
    $statpot{'a9RD'}=0.500;
    $statpot{'a9RC'}=-0.473;
    $statpot{'a9RQ'}=0.088;
    $statpot{'a9RE'}=0.245;
    $statpot{'a9RG'}=0.094;
    $statpot{'a9RH'}=0.030;
    $statpot{'a9RI'}=-0.323;
    $statpot{'a9RL'}=-0.318;
    $statpot{'a9RK'}=0.310;
    $statpot{'a9RM'}=-0.122;
    $statpot{'a9RF'}=-0.258;
    $statpot{'a9RP'}=0.296;
    $statpot{'a9RS'}=-0.018;
    $statpot{'a9RT'}=-0.127;
    $statpot{'a9RW'}=-0.454;
    $statpot{'a9RY'}=-0.189;
    $statpot{'a9RV'}=-0.241;
    $statpot{'a9NA'}=-0.233;
    $statpot{'a9NR'}=0.076;
    $statpot{'a9NN'}=0.218;
    $statpot{'a9ND'}=0.462;
    $statpot{'a9NC'}=-0.462;
    $statpot{'a9NQ'}=0.125;
    $statpot{'a9NE'}=0.339;
    $statpot{'a9NG'}=0.354;
    $statpot{'a9NH'}=0.083;
    $statpot{'a9NI'}=-0.179;
    $statpot{'a9NL'}=-0.337;
    $statpot{'a9NK'}=0.099;
    $statpot{'a9NM'}=-0.224;
    $statpot{'a9NF'}=-0.177;
    $statpot{'a9NP'}=-0.105;
    $statpot{'a9NS'}=-0.070;
    $statpot{'a9NT'}=0.151;
    $statpot{'a9NW'}=-0.452;
    $statpot{'a9NY'}=-0.117;
    $statpot{'a9NV'}=-0.202;
    $statpot{'a9DA'}=-0.184;
    $statpot{'a9DR'}=0.273;
    $statpot{'a9DN'}=0.217;
    $statpot{'a9DD'}=0.363;
    $statpot{'a9DC'}=-0.336;
    $statpot{'a9DQ'}=0.050;
    $statpot{'a9DE'}=0.310;
    $statpot{'a9DG'}=0.349;
    $statpot{'a9DH'}=0.151;
    $statpot{'a9DI'}=-0.348;
    $statpot{'a9DL'}=-0.286;
    $statpot{'a9DK'}=0.147;
    $statpot{'a9DM'}=-0.375;
    $statpot{'a9DF'}=-0.285;
    $statpot{'a9DP'}=0.086;
    $statpot{'a9DS'}=0.136;
    $statpot{'a9DT'}=0.011;
    $statpot{'a9DW'}=-0.275;
    $statpot{'a9DY'}=-0.266;
    $statpot{'a9DV'}=-0.291;
    $statpot{'a9CA'}=-0.130;
    $statpot{'a9CR'}=-0.158;
    $statpot{'a9CN'}=-0.410;
    $statpot{'a9CD'}=0.051;
    $statpot{'a9CC'}=-0.386;
    $statpot{'a9CQ'}=-0.242;
    $statpot{'a9CE'}=-0.044;
    $statpot{'a9CG'}=0.289;
    $statpot{'a9CH'}=-0.110;
    $statpot{'a9CI'}=-0.054;
    $statpot{'a9CL'}=0.063;
    $statpot{'a9CK'}=-0.048;
    $statpot{'a9CM'}=-0.440;
    $statpot{'a9CF'}=-0.043;
    $statpot{'a9CP'}=-0.054;
    $statpot{'a9CS'}=-0.115;
    $statpot{'a9CT'}=0.097;
    $statpot{'a9CW'}=-0.395;
    $statpot{'a9CY'}=0.051;
    $statpot{'a9CV'}=0.034;
    $statpot{'a9QA'}=-0.187;
    $statpot{'a9QR'}=0.167;
    $statpot{'a9QN'}=0.127;
    $statpot{'a9QD'}=0.311;
    $statpot{'a9QC'}=-0.477;
    $statpot{'a9QQ'}=0.441;
    $statpot{'a9QE'}=0.151;
    $statpot{'a9QG'}=0.290;
    $statpot{'a9QH'}=0.506;
    $statpot{'a9QI'}=-0.132;
    $statpot{'a9QL'}=-0.340;
    $statpot{'a9QK'}=0.100;
    $statpot{'a9QM'}=-0.503;
    $statpot{'a9QF'}=-0.095;
    $statpot{'a9QP'}=0.128;
    $statpot{'a9QS'}=0.091;
    $statpot{'a9QT'}=0.058;
    $statpot{'a9QW'}=-0.309;
    $statpot{'a9QY'}=-0.188;
    $statpot{'a9QV'}=-0.274;
    $statpot{'a9EA'}=-0.249;
    $statpot{'a9ER'}=0.105;
    $statpot{'a9EN'}=0.227;
    $statpot{'a9ED'}=0.302;
    $statpot{'a9EC'}=-0.244;
    $statpot{'a9EQ'}=0.200;
    $statpot{'a9EE'}=0.374;
    $statpot{'a9EG'}=0.257;
    $statpot{'a9EH'}=0.046;
    $statpot{'a9EI'}=-0.319;
    $statpot{'a9EL'}=-0.323;
    $statpot{'a9EK'}=0.389;
    $statpot{'a9EM'}=-0.323;
    $statpot{'a9EF'}=-0.163;
    $statpot{'a9EP'}=0.242;
    $statpot{'a9ES'}=0.179;
    $statpot{'a9ET'}=0.141;
    $statpot{'a9EW'}=-0.248;
    $statpot{'a9EY'}=-0.030;
    $statpot{'a9EV'}=-0.177;
    $statpot{'a9GA'}=-0.057;
    $statpot{'a9GR'}=0.222;
    $statpot{'a9GN'}=0.347;
    $statpot{'a9GD'}=0.421;
    $statpot{'a9GC'}=-0.106;
    $statpot{'a9GQ'}=0.268;
    $statpot{'a9GE'}=0.495;
    $statpot{'a9GG'}=0.300;
    $statpot{'a9GH'}=0.160;
    $statpot{'a9GI'}=-0.112;
    $statpot{'a9GL'}=-0.184;
    $statpot{'a9GK'}=0.342;
    $statpot{'a9GM'}=-0.074;
    $statpot{'a9GF'}=-0.138;
    $statpot{'a9GP'}=0.201;
    $statpot{'a9GS'}=0.115;
    $statpot{'a9GT'}=0.160;
    $statpot{'a9GW'}=-0.182;
    $statpot{'a9GY'}=-0.011;
    $statpot{'a9GV'}=-0.146;
    $statpot{'a9HA'}=-0.173;
    $statpot{'a9HR'}=0.178;
    $statpot{'a9HN'}=-0.049;
    $statpot{'a9HD'}=0.441;
    $statpot{'a9HC'}=-0.184;
    $statpot{'a9HQ'}=0.460;
    $statpot{'a9HE'}=0.242;
    $statpot{'a9HG'}=0.265;
    $statpot{'a9HH'}=-0.237;
    $statpot{'a9HI'}=-0.156;
    $statpot{'a9HL'}=-0.111;
    $statpot{'a9HK'}=0.198;
    $statpot{'a9HM'}=-0.254;
    $statpot{'a9HF'}=-0.071;
    $statpot{'a9HP'}=0.001;
    $statpot{'a9HS'}=0.000;
    $statpot{'a9HT'}=-0.265;
    $statpot{'a9HW'}=-0.422;
    $statpot{'a9HY'}=-0.072;
    $statpot{'a9HV'}=-0.127;
    $statpot{'a9IA'}=-0.095;
    $statpot{'a9IR'}=-0.001;
    $statpot{'a9IN'}=-0.019;
    $statpot{'a9ID'}=-0.040;
    $statpot{'a9IC'}=-0.405;
    $statpot{'a9IQ'}=0.094;
    $statpot{'a9IE'}=-0.095;
    $statpot{'a9IG'}=-0.047;
    $statpot{'a9IH'}=-0.001;
    $statpot{'a9II'}=0.123;
    $statpot{'a9IL'}=0.313;
    $statpot{'a9IK'}=-0.167;
    $statpot{'a9IM'}=0.051;
    $statpot{'a9IF'}=0.144;
    $statpot{'a9IP'}=0.091;
    $statpot{'a9IS'}=-0.035;
    $statpot{'a9IT'}=-0.081;
    $statpot{'a9IW'}=0.317;
    $statpot{'a9IY'}=0.147;
    $statpot{'a9IV'}=0.028;
    $statpot{'a9LA'}=-0.224;
    $statpot{'a9LR'}=-0.080;
    $statpot{'a9LN'}=-0.020;
    $statpot{'a9LD'}=0.015;
    $statpot{'a9LC'}=0.202;
    $statpot{'a9LQ'}=-0.133;
    $statpot{'a9LE'}=-0.096;
    $statpot{'a9LG'}=0.089;
    $statpot{'a9LH'}=-0.144;
    $statpot{'a9LI'}=0.311;
    $statpot{'a9LL'}=0.160;
    $statpot{'a9LK'}=-0.140;
    $statpot{'a9LM'}=-0.019;
    $statpot{'a9LF'}=0.016;
    $statpot{'a9LP'}=0.041;
    $statpot{'a9LS'}=-0.056;
    $statpot{'a9LT'}=0.175;
    $statpot{'a9LW'}=0.265;
    $statpot{'a9LY'}=0.122;
    $statpot{'a9LV'}=0.058;
    $statpot{'a9KA'}=-0.174;
    $statpot{'a9KR'}=0.292;
    $statpot{'a9KN'}=0.094;
    $statpot{'a9KD'}=0.411;
    $statpot{'a9KC'}=-0.288;
    $statpot{'a9KQ'}=0.148;
    $statpot{'a9KE'}=0.402;
    $statpot{'a9KG'}=0.341;
    $statpot{'a9KH'}=0.158;
    $statpot{'a9KI'}=-0.305;
    $statpot{'a9KL'}=-0.248;
    $statpot{'a9KK'}=0.212;
    $statpot{'a9KM'}=-0.140;
    $statpot{'a9KF'}=-0.241;
    $statpot{'a9KP'}=0.157;
    $statpot{'a9KS'}=0.219;
    $statpot{'a9KT'}=0.040;
    $statpot{'a9KW'}=-0.405;
    $statpot{'a9KY'}=-0.084;
    $statpot{'a9KV'}=-0.185;
    $statpot{'a9MA'}=-0.187;
    $statpot{'a9MR'}=-0.248;
    $statpot{'a9MN'}=0.187;
    $statpot{'a9MD'}=0.102;
    $statpot{'a9MC'}=-0.283;
    $statpot{'a9MQ'}=-0.238;
    $statpot{'a9ME'}=0.036;
    $statpot{'a9MG'}=0.080;
    $statpot{'a9MH'}=-0.145;
    $statpot{'a9MI'}=0.018;
    $statpot{'a9ML'}=-0.121;
    $statpot{'a9MK'}=0.174;
    $statpot{'a9MM'}=-0.256;
    $statpot{'a9MF'}=0.218;
    $statpot{'a9MP'}=0.143;
    $statpot{'a9MS'}=0.299;
    $statpot{'a9MT'}=-0.001;
    $statpot{'a9MW'}=0.107;
    $statpot{'a9MY'}=-0.012;
    $statpot{'a9MV'}=-0.201;
    $statpot{'a9FA'}=-0.085;
    $statpot{'a9FR'}=-0.165;
    $statpot{'a9FN'}=-0.048;
    $statpot{'a9FD'}=-0.156;
    $statpot{'a9FC'}=-0.128;
    $statpot{'a9FQ'}=-0.164;
    $statpot{'a9FE'}=0.121;
    $statpot{'a9FG'}=-0.163;
    $statpot{'a9FH'}=-0.127;
    $statpot{'a9FI'}=0.072;
    $statpot{'a9FL'}=0.122;
    $statpot{'a9FK'}=-0.126;
    $statpot{'a9FM'}=0.160;
    $statpot{'a9FF'}=0.038;
    $statpot{'a9FP'}=-0.143;
    $statpot{'a9FS'}=-0.060;
    $statpot{'a9FT'}=-0.045;
    $statpot{'a9FW'}=0.150;
    $statpot{'a9FY'}=0.062;
    $statpot{'a9FV'}=-0.010;
    $statpot{'a9PA'}=-0.222;
    $statpot{'a9PR'}=0.198;
    $statpot{'a9PN'}=-0.006;
    $statpot{'a9PD'}=0.145;
    $statpot{'a9PC'}=-0.292;
    $statpot{'a9PQ'}=0.154;
    $statpot{'a9PE'}=0.272;
    $statpot{'a9PG'}=0.116;
    $statpot{'a9PH'}=-0.117;
    $statpot{'a9PI'}=0.052;
    $statpot{'a9PL'}=-0.061;
    $statpot{'a9PK'}=0.120;
    $statpot{'a9PM'}=0.174;
    $statpot{'a9PF'}=-0.134;
    $statpot{'a9PP'}=-0.065;
    $statpot{'a9PS'}=-0.109;
    $statpot{'a9PT'}=0.038;
    $statpot{'a9PW'}=-0.412;
    $statpot{'a9PY'}=-0.115;
    $statpot{'a9PV'}=-0.045;
    $statpot{'a9SA'}=-0.190;
    $statpot{'a9SR'}=-0.027;
    $statpot{'a9SN'}=0.089;
    $statpot{'a9SD'}=0.300;
    $statpot{'a9SC'}=-0.294;
    $statpot{'a9SQ'}=0.155;
    $statpot{'a9SE'}=0.395;
    $statpot{'a9SG'}=0.087;
    $statpot{'a9SH'}=-0.077;
    $statpot{'a9SI'}=-0.168;
    $statpot{'a9SL'}=-0.185;
    $statpot{'a9SK'}=0.290;
    $statpot{'a9SM'}=-0.013;
    $statpot{'a9SF'}=-0.055;
    $statpot{'a9SP'}=-0.092;
    $statpot{'a9SS'}=0.096;
    $statpot{'a9ST'}=0.108;
    $statpot{'a9SW'}=-0.270;
    $statpot{'a9SY'}=-0.125;
    $statpot{'a9SV'}=-0.148;
    $statpot{'a9TA'}=-0.067;
    $statpot{'a9TR'}=-0.034;
    $statpot{'a9TN'}=0.305;
    $statpot{'a9TD'}=0.192;
    $statpot{'a9TC'}=-0.362;
    $statpot{'a9TQ'}=0.194;
    $statpot{'a9TE'}=0.235;
    $statpot{'a9TG'}=0.172;
    $statpot{'a9TH'}=-0.179;
    $statpot{'a9TI'}=-0.094;
    $statpot{'a9TL'}=-0.206;
    $statpot{'a9TK'}=0.210;
    $statpot{'a9TM'}=-0.155;
    $statpot{'a9TF'}=-0.057;
    $statpot{'a9TP'}=0.190;
    $statpot{'a9TS'}=0.109;
    $statpot{'a9TT'}=0.202;
    $statpot{'a9TW'}=0.067;
    $statpot{'a9TY'}=-0.062;
    $statpot{'a9TV'}=-0.133;
    $statpot{'a9WA'}=-0.149;
    $statpot{'a9WR'}=-0.235;
    $statpot{'a9WN'}=-0.069;
    $statpot{'a9WD'}=-0.231;
    $statpot{'a9WC'}=-0.168;
    $statpot{'a9WQ'}=0.212;
    $statpot{'a9WE'}=-0.146;
    $statpot{'a9WG'}=-0.371;
    $statpot{'a9WH'}=-0.329;
    $statpot{'a9WI'}=0.007;
    $statpot{'a9WL'}=0.165;
    $statpot{'a9WK'}=-0.056;
    $statpot{'a9WM'}=-0.131;
    $statpot{'a9WF'}=0.078;
    $statpot{'a9WP'}=-0.041;
    $statpot{'a9WS'}=-0.270;
    $statpot{'a9WT'}=0.370;
    $statpot{'a9WW'}=-0.333;
    $statpot{'a9WY'}=0.252;
    $statpot{'a9WV'}=-0.185;
    $statpot{'a9YA'}=-0.106;
    $statpot{'a9YR'}=-0.043;
    $statpot{'a9YN'}=-0.069;
    $statpot{'a9YD'}=-0.009;
    $statpot{'a9YC'}=-0.325;
    $statpot{'a9YQ'}=0.059;
    $statpot{'a9YE'}=0.273;
    $statpot{'a9YG'}=0.040;
    $statpot{'a9YH'}=0.130;
    $statpot{'a9YI'}=0.042;
    $statpot{'a9YL'}=0.013;
    $statpot{'a9YK'}=0.051;
    $statpot{'a9YM'}=-0.093;
    $statpot{'a9YF'}=-0.125;
    $statpot{'a9YP'}=0.212;
    $statpot{'a9YS'}=0.020;
    $statpot{'a9YT'}=0.077;
    $statpot{'a9YW'}=0.306;
    $statpot{'a9YY'}=-0.180;
    $statpot{'a9YV'}=0.061;
    $statpot{'a9VA'}=-0.273;
    $statpot{'a9VR'}=-0.129;
    $statpot{'a9VN'}=-0.119;
    $statpot{'a9VD'}=0.014;
    $statpot{'a9VC'}=-0.182;
    $statpot{'a9VQ'}=-0.126;
    $statpot{'a9VE'}=-0.047;
    $statpot{'a9VG'}=0.028;
    $statpot{'a9VH'}=0.015;
    $statpot{'a9VI'}=0.013;
    $statpot{'a9VL'}=0.023;
    $statpot{'a9VK'}=-0.051;
    $statpot{'a9VM'}=-0.243;
    $statpot{'a9VF'}=0.122;
    $statpot{'a9VP'}=0.166;
    $statpot{'a9VS'}=-0.125;
    $statpot{'a9VT'}=0.010;
    $statpot{'a9VW'}=-0.046;
    $statpot{'a9VY'}=0.033;
    $statpot{'a9VV'}=0.065;
    $statpot{'p10AA'}=-0.092;
    $statpot{'p10AR'}=0.116;
    $statpot{'p10AN'}=0.078;
    $statpot{'p10AD'}=0.223;
    $statpot{'p10AC'}=-0.275;
    $statpot{'p10AQ'}=0.054;
    $statpot{'p10AE'}=0.107;
    $statpot{'p10AG'}=0.196;
    $statpot{'p10AH'}=-0.021;
    $statpot{'p10AI'}=-0.289;
    $statpot{'p10AL'}=-0.204;
    $statpot{'p10AK'}=0.140;
    $statpot{'p10AM'}=-0.218;
    $statpot{'p10AF'}=-0.185;
    $statpot{'p10AP'}=0.084;
    $statpot{'p10AS'}=0.051;
    $statpot{'p10AT'}=-0.066;
    $statpot{'p10AW'}=-0.054;
    $statpot{'p10AY'}=-0.152;
    $statpot{'p10AV'}=-0.249;
    $statpot{'p10RA'}=0.116;
    $statpot{'p10RR'}=0.050;
    $statpot{'p10RN'}=0.113;
    $statpot{'p10RD'}=0.114;
    $statpot{'p10RC'}=-0.058;
    $statpot{'p10RQ'}=0.102;
    $statpot{'p10RE'}=0.109;
    $statpot{'p10RG'}=0.241;
    $statpot{'p10RH'}=0.097;
    $statpot{'p10RI'}=-0.134;
    $statpot{'p10RL'}=-0.078;
    $statpot{'p10RK'}=0.131;
    $statpot{'p10RM'}=-0.093;
    $statpot{'p10RF'}=-0.010;
    $statpot{'p10RP'}=0.059;
    $statpot{'p10RS'}=0.120;
    $statpot{'p10RT'}=0.057;
    $statpot{'p10RW'}=-0.006;
    $statpot{'p10RY'}=0.033;
    $statpot{'p10RV'}=-0.041;
    $statpot{'p10NA'}=0.078;
    $statpot{'p10NR'}=0.113;
    $statpot{'p10NN'}=0.006;
    $statpot{'p10ND'}=0.267;
    $statpot{'p10NC'}=0.140;
    $statpot{'p10NQ'}=0.219;
    $statpot{'p10NE'}=0.284;
    $statpot{'p10NG'}=0.187;
    $statpot{'p10NH'}=0.017;
    $statpot{'p10NI'}=-0.024;
    $statpot{'p10NL'}=0.070;
    $statpot{'p10NK'}=0.246;
    $statpot{'p10NM'}=0.182;
    $statpot{'p10NF'}=0.028;
    $statpot{'p10NP'}=0.171;
    $statpot{'p10NS'}=0.074;
    $statpot{'p10NT'}=0.082;
    $statpot{'p10NW'}=-0.020;
    $statpot{'p10NY'}=0.094;
    $statpot{'p10NV'}=-0.061;
    $statpot{'p10DA'}=0.223;
    $statpot{'p10DR'}=0.114;
    $statpot{'p10DN'}=0.267;
    $statpot{'p10DD'}=0.211;
    $statpot{'p10DC'}=0.044;
    $statpot{'p10DQ'}=0.165;
    $statpot{'p10DE'}=0.195;
    $statpot{'p10DG'}=0.329;
    $statpot{'p10DH'}=0.239;
    $statpot{'p10DI'}=0.070;
    $statpot{'p10DL'}=0.131;
    $statpot{'p10DK'}=0.228;
    $statpot{'p10DM'}=0.242;
    $statpot{'p10DF'}=0.152;
    $statpot{'p10DP'}=0.204;
    $statpot{'p10DS'}=0.225;
    $statpot{'p10DT'}=0.181;
    $statpot{'p10DW'}=0.056;
    $statpot{'p10DY'}=0.110;
    $statpot{'p10DV'}=0.092;
    $statpot{'p10CA'}=-0.275;
    $statpot{'p10CR'}=-0.058;
    $statpot{'p10CN'}=0.140;
    $statpot{'p10CD'}=0.044;
    $statpot{'p10CC'}=-0.047;
    $statpot{'p10CQ'}=0.124;
    $statpot{'p10CE'}=0.213;
    $statpot{'p10CG'}=-0.095;
    $statpot{'p10CH'}=0.186;
    $statpot{'p10CI'}=-0.311;
    $statpot{'p10CL'}=-0.393;
    $statpot{'p10CK'}=0.105;
    $statpot{'p10CM'}=-0.213;
    $statpot{'p10CF'}=-0.418;
    $statpot{'p10CP'}=-0.017;
    $statpot{'p10CS'}=-0.136;
    $statpot{'p10CT'}=-0.160;
    $statpot{'p10CW'}=-0.269;
    $statpot{'p10CY'}=-0.298;
    $statpot{'p10CV'}=-0.371;
    $statpot{'p10QA'}=0.054;
    $statpot{'p10QR'}=0.102;
    $statpot{'p10QN'}=0.219;
    $statpot{'p10QD'}=0.165;
    $statpot{'p10QC'}=0.124;
    $statpot{'p10QQ'}=0.087;
    $statpot{'p10QE'}=0.188;
    $statpot{'p10QG'}=0.170;
    $statpot{'p10QH'}=0.119;
    $statpot{'p10QI'}=0.016;
    $statpot{'p10QL'}=-0.009;
    $statpot{'p10QK'}=0.201;
    $statpot{'p10QM'}=0.014;
    $statpot{'p10QF'}=-0.022;
    $statpot{'p10QP'}=0.084;
    $statpot{'p10QS'}=0.193;
    $statpot{'p10QT'}=0.081;
    $statpot{'p10QW'}=-0.064;
    $statpot{'p10QY'}=0.058;
    $statpot{'p10QV'}=-0.046;
    $statpot{'p10EA'}=0.107;
    $statpot{'p10ER'}=0.109;
    $statpot{'p10EN'}=0.284;
    $statpot{'p10ED'}=0.195;
    $statpot{'p10EC'}=0.213;
    $statpot{'p10EQ'}=0.188;
    $statpot{'p10EE'}=0.186;
    $statpot{'p10EG'}=0.407;
    $statpot{'p10EH'}=0.287;
    $statpot{'p10EI'}=0.035;
    $statpot{'p10EL'}=0.092;
    $statpot{'p10EK'}=0.146;
    $statpot{'p10EM'}=0.214;
    $statpot{'p10EF'}=0.144;
    $statpot{'p10EP'}=0.254;
    $statpot{'p10ES'}=0.289;
    $statpot{'p10ET'}=0.213;
    $statpot{'p10EW'}=0.154;
    $statpot{'p10EY'}=0.092;
    $statpot{'p10EV'}=0.066;
    $statpot{'p10GA'}=0.196;
    $statpot{'p10GR'}=0.241;
    $statpot{'p10GN'}=0.187;
    $statpot{'p10GD'}=0.329;
    $statpot{'p10GC'}=-0.095;
    $statpot{'p10GQ'}=0.170;
    $statpot{'p10GE'}=0.407;
    $statpot{'p10GG'}=0.385;
    $statpot{'p10GH'}=0.220;
    $statpot{'p10GI'}=0.032;
    $statpot{'p10GL'}=0.072;
    $statpot{'p10GK'}=0.327;
    $statpot{'p10GM'}=0.164;
    $statpot{'p10GF'}=0.174;
    $statpot{'p10GP'}=0.215;
    $statpot{'p10GS'}=0.186;
    $statpot{'p10GT'}=0.111;
    $statpot{'p10GW'}=0.159;
    $statpot{'p10GY'}=0.137;
    $statpot{'p10GV'}=0.051;
    $statpot{'p10HA'}=-0.021;
    $statpot{'p10HR'}=0.097;
    $statpot{'p10HN'}=0.017;
    $statpot{'p10HD'}=0.239;
    $statpot{'p10HC'}=0.186;
    $statpot{'p10HQ'}=0.119;
    $statpot{'p10HE'}=0.287;
    $statpot{'p10HG'}=0.220;
    $statpot{'p10HH'}=-0.106;
    $statpot{'p10HI'}=-0.144;
    $statpot{'p10HL'}=-0.218;
    $statpot{'p10HK'}=0.174;
    $statpot{'p10HM'}=0.005;
    $statpot{'p10HF'}=-0.184;
    $statpot{'p10HP'}=0.188;
    $statpot{'p10HS'}=0.174;
    $statpot{'p10HT'}=-0.094;
    $statpot{'p10HW'}=-0.007;
    $statpot{'p10HY'}=-0.057;
    $statpot{'p10HV'}=-0.068;
    $statpot{'p10IA'}=-0.289;
    $statpot{'p10IR'}=-0.134;
    $statpot{'p10IN'}=-0.024;
    $statpot{'p10ID'}=0.070;
    $statpot{'p10IC'}=-0.311;
    $statpot{'p10IQ'}=0.016;
    $statpot{'p10IE'}=0.035;
    $statpot{'p10IG'}=0.032;
    $statpot{'p10IH'}=-0.144;
    $statpot{'p10II'}=-0.490;
    $statpot{'p10IL'}=-0.403;
    $statpot{'p10IK'}=0.007;
    $statpot{'p10IM'}=-0.338;
    $statpot{'p10IF'}=-0.368;
    $statpot{'p10IP'}=-0.021;
    $statpot{'p10IS'}=-0.077;
    $statpot{'p10IT'}=-0.152;
    $statpot{'p10IW'}=-0.390;
    $statpot{'p10IY'}=-0.269;
    $statpot{'p10IV'}=-0.434;
    $statpot{'p10LA'}=-0.204;
    $statpot{'p10LR'}=-0.078;
    $statpot{'p10LN'}=0.070;
    $statpot{'p10LD'}=0.131;
    $statpot{'p10LC'}=-0.393;
    $statpot{'p10LQ'}=-0.009;
    $statpot{'p10LE'}=0.092;
    $statpot{'p10LG'}=0.072;
    $statpot{'p10LH'}=-0.218;
    $statpot{'p10LI'}=-0.403;
    $statpot{'p10LL'}=-0.425;
    $statpot{'p10LK'}=0.047;
    $statpot{'p10LM'}=-0.338;
    $statpot{'p10LF'}=-0.303;
    $statpot{'p10LP'}=0.047;
    $statpot{'p10LS'}=-0.096;
    $statpot{'p10LT'}=-0.176;
    $statpot{'p10LW'}=-0.238;
    $statpot{'p10LY'}=-0.223;
    $statpot{'p10LV'}=-0.427;
    $statpot{'p10KA'}=0.140;
    $statpot{'p10KR'}=0.131;
    $statpot{'p10KN'}=0.246;
    $statpot{'p10KD'}=0.228;
    $statpot{'p10KC'}=0.105;
    $statpot{'p10KQ'}=0.201;
    $statpot{'p10KE'}=0.146;
    $statpot{'p10KG'}=0.327;
    $statpot{'p10KH'}=0.174;
    $statpot{'p10KI'}=0.007;
    $statpot{'p10KL'}=0.047;
    $statpot{'p10KK'}=0.339;
    $statpot{'p10KM'}=0.233;
    $statpot{'p10KF'}=0.131;
    $statpot{'p10KP'}=0.321;
    $statpot{'p10KS'}=0.175;
    $statpot{'p10KT'}=0.183;
    $statpot{'p10KW'}=0.285;
    $statpot{'p10KY'}=0.142;
    $statpot{'p10KV'}=0.016;
    $statpot{'p10MA'}=-0.218;
    $statpot{'p10MR'}=-0.093;
    $statpot{'p10MN'}=0.182;
    $statpot{'p10MD'}=0.242;
    $statpot{'p10MC'}=-0.213;
    $statpot{'p10MQ'}=0.014;
    $statpot{'p10ME'}=0.214;
    $statpot{'p10MG'}=0.164;
    $statpot{'p10MH'}=0.005;
    $statpot{'p10MI'}=-0.338;
    $statpot{'p10ML'}=-0.338;
    $statpot{'p10MK'}=0.233;
    $statpot{'p10MM'}=-0.291;
    $statpot{'p10MF'}=-0.221;
    $statpot{'p10MP'}=0.050;
    $statpot{'p10MS'}=-0.088;
    $statpot{'p10MT'}=-0.114;
    $statpot{'p10MW'}=-0.253;
    $statpot{'p10MY'}=-0.227;
    $statpot{'p10MV'}=-0.282;
    $statpot{'p10FA'}=-0.185;
    $statpot{'p10FR'}=-0.010;
    $statpot{'p10FN'}=0.028;
    $statpot{'p10FD'}=0.152;
    $statpot{'p10FC'}=-0.418;
    $statpot{'p10FQ'}=-0.022;
    $statpot{'p10FE'}=0.144;
    $statpot{'p10FG'}=0.174;
    $statpot{'p10FH'}=-0.184;
    $statpot{'p10FI'}=-0.368;
    $statpot{'p10FL'}=-0.303;
    $statpot{'p10FK'}=0.131;
    $statpot{'p10FM'}=-0.221;
    $statpot{'p10FF'}=-0.425;
    $statpot{'p10FP'}=0.096;
    $statpot{'p10FS'}=-0.016;
    $statpot{'p10FT'}=-0.126;
    $statpot{'p10FW'}=-0.218;
    $statpot{'p10FY'}=-0.204;
    $statpot{'p10FV'}=-0.332;
    $statpot{'p10PA'}=0.084;
    $statpot{'p10PR'}=0.059;
    $statpot{'p10PN'}=0.171;
    $statpot{'p10PD'}=0.204;
    $statpot{'p10PC'}=-0.017;
    $statpot{'p10PQ'}=0.084;
    $statpot{'p10PE'}=0.254;
    $statpot{'p10PG'}=0.215;
    $statpot{'p10PH'}=0.188;
    $statpot{'p10PI'}=-0.021;
    $statpot{'p10PL'}=0.047;
    $statpot{'p10PK'}=0.321;
    $statpot{'p10PM'}=0.050;
    $statpot{'p10PF'}=0.096;
    $statpot{'p10PP'}=0.052;
    $statpot{'p10PS'}=0.144;
    $statpot{'p10PT'}=0.088;
    $statpot{'p10PW'}=-0.052;
    $statpot{'p10PY'}=-0.009;
    $statpot{'p10PV'}=-0.016;
    $statpot{'p10SA'}=0.051;
    $statpot{'p10SR'}=0.120;
    $statpot{'p10SN'}=0.074;
    $statpot{'p10SD'}=0.225;
    $statpot{'p10SC'}=-0.136;
    $statpot{'p10SQ'}=0.193;
    $statpot{'p10SE'}=0.289;
    $statpot{'p10SG'}=0.186;
    $statpot{'p10SH'}=0.174;
    $statpot{'p10SI'}=-0.077;
    $statpot{'p10SL'}=-0.096;
    $statpot{'p10SK'}=0.175;
    $statpot{'p10SM'}=-0.088;
    $statpot{'p10SF'}=-0.016;
    $statpot{'p10SP'}=0.144;
    $statpot{'p10SS'}=-0.003;
    $statpot{'p10ST'}=0.021;
    $statpot{'p10SW'}=0.041;
    $statpot{'p10SY'}=0.035;
    $statpot{'p10SV'}=-0.087;
    $statpot{'p10TA'}=-0.066;
    $statpot{'p10TR'}=0.057;
    $statpot{'p10TN'}=0.082;
    $statpot{'p10TD'}=0.181;
    $statpot{'p10TC'}=-0.160;
    $statpot{'p10TQ'}=0.081;
    $statpot{'p10TE'}=0.213;
    $statpot{'p10TG'}=0.111;
    $statpot{'p10TH'}=-0.094;
    $statpot{'p10TI'}=-0.152;
    $statpot{'p10TL'}=-0.176;
    $statpot{'p10TK'}=0.183;
    $statpot{'p10TM'}=-0.114;
    $statpot{'p10TF'}=-0.126;
    $statpot{'p10TP'}=0.088;
    $statpot{'p10TS'}=0.021;
    $statpot{'p10TT'}=-0.059;
    $statpot{'p10TW'}=-0.036;
    $statpot{'p10TY'}=-0.106;
    $statpot{'p10TV'}=-0.178;
    $statpot{'p10WA'}=-0.054;
    $statpot{'p10WR'}=-0.006;
    $statpot{'p10WN'}=-0.020;
    $statpot{'p10WD'}=0.056;
    $statpot{'p10WC'}=-0.269;
    $statpot{'p10WQ'}=-0.064;
    $statpot{'p10WE'}=0.154;
    $statpot{'p10WG'}=0.159;
    $statpot{'p10WH'}=-0.007;
    $statpot{'p10WI'}=-0.390;
    $statpot{'p10WL'}=-0.238;
    $statpot{'p10WK'}=0.285;
    $statpot{'p10WM'}=-0.253;
    $statpot{'p10WF'}=-0.218;
    $statpot{'p10WP'}=-0.052;
    $statpot{'p10WS'}=0.041;
    $statpot{'p10WT'}=-0.036;
    $statpot{'p10WW'}=-0.490;
    $statpot{'p10WY'}=-0.295;
    $statpot{'p10WV'}=-0.256;
    $statpot{'p10YA'}=-0.152;
    $statpot{'p10YR'}=0.033;
    $statpot{'p10YN'}=0.094;
    $statpot{'p10YD'}=0.110;
    $statpot{'p10YC'}=-0.298;
    $statpot{'p10YQ'}=0.058;
    $statpot{'p10YE'}=0.092;
    $statpot{'p10YG'}=0.137;
    $statpot{'p10YH'}=-0.057;
    $statpot{'p10YI'}=-0.269;
    $statpot{'p10YL'}=-0.223;
    $statpot{'p10YK'}=0.142;
    $statpot{'p10YM'}=-0.227;
    $statpot{'p10YF'}=-0.204;
    $statpot{'p10YP'}=-0.009;
    $statpot{'p10YS'}=0.035;
    $statpot{'p10YT'}=-0.106;
    $statpot{'p10YW'}=-0.295;
    $statpot{'p10YY'}=-0.115;
    $statpot{'p10YV'}=-0.289;
    $statpot{'p10VA'}=-0.249;
    $statpot{'p10VR'}=-0.041;
    $statpot{'p10VN'}=-0.061;
    $statpot{'p10VD'}=0.092;
    $statpot{'p10VC'}=-0.371;
    $statpot{'p10VQ'}=-0.046;
    $statpot{'p10VE'}=0.066;
    $statpot{'p10VG'}=0.051;
    $statpot{'p10VH'}=-0.068;
    $statpot{'p10VI'}=-0.434;
    $statpot{'p10VL'}=-0.427;
    $statpot{'p10VK'}=0.016;
    $statpot{'p10VM'}=-0.282;
    $statpot{'p10VF'}=-0.332;
    $statpot{'p10VP'}=-0.016;
    $statpot{'p10VS'}=-0.087;
    $statpot{'p10VT'}=-0.178;
    $statpot{'p10VW'}=-0.256;
    $statpot{'p10VY'}=-0.289;
    $statpot{'p10VV'}=-0.468;
    $statpot{'f10AA'}=-0.054;
    $statpot{'f10AR'}=0.199;
    $statpot{'f10AN'}=0.229;
    $statpot{'f10AD'}=0.346;
    $statpot{'f10AC'}=-0.132;
    $statpot{'f10AQ'}=0.117;
    $statpot{'f10AE'}=0.115;
    $statpot{'f10AG'}=0.075;
    $statpot{'f10AH'}=-0.012;
    $statpot{'f10AI'}=-0.353;
    $statpot{'f10AL'}=-0.299;
    $statpot{'f10AK'}=0.210;
    $statpot{'f10AM'}=-0.352;
    $statpot{'f10AF'}=-0.252;
    $statpot{'f10AP'}=0.157;
    $statpot{'f10AS'}=0.065;
    $statpot{'f10AT'}=-0.042;
    $statpot{'f10AW'}=-0.174;
    $statpot{'f10AY'}=-0.219;
    $statpot{'f10AV'}=-0.316;
    $statpot{'f10RA'}=0.287;
    $statpot{'f10RR'}=0.414;
    $statpot{'f10RN'}=0.290;
    $statpot{'f10RD'}=0.323;
    $statpot{'f10RC'}=0.254;
    $statpot{'f10RQ'}=0.211;
    $statpot{'f10RE'}=0.289;
    $statpot{'f10RG'}=0.438;
    $statpot{'f10RH'}=0.227;
    $statpot{'f10RI'}=0.051;
    $statpot{'f10RL'}=-0.068;
    $statpot{'f10RK'}=0.619;
    $statpot{'f10RM'}=-0.019;
    $statpot{'f10RF'}=0.021;
    $statpot{'f10RP'}=0.361;
    $statpot{'f10RS'}=0.309;
    $statpot{'f10RT'}=0.243;
    $statpot{'f10RW'}=0.194;
    $statpot{'f10RY'}=0.031;
    $statpot{'f10RV'}=0.050;
    $statpot{'f10NA'}=0.330;
    $statpot{'f10NR'}=0.517;
    $statpot{'f10NN'}=0.583;
    $statpot{'f10ND'}=0.422;
    $statpot{'f10NC'}=0.249;
    $statpot{'f10NQ'}=0.349;
    $statpot{'f10NE'}=0.660;
    $statpot{'f10NG'}=0.314;
    $statpot{'f10NH'}=0.229;
    $statpot{'f10NI'}=0.049;
    $statpot{'f10NL'}=0.013;
    $statpot{'f10NK'}=0.722;
    $statpot{'f10NM'}=0.157;
    $statpot{'f10NF'}=0.087;
    $statpot{'f10NP'}=0.543;
    $statpot{'f10NS'}=0.371;
    $statpot{'f10NT'}=0.260;
    $statpot{'f10NW'}=0.125;
    $statpot{'f10NY'}=-0.027;
    $statpot{'f10NV'}=-0.012;
    $statpot{'f10DA'}=0.491;
    $statpot{'f10DR'}=0.483;
    $statpot{'f10DN'}=0.520;
    $statpot{'f10DD'}=0.683;
    $statpot{'f10DC'}=0.123;
    $statpot{'f10DQ'}=0.543;
    $statpot{'f10DE'}=0.763;
    $statpot{'f10DG'}=0.640;
    $statpot{'f10DH'}=0.609;
    $statpot{'f10DI'}=0.133;
    $statpot{'f10DL'}=0.056;
    $statpot{'f10DK'}=0.766;
    $statpot{'f10DM'}=0.346;
    $statpot{'f10DF'}=0.169;
    $statpot{'f10DP'}=0.654;
    $statpot{'f10DS'}=0.487;
    $statpot{'f10DT'}=0.422;
    $statpot{'f10DW'}=0.221;
    $statpot{'f10DY'}=0.223;
    $statpot{'f10DV'}=0.209;
    $statpot{'f10CA'}=-0.206;
    $statpot{'f10CR'}=0.210;
    $statpot{'f10CN'}=-0.082;
    $statpot{'f10CD'}=-0.024;
    $statpot{'f10CC'}=-0.108;
    $statpot{'f10CQ'}=-0.156;
    $statpot{'f10CE'}=-0.077;
    $statpot{'f10CG'}=-0.337;
    $statpot{'f10CH'}=-0.153;
    $statpot{'f10CI'}=-0.459;
    $statpot{'f10CL'}=-0.468;
    $statpot{'f10CK'}=-0.164;
    $statpot{'f10CM'}=-0.548;
    $statpot{'f10CF'}=-0.546;
    $statpot{'f10CP'}=-0.168;
    $statpot{'f10CS'}=-0.217;
    $statpot{'f10CT'}=-0.168;
    $statpot{'f10CW'}=-0.324;
    $statpot{'f10CY'}=-0.299;
    $statpot{'f10CV'}=-0.594;
    $statpot{'f10QA'}=0.161;
    $statpot{'f10QR'}=0.353;
    $statpot{'f10QN'}=0.305;
    $statpot{'f10QD'}=0.427;
    $statpot{'f10QC'}=0.204;
    $statpot{'f10QQ'}=0.448;
    $statpot{'f10QE'}=0.499;
    $statpot{'f10QG'}=0.450;
    $statpot{'f10QH'}=0.086;
    $statpot{'f10QI'}=-0.221;
    $statpot{'f10QL'}=0.009;
    $statpot{'f10QK'}=0.542;
    $statpot{'f10QM'}=0.273;
    $statpot{'f10QF'}=0.003;
    $statpot{'f10QP'}=0.425;
    $statpot{'f10QS'}=0.311;
    $statpot{'f10QT'}=0.205;
    $statpot{'f10QW'}=0.069;
    $statpot{'f10QY'}=0.024;
    $statpot{'f10QV'}=-0.044;
    $statpot{'f10EA'}=0.333;
    $statpot{'f10ER'}=0.351;
    $statpot{'f10EN'}=0.788;
    $statpot{'f10ED'}=0.717;
    $statpot{'f10EC'}=0.281;
    $statpot{'f10EQ'}=0.625;
    $statpot{'f10EE'}=0.542;
    $statpot{'f10EG'}=0.653;
    $statpot{'f10EH'}=0.502;
    $statpot{'f10EI'}=0.135;
    $statpot{'f10EL'}=0.151;
    $statpot{'f10EK'}=0.604;
    $statpot{'f10EM'}=0.213;
    $statpot{'f10EF'}=0.137;
    $statpot{'f10EP'}=0.674;
    $statpot{'f10ES'}=0.423;
    $statpot{'f10ET'}=0.451;
    $statpot{'f10EW'}=0.329;
    $statpot{'f10EY'}=0.188;
    $statpot{'f10EV'}=0.118;
    $statpot{'f10GA'}=0.192;
    $statpot{'f10GR'}=0.428;
    $statpot{'f10GN'}=0.278;
    $statpot{'f10GD'}=0.576;
    $statpot{'f10GC'}=-0.135;
    $statpot{'f10GQ'}=0.384;
    $statpot{'f10GE'}=0.658;
    $statpot{'f10GG'}=0.393;
    $statpot{'f10GH'}=0.112;
    $statpot{'f10GI'}=0.074;
    $statpot{'f10GL'}=0.086;
    $statpot{'f10GK'}=0.648;
    $statpot{'f10GM'}=0.095;
    $statpot{'f10GF'}=-0.065;
    $statpot{'f10GP'}=0.314;
    $statpot{'f10GS'}=0.311;
    $statpot{'f10GT'}=0.202;
    $statpot{'f10GW'}=0.063;
    $statpot{'f10GY'}=-0.055;
    $statpot{'f10GV'}=0.039;
    $statpot{'f10HA'}=0.019;
    $statpot{'f10HR'}=0.225;
    $statpot{'f10HN'}=0.237;
    $statpot{'f10HD'}=0.423;
    $statpot{'f10HC'}=-0.074;
    $statpot{'f10HQ'}=-0.015;
    $statpot{'f10HE'}=0.370;
    $statpot{'f10HG'}=0.067;
    $statpot{'f10HH'}=-0.070;
    $statpot{'f10HI'}=-0.219;
    $statpot{'f10HL'}=-0.105;
    $statpot{'f10HK'}=0.473;
    $statpot{'f10HM'}=-0.321;
    $statpot{'f10HF'}=-0.303;
    $statpot{'f10HP'}=0.083;
    $statpot{'f10HS'}=0.152;
    $statpot{'f10HT'}=0.002;
    $statpot{'f10HW'}=-0.147;
    $statpot{'f10HY'}=-0.201;
    $statpot{'f10HV'}=-0.152;
    $statpot{'f10IA'}=-0.442;
    $statpot{'f10IR'}=-0.195;
    $statpot{'f10IN'}=-0.226;
    $statpot{'f10ID'}=-0.147;
    $statpot{'f10IC'}=-0.426;
    $statpot{'f10IQ'}=-0.337;
    $statpot{'f10IE'}=-0.098;
    $statpot{'f10IG'}=-0.137;
    $statpot{'f10IH'}=-0.388;
    $statpot{'f10II'}=-0.652;
    $statpot{'f10IL'}=-0.652;
    $statpot{'f10IK'}=-0.143;
    $statpot{'f10IM'}=-0.589;
    $statpot{'f10IF'}=-0.494;
    $statpot{'f10IP'}=-0.135;
    $statpot{'f10IS'}=-0.244;
    $statpot{'f10IT'}=-0.533;
    $statpot{'f10IW'}=-0.499;
    $statpot{'f10IY'}=-0.508;
    $statpot{'f10IV'}=-0.714;
    $statpot{'f10LA'}=-0.375;
    $statpot{'f10LR'}=-0.260;
    $statpot{'f10LN'}=-0.192;
    $statpot{'f10LD'}=-0.089;
    $statpot{'f10LC'}=-0.495;
    $statpot{'f10LQ'}=-0.207;
    $statpot{'f10LE'}=-0.099;
    $statpot{'f10LG'}=-0.081;
    $statpot{'f10LH'}=-0.324;
    $statpot{'f10LI'}=-0.659;
    $statpot{'f10LL'}=-0.542;
    $statpot{'f10LK'}=-0.093;
    $statpot{'f10LM'}=-0.422;
    $statpot{'f10LF'}=-0.568;
    $statpot{'f10LP'}=-0.109;
    $statpot{'f10LS'}=-0.212;
    $statpot{'f10LT'}=-0.305;
    $statpot{'f10LW'}=-0.572;
    $statpot{'f10LY'}=-0.425;
    $statpot{'f10LV'}=-0.559;
    $statpot{'f10KA'}=0.361;
    $statpot{'f10KR'}=0.677;
    $statpot{'f10KN'}=0.593;
    $statpot{'f10KD'}=0.678;
    $statpot{'f10KC'}=-0.013;
    $statpot{'f10KQ'}=0.505;
    $statpot{'f10KE'}=0.532;
    $statpot{'f10KG'}=0.723;
    $statpot{'f10KH'}=0.587;
    $statpot{'f10KI'}=0.048;
    $statpot{'f10KL'}=0.172;
    $statpot{'f10KK'}=0.821;
    $statpot{'f10KM'}=0.321;
    $statpot{'f10KF'}=0.138;
    $statpot{'f10KP'}=0.784;
    $statpot{'f10KS'}=0.571;
    $statpot{'f10KT'}=0.466;
    $statpot{'f10KW'}=0.201;
    $statpot{'f10KY'}=0.115;
    $statpot{'f10KV'}=0.236;
    $statpot{'f10MA'}=-0.308;
    $statpot{'f10MR'}=-0.274;
    $statpot{'f10MN'}=-0.169;
    $statpot{'f10MD'}=0.008;
    $statpot{'f10MC'}=-0.528;
    $statpot{'f10MQ'}=-0.023;
    $statpot{'f10ME'}=0.069;
    $statpot{'f10MG'}=-0.123;
    $statpot{'f10MH'}=-0.353;
    $statpot{'f10MI'}=-0.545;
    $statpot{'f10ML'}=-0.468;
    $statpot{'f10MK'}=0.121;
    $statpot{'f10MM'}=-0.268;
    $statpot{'f10MF'}=-0.434;
    $statpot{'f10MP'}=-0.196;
    $statpot{'f10MS'}=-0.225;
    $statpot{'f10MT'}=-0.240;
    $statpot{'f10MW'}=-0.370;
    $statpot{'f10MY'}=-0.545;
    $statpot{'f10MV'}=-0.365;
    $statpot{'f10FA'}=-0.269;
    $statpot{'f10FR'}=-0.041;
    $statpot{'f10FN'}=-0.008;
    $statpot{'f10FD'}=-0.066;
    $statpot{'f10FC'}=-0.589;
    $statpot{'f10FQ'}=-0.071;
    $statpot{'f10FE'}=0.040;
    $statpot{'f10FG'}=-0.155;
    $statpot{'f10FH'}=-0.377;
    $statpot{'f10FI'}=-0.497;
    $statpot{'f10FL'}=-0.544;
    $statpot{'f10FK'}=0.103;
    $statpot{'f10FM'}=-0.442;
    $statpot{'f10FF'}=-0.547;
    $statpot{'f10FP'}=0.011;
    $statpot{'f10FS'}=-0.111;
    $statpot{'f10FT'}=-0.221;
    $statpot{'f10FW'}=-0.406;
    $statpot{'f10FY'}=-0.450;
    $statpot{'f10FV'}=-0.459;
    $statpot{'f10PA'}=0.266;
    $statpot{'f10PR'}=0.414;
    $statpot{'f10PN'}=0.464;
    $statpot{'f10PD'}=0.604;
    $statpot{'f10PC'}=0.172;
    $statpot{'f10PQ'}=0.591;
    $statpot{'f10PE'}=0.697;
    $statpot{'f10PG'}=0.345;
    $statpot{'f10PH'}=0.212;
    $statpot{'f10PI'}=0.127;
    $statpot{'f10PL'}=0.104;
    $statpot{'f10PK'}=0.679;
    $statpot{'f10PM'}=0.163;
    $statpot{'f10PF'}=0.126;
    $statpot{'f10PP'}=0.811;
    $statpot{'f10PS'}=0.392;
    $statpot{'f10PT'}=0.395;
    $statpot{'f10PW'}=0.087;
    $statpot{'f10PY'}=0.062;
    $statpot{'f10PV'}=0.180;
    $statpot{'f10SA'}=0.156;
    $statpot{'f10SR'}=0.361;
    $statpot{'f10SN'}=0.450;
    $statpot{'f10SD'}=0.368;
    $statpot{'f10SC'}=0.034;
    $statpot{'f10SQ'}=0.365;
    $statpot{'f10SE'}=0.394;
    $statpot{'f10SG'}=0.311;
    $statpot{'f10SH'}=0.184;
    $statpot{'f10SI'}=-0.091;
    $statpot{'f10SL'}=-0.030;
    $statpot{'f10SK'}=0.590;
    $statpot{'f10SM'}=-0.084;
    $statpot{'f10SF'}=-0.064;
    $statpot{'f10SP'}=0.420;
    $statpot{'f10SS'}=0.253;
    $statpot{'f10ST'}=0.201;
    $statpot{'f10SW'}=-0.077;
    $statpot{'f10SY'}=-0.003;
    $statpot{'f10SV'}=-0.106;
    $statpot{'f10TA'}=0.088;
    $statpot{'f10TR'}=0.222;
    $statpot{'f10TN'}=0.264;
    $statpot{'f10TD'}=0.336;
    $statpot{'f10TC'}=-0.006;
    $statpot{'f10TQ'}=0.204;
    $statpot{'f10TE'}=0.379;
    $statpot{'f10TG'}=0.203;
    $statpot{'f10TH'}=-0.005;
    $statpot{'f10TI'}=-0.303;
    $statpot{'f10TL'}=-0.170;
    $statpot{'f10TK'}=0.470;
    $statpot{'f10TM'}=-0.151;
    $statpot{'f10TF'}=-0.111;
    $statpot{'f10TP'}=0.254;
    $statpot{'f10TS'}=0.224;
    $statpot{'f10TT'}=0.222;
    $statpot{'f10TW'}=-0.030;
    $statpot{'f10TY'}=-0.036;
    $statpot{'f10TV'}=-0.231;
    $statpot{'f10WA'}=-0.260;
    $statpot{'f10WR'}=0.078;
    $statpot{'f10WN'}=-0.104;
    $statpot{'f10WD'}=-0.025;
    $statpot{'f10WC'}=-0.260;
    $statpot{'f10WQ'}=-0.089;
    $statpot{'f10WE'}=0.148;
    $statpot{'f10WG'}=-0.062;
    $statpot{'f10WH'}=-0.389;
    $statpot{'f10WI'}=-0.552;
    $statpot{'f10WL'}=-0.454;
    $statpot{'f10WK'}=-0.151;
    $statpot{'f10WM'}=-0.509;
    $statpot{'f10WF'}=-0.527;
    $statpot{'f10WP'}=-0.131;
    $statpot{'f10WS'}=-0.273;
    $statpot{'f10WT'}=-0.096;
    $statpot{'f10WW'}=-0.436;
    $statpot{'f10WY'}=-0.333;
    $statpot{'f10WV'}=-0.382;
    $statpot{'f10YA'}=-0.245;
    $statpot{'f10YR'}=-0.008;
    $statpot{'f10YN'}=-0.176;
    $statpot{'f10YD'}=0.054;
    $statpot{'f10YC'}=-0.364;
    $statpot{'f10YQ'}=-0.088;
    $statpot{'f10YE'}=0.056;
    $statpot{'f10YG'}=-0.188;
    $statpot{'f10YH'}=-0.282;
    $statpot{'f10YI'}=-0.363;
    $statpot{'f10YL'}=-0.310;
    $statpot{'f10YK'}=-0.021;
    $statpot{'f10YM'}=-0.491;
    $statpot{'f10YF'}=-0.443;
    $statpot{'f10YP'}=-0.072;
    $statpot{'f10YS'}=-0.170;
    $statpot{'f10YT'}=-0.235;
    $statpot{'f10YW'}=-0.330;
    $statpot{'f10YY'}=-0.236;
    $statpot{'f10YV'}=-0.368;
    $statpot{'f10VA'}=-0.328;
    $statpot{'f10VR'}=-0.084;
    $statpot{'f10VN'}=-0.123;
    $statpot{'f10VD'}=-0.004;
    $statpot{'f10VC'}=-0.536;
    $statpot{'f10VQ'}=-0.182;
    $statpot{'f10VE'}=-0.122;
    $statpot{'f10VG'}=-0.166;
    $statpot{'f10VH'}=-0.192;
    $statpot{'f10VI'}=-0.656;
    $statpot{'f10VL'}=-0.565;
    $statpot{'f10VK'}=-0.040;
    $statpot{'f10VM'}=-0.365;
    $statpot{'f10VF'}=-0.520;
    $statpot{'f10VP'}=-0.010;
    $statpot{'f10VS'}=-0.240;
    $statpot{'f10VT'}=-0.391;
    $statpot{'f10VW'}=-0.400;
    $statpot{'f10VY'}=-0.440;
    $statpot{'f10VV'}=-0.552;
    $statpot{'a10AA'}=0.067;
    $statpot{'a10AR'}=0.090;
    $statpot{'a10AN'}=0.236;
    $statpot{'a10AD'}=0.237;
    $statpot{'a10AC'}=-0.120;
    $statpot{'a10AQ'}=0.064;
    $statpot{'a10AE'}=0.293;
    $statpot{'a10AG'}=0.152;
    $statpot{'a10AH'}=0.107;
    $statpot{'a10AI'}=-0.187;
    $statpot{'a10AL'}=-0.116;
    $statpot{'a10AK'}=0.147;
    $statpot{'a10AM'}=0.013;
    $statpot{'a10AF'}=-0.057;
    $statpot{'a10AP'}=0.161;
    $statpot{'a10AS'}=0.092;
    $statpot{'a10AT'}=0.125;
    $statpot{'a10AW'}=-0.100;
    $statpot{'a10AY'}=-0.077;
    $statpot{'a10AV'}=-0.134;
    $statpot{'a10RA'}=-0.009;
    $statpot{'a10RR'}=0.125;
    $statpot{'a10RN'}=0.323;
    $statpot{'a10RD'}=0.492;
    $statpot{'a10RC'}=0.073;
    $statpot{'a10RQ'}=0.205;
    $statpot{'a10RE'}=0.354;
    $statpot{'a10RG'}=0.201;
    $statpot{'a10RH'}=0.055;
    $statpot{'a10RI'}=-0.292;
    $statpot{'a10RL'}=-0.326;
    $statpot{'a10RK'}=0.257;
    $statpot{'a10RM'}=-0.366;
    $statpot{'a10RF'}=-0.133;
    $statpot{'a10RP'}=0.038;
    $statpot{'a10RS'}=0.173;
    $statpot{'a10RT'}=-0.018;
    $statpot{'a10RW'}=-0.117;
    $statpot{'a10RY'}=-0.160;
    $statpot{'a10RV'}=-0.241;
    $statpot{'a10NA'}=0.112;
    $statpot{'a10NR'}=0.074;
    $statpot{'a10NN'}=0.124;
    $statpot{'a10ND'}=0.579;
    $statpot{'a10NC'}=-0.184;
    $statpot{'a10NQ'}=0.145;
    $statpot{'a10NE'}=0.540;
    $statpot{'a10NG'}=0.235;
    $statpot{'a10NH'}=0.179;
    $statpot{'a10NI'}=-0.397;
    $statpot{'a10NL'}=-0.258;
    $statpot{'a10NK'}=0.198;
    $statpot{'a10NM'}=-0.189;
    $statpot{'a10NF'}=-0.189;
    $statpot{'a10NP'}=0.183;
    $statpot{'a10NS'}=0.261;
    $statpot{'a10NT'}=0.059;
    $statpot{'a10NW'}=-0.282;
    $statpot{'a10NY'}=-0.157;
    $statpot{'a10NV'}=-0.161;
    $statpot{'a10DA'}=0.084;
    $statpot{'a10DR'}=0.278;
    $statpot{'a10DN'}=0.442;
    $statpot{'a10DD'}=0.603;
    $statpot{'a10DC'}=-0.232;
    $statpot{'a10DQ'}=0.337;
    $statpot{'a10DE'}=0.374;
    $statpot{'a10DG'}=0.413;
    $statpot{'a10DH'}=0.307;
    $statpot{'a10DI'}=-0.404;
    $statpot{'a10DL'}=-0.261;
    $statpot{'a10DK'}=0.436;
    $statpot{'a10DM'}=-0.254;
    $statpot{'a10DF'}=-0.310;
    $statpot{'a10DP'}=0.213;
    $statpot{'a10DS'}=0.217;
    $statpot{'a10DT'}=0.162;
    $statpot{'a10DW'}=-0.172;
    $statpot{'a10DY'}=-0.083;
    $statpot{'a10DV'}=-0.281;
    $statpot{'a10CA'}=-0.009;
    $statpot{'a10CR'}=0.123;
    $statpot{'a10CN'}=0.225;
    $statpot{'a10CD'}=-0.071;
    $statpot{'a10CC'}=0.215;
    $statpot{'a10CQ'}=0.002;
    $statpot{'a10CE'}=0.250;
    $statpot{'a10CG'}=0.028;
    $statpot{'a10CH'}=-0.109;
    $statpot{'a10CI'}=-0.012;
    $statpot{'a10CL'}=-0.149;
    $statpot{'a10CK'}=0.078;
    $statpot{'a10CM'}=0.133;
    $statpot{'a10CF'}=0.403;
    $statpot{'a10CP'}=-0.055;
    $statpot{'a10CS'}=-0.141;
    $statpot{'a10CT'}=0.051;
    $statpot{'a10CW'}=-0.238;
    $statpot{'a10CY'}=-0.015;
    $statpot{'a10CV'}=-0.176;
    $statpot{'a10QA'}=0.010;
    $statpot{'a10QR'}=0.039;
    $statpot{'a10QN'}=0.196;
    $statpot{'a10QD'}=0.483;
    $statpot{'a10QC'}=-0.381;
    $statpot{'a10QQ'}=0.264;
    $statpot{'a10QE'}=0.269;
    $statpot{'a10QG'}=0.242;
    $statpot{'a10QH'}=-0.149;
    $statpot{'a10QI'}=-0.244;
    $statpot{'a10QL'}=-0.275;
    $statpot{'a10QK'}=0.111;
    $statpot{'a10QM'}=-0.239;
    $statpot{'a10QF'}=-0.028;
    $statpot{'a10QP'}=0.125;
    $statpot{'a10QS'}=0.118;
    $statpot{'a10QT'}=0.191;
    $statpot{'a10QW'}=-0.247;
    $statpot{'a10QY'}=-0.183;
    $statpot{'a10QV'}=-0.216;
    $statpot{'a10EA'}=0.012;
    $statpot{'a10ER'}=0.269;
    $statpot{'a10EN'}=0.405;
    $statpot{'a10ED'}=0.419;
    $statpot{'a10EC'}=-0.192;
    $statpot{'a10EQ'}=0.150;
    $statpot{'a10EE'}=0.454;
    $statpot{'a10EG'}=0.380;
    $statpot{'a10EH'}=0.083;
    $statpot{'a10EI'}=-0.336;
    $statpot{'a10EL'}=-0.322;
    $statpot{'a10EK'}=0.290;
    $statpot{'a10EM'}=-0.160;
    $statpot{'a10EF'}=-0.170;
    $statpot{'a10EP'}=0.263;
    $statpot{'a10ES'}=0.236;
    $statpot{'a10ET'}=0.181;
    $statpot{'a10EW'}=-0.127;
    $statpot{'a10EY'}=0.076;
    $statpot{'a10EV'}=-0.287;
    $statpot{'a10GA'}=0.001;
    $statpot{'a10GR'}=0.214;
    $statpot{'a10GN'}=0.282;
    $statpot{'a10GD'}=0.488;
    $statpot{'a10GC'}=-0.269;
    $statpot{'a10GQ'}=0.321;
    $statpot{'a10GE'}=0.377;
    $statpot{'a10GG'}=0.226;
    $statpot{'a10GH'}=0.130;
    $statpot{'a10GI'}=-0.232;
    $statpot{'a10GL'}=-0.190;
    $statpot{'a10GK'}=0.384;
    $statpot{'a10GM'}=-0.190;
    $statpot{'a10GF'}=-0.095;
    $statpot{'a10GP'}=0.111;
    $statpot{'a10GS'}=0.138;
    $statpot{'a10GT'}=0.081;
    $statpot{'a10GW'}=-0.094;
    $statpot{'a10GY'}=-0.236;
    $statpot{'a10GV'}=-0.209;
    $statpot{'a10HA'}=0.060;
    $statpot{'a10HR'}=0.057;
    $statpot{'a10HN'}=0.169;
    $statpot{'a10HD'}=0.538;
    $statpot{'a10HC'}=-0.210;
    $statpot{'a10HQ'}=-0.027;
    $statpot{'a10HE'}=0.219;
    $statpot{'a10HG'}=0.197;
    $statpot{'a10HH'}=0.051;
    $statpot{'a10HI'}=-0.395;
    $statpot{'a10HL'}=-0.310;
    $statpot{'a10HK'}=0.472;
    $statpot{'a10HM'}=-0.155;
    $statpot{'a10HF'}=-0.232;
    $statpot{'a10HP'}=0.041;
    $statpot{'a10HS'}=0.107;
    $statpot{'a10HT'}=-0.029;
    $statpot{'a10HW'}=-0.305;
    $statpot{'a10HY'}=-0.214;
    $statpot{'a10HV'}=-0.081;
    $statpot{'a10IA'}=-0.023;
    $statpot{'a10IR'}=0.025;
    $statpot{'a10IN'}=-0.076;
    $statpot{'a10ID'}=-0.105;
    $statpot{'a10IC'}=-0.076;
    $statpot{'a10IQ'}=-0.062;
    $statpot{'a10IE'}=-0.081;
    $statpot{'a10IG'}=0.036;
    $statpot{'a10IH'}=-0.155;
    $statpot{'a10II'}=-0.093;
    $statpot{'a10IL'}=-0.162;
    $statpot{'a10IK'}=-0.050;
    $statpot{'a10IM'}=-0.038;
    $statpot{'a10IF'}=-0.110;
    $statpot{'a10IP'}=-0.015;
    $statpot{'a10IS'}=-0.074;
    $statpot{'a10IT'}=-0.142;
    $statpot{'a10IW'}=-0.044;
    $statpot{'a10IY'}=0.022;
    $statpot{'a10IV'}=-0.222;
    $statpot{'a10LA'}=0.026;
    $statpot{'a10LR'}=-0.069;
    $statpot{'a10LN'}=0.008;
    $statpot{'a10LD'}=-0.092;
    $statpot{'a10LC'}=-0.101;
    $statpot{'a10LQ'}=0.010;
    $statpot{'a10LE'}=-0.043;
    $statpot{'a10LG'}=0.017;
    $statpot{'a10LH'}=0.010;
    $statpot{'a10LI'}=-0.147;
    $statpot{'a10LL'}=-0.072;
    $statpot{'a10LK'}=-0.044;
    $statpot{'a10LM'}=-0.126;
    $statpot{'a10LF'}=-0.030;
    $statpot{'a10LP'}=-0.011;
    $statpot{'a10LS'}=-0.046;
    $statpot{'a10LT'}=-0.112;
    $statpot{'a10LW'}=0.122;
    $statpot{'a10LY'}=0.076;
    $statpot{'a10LV'}=-0.128;
    $statpot{'a10KA'}=-0.019;
    $statpot{'a10KR'}=0.204;
    $statpot{'a10KN'}=0.314;
    $statpot{'a10KD'}=0.530;
    $statpot{'a10KC'}=-0.134;
    $statpot{'a10KQ'}=0.144;
    $statpot{'a10KE'}=0.367;
    $statpot{'a10KG'}=0.309;
    $statpot{'a10KH'}=0.336;
    $statpot{'a10KI'}=-0.279;
    $statpot{'a10KL'}=-0.331;
    $statpot{'a10KK'}=0.271;
    $statpot{'a10KM'}=-0.144;
    $statpot{'a10KF'}=-0.186;
    $statpot{'a10KP'}=0.030;
    $statpot{'a10KS'}=0.290;
    $statpot{'a10KT'}=0.176;
    $statpot{'a10KW'}=-0.316;
    $statpot{'a10KY'}=-0.115;
    $statpot{'a10KV'}=-0.286;
    $statpot{'a10MA'}=-0.068;
    $statpot{'a10MR'}=-0.032;
    $statpot{'a10MN'}=0.271;
    $statpot{'a10MD'}=0.106;
    $statpot{'a10MC'}=0.086;
    $statpot{'a10MQ'}=0.094;
    $statpot{'a10ME'}=-0.002;
    $statpot{'a10MG'}=0.098;
    $statpot{'a10MH'}=-0.100;
    $statpot{'a10MI'}=-0.134;
    $statpot{'a10ML'}=-0.036;
    $statpot{'a10MK'}=0.067;
    $statpot{'a10MM'}=0.026;
    $statpot{'a10MF'}=-0.119;
    $statpot{'a10MP'}=0.089;
    $statpot{'a10MS'}=-0.081;
    $statpot{'a10MT'}=-0.094;
    $statpot{'a10MW'}=-0.260;
    $statpot{'a10MY'}=-0.214;
    $statpot{'a10MV'}=-0.036;
    $statpot{'a10FA'}=-0.028;
    $statpot{'a10FR'}=-0.055;
    $statpot{'a10FN'}=-0.082;
    $statpot{'a10FD'}=-0.056;
    $statpot{'a10FC'}=0.560;
    $statpot{'a10FQ'}=0.079;
    $statpot{'a10FE'}=-0.063;
    $statpot{'a10FG'}=0.036;
    $statpot{'a10FH'}=-0.114;
    $statpot{'a10FI'}=-0.104;
    $statpot{'a10FL'}=-0.084;
    $statpot{'a10FK'}=-0.151;
    $statpot{'a10FM'}=-0.105;
    $statpot{'a10FF'}=0.067;
    $statpot{'a10FP'}=-0.057;
    $statpot{'a10FS'}=-0.165;
    $statpot{'a10FT'}=-0.058;
    $statpot{'a10FW'}=-0.154;
    $statpot{'a10FY'}=-0.081;
    $statpot{'a10FV'}=-0.134;
    $statpot{'a10PA'}=0.028;
    $statpot{'a10PR'}=-0.012;
    $statpot{'a10PN'}=0.262;
    $statpot{'a10PD'}=0.258;
    $statpot{'a10PC'}=-0.405;
    $statpot{'a10PQ'}=-0.020;
    $statpot{'a10PE'}=0.244;
    $statpot{'a10PG'}=0.075;
    $statpot{'a10PH'}=-0.105;
    $statpot{'a10PI'}=-0.318;
    $statpot{'a10PL'}=-0.265;
    $statpot{'a10PK'}=0.102;
    $statpot{'a10PM'}=-0.347;
    $statpot{'a10PF'}=-0.185;
    $statpot{'a10PP'}=0.010;
    $statpot{'a10PS'}=0.118;
    $statpot{'a10PT'}=-0.001;
    $statpot{'a10PW'}=-0.312;
    $statpot{'a10PY'}=-0.237;
    $statpot{'a10PV'}=-0.244;
    $statpot{'a10SA'}=-0.024;
    $statpot{'a10SR'}=0.115;
    $statpot{'a10SN'}=0.174;
    $statpot{'a10SD'}=0.358;
    $statpot{'a10SC'}=-0.414;
    $statpot{'a10SQ'}=0.061;
    $statpot{'a10SE'}=0.269;
    $statpot{'a10SG'}=0.137;
    $statpot{'a10SH'}=0.068;
    $statpot{'a10SI'}=-0.279;
    $statpot{'a10SL'}=-0.282;
    $statpot{'a10SK'}=0.270;
    $statpot{'a10SM'}=-0.270;
    $statpot{'a10SF'}=-0.223;
    $statpot{'a10SP'}=0.091;
    $statpot{'a10SS'}=0.192;
    $statpot{'a10ST'}=0.069;
    $statpot{'a10SW'}=-0.295;
    $statpot{'a10SY'}=-0.215;
    $statpot{'a10SV'}=-0.311;
    $statpot{'a10TA'}=-0.055;
    $statpot{'a10TR'}=0.005;
    $statpot{'a10TN'}=0.055;
    $statpot{'a10TD'}=0.261;
    $statpot{'a10TC'}=-0.171;
    $statpot{'a10TQ'}=0.192;
    $statpot{'a10TE'}=0.262;
    $statpot{'a10TG'}=0.079;
    $statpot{'a10TH'}=-0.021;
    $statpot{'a10TI'}=-0.487;
    $statpot{'a10TL'}=-0.302;
    $statpot{'a10TK'}=0.172;
    $statpot{'a10TM'}=-0.220;
    $statpot{'a10TF'}=-0.211;
    $statpot{'a10TP'}=0.147;
    $statpot{'a10TS'}=0.043;
    $statpot{'a10TT'}=0.017;
    $statpot{'a10TW'}=-0.162;
    $statpot{'a10TY'}=-0.365;
    $statpot{'a10TV'}=-0.377;
    $statpot{'a10WA'}=0.042;
    $statpot{'a10WR'}=0.014;
    $statpot{'a10WN'}=-0.024;
    $statpot{'a10WD'}=0.121;
    $statpot{'a10WC'}=-0.322;
    $statpot{'a10WQ'}=-0.065;
    $statpot{'a10WE'}=0.061;
    $statpot{'a10WG'}=0.070;
    $statpot{'a10WH'}=0.075;
    $statpot{'a10WI'}=0.075;
    $statpot{'a10WL'}=-0.143;
    $statpot{'a10WK'}=0.097;
    $statpot{'a10WM'}=-0.004;
    $statpot{'a10WF'}=0.098;
    $statpot{'a10WP'}=-0.062;
    $statpot{'a10WS'}=-0.032;
    $statpot{'a10WT'}=-0.079;
    $statpot{'a10WW'}=-0.277;
    $statpot{'a10WY'}=-0.160;
    $statpot{'a10WV'}=-0.308;
    $statpot{'a10YA'}=-0.033;
    $statpot{'a10YR'}=-0.115;
    $statpot{'a10YN'}=0.052;
    $statpot{'a10YD'}=0.119;
    $statpot{'a10YC'}=0.108;
    $statpot{'a10YQ'}=-0.045;
    $statpot{'a10YE'}=0.264;
    $statpot{'a10YG'}=-0.062;
    $statpot{'a10YH'}=-0.093;
    $statpot{'a10YI'}=-0.249;
    $statpot{'a10YL'}=-0.142;
    $statpot{'a10YK'}=0.054;
    $statpot{'a10YM'}=-0.309;
    $statpot{'a10YF'}=-0.094;
    $statpot{'a10YP'}=-0.082;
    $statpot{'a10YS'}=0.004;
    $statpot{'a10YT'}=-0.126;
    $statpot{'a10YW'}=-0.163;
    $statpot{'a10YY'}=0.036;
    $statpot{'a10YV'}=-0.277;
    $statpot{'a10VA'}=-0.114;
    $statpot{'a10VR'}=-0.082;
    $statpot{'a10VN'}=-0.016;
    $statpot{'a10VD'}=-0.061;
    $statpot{'a10VC'}=-0.283;
    $statpot{'a10VQ'}=-0.031;
    $statpot{'a10VE'}=-0.005;
    $statpot{'a10VG'}=0.065;
    $statpot{'a10VH'}=-0.018;
    $statpot{'a10VI'}=-0.340;
    $statpot{'a10VL'}=-0.114;
    $statpot{'a10VK'}=0.008;
    $statpot{'a10VM'}=-0.037;
    $statpot{'a10VF'}=-0.008;
    $statpot{'a10VP'}=-0.036;
    $statpot{'a10VS'}=-0.140;
    $statpot{'a10VT'}=-0.151;
    $statpot{'a10VW'}=-0.281;
    $statpot{'a10VY'}=-0.159;
    $statpot{'a10VV'}=-0.367;
    $statpot{'p11AA'}=-0.031;
    $statpot{'p11AR'}=0.080;
    $statpot{'p11AN'}=0.096;
    $statpot{'p11AD'}=0.178;
    $statpot{'p11AC'}=-0.103;
    $statpot{'p11AQ'}=0.088;
    $statpot{'p11AE'}=0.251;
    $statpot{'p11AG'}=0.134;
    $statpot{'p11AH'}=-0.062;
    $statpot{'p11AI'}=-0.240;
    $statpot{'p11AL'}=-0.191;
    $statpot{'p11AK'}=0.225;
    $statpot{'p11AM'}=-0.177;
    $statpot{'p11AF'}=-0.204;
    $statpot{'p11AP'}=0.017;
    $statpot{'p11AS'}=0.052;
    $statpot{'p11AT'}=-0.036;
    $statpot{'p11AW'}=-0.124;
    $statpot{'p11AY'}=-0.151;
    $statpot{'p11AV'}=-0.135;
    $statpot{'p11RA'}=0.080;
    $statpot{'p11RR'}=0.026;
    $statpot{'p11RN'}=0.116;
    $statpot{'p11RD'}=0.196;
    $statpot{'p11RC'}=-0.044;
    $statpot{'p11RQ'}=0.124;
    $statpot{'p11RE'}=0.185;
    $statpot{'p11RG'}=0.224;
    $statpot{'p11RH'}=-0.016;
    $statpot{'p11RI'}=-0.163;
    $statpot{'p11RL'}=-0.066;
    $statpot{'p11RK'}=0.240;
    $statpot{'p11RM'}=-0.041;
    $statpot{'p11RF'}=-0.121;
    $statpot{'p11RP'}=0.184;
    $statpot{'p11RS'}=0.234;
    $statpot{'p11RT'}=0.095;
    $statpot{'p11RW'}=0.117;
    $statpot{'p11RY'}=0.055;
    $statpot{'p11RV'}=-0.080;
    $statpot{'p11NA'}=0.096;
    $statpot{'p11NR'}=0.116;
    $statpot{'p11NN'}=0.232;
    $statpot{'p11ND'}=0.232;
    $statpot{'p11NC'}=0.096;
    $statpot{'p11NQ'}=0.279;
    $statpot{'p11NE'}=0.269;
    $statpot{'p11NG'}=0.186;
    $statpot{'p11NH'}=0.014;
    $statpot{'p11NI'}=-0.129;
    $statpot{'p11NL'}=-0.047;
    $statpot{'p11NK'}=0.343;
    $statpot{'p11NM'}=-0.105;
    $statpot{'p11NF'}=-0.014;
    $statpot{'p11NP'}=0.150;
    $statpot{'p11NS'}=0.083;
    $statpot{'p11NT'}=0.082;
    $statpot{'p11NW'}=-0.013;
    $statpot{'p11NY'}=-0.015;
    $statpot{'p11NV'}=-0.073;
    $statpot{'p11DA'}=0.178;
    $statpot{'p11DR'}=0.196;
    $statpot{'p11DN'}=0.232;
    $statpot{'p11DD'}=0.233;
    $statpot{'p11DC'}=0.157;
    $statpot{'p11DQ'}=0.189;
    $statpot{'p11DE'}=0.276;
    $statpot{'p11DG'}=0.234;
    $statpot{'p11DH'}=0.146;
    $statpot{'p11DI'}=-0.004;
    $statpot{'p11DL'}=0.045;
    $statpot{'p11DK'}=0.264;
    $statpot{'p11DM'}=0.113;
    $statpot{'p11DF'}=0.061;
    $statpot{'p11DP'}=0.155;
    $statpot{'p11DS'}=0.183;
    $statpot{'p11DT'}=0.215;
    $statpot{'p11DW'}=0.105;
    $statpot{'p11DY'}=0.097;
    $statpot{'p11DV'}=0.106;
    $statpot{'p11CA'}=-0.103;
    $statpot{'p11CR'}=-0.044;
    $statpot{'p11CN'}=0.096;
    $statpot{'p11CD'}=0.157;
    $statpot{'p11CC'}=0.220;
    $statpot{'p11CQ'}=-0.075;
    $statpot{'p11CE'}=0.221;
    $statpot{'p11CG'}=-0.012;
    $statpot{'p11CH'}=-0.138;
    $statpot{'p11CI'}=-0.212;
    $statpot{'p11CL'}=-0.311;
    $statpot{'p11CK'}=0.302;
    $statpot{'p11CM'}=-0.290;
    $statpot{'p11CF'}=-0.199;
    $statpot{'p11CP'}=0.123;
    $statpot{'p11CS'}=0.015;
    $statpot{'p11CT'}=-0.105;
    $statpot{'p11CW'}=-0.372;
    $statpot{'p11CY'}=-0.244;
    $statpot{'p11CV'}=-0.071;
    $statpot{'p11QA'}=0.088;
    $statpot{'p11QR'}=0.124;
    $statpot{'p11QN'}=0.279;
    $statpot{'p11QD'}=0.189;
    $statpot{'p11QC'}=-0.075;
    $statpot{'p11QQ'}=0.061;
    $statpot{'p11QE'}=0.195;
    $statpot{'p11QG'}=0.230;
    $statpot{'p11QH'}=0.031;
    $statpot{'p11QI'}=-0.129;
    $statpot{'p11QL'}=-0.090;
    $statpot{'p11QK'}=0.280;
    $statpot{'p11QM'}=-0.099;
    $statpot{'p11QF'}=-0.072;
    $statpot{'p11QP'}=0.137;
    $statpot{'p11QS'}=0.102;
    $statpot{'p11QT'}=0.087;
    $statpot{'p11QW'}=0.085;
    $statpot{'p11QY'}=0.052;
    $statpot{'p11QV'}=0.001;
    $statpot{'p11EA'}=0.251;
    $statpot{'p11ER'}=0.185;
    $statpot{'p11EN'}=0.269;
    $statpot{'p11ED'}=0.276;
    $statpot{'p11EC'}=0.221;
    $statpot{'p11EQ'}=0.195;
    $statpot{'p11EE'}=0.274;
    $statpot{'p11EG'}=0.393;
    $statpot{'p11EH'}=0.292;
    $statpot{'p11EI'}=0.108;
    $statpot{'p11EL'}=0.078;
    $statpot{'p11EK'}=0.337;
    $statpot{'p11EM'}=0.112;
    $statpot{'p11EF'}=0.097;
    $statpot{'p11EP'}=0.217;
    $statpot{'p11ES'}=0.289;
    $statpot{'p11ET'}=0.174;
    $statpot{'p11EW'}=0.012;
    $statpot{'p11EY'}=0.085;
    $statpot{'p11EV'}=0.071;
    $statpot{'p11GA'}=0.134;
    $statpot{'p11GR'}=0.224;
    $statpot{'p11GN'}=0.186;
    $statpot{'p11GD'}=0.234;
    $statpot{'p11GC'}=-0.012;
    $statpot{'p11GQ'}=0.230;
    $statpot{'p11GE'}=0.393;
    $statpot{'p11GG'}=0.244;
    $statpot{'p11GH'}=0.037;
    $statpot{'p11GI'}=-0.039;
    $statpot{'p11GL'}=0.058;
    $statpot{'p11GK'}=0.271;
    $statpot{'p11GM'}=-0.014;
    $statpot{'p11GF'}=-0.031;
    $statpot{'p11GP'}=0.255;
    $statpot{'p11GS'}=0.153;
    $statpot{'p11GT'}=0.113;
    $statpot{'p11GW'}=0.079;
    $statpot{'p11GY'}=0.057;
    $statpot{'p11GV'}=0.009;
    $statpot{'p11HA'}=-0.062;
    $statpot{'p11HR'}=-0.016;
    $statpot{'p11HN'}=0.014;
    $statpot{'p11HD'}=0.146;
    $statpot{'p11HC'}=-0.138;
    $statpot{'p11HQ'}=0.031;
    $statpot{'p11HE'}=0.292;
    $statpot{'p11HG'}=0.037;
    $statpot{'p11HH'}=-0.153;
    $statpot{'p11HI'}=-0.212;
    $statpot{'p11HL'}=-0.130;
    $statpot{'p11HK'}=0.228;
    $statpot{'p11HM'}=-0.153;
    $statpot{'p11HF'}=-0.096;
    $statpot{'p11HP'}=0.179;
    $statpot{'p11HS'}=0.029;
    $statpot{'p11HT'}=0.028;
    $statpot{'p11HW'}=-0.207;
    $statpot{'p11HY'}=-0.183;
    $statpot{'p11HV'}=-0.096;
    $statpot{'p11IA'}=-0.240;
    $statpot{'p11IR'}=-0.163;
    $statpot{'p11IN'}=-0.129;
    $statpot{'p11ID'}=-0.004;
    $statpot{'p11IC'}=-0.212;
    $statpot{'p11IQ'}=-0.129;
    $statpot{'p11IE'}=0.108;
    $statpot{'p11IG'}=-0.039;
    $statpot{'p11IH'}=-0.212;
    $statpot{'p11II'}=-0.339;
    $statpot{'p11IL'}=-0.424;
    $statpot{'p11IK'}=0.048;
    $statpot{'p11IM'}=-0.315;
    $statpot{'p11IF'}=-0.325;
    $statpot{'p11IP'}=-0.105;
    $statpot{'p11IS'}=-0.119;
    $statpot{'p11IT'}=-0.174;
    $statpot{'p11IW'}=-0.203;
    $statpot{'p11IY'}=-0.250;
    $statpot{'p11IV'}=-0.353;
    $statpot{'p11LA'}=-0.191;
    $statpot{'p11LR'}=-0.066;
    $statpot{'p11LN'}=-0.047;
    $statpot{'p11LD'}=0.045;
    $statpot{'p11LC'}=-0.311;
    $statpot{'p11LQ'}=-0.090;
    $statpot{'p11LE'}=0.078;
    $statpot{'p11LG'}=0.058;
    $statpot{'p11LH'}=-0.130;
    $statpot{'p11LI'}=-0.424;
    $statpot{'p11LL'}=-0.439;
    $statpot{'p11LK'}=0.055;
    $statpot{'p11LM'}=-0.309;
    $statpot{'p11LF'}=-0.302;
    $statpot{'p11LP'}=0.002;
    $statpot{'p11LS'}=-0.108;
    $statpot{'p11LT'}=-0.190;
    $statpot{'p11LW'}=-0.286;
    $statpot{'p11LY'}=-0.237;
    $statpot{'p11LV'}=-0.339;
    $statpot{'p11KA'}=0.225;
    $statpot{'p11KR'}=0.240;
    $statpot{'p11KN'}=0.343;
    $statpot{'p11KD'}=0.264;
    $statpot{'p11KC'}=0.302;
    $statpot{'p11KQ'}=0.280;
    $statpot{'p11KE'}=0.337;
    $statpot{'p11KG'}=0.271;
    $statpot{'p11KH'}=0.228;
    $statpot{'p11KI'}=0.048;
    $statpot{'p11KL'}=0.055;
    $statpot{'p11KK'}=0.249;
    $statpot{'p11KM'}=0.119;
    $statpot{'p11KF'}=-0.005;
    $statpot{'p11KP'}=0.258;
    $statpot{'p11KS'}=0.249;
    $statpot{'p11KT'}=0.266;
    $statpot{'p11KW'}=0.068;
    $statpot{'p11KY'}=0.072;
    $statpot{'p11KV'}=0.089;
    $statpot{'p11MA'}=-0.177;
    $statpot{'p11MR'}=-0.041;
    $statpot{'p11MN'}=-0.105;
    $statpot{'p11MD'}=0.113;
    $statpot{'p11MC'}=-0.290;
    $statpot{'p11MQ'}=-0.099;
    $statpot{'p11ME'}=0.112;
    $statpot{'p11MG'}=-0.014;
    $statpot{'p11MH'}=-0.153;
    $statpot{'p11MI'}=-0.315;
    $statpot{'p11ML'}=-0.309;
    $statpot{'p11MK'}=0.119;
    $statpot{'p11MM'}=-0.336;
    $statpot{'p11MF'}=-0.217;
    $statpot{'p11MP'}=0.057;
    $statpot{'p11MS'}=0.005;
    $statpot{'p11MT'}=-0.163;
    $statpot{'p11MW'}=-0.289;
    $statpot{'p11MY'}=-0.226;
    $statpot{'p11MV'}=-0.284;
    $statpot{'p11FA'}=-0.204;
    $statpot{'p11FR'}=-0.121;
    $statpot{'p11FN'}=-0.014;
    $statpot{'p11FD'}=0.061;
    $statpot{'p11FC'}=-0.199;
    $statpot{'p11FQ'}=-0.072;
    $statpot{'p11FE'}=0.097;
    $statpot{'p11FG'}=-0.031;
    $statpot{'p11FH'}=-0.096;
    $statpot{'p11FI'}=-0.325;
    $statpot{'p11FL'}=-0.302;
    $statpot{'p11FK'}=-0.005;
    $statpot{'p11FM'}=-0.217;
    $statpot{'p11FF'}=-0.387;
    $statpot{'p11FP'}=0.078;
    $statpot{'p11FS'}=-0.208;
    $statpot{'p11FT'}=-0.253;
    $statpot{'p11FW'}=-0.357;
    $statpot{'p11FY'}=-0.258;
    $statpot{'p11FV'}=-0.291;
    $statpot{'p11PA'}=0.017;
    $statpot{'p11PR'}=0.184;
    $statpot{'p11PN'}=0.150;
    $statpot{'p11PD'}=0.155;
    $statpot{'p11PC'}=0.123;
    $statpot{'p11PQ'}=0.137;
    $statpot{'p11PE'}=0.217;
    $statpot{'p11PG'}=0.255;
    $statpot{'p11PH'}=0.179;
    $statpot{'p11PI'}=-0.105;
    $statpot{'p11PL'}=0.002;
    $statpot{'p11PK'}=0.258;
    $statpot{'p11PM'}=0.057;
    $statpot{'p11PF'}=0.078;
    $statpot{'p11PP'}=0.016;
    $statpot{'p11PS'}=0.103;
    $statpot{'p11PT'}=0.164;
    $statpot{'p11PW'}=-0.002;
    $statpot{'p11PY'}=-0.021;
    $statpot{'p11PV'}=-0.104;
    $statpot{'p11SA'}=0.052;
    $statpot{'p11SR'}=0.234;
    $statpot{'p11SN'}=0.083;
    $statpot{'p11SD'}=0.183;
    $statpot{'p11SC'}=0.015;
    $statpot{'p11SQ'}=0.102;
    $statpot{'p11SE'}=0.289;
    $statpot{'p11SG'}=0.153;
    $statpot{'p11SH'}=0.029;
    $statpot{'p11SI'}=-0.119;
    $statpot{'p11SL'}=-0.108;
    $statpot{'p11SK'}=0.249;
    $statpot{'p11SM'}=0.005;
    $statpot{'p11SF'}=-0.208;
    $statpot{'p11SP'}=0.103;
    $statpot{'p11SS'}=0.078;
    $statpot{'p11ST'}=0.009;
    $statpot{'p11SW'}=-0.112;
    $statpot{'p11SY'}=-0.077;
    $statpot{'p11SV'}=-0.097;
    $statpot{'p11TA'}=-0.036;
    $statpot{'p11TR'}=0.095;
    $statpot{'p11TN'}=0.082;
    $statpot{'p11TD'}=0.215;
    $statpot{'p11TC'}=-0.105;
    $statpot{'p11TQ'}=0.087;
    $statpot{'p11TE'}=0.174;
    $statpot{'p11TG'}=0.113;
    $statpot{'p11TH'}=0.028;
    $statpot{'p11TI'}=-0.174;
    $statpot{'p11TL'}=-0.190;
    $statpot{'p11TK'}=0.266;
    $statpot{'p11TM'}=-0.163;
    $statpot{'p11TF'}=-0.253;
    $statpot{'p11TP'}=0.164;
    $statpot{'p11TS'}=0.009;
    $statpot{'p11TT'}=0.151;
    $statpot{'p11TW'}=-0.081;
    $statpot{'p11TY'}=-0.086;
    $statpot{'p11TV'}=-0.123;
    $statpot{'p11WA'}=-0.124;
    $statpot{'p11WR'}=0.117;
    $statpot{'p11WN'}=-0.013;
    $statpot{'p11WD'}=0.105;
    $statpot{'p11WC'}=-0.372;
    $statpot{'p11WQ'}=0.085;
    $statpot{'p11WE'}=0.012;
    $statpot{'p11WG'}=0.079;
    $statpot{'p11WH'}=-0.207;
    $statpot{'p11WI'}=-0.203;
    $statpot{'p11WL'}=-0.286;
    $statpot{'p11WK'}=0.068;
    $statpot{'p11WM'}=-0.289;
    $statpot{'p11WF'}=-0.357;
    $statpot{'p11WP'}=-0.002;
    $statpot{'p11WS'}=-0.112;
    $statpot{'p11WT'}=-0.081;
    $statpot{'p11WW'}=-0.193;
    $statpot{'p11WY'}=-0.326;
    $statpot{'p11WV'}=-0.276;
    $statpot{'p11YA'}=-0.151;
    $statpot{'p11YR'}=0.055;
    $statpot{'p11YN'}=-0.015;
    $statpot{'p11YD'}=0.097;
    $statpot{'p11YC'}=-0.244;
    $statpot{'p11YQ'}=0.052;
    $statpot{'p11YE'}=0.085;
    $statpot{'p11YG'}=0.057;
    $statpot{'p11YH'}=-0.183;
    $statpot{'p11YI'}=-0.250;
    $statpot{'p11YL'}=-0.237;
    $statpot{'p11YK'}=0.072;
    $statpot{'p11YM'}=-0.226;
    $statpot{'p11YF'}=-0.258;
    $statpot{'p11YP'}=-0.021;
    $statpot{'p11YS'}=-0.077;
    $statpot{'p11YT'}=-0.086;
    $statpot{'p11YW'}=-0.326;
    $statpot{'p11YY'}=-0.174;
    $statpot{'p11YV'}=-0.187;
    $statpot{'p11VA'}=-0.135;
    $statpot{'p11VR'}=-0.080;
    $statpot{'p11VN'}=-0.073;
    $statpot{'p11VD'}=0.106;
    $statpot{'p11VC'}=-0.071;
    $statpot{'p11VQ'}=0.001;
    $statpot{'p11VE'}=0.071;
    $statpot{'p11VG'}=0.009;
    $statpot{'p11VH'}=-0.096;
    $statpot{'p11VI'}=-0.353;
    $statpot{'p11VL'}=-0.339;
    $statpot{'p11VK'}=0.089;
    $statpot{'p11VM'}=-0.284;
    $statpot{'p11VF'}=-0.291;
    $statpot{'p11VP'}=-0.104;
    $statpot{'p11VS'}=-0.097;
    $statpot{'p11VT'}=-0.123;
    $statpot{'p11VW'}=-0.276;
    $statpot{'p11VY'}=-0.187;
    $statpot{'p11VV'}=-0.322;
    $statpot{'f11AA'}=-0.142;
    $statpot{'f11AR'}=0.161;
    $statpot{'f11AN'}=0.113;
    $statpot{'f11AD'}=0.207;
    $statpot{'f11AC'}=-0.105;
    $statpot{'f11AQ'}=0.030;
    $statpot{'f11AE'}=0.303;
    $statpot{'f11AG'}=0.018;
    $statpot{'f11AH'}=-0.183;
    $statpot{'f11AI'}=-0.221;
    $statpot{'f11AL'}=-0.186;
    $statpot{'f11AK'}=0.343;
    $statpot{'f11AM'}=-0.129;
    $statpot{'f11AF'}=-0.184;
    $statpot{'f11AP'}=0.193;
    $statpot{'f11AS'}=-0.029;
    $statpot{'f11AT'}=-0.027;
    $statpot{'f11AW'}=-0.160;
    $statpot{'f11AY'}=-0.171;
    $statpot{'f11AV'}=-0.184;
    $statpot{'f11RA'}=0.189;
    $statpot{'f11RR'}=0.441;
    $statpot{'f11RN'}=0.308;
    $statpot{'f11RD'}=0.387;
    $statpot{'f11RC'}=0.026;
    $statpot{'f11RQ'}=0.480;
    $statpot{'f11RE'}=0.353;
    $statpot{'f11RG'}=0.346;
    $statpot{'f11RH'}=0.182;
    $statpot{'f11RI'}=-0.039;
    $statpot{'f11RL'}=0.081;
    $statpot{'f11RK'}=0.424;
    $statpot{'f11RM'}=0.091;
    $statpot{'f11RF'}=-0.134;
    $statpot{'f11RP'}=0.514;
    $statpot{'f11RS'}=0.263;
    $statpot{'f11RT'}=0.204;
    $statpot{'f11RW'}=-0.091;
    $statpot{'f11RY'}=0.018;
    $statpot{'f11RV'}=0.048;
    $statpot{'f11NA'}=0.262;
    $statpot{'f11NR'}=0.312;
    $statpot{'f11NN'}=0.489;
    $statpot{'f11ND'}=0.434;
    $statpot{'f11NC'}=0.186;
    $statpot{'f11NQ'}=0.446;
    $statpot{'f11NE'}=0.443;
    $statpot{'f11NG'}=0.310;
    $statpot{'f11NH'}=0.184;
    $statpot{'f11NI'}=0.120;
    $statpot{'f11NL'}=0.156;
    $statpot{'f11NK'}=0.698;
    $statpot{'f11NM'}=0.011;
    $statpot{'f11NF'}=-0.066;
    $statpot{'f11NP'}=0.374;
    $statpot{'f11NS'}=0.261;
    $statpot{'f11NT'}=0.128;
    $statpot{'f11NW'}=0.081;
    $statpot{'f11NY'}=0.109;
    $statpot{'f11NV'}=0.092;
    $statpot{'f11DA'}=0.384;
    $statpot{'f11DR'}=0.464;
    $statpot{'f11DN'}=0.555;
    $statpot{'f11DD'}=0.555;
    $statpot{'f11DC'}=0.016;
    $statpot{'f11DQ'}=0.638;
    $statpot{'f11DE'}=0.473;
    $statpot{'f11DG'}=0.433;
    $statpot{'f11DH'}=0.460;
    $statpot{'f11DI'}=0.216;
    $statpot{'f11DL'}=0.147;
    $statpot{'f11DK'}=0.779;
    $statpot{'f11DM'}=0.227;
    $statpot{'f11DF'}=0.032;
    $statpot{'f11DP'}=0.393;
    $statpot{'f11DS'}=0.532;
    $statpot{'f11DT'}=0.364;
    $statpot{'f11DW'}=0.287;
    $statpot{'f11DY'}=0.306;
    $statpot{'f11DV'}=0.200;
    $statpot{'f11CA'}=-0.177;
    $statpot{'f11CR'}=-0.126;
    $statpot{'f11CN'}=-0.060;
    $statpot{'f11CD'}=-0.109;
    $statpot{'f11CC'}=-0.491;
    $statpot{'f11CQ'}=-0.153;
    $statpot{'f11CE'}=0.041;
    $statpot{'f11CG'}=-0.197;
    $statpot{'f11CH'}=-0.276;
    $statpot{'f11CI'}=-0.540;
    $statpot{'f11CL'}=-0.441;
    $statpot{'f11CK'}=-0.128;
    $statpot{'f11CM'}=-0.577;
    $statpot{'f11CF'}=-0.481;
    $statpot{'f11CP'}=-0.215;
    $statpot{'f11CS'}=-0.177;
    $statpot{'f11CT'}=-0.349;
    $statpot{'f11CW'}=-0.423;
    $statpot{'f11CY'}=-0.380;
    $statpot{'f11CV'}=-0.326;
    $statpot{'f11QA'}=0.184;
    $statpot{'f11QR'}=0.372;
    $statpot{'f11QN'}=0.504;
    $statpot{'f11QD'}=0.458;
    $statpot{'f11QC'}=0.086;
    $statpot{'f11QQ'}=0.384;
    $statpot{'f11QE'}=0.492;
    $statpot{'f11QG'}=0.202;
    $statpot{'f11QH'}=0.070;
    $statpot{'f11QI'}=-0.114;
    $statpot{'f11QL'}=0.092;
    $statpot{'f11QK'}=0.581;
    $statpot{'f11QM'}=0.168;
    $statpot{'f11QF'}=-0.023;
    $statpot{'f11QP'}=0.151;
    $statpot{'f11QS'}=0.296;
    $statpot{'f11QT'}=0.383;
    $statpot{'f11QW'}=0.060;
    $statpot{'f11QY'}=-0.036;
    $statpot{'f11QV'}=0.052;
    $statpot{'f11EA'}=0.414;
    $statpot{'f11ER'}=0.427;
    $statpot{'f11EN'}=0.528;
    $statpot{'f11ED'}=0.428;
    $statpot{'f11EC'}=0.238;
    $statpot{'f11EQ'}=0.536;
    $statpot{'f11EE'}=0.588;
    $statpot{'f11EG'}=0.573;
    $statpot{'f11EH'}=0.365;
    $statpot{'f11EI'}=0.222;
    $statpot{'f11EL'}=0.180;
    $statpot{'f11EK'}=0.746;
    $statpot{'f11EM'}=0.199;
    $statpot{'f11EF'}=0.145;
    $statpot{'f11EP'}=0.662;
    $statpot{'f11ES'}=0.584;
    $statpot{'f11ET'}=0.399;
    $statpot{'f11EW'}=0.159;
    $statpot{'f11EY'}=0.488;
    $statpot{'f11EV'}=0.310;
    $statpot{'f11GA'}=0.158;
    $statpot{'f11GR'}=0.369;
    $statpot{'f11GN'}=0.323;
    $statpot{'f11GD'}=0.379;
    $statpot{'f11GC'}=-0.063;
    $statpot{'f11GQ'}=0.191;
    $statpot{'f11GE'}=0.558;
    $statpot{'f11GG'}=0.239;
    $statpot{'f11GH'}=0.035;
    $statpot{'f11GI'}=-0.055;
    $statpot{'f11GL'}=0.007;
    $statpot{'f11GK'}=0.524;
    $statpot{'f11GM'}=0.081;
    $statpot{'f11GF'}=-0.091;
    $statpot{'f11GP'}=0.368;
    $statpot{'f11GS'}=0.231;
    $statpot{'f11GT'}=0.132;
    $statpot{'f11GW'}=-0.158;
    $statpot{'f11GY'}=-0.000;
    $statpot{'f11GV'}=-0.008;
    $statpot{'f11HA'}=-0.164;
    $statpot{'f11HR'}=0.169;
    $statpot{'f11HN'}=0.160;
    $statpot{'f11HD'}=0.360;
    $statpot{'f11HC'}=-0.296;
    $statpot{'f11HQ'}=-0.086;
    $statpot{'f11HE'}=0.253;
    $statpot{'f11HG'}=-0.076;
    $statpot{'f11HH'}=0.265;
    $statpot{'f11HI'}=-0.295;
    $statpot{'f11HL'}=-0.162;
    $statpot{'f11HK'}=0.301;
    $statpot{'f11HM'}=-0.413;
    $statpot{'f11HF'}=-0.142;
    $statpot{'f11HP'}=-0.069;
    $statpot{'f11HS'}=-0.034;
    $statpot{'f11HT'}=-0.010;
    $statpot{'f11HW'}=-0.147;
    $statpot{'f11HY'}=-0.070;
    $statpot{'f11HV'}=-0.270;
    $statpot{'f11IA'}=-0.359;
    $statpot{'f11IR'}=-0.243;
    $statpot{'f11IN'}=-0.093;
    $statpot{'f11ID'}=-0.130;
    $statpot{'f11IC'}=-0.640;
    $statpot{'f11IQ'}=-0.222;
    $statpot{'f11IE'}=-0.068;
    $statpot{'f11IG'}=-0.270;
    $statpot{'f11IH'}=-0.329;
    $statpot{'f11II'}=-0.634;
    $statpot{'f11IL'}=-0.555;
    $statpot{'f11IK'}=-0.137;
    $statpot{'f11IM'}=-0.503;
    $statpot{'f11IF'}=-0.567;
    $statpot{'f11IP'}=-0.147;
    $statpot{'f11IS'}=-0.334;
    $statpot{'f11IT'}=-0.332;
    $statpot{'f11IW'}=-0.469;
    $statpot{'f11IY'}=-0.405;
    $statpot{'f11IV'}=-0.548;
    $statpot{'f11LA'}=-0.286;
    $statpot{'f11LR'}=-0.197;
    $statpot{'f11LN'}=-0.196;
    $statpot{'f11LD'}=-0.202;
    $statpot{'f11LC'}=-0.501;
    $statpot{'f11LQ'}=-0.194;
    $statpot{'f11LE'}=-0.140;
    $statpot{'f11LG'}=-0.159;
    $statpot{'f11LH'}=-0.355;
    $statpot{'f11LI'}=-0.552;
    $statpot{'f11LL'}=-0.519;
    $statpot{'f11LK'}=-0.020;
    $statpot{'f11LM'}=-0.493;
    $statpot{'f11LF'}=-0.426;
    $statpot{'f11LP'}=-0.111;
    $statpot{'f11LS'}=-0.207;
    $statpot{'f11LT'}=-0.276;
    $statpot{'f11LW'}=-0.413;
    $statpot{'f11LY'}=-0.350;
    $statpot{'f11LV'}=-0.561;
    $statpot{'f11KA'}=0.423;
    $statpot{'f11KR'}=0.560;
    $statpot{'f11KN'}=0.651;
    $statpot{'f11KD'}=0.665;
    $statpot{'f11KC'}=0.136;
    $statpot{'f11KQ'}=0.655;
    $statpot{'f11KE'}=0.698;
    $statpot{'f11KG'}=0.564;
    $statpot{'f11KH'}=0.375;
    $statpot{'f11KI'}=0.021;
    $statpot{'f11KL'}=0.313;
    $statpot{'f11KK'}=0.752;
    $statpot{'f11KM'}=0.302;
    $statpot{'f11KF'}=0.170;
    $statpot{'f11KP'}=0.583;
    $statpot{'f11KS'}=0.605;
    $statpot{'f11KT'}=0.435;
    $statpot{'f11KW'}=0.057;
    $statpot{'f11KY'}=0.307;
    $statpot{'f11KV'}=0.181;
    $statpot{'f11MA'}=-0.207;
    $statpot{'f11MR'}=-0.152;
    $statpot{'f11MN'}=-0.139;
    $statpot{'f11MD'}=0.014;
    $statpot{'f11MC'}=-0.655;
    $statpot{'f11MQ'}=-0.041;
    $statpot{'f11ME'}=0.070;
    $statpot{'f11MG'}=-0.096;
    $statpot{'f11MH'}=-0.375;
    $statpot{'f11MI'}=-0.487;
    $statpot{'f11ML'}=-0.444;
    $statpot{'f11MK'}=0.101;
    $statpot{'f11MM'}=-0.529;
    $statpot{'f11MF'}=-0.550;
    $statpot{'f11MP'}=-0.128;
    $statpot{'f11MS'}=-0.264;
    $statpot{'f11MT'}=-0.447;
    $statpot{'f11MW'}=-0.348;
    $statpot{'f11MY'}=-0.350;
    $statpot{'f11MV'}=-0.536;
    $statpot{'f11FA'}=-0.283;
    $statpot{'f11FR'}=-0.268;
    $statpot{'f11FN'}=-0.151;
    $statpot{'f11FD'}=-0.218;
    $statpot{'f11FC'}=-0.434;
    $statpot{'f11FQ'}=-0.272;
    $statpot{'f11FE'}=0.000;
    $statpot{'f11FG'}=-0.254;
    $statpot{'f11FH'}=-0.178;
    $statpot{'f11FI'}=-0.530;
    $statpot{'f11FL'}=-0.381;
    $statpot{'f11FK'}=-0.049;
    $statpot{'f11FM'}=-0.570;
    $statpot{'f11FF'}=-0.558;
    $statpot{'f11FP'}=-0.100;
    $statpot{'f11FS'}=-0.286;
    $statpot{'f11FT'}=-0.364;
    $statpot{'f11FW'}=-0.568;
    $statpot{'f11FY'}=-0.477;
    $statpot{'f11FV'}=-0.437;
    $statpot{'f11PA'}=0.199;
    $statpot{'f11PR'}=0.352;
    $statpot{'f11PN'}=0.266;
    $statpot{'f11PD'}=0.378;
    $statpot{'f11PC'}=-0.000;
    $statpot{'f11PQ'}=0.196;
    $statpot{'f11PE'}=0.525;
    $statpot{'f11PG'}=0.322;
    $statpot{'f11PH'}=0.184;
    $statpot{'f11PI'}=0.127;
    $statpot{'f11PL'}=0.114;
    $statpot{'f11PK'}=0.452;
    $statpot{'f11PM'}=0.052;
    $statpot{'f11PF'}=0.078;
    $statpot{'f11PP'}=0.597;
    $statpot{'f11PS'}=0.330;
    $statpot{'f11PT'}=0.321;
    $statpot{'f11PW'}=-0.017;
    $statpot{'f11PY'}=0.044;
    $statpot{'f11PV'}=0.143;
    $statpot{'f11SA'}=0.046;
    $statpot{'f11SR'}=0.348;
    $statpot{'f11SN'}=0.282;
    $statpot{'f11SD'}=0.423;
    $statpot{'f11SC'}=0.077;
    $statpot{'f11SQ'}=0.288;
    $statpot{'f11SE'}=0.481;
    $statpot{'f11SG'}=0.212;
    $statpot{'f11SH'}=0.153;
    $statpot{'f11SI'}=-0.146;
    $statpot{'f11SL'}=0.028;
    $statpot{'f11SK'}=0.580;
    $statpot{'f11SM'}=-0.151;
    $statpot{'f11SF'}=-0.076;
    $statpot{'f11SP'}=0.323;
    $statpot{'f11SS'}=0.350;
    $statpot{'f11ST'}=0.208;
    $statpot{'f11SW'}=-0.106;
    $statpot{'f11SY'}=-0.016;
    $statpot{'f11SV'}=-0.039;
    $statpot{'f11TA'}=0.030;
    $statpot{'f11TR'}=0.236;
    $statpot{'f11TN'}=0.132;
    $statpot{'f11TD'}=0.185;
    $statpot{'f11TC'}=-0.151;
    $statpot{'f11TQ'}=0.347;
    $statpot{'f11TE'}=0.353;
    $statpot{'f11TG'}=0.064;
    $statpot{'f11TH'}=0.002;
    $statpot{'f11TI'}=-0.192;
    $statpot{'f11TL'}=-0.064;
    $statpot{'f11TK'}=0.376;
    $statpot{'f11TM'}=-0.337;
    $statpot{'f11TF'}=-0.280;
    $statpot{'f11TP'}=0.148;
    $statpot{'f11TS'}=0.191;
    $statpot{'f11TT'}=0.132;
    $statpot{'f11TW'}=-0.193;
    $statpot{'f11TY'}=-0.158;
    $statpot{'f11TV'}=-0.074;
    $statpot{'f11WA'}=-0.134;
    $statpot{'f11WR'}=-0.231;
    $statpot{'f11WN'}=-0.029;
    $statpot{'f11WD'}=0.051;
    $statpot{'f11WC'}=-0.340;
    $statpot{'f11WQ'}=-0.058;
    $statpot{'f11WE'}=0.007;
    $statpot{'f11WG'}=-0.221;
    $statpot{'f11WH'}=-0.252;
    $statpot{'f11WI'}=-0.402;
    $statpot{'f11WL'}=-0.386;
    $statpot{'f11WK'}=0.060;
    $statpot{'f11WM'}=-0.307;
    $statpot{'f11WF'}=-0.608;
    $statpot{'f11WP'}=-0.082;
    $statpot{'f11WS'}=-0.081;
    $statpot{'f11WT'}=-0.341;
    $statpot{'f11WW'}=-0.307;
    $statpot{'f11WY'}=-0.231;
    $statpot{'f11WV'}=-0.237;
    $statpot{'f11YA'}=-0.291;
    $statpot{'f11YR'}=-0.159;
    $statpot{'f11YN'}=0.008;
    $statpot{'f11YD'}=0.182;
    $statpot{'f11YC'}=-0.439;
    $statpot{'f11YQ'}=-0.160;
    $statpot{'f11YE'}=0.101;
    $statpot{'f11YG'}=-0.171;
    $statpot{'f11YH'}=-0.120;
    $statpot{'f11YI'}=-0.411;
    $statpot{'f11YL'}=-0.231;
    $statpot{'f11YK'}=0.073;
    $statpot{'f11YM'}=-0.459;
    $statpot{'f11YF'}=-0.390;
    $statpot{'f11YP'}=-0.058;
    $statpot{'f11YS'}=-0.144;
    $statpot{'f11YT'}=-0.284;
    $statpot{'f11YW'}=-0.432;
    $statpot{'f11YY'}=-0.496;
    $statpot{'f11YV'}=-0.412;
    $statpot{'f11VA'}=-0.294;
    $statpot{'f11VR'}=-0.107;
    $statpot{'f11VN'}=-0.102;
    $statpot{'f11VD'}=-0.066;
    $statpot{'f11VC'}=-0.362;
    $statpot{'f11VQ'}=-0.173;
    $statpot{'f11VE'}=0.037;
    $statpot{'f11VG'}=-0.167;
    $statpot{'f11VH'}=-0.342;
    $statpot{'f11VI'}=-0.542;
    $statpot{'f11VL'}=-0.503;
    $statpot{'f11VK'}=-0.033;
    $statpot{'f11VM'}=-0.578;
    $statpot{'f11VF'}=-0.512;
    $statpot{'f11VP'}=-0.028;
    $statpot{'f11VS'}=-0.221;
    $statpot{'f11VT'}=-0.231;
    $statpot{'f11VW'}=-0.347;
    $statpot{'f11VY'}=-0.418;
    $statpot{'f11VV'}=-0.425;
    $statpot{'a11AA'}=0.183;
    $statpot{'a11AR'}=0.096;
    $statpot{'a11AN'}=0.131;
    $statpot{'a11AD'}=0.279;
    $statpot{'a11AC'}=-0.011;
    $statpot{'a11AQ'}=0.104;
    $statpot{'a11AE'}=0.327;
    $statpot{'a11AG'}=0.128;
    $statpot{'a11AH'}=-0.041;
    $statpot{'a11AI'}=-0.160;
    $statpot{'a11AL'}=-0.066;
    $statpot{'a11AK'}=0.166;
    $statpot{'a11AM'}=-0.040;
    $statpot{'a11AF'}=-0.094;
    $statpot{'a11AP'}=0.072;
    $statpot{'a11AS'}=0.024;
    $statpot{'a11AT'}=0.039;
    $statpot{'a11AW'}=-0.130;
    $statpot{'a11AY'}=-0.101;
    $statpot{'a11AV'}=-0.081;
    $statpot{'a11RA'}=0.064;
    $statpot{'a11RR'}=0.249;
    $statpot{'a11RN'}=0.105;
    $statpot{'a11RD'}=0.279;
    $statpot{'a11RC'}=-0.362;
    $statpot{'a11RQ'}=0.235;
    $statpot{'a11RE'}=0.472;
    $statpot{'a11RG'}=0.227;
    $statpot{'a11RH'}=0.120;
    $statpot{'a11RI'}=-0.322;
    $statpot{'a11RL'}=-0.319;
    $statpot{'a11RK'}=0.246;
    $statpot{'a11RM'}=-0.255;
    $statpot{'a11RF'}=-0.223;
    $statpot{'a11RP'}=-0.062;
    $statpot{'a11RS'}=0.173;
    $statpot{'a11RT'}=0.095;
    $statpot{'a11RW'}=-0.084;
    $statpot{'a11RY'}=-0.051;
    $statpot{'a11RV'}=-0.316;
    $statpot{'a11NA'}=-0.026;
    $statpot{'a11NR'}=0.101;
    $statpot{'a11NN'}=0.340;
    $statpot{'a11ND'}=0.450;
    $statpot{'a11NC'}=-0.176;
    $statpot{'a11NQ'}=0.360;
    $statpot{'a11NE'}=0.401;
    $statpot{'a11NG'}=0.185;
    $statpot{'a11NH'}=0.204;
    $statpot{'a11NI'}=-0.367;
    $statpot{'a11NL'}=-0.312;
    $statpot{'a11NK'}=0.384;
    $statpot{'a11NM'}=-0.230;
    $statpot{'a11NF'}=-0.216;
    $statpot{'a11NP'}=-0.034;
    $statpot{'a11NS'}=0.190;
    $statpot{'a11NT'}=0.076;
    $statpot{'a11NW'}=-0.032;
    $statpot{'a11NY'}=-0.157;
    $statpot{'a11NV'}=-0.293;
    $statpot{'a11DA'}=0.084;
    $statpot{'a11DR'}=0.202;
    $statpot{'a11DN'}=0.321;
    $statpot{'a11DD'}=0.418;
    $statpot{'a11DC'}=-0.109;
    $statpot{'a11DQ'}=0.229;
    $statpot{'a11DE'}=0.295;
    $statpot{'a11DG'}=0.310;
    $statpot{'a11DH'}=0.203;
    $statpot{'a11DI'}=-0.337;
    $statpot{'a11DL'}=-0.343;
    $statpot{'a11DK'}=0.498;
    $statpot{'a11DM'}=-0.122;
    $statpot{'a11DF'}=-0.178;
    $statpot{'a11DP'}=0.246;
    $statpot{'a11DS'}=0.315;
    $statpot{'a11DT'}=0.101;
    $statpot{'a11DW'}=-0.029;
    $statpot{'a11DY'}=-0.020;
    $statpot{'a11DV'}=-0.263;
    $statpot{'a11CA'}=0.093;
    $statpot{'a11CR'}=-0.223;
    $statpot{'a11CN'}=0.076;
    $statpot{'a11CD'}=0.038;
    $statpot{'a11CC'}=0.302;
    $statpot{'a11CQ'}=0.031;
    $statpot{'a11CE'}=0.170;
    $statpot{'a11CG'}=-0.024;
    $statpot{'a11CH'}=0.174;
    $statpot{'a11CI'}=-0.159;
    $statpot{'a11CL'}=-0.107;
    $statpot{'a11CK'}=0.165;
    $statpot{'a11CM'}=-0.311;
    $statpot{'a11CF'}=0.062;
    $statpot{'a11CP'}=-0.189;
    $statpot{'a11CS'}=-0.060;
    $statpot{'a11CT'}=-0.202;
    $statpot{'a11CW'}=-0.137;
    $statpot{'a11CY'}=-0.125;
    $statpot{'a11CV'}=-0.207;
    $statpot{'a11QA'}=-0.071;
    $statpot{'a11QR'}=0.349;
    $statpot{'a11QN'}=0.301;
    $statpot{'a11QD'}=0.401;
    $statpot{'a11QC'}=-0.228;
    $statpot{'a11QQ'}=0.313;
    $statpot{'a11QE'}=0.337;
    $statpot{'a11QG'}=0.245;
    $statpot{'a11QH'}=-0.020;
    $statpot{'a11QI'}=-0.305;
    $statpot{'a11QL'}=-0.308;
    $statpot{'a11QK'}=0.388;
    $statpot{'a11QM'}=-0.084;
    $statpot{'a11QF'}=-0.297;
    $statpot{'a11QP'}=0.108;
    $statpot{'a11QS'}=0.186;
    $statpot{'a11QT'}=0.036;
    $statpot{'a11QW'}=-0.060;
    $statpot{'a11QY'}=-0.126;
    $statpot{'a11QV'}=-0.179;
    $statpot{'a11EA'}=0.200;
    $statpot{'a11ER'}=0.378;
    $statpot{'a11EN'}=0.311;
    $statpot{'a11ED'}=0.342;
    $statpot{'a11EC'}=-0.045;
    $statpot{'a11EQ'}=0.293;
    $statpot{'a11EE'}=0.299;
    $statpot{'a11EG'}=0.317;
    $statpot{'a11EH'}=0.234;
    $statpot{'a11EI'}=-0.287;
    $statpot{'a11EL'}=-0.310;
    $statpot{'a11EK'}=0.354;
    $statpot{'a11EM'}=-0.085;
    $statpot{'a11EF'}=-0.143;
    $statpot{'a11EP'}=0.184;
    $statpot{'a11ES'}=0.240;
    $statpot{'a11ET'}=0.112;
    $statpot{'a11EW'}=0.015;
    $statpot{'a11EY'}=-0.106;
    $statpot{'a11EV'}=-0.162;
    $statpot{'a11GA'}=-0.036;
    $statpot{'a11GR'}=0.204;
    $statpot{'a11GN'}=0.173;
    $statpot{'a11GD'}=0.371;
    $statpot{'a11GC'}=-0.183;
    $statpot{'a11GQ'}=0.258;
    $statpot{'a11GE'}=0.334;
    $statpot{'a11GG'}=0.180;
    $statpot{'a11GH'}=0.066;
    $statpot{'a11GI'}=-0.324;
    $statpot{'a11GL'}=-0.179;
    $statpot{'a11GK'}=0.403;
    $statpot{'a11GM'}=-0.164;
    $statpot{'a11GF'}=-0.213;
    $statpot{'a11GP'}=0.079;
    $statpot{'a11GS'}=0.099;
    $statpot{'a11GT'}=0.063;
    $statpot{'a11GW'}=-0.048;
    $statpot{'a11GY'}=-0.225;
    $statpot{'a11GV'}=-0.203;
    $statpot{'a11HA'}=-0.068;
    $statpot{'a11HR'}=0.133;
    $statpot{'a11HN'}=0.233;
    $statpot{'a11HD'}=0.305;
    $statpot{'a11HC'}=0.213;
    $statpot{'a11HQ'}=0.184;
    $statpot{'a11HE'}=0.369;
    $statpot{'a11HG'}=0.225;
    $statpot{'a11HH'}=0.085;
    $statpot{'a11HI'}=-0.234;
    $statpot{'a11HL'}=-0.379;
    $statpot{'a11HK'}=0.336;
    $statpot{'a11HM'}=-0.097;
    $statpot{'a11HF'}=-0.278;
    $statpot{'a11HP'}=0.098;
    $statpot{'a11HS'}=0.205;
    $statpot{'a11HT'}=-0.082;
    $statpot{'a11HW'}=-0.119;
    $statpot{'a11HY'}=0.028;
    $statpot{'a11HV'}=-0.274;
    $statpot{'a11IA'}=0.060;
    $statpot{'a11IR'}=-0.090;
    $statpot{'a11IN'}=-0.176;
    $statpot{'a11ID'}=-0.000;
    $statpot{'a11IC'}=0.035;
    $statpot{'a11IQ'}=-0.183;
    $statpot{'a11IE'}=-0.002;
    $statpot{'a11IG'}=-0.073;
    $statpot{'a11IH'}=-0.190;
    $statpot{'a11II'}=-0.165;
    $statpot{'a11IL'}=-0.060;
    $statpot{'a11IK'}=-0.121;
    $statpot{'a11IM'}=-0.153;
    $statpot{'a11IF'}=-0.125;
    $statpot{'a11IP'}=-0.101;
    $statpot{'a11IS'}=-0.089;
    $statpot{'a11IT'}=-0.172;
    $statpot{'a11IW'}=-0.126;
    $statpot{'a11IY'}=-0.121;
    $statpot{'a11IV'}=-0.350;
    $statpot{'a11LA'}=0.095;
    $statpot{'a11LR'}=-0.014;
    $statpot{'a11LN'}=0.068;
    $statpot{'a11LD'}=0.031;
    $statpot{'a11LC'}=0.001;
    $statpot{'a11LQ'}=0.006;
    $statpot{'a11LE'}=0.025;
    $statpot{'a11LG'}=0.021;
    $statpot{'a11LH'}=-0.146;
    $statpot{'a11LI'}=-0.065;
    $statpot{'a11LL'}=0.031;
    $statpot{'a11LK'}=-0.014;
    $statpot{'a11LM'}=-0.039;
    $statpot{'a11LF'}=0.118;
    $statpot{'a11LP'}=-0.075;
    $statpot{'a11LS'}=-0.021;
    $statpot{'a11LT'}=-0.100;
    $statpot{'a11LW'}=0.053;
    $statpot{'a11LY'}=-0.015;
    $statpot{'a11LV'}=-0.178;
    $statpot{'a11KA'}=0.089;
    $statpot{'a11KR'}=0.124;
    $statpot{'a11KN'}=0.426;
    $statpot{'a11KD'}=0.612;
    $statpot{'a11KC'}=-0.143;
    $statpot{'a11KQ'}=0.319;
    $statpot{'a11KE'}=0.396;
    $statpot{'a11KG'}=0.360;
    $statpot{'a11KH'}=0.250;
    $statpot{'a11KI'}=-0.286;
    $statpot{'a11KL'}=-0.310;
    $statpot{'a11KK'}=0.448;
    $statpot{'a11KM'}=-0.136;
    $statpot{'a11KF'}=-0.184;
    $statpot{'a11KP'}=0.051;
    $statpot{'a11KS'}=0.220;
    $statpot{'a11KT'}=0.127;
    $statpot{'a11KW'}=-0.036;
    $statpot{'a11KY'}=-0.097;
    $statpot{'a11KV'}=-0.254;
    $statpot{'a11MA'}=0.082;
    $statpot{'a11MR'}=0.018;
    $statpot{'a11MN'}=-0.064;
    $statpot{'a11MD'}=0.107;
    $statpot{'a11MC'}=-0.174;
    $statpot{'a11MQ'}=0.164;
    $statpot{'a11ME'}=0.050;
    $statpot{'a11MG'}=0.040;
    $statpot{'a11MH'}=-0.155;
    $statpot{'a11MI'}=-0.181;
    $statpot{'a11ML'}=-0.127;
    $statpot{'a11MK'}=0.055;
    $statpot{'a11MM'}=-0.037;
    $statpot{'a11MF'}=-0.080;
    $statpot{'a11MP'}=0.048;
    $statpot{'a11MS'}=-0.050;
    $statpot{'a11MT'}=-0.200;
    $statpot{'a11MW'}=0.099;
    $statpot{'a11MY'}=-0.295;
    $statpot{'a11MV'}=-0.103;
    $statpot{'a11FA'}=0.057;
    $statpot{'a11FR'}=-0.052;
    $statpot{'a11FN'}=-0.123;
    $statpot{'a11FD'}=0.142;
    $statpot{'a11FC'}=-0.025;
    $statpot{'a11FQ'}=-0.003;
    $statpot{'a11FE'}=0.009;
    $statpot{'a11FG'}=-0.006;
    $statpot{'a11FH'}=-0.238;
    $statpot{'a11FI'}=-0.192;
    $statpot{'a11FL'}=0.030;
    $statpot{'a11FK'}=0.046;
    $statpot{'a11FM'}=-0.040;
    $statpot{'a11FF'}=-0.133;
    $statpot{'a11FP'}=-0.120;
    $statpot{'a11FS'}=-0.077;
    $statpot{'a11FT'}=-0.138;
    $statpot{'a11FW'}=-0.125;
    $statpot{'a11FY'}=0.065;
    $statpot{'a11FV'}=-0.205;
    $statpot{'a11PA'}=0.065;
    $statpot{'a11PR'}=0.067;
    $statpot{'a11PN'}=0.059;
    $statpot{'a11PD'}=0.261;
    $statpot{'a11PC'}=-0.394;
    $statpot{'a11PQ'}=0.059;
    $statpot{'a11PE'}=0.302;
    $statpot{'a11PG'}=0.120;
    $statpot{'a11PH'}=-0.177;
    $statpot{'a11PI'}=-0.367;
    $statpot{'a11PL'}=-0.303;
    $statpot{'a11PK'}=0.157;
    $statpot{'a11PM'}=-0.168;
    $statpot{'a11PF'}=-0.295;
    $statpot{'a11PP'}=-0.087;
    $statpot{'a11PS'}=0.142;
    $statpot{'a11PT'}=-0.005;
    $statpot{'a11PW'}=-0.181;
    $statpot{'a11PY'}=-0.163;
    $statpot{'a11PV'}=-0.196;
    $statpot{'a11SA'}=-0.064;
    $statpot{'a11SR'}=0.088;
    $statpot{'a11SN'}=0.168;
    $statpot{'a11SD'}=0.430;
    $statpot{'a11SC'}=-0.311;
    $statpot{'a11SQ'}=0.194;
    $statpot{'a11SE'}=0.336;
    $statpot{'a11SG'}=0.118;
    $statpot{'a11SH'}=-0.024;
    $statpot{'a11SI'}=-0.320;
    $statpot{'a11SL'}=-0.285;
    $statpot{'a11SK'}=0.240;
    $statpot{'a11SM'}=-0.199;
    $statpot{'a11SF'}=-0.319;
    $statpot{'a11SP'}=0.149;
    $statpot{'a11SS'}=0.149;
    $statpot{'a11ST'}=0.181;
    $statpot{'a11SW'}=-0.132;
    $statpot{'a11SY'}=-0.121;
    $statpot{'a11SV'}=-0.303;
    $statpot{'a11TA'}=-0.031;
    $statpot{'a11TR'}=0.061;
    $statpot{'a11TN'}=0.072;
    $statpot{'a11TD'}=0.298;
    $statpot{'a11TC'}=-0.417;
    $statpot{'a11TQ'}=0.067;
    $statpot{'a11TE'}=0.155;
    $statpot{'a11TG'}=0.143;
    $statpot{'a11TH'}=-0.095;
    $statpot{'a11TI'}=-0.340;
    $statpot{'a11TL'}=-0.342;
    $statpot{'a11TK'}=0.180;
    $statpot{'a11TM'}=-0.350;
    $statpot{'a11TF'}=-0.251;
    $statpot{'a11TP'}=0.173;
    $statpot{'a11TS'}=0.201;
    $statpot{'a11TT'}=-0.009;
    $statpot{'a11TW'}=-0.285;
    $statpot{'a11TY'}=-0.303;
    $statpot{'a11TV'}=-0.373;
    $statpot{'a11WA'}=-0.162;
    $statpot{'a11WR'}=0.115;
    $statpot{'a11WN'}=0.097;
    $statpot{'a11WD'}=0.234;
    $statpot{'a11WC'}=-0.249;
    $statpot{'a11WQ'}=0.081;
    $statpot{'a11WE'}=0.203;
    $statpot{'a11WG'}=0.043;
    $statpot{'a11WH'}=0.026;
    $statpot{'a11WI'}=-0.231;
    $statpot{'a11WL'}=0.002;
    $statpot{'a11WK'}=-0.039;
    $statpot{'a11WM'}=0.025;
    $statpot{'a11WF'}=-0.047;
    $statpot{'a11WP'}=-0.110;
    $statpot{'a11WS'}=-0.160;
    $statpot{'a11WT'}=-0.103;
    $statpot{'a11WW'}=0.003;
    $statpot{'a11WY'}=-0.302;
    $statpot{'a11WV'}=-0.347;
    $statpot{'a11YA'}=0.084;
    $statpot{'a11YR'}=0.193;
    $statpot{'a11YN'}=-0.056;
    $statpot{'a11YD'}=0.100;
    $statpot{'a11YC'}=-0.029;
    $statpot{'a11YQ'}=0.029;
    $statpot{'a11YE'}=0.276;
    $statpot{'a11YG'}=-0.031;
    $statpot{'a11YH'}=0.098;
    $statpot{'a11YI'}=-0.113;
    $statpot{'a11YL'}=-0.189;
    $statpot{'a11YK'}=0.141;
    $statpot{'a11YM'}=-0.135;
    $statpot{'a11YF'}=-0.093;
    $statpot{'a11YP'}=-0.051;
    $statpot{'a11YS'}=0.034;
    $statpot{'a11YT'}=-0.156;
    $statpot{'a11YW'}=-0.021;
    $statpot{'a11YY'}=0.041;
    $statpot{'a11YV'}=-0.266;
    $statpot{'a11VA'}=0.095;
    $statpot{'a11VR'}=-0.164;
    $statpot{'a11VN'}=-0.104;
    $statpot{'a11VD'}=-0.002;
    $statpot{'a11VC'}=-0.157;
    $statpot{'a11VQ'}=0.095;
    $statpot{'a11VE'}=0.110;
    $statpot{'a11VG'}=-0.017;
    $statpot{'a11VH'}=-0.181;
    $statpot{'a11VI'}=-0.360;
    $statpot{'a11VL'}=-0.274;
    $statpot{'a11VK'}=-0.050;
    $statpot{'a11VM'}=-0.019;
    $statpot{'a11VF'}=-0.081;
    $statpot{'a11VP'}=-0.021;
    $statpot{'a11VS'}=-0.104;
    $statpot{'a11VT'}=-0.212;
    $statpot{'a11VW'}=-0.217;
    $statpot{'a11VY'}=-0.258;
    $statpot{'a11VV'}=-0.301;
    $statpot{'p12AA'}=-0.085;
    $statpot{'p12AR'}=0.049;
    $statpot{'p12AN'}=0.032;
    $statpot{'p12AD'}=0.124;
    $statpot{'p12AC'}=-0.178;
    $statpot{'p12AQ'}=-0.015;
    $statpot{'p12AE'}=0.155;
    $statpot{'p12AG'}=0.146;
    $statpot{'p12AH'}=-0.030;
    $statpot{'p12AI'}=-0.134;
    $statpot{'p12AL'}=-0.156;
    $statpot{'p12AK'}=0.178;
    $statpot{'p12AM'}=-0.117;
    $statpot{'p12AF'}=-0.192;
    $statpot{'p12AP'}=0.129;
    $statpot{'p12AS'}=0.020;
    $statpot{'p12AT'}=-0.018;
    $statpot{'p12AW'}=-0.101;
    $statpot{'p12AY'}=-0.113;
    $statpot{'p12AV'}=-0.158;
    $statpot{'p12RA'}=0.049;
    $statpot{'p12RR'}=0.145;
    $statpot{'p12RN'}=0.113;
    $statpot{'p12RD'}=0.256;
    $statpot{'p12RC'}=-0.114;
    $statpot{'p12RQ'}=0.108;
    $statpot{'p12RE'}=0.144;
    $statpot{'p12RG'}=0.173;
    $statpot{'p12RH'}=0.026;
    $statpot{'p12RI'}=-0.125;
    $statpot{'p12RL'}=-0.146;
    $statpot{'p12RK'}=0.186;
    $statpot{'p12RM'}=-0.090;
    $statpot{'p12RF'}=-0.103;
    $statpot{'p12RP'}=0.092;
    $statpot{'p12RS'}=0.139;
    $statpot{'p12RT'}=0.048;
    $statpot{'p12RW'}=0.149;
    $statpot{'p12RY'}=-0.111;
    $statpot{'p12RV'}=-0.120;
    $statpot{'p12NA'}=0.032;
    $statpot{'p12NR'}=0.113;
    $statpot{'p12NN'}=0.222;
    $statpot{'p12ND'}=0.223;
    $statpot{'p12NC'}=0.086;
    $statpot{'p12NQ'}=0.200;
    $statpot{'p12NE'}=0.210;
    $statpot{'p12NG'}=0.198;
    $statpot{'p12NH'}=0.038;
    $statpot{'p12NI'}=-0.035;
    $statpot{'p12NL'}=-0.045;
    $statpot{'p12NK'}=0.279;
    $statpot{'p12NM'}=-0.015;
    $statpot{'p12NF'}=-0.006;
    $statpot{'p12NP'}=0.181;
    $statpot{'p12NS'}=0.155;
    $statpot{'p12NT'}=0.090;
    $statpot{'p12NW'}=-0.066;
    $statpot{'p12NY'}=0.051;
    $statpot{'p12NV'}=-0.048;
    $statpot{'p12DA'}=0.124;
    $statpot{'p12DR'}=0.256;
    $statpot{'p12DN'}=0.223;
    $statpot{'p12DD'}=0.190;
    $statpot{'p12DC'}=0.025;
    $statpot{'p12DQ'}=0.115;
    $statpot{'p12DE'}=0.181;
    $statpot{'p12DG'}=0.242;
    $statpot{'p12DH'}=0.223;
    $statpot{'p12DI'}=0.003;
    $statpot{'p12DL'}=0.058;
    $statpot{'p12DK'}=0.231;
    $statpot{'p12DM'}=0.108;
    $statpot{'p12DF'}=0.094;
    $statpot{'p12DP'}=0.259;
    $statpot{'p12DS'}=0.169;
    $statpot{'p12DT'}=0.151;
    $statpot{'p12DW'}=0.034;
    $statpot{'p12DY'}=0.175;
    $statpot{'p12DV'}=0.015;
    $statpot{'p12CA'}=-0.178;
    $statpot{'p12CR'}=-0.114;
    $statpot{'p12CN'}=0.086;
    $statpot{'p12CD'}=0.025;
    $statpot{'p12CC'}=-0.004;
    $statpot{'p12CQ'}=0.032;
    $statpot{'p12CE'}=0.041;
    $statpot{'p12CG'}=0.014;
    $statpot{'p12CH'}=0.076;
    $statpot{'p12CI'}=-0.320;
    $statpot{'p12CL'}=-0.286;
    $statpot{'p12CK'}=0.251;
    $statpot{'p12CM'}=-0.197;
    $statpot{'p12CF'}=-0.219;
    $statpot{'p12CP'}=0.080;
    $statpot{'p12CS'}=-0.071;
    $statpot{'p12CT'}=-0.009;
    $statpot{'p12CW'}=-0.118;
    $statpot{'p12CY'}=-0.123;
    $statpot{'p12CV'}=-0.249;
    $statpot{'p12QA'}=-0.015;
    $statpot{'p12QR'}=0.108;
    $statpot{'p12QN'}=0.200;
    $statpot{'p12QD'}=0.115;
    $statpot{'p12QC'}=0.032;
    $statpot{'p12QQ'}=0.078;
    $statpot{'p12QE'}=0.226;
    $statpot{'p12QG'}=0.232;
    $statpot{'p12QH'}=0.178;
    $statpot{'p12QI'}=-0.150;
    $statpot{'p12QL'}=-0.093;
    $statpot{'p12QK'}=0.279;
    $statpot{'p12QM'}=-0.088;
    $statpot{'p12QF'}=-0.048;
    $statpot{'p12QP'}=0.159;
    $statpot{'p12QS'}=0.122;
    $statpot{'p12QT'}=0.073;
    $statpot{'p12QW'}=0.029;
    $statpot{'p12QY'}=-0.001;
    $statpot{'p12QV'}=-0.045;
    $statpot{'p12EA'}=0.155;
    $statpot{'p12ER'}=0.144;
    $statpot{'p12EN'}=0.210;
    $statpot{'p12ED'}=0.181;
    $statpot{'p12EC'}=0.041;
    $statpot{'p12EQ'}=0.226;
    $statpot{'p12EE'}=0.193;
    $statpot{'p12EG'}=0.314;
    $statpot{'p12EH'}=0.201;
    $statpot{'p12EI'}=-0.005;
    $statpot{'p12EL'}=0.037;
    $statpot{'p12EK'}=0.304;
    $statpot{'p12EM'}=0.066;
    $statpot{'p12EF'}=0.006;
    $statpot{'p12EP'}=0.211;
    $statpot{'p12ES'}=0.241;
    $statpot{'p12ET'}=0.186;
    $statpot{'p12EW'}=0.023;
    $statpot{'p12EY'}=0.038;
    $statpot{'p12EV'}=0.023;
    $statpot{'p12GA'}=0.146;
    $statpot{'p12GR'}=0.173;
    $statpot{'p12GN'}=0.198;
    $statpot{'p12GD'}=0.242;
    $statpot{'p12GC'}=0.014;
    $statpot{'p12GQ'}=0.232;
    $statpot{'p12GE'}=0.314;
    $statpot{'p12GG'}=0.135;
    $statpot{'p12GH'}=0.075;
    $statpot{'p12GI'}=0.001;
    $statpot{'p12GL'}=0.044;
    $statpot{'p12GK'}=0.303;
    $statpot{'p12GM'}=0.054;
    $statpot{'p12GF'}=-0.037;
    $statpot{'p12GP'}=0.170;
    $statpot{'p12GS'}=0.148;
    $statpot{'p12GT'}=0.117;
    $statpot{'p12GW'}=0.033;
    $statpot{'p12GY'}=0.023;
    $statpot{'p12GV'}=0.017;
    $statpot{'p12HA'}=-0.030;
    $statpot{'p12HR'}=0.026;
    $statpot{'p12HN'}=0.038;
    $statpot{'p12HD'}=0.223;
    $statpot{'p12HC'}=0.076;
    $statpot{'p12HQ'}=0.178;
    $statpot{'p12HE'}=0.201;
    $statpot{'p12HG'}=0.075;
    $statpot{'p12HH'}=-0.331;
    $statpot{'p12HI'}=-0.042;
    $statpot{'p12HL'}=-0.049;
    $statpot{'p12HK'}=0.189;
    $statpot{'p12HM'}=-0.169;
    $statpot{'p12HF'}=-0.165;
    $statpot{'p12HP'}=0.078;
    $statpot{'p12HS'}=-0.054;
    $statpot{'p12HT'}=-0.025;
    $statpot{'p12HW'}=-0.209;
    $statpot{'p12HY'}=-0.056;
    $statpot{'p12HV'}=-0.147;
    $statpot{'p12IA'}=-0.134;
    $statpot{'p12IR'}=-0.125;
    $statpot{'p12IN'}=-0.035;
    $statpot{'p12ID'}=0.003;
    $statpot{'p12IC'}=-0.320;
    $statpot{'p12IQ'}=-0.150;
    $statpot{'p12IE'}=-0.005;
    $statpot{'p12IG'}=0.001;
    $statpot{'p12IH'}=-0.042;
    $statpot{'p12II'}=-0.208;
    $statpot{'p12IL'}=-0.225;
    $statpot{'p12IK'}=0.004;
    $statpot{'p12IM'}=-0.303;
    $statpot{'p12IF'}=-0.336;
    $statpot{'p12IP'}=0.113;
    $statpot{'p12IS'}=-0.111;
    $statpot{'p12IT'}=-0.125;
    $statpot{'p12IW'}=-0.122;
    $statpot{'p12IY'}=-0.245;
    $statpot{'p12IV'}=-0.257;
    $statpot{'p12LA'}=-0.156;
    $statpot{'p12LR'}=-0.146;
    $statpot{'p12LN'}=-0.045;
    $statpot{'p12LD'}=0.058;
    $statpot{'p12LC'}=-0.286;
    $statpot{'p12LQ'}=-0.093;
    $statpot{'p12LE'}=0.037;
    $statpot{'p12LG'}=0.044;
    $statpot{'p12LH'}=-0.049;
    $statpot{'p12LI'}=-0.225;
    $statpot{'p12LL'}=-0.211;
    $statpot{'p12LK'}=0.093;
    $statpot{'p12LM'}=-0.224;
    $statpot{'p12LF'}=-0.286;
    $statpot{'p12LP'}=0.058;
    $statpot{'p12LS'}=-0.113;
    $statpot{'p12LT'}=-0.133;
    $statpot{'p12LW'}=-0.218;
    $statpot{'p12LY'}=-0.235;
    $statpot{'p12LV'}=-0.287;
    $statpot{'p12KA'}=0.178;
    $statpot{'p12KR'}=0.186;
    $statpot{'p12KN'}=0.279;
    $statpot{'p12KD'}=0.231;
    $statpot{'p12KC'}=0.251;
    $statpot{'p12KQ'}=0.279;
    $statpot{'p12KE'}=0.304;
    $statpot{'p12KG'}=0.303;
    $statpot{'p12KH'}=0.189;
    $statpot{'p12KI'}=0.004;
    $statpot{'p12KL'}=0.093;
    $statpot{'p12KK'}=0.317;
    $statpot{'p12KM'}=0.126;
    $statpot{'p12KF'}=-0.018;
    $statpot{'p12KP'}=0.192;
    $statpot{'p12KS'}=0.213;
    $statpot{'p12KT'}=0.201;
    $statpot{'p12KW'}=0.136;
    $statpot{'p12KY'}=0.062;
    $statpot{'p12KV'}=0.027;
    $statpot{'p12MA'}=-0.117;
    $statpot{'p12MR'}=-0.090;
    $statpot{'p12MN'}=-0.015;
    $statpot{'p12MD'}=0.108;
    $statpot{'p12MC'}=-0.197;
    $statpot{'p12MQ'}=-0.088;
    $statpot{'p12ME'}=0.066;
    $statpot{'p12MG'}=0.054;
    $statpot{'p12MH'}=-0.169;
    $statpot{'p12MI'}=-0.303;
    $statpot{'p12ML'}=-0.224;
    $statpot{'p12MK'}=0.126;
    $statpot{'p12MM'}=-0.046;
    $statpot{'p12MF'}=-0.335;
    $statpot{'p12MP'}=0.105;
    $statpot{'p12MS'}=-0.075;
    $statpot{'p12MT'}=-0.177;
    $statpot{'p12MW'}=-0.219;
    $statpot{'p12MY'}=-0.249;
    $statpot{'p12MV'}=-0.266;
    $statpot{'p12FA'}=-0.192;
    $statpot{'p12FR'}=-0.103;
    $statpot{'p12FN'}=-0.006;
    $statpot{'p12FD'}=0.094;
    $statpot{'p12FC'}=-0.219;
    $statpot{'p12FQ'}=-0.048;
    $statpot{'p12FE'}=0.006;
    $statpot{'p12FG'}=-0.037;
    $statpot{'p12FH'}=-0.165;
    $statpot{'p12FI'}=-0.336;
    $statpot{'p12FL'}=-0.286;
    $statpot{'p12FK'}=-0.018;
    $statpot{'p12FM'}=-0.335;
    $statpot{'p12FF'}=-0.279;
    $statpot{'p12FP'}=0.073;
    $statpot{'p12FS'}=-0.162;
    $statpot{'p12FT'}=-0.151;
    $statpot{'p12FW'}=-0.226;
    $statpot{'p12FY'}=-0.335;
    $statpot{'p12FV'}=-0.304;
    $statpot{'p12PA'}=0.129;
    $statpot{'p12PR'}=0.092;
    $statpot{'p12PN'}=0.181;
    $statpot{'p12PD'}=0.259;
    $statpot{'p12PC'}=0.080;
    $statpot{'p12PQ'}=0.159;
    $statpot{'p12PE'}=0.211;
    $statpot{'p12PG'}=0.170;
    $statpot{'p12PH'}=0.078;
    $statpot{'p12PI'}=0.113;
    $statpot{'p12PL'}=0.058;
    $statpot{'p12PK'}=0.192;
    $statpot{'p12PM'}=0.105;
    $statpot{'p12PF'}=0.073;
    $statpot{'p12PP'}=0.089;
    $statpot{'p12PS'}=0.134;
    $statpot{'p12PT'}=0.146;
    $statpot{'p12PW'}=0.127;
    $statpot{'p12PY'}=0.040;
    $statpot{'p12PV'}=0.050;
    $statpot{'p12SA'}=0.020;
    $statpot{'p12SR'}=0.139;
    $statpot{'p12SN'}=0.155;
    $statpot{'p12SD'}=0.169;
    $statpot{'p12SC'}=-0.071;
    $statpot{'p12SQ'}=0.122;
    $statpot{'p12SE'}=0.241;
    $statpot{'p12SG'}=0.148;
    $statpot{'p12SH'}=-0.054;
    $statpot{'p12SI'}=-0.111;
    $statpot{'p12SL'}=-0.113;
    $statpot{'p12SK'}=0.213;
    $statpot{'p12SM'}=-0.075;
    $statpot{'p12SF'}=-0.162;
    $statpot{'p12SP'}=0.134;
    $statpot{'p12SS'}=0.085;
    $statpot{'p12ST'}=0.042;
    $statpot{'p12SW'}=-0.091;
    $statpot{'p12SY'}=-0.112;
    $statpot{'p12SV'}=-0.080;
    $statpot{'p12TA'}=-0.018;
    $statpot{'p12TR'}=0.048;
    $statpot{'p12TN'}=0.090;
    $statpot{'p12TD'}=0.151;
    $statpot{'p12TC'}=-0.009;
    $statpot{'p12TQ'}=0.073;
    $statpot{'p12TE'}=0.186;
    $statpot{'p12TG'}=0.117;
    $statpot{'p12TH'}=-0.025;
    $statpot{'p12TI'}=-0.125;
    $statpot{'p12TL'}=-0.133;
    $statpot{'p12TK'}=0.201;
    $statpot{'p12TM'}=-0.177;
    $statpot{'p12TF'}=-0.151;
    $statpot{'p12TP'}=0.146;
    $statpot{'p12TS'}=0.042;
    $statpot{'p12TT'}=0.018;
    $statpot{'p12TW'}=0.059;
    $statpot{'p12TY'}=-0.041;
    $statpot{'p12TV'}=-0.073;
    $statpot{'p12WA'}=-0.101;
    $statpot{'p12WR'}=0.149;
    $statpot{'p12WN'}=-0.066;
    $statpot{'p12WD'}=0.034;
    $statpot{'p12WC'}=-0.118;
    $statpot{'p12WQ'}=0.029;
    $statpot{'p12WE'}=0.023;
    $statpot{'p12WG'}=0.033;
    $statpot{'p12WH'}=-0.209;
    $statpot{'p12WI'}=-0.122;
    $statpot{'p12WL'}=-0.218;
    $statpot{'p12WK'}=0.136;
    $statpot{'p12WM'}=-0.219;
    $statpot{'p12WF'}=-0.226;
    $statpot{'p12WP'}=0.127;
    $statpot{'p12WS'}=-0.091;
    $statpot{'p12WT'}=0.059;
    $statpot{'p12WW'}=-0.333;
    $statpot{'p12WY'}=-0.273;
    $statpot{'p12WV'}=-0.180;
    $statpot{'p12YA'}=-0.113;
    $statpot{'p12YR'}=-0.111;
    $statpot{'p12YN'}=0.051;
    $statpot{'p12YD'}=0.175;
    $statpot{'p12YC'}=-0.123;
    $statpot{'p12YQ'}=-0.001;
    $statpot{'p12YE'}=0.038;
    $statpot{'p12YG'}=0.023;
    $statpot{'p12YH'}=-0.056;
    $statpot{'p12YI'}=-0.245;
    $statpot{'p12YL'}=-0.235;
    $statpot{'p12YK'}=0.062;
    $statpot{'p12YM'}=-0.249;
    $statpot{'p12YF'}=-0.335;
    $statpot{'p12YP'}=0.040;
    $statpot{'p12YS'}=-0.112;
    $statpot{'p12YT'}=-0.041;
    $statpot{'p12YW'}=-0.273;
    $statpot{'p12YY'}=-0.296;
    $statpot{'p12YV'}=-0.188;
    $statpot{'p12VA'}=-0.158;
    $statpot{'p12VR'}=-0.120;
    $statpot{'p12VN'}=-0.048;
    $statpot{'p12VD'}=0.015;
    $statpot{'p12VC'}=-0.249;
    $statpot{'p12VQ'}=-0.045;
    $statpot{'p12VE'}=0.023;
    $statpot{'p12VG'}=0.017;
    $statpot{'p12VH'}=-0.147;
    $statpot{'p12VI'}=-0.257;
    $statpot{'p12VL'}=-0.287;
    $statpot{'p12VK'}=0.027;
    $statpot{'p12VM'}=-0.266;
    $statpot{'p12VF'}=-0.304;
    $statpot{'p12VP'}=0.050;
    $statpot{'p12VS'}=-0.080;
    $statpot{'p12VT'}=-0.073;
    $statpot{'p12VW'}=-0.180;
    $statpot{'p12VY'}=-0.188;
    $statpot{'p12VV'}=-0.166;
    $statpot{'f12AA'}=-0.057;
    $statpot{'f12AR'}=0.137;
    $statpot{'f12AN'}=-0.027;
    $statpot{'f12AD'}=0.127;
    $statpot{'f12AC'}=-0.251;
    $statpot{'f12AQ'}=0.172;
    $statpot{'f12AE'}=0.234;
    $statpot{'f12AG'}=-0.050;
    $statpot{'f12AH'}=-0.087;
    $statpot{'f12AI'}=-0.323;
    $statpot{'f12AL'}=-0.212;
    $statpot{'f12AK'}=0.291;
    $statpot{'f12AM'}=-0.225;
    $statpot{'f12AF'}=-0.243;
    $statpot{'f12AP'}=0.052;
    $statpot{'f12AS'}=-0.112;
    $statpot{'f12AT'}=-0.102;
    $statpot{'f12AW'}=-0.244;
    $statpot{'f12AY'}=-0.222;
    $statpot{'f12AV'}=-0.232;
    $statpot{'f12RA'}=0.153;
    $statpot{'f12RR'}=0.386;
    $statpot{'f12RN'}=0.274;
    $statpot{'f12RD'}=0.335;
    $statpot{'f12RC'}=0.200;
    $statpot{'f12RQ'}=0.398;
    $statpot{'f12RE'}=0.523;
    $statpot{'f12RG'}=0.316;
    $statpot{'f12RH'}=0.123;
    $statpot{'f12RI'}=-0.014;
    $statpot{'f12RL'}=0.094;
    $statpot{'f12RK'}=0.516;
    $statpot{'f12RM'}=-0.104;
    $statpot{'f12RF'}=-0.057;
    $statpot{'f12RP'}=0.177;
    $statpot{'f12RS'}=0.148;
    $statpot{'f12RT'}=0.203;
    $statpot{'f12RW'}=0.148;
    $statpot{'f12RY'}=-0.089;
    $statpot{'f12RV'}=0.052;
    $statpot{'f12NA'}=0.107;
    $statpot{'f12NR'}=0.344;
    $statpot{'f12NN'}=0.394;
    $statpot{'f12ND'}=0.447;
    $statpot{'f12NC'}=0.244;
    $statpot{'f12NQ'}=0.419;
    $statpot{'f12NE'}=0.588;
    $statpot{'f12NG'}=0.248;
    $statpot{'f12NH'}=0.054;
    $statpot{'f12NI'}=0.139;
    $statpot{'f12NL'}=0.037;
    $statpot{'f12NK'}=0.549;
    $statpot{'f12NM'}=-0.140;
    $statpot{'f12NF'}=0.003;
    $statpot{'f12NP'}=0.310;
    $statpot{'f12NS'}=0.232;
    $statpot{'f12NT'}=0.300;
    $statpot{'f12NW'}=-0.038;
    $statpot{'f12NY'}=0.125;
    $statpot{'f12NV'}=0.111;
    $statpot{'f12DA'}=0.264;
    $statpot{'f12DR'}=0.485;
    $statpot{'f12DN'}=0.471;
    $statpot{'f12DD'}=0.478;
    $statpot{'f12DC'}=0.027;
    $statpot{'f12DQ'}=0.281;
    $statpot{'f12DE'}=0.609;
    $statpot{'f12DG'}=0.410;
    $statpot{'f12DH'}=0.200;
    $statpot{'f12DI'}=0.134;
    $statpot{'f12DL'}=0.229;
    $statpot{'f12DK'}=0.670;
    $statpot{'f12DM'}=0.025;
    $statpot{'f12DF'}=0.159;
    $statpot{'f12DP'}=0.492;
    $statpot{'f12DS'}=0.486;
    $statpot{'f12DT'}=0.292;
    $statpot{'f12DW'}=-0.023;
    $statpot{'f12DY'}=0.166;
    $statpot{'f12DV'}=0.284;
    $statpot{'f12CA'}=-0.359;
    $statpot{'f12CR'}=0.081;
    $statpot{'f12CN'}=0.016;
    $statpot{'f12CD'}=-0.252;
    $statpot{'f12CC'}=-0.174;
    $statpot{'f12CQ'}=-0.114;
    $statpot{'f12CE'}=-0.148;
    $statpot{'f12CG'}=-0.316;
    $statpot{'f12CH'}=-0.202;
    $statpot{'f12CI'}=-0.417;
    $statpot{'f12CL'}=-0.367;
    $statpot{'f12CK'}=0.023;
    $statpot{'f12CM'}=-0.563;
    $statpot{'f12CF'}=-0.580;
    $statpot{'f12CP'}=-0.098;
    $statpot{'f12CS'}=-0.177;
    $statpot{'f12CT'}=-0.330;
    $statpot{'f12CW'}=-0.517;
    $statpot{'f12CY'}=-0.465;
    $statpot{'f12CV'}=-0.447;
    $statpot{'f12QA'}=0.179;
    $statpot{'f12QR'}=0.322;
    $statpot{'f12QN'}=0.400;
    $statpot{'f12QD'}=0.300;
    $statpot{'f12QC'}=-0.060;
    $statpot{'f12QQ'}=0.482;
    $statpot{'f12QE'}=0.580;
    $statpot{'f12QG'}=0.240;
    $statpot{'f12QH'}=0.489;
    $statpot{'f12QI'}=0.004;
    $statpot{'f12QL'}=0.065;
    $statpot{'f12QK'}=0.523;
    $statpot{'f12QM'}=0.111;
    $statpot{'f12QF'}=0.055;
    $statpot{'f12QP'}=0.254;
    $statpot{'f12QS'}=0.287;
    $statpot{'f12QT'}=0.157;
    $statpot{'f12QW'}=0.141;
    $statpot{'f12QY'}=0.069;
    $statpot{'f12QV'}=0.084;
    $statpot{'f12EA'}=0.399;
    $statpot{'f12ER'}=0.593;
    $statpot{'f12EN'}=0.600;
    $statpot{'f12ED'}=0.543;
    $statpot{'f12EC'}=-0.012;
    $statpot{'f12EQ'}=0.683;
    $statpot{'f12EE'}=0.660;
    $statpot{'f12EG'}=0.505;
    $statpot{'f12EH'}=0.387;
    $statpot{'f12EI'}=0.389;
    $statpot{'f12EL'}=0.302;
    $statpot{'f12EK'}=0.690;
    $statpot{'f12EM'}=0.145;
    $statpot{'f12EF'}=0.262;
    $statpot{'f12EP'}=0.487;
    $statpot{'f12ES'}=0.527;
    $statpot{'f12ET'}=0.606;
    $statpot{'f12EW'}=0.115;
    $statpot{'f12EY'}=0.335;
    $statpot{'f12EV'}=0.298;
    $statpot{'f12GA'}=0.008;
    $statpot{'f12GR'}=0.267;
    $statpot{'f12GN'}=0.215;
    $statpot{'f12GD'}=0.349;
    $statpot{'f12GC'}=-0.208;
    $statpot{'f12GQ'}=0.214;
    $statpot{'f12GE'}=0.440;
    $statpot{'f12GG'}=0.198;
    $statpot{'f12GH'}=-0.054;
    $statpot{'f12GI'}=-0.129;
    $statpot{'f12GL'}=-0.015;
    $statpot{'f12GK'}=0.474;
    $statpot{'f12GM'}=-0.153;
    $statpot{'f12GF'}=-0.192;
    $statpot{'f12GP'}=0.317;
    $statpot{'f12GS'}=0.127;
    $statpot{'f12GT'}=0.064;
    $statpot{'f12GW'}=0.042;
    $statpot{'f12GY'}=-0.138;
    $statpot{'f12GV'}=0.002;
    $statpot{'f12HA'}=-0.070;
    $statpot{'f12HR'}=0.118;
    $statpot{'f12HN'}=-0.063;
    $statpot{'f12HD'}=0.093;
    $statpot{'f12HC'}=-0.213;
    $statpot{'f12HQ'}=0.253;
    $statpot{'f12HE'}=0.330;
    $statpot{'f12HG'}=-0.007;
    $statpot{'f12HH'}=-0.068;
    $statpot{'f12HI'}=-0.145;
    $statpot{'f12HL'}=-0.057;
    $statpot{'f12HK'}=0.330;
    $statpot{'f12HM'}=-0.079;
    $statpot{'f12HF'}=-0.228;
    $statpot{'f12HP'}=0.103;
    $statpot{'f12HS'}=0.012;
    $statpot{'f12HT'}=-0.010;
    $statpot{'f12HW'}=-0.408;
    $statpot{'f12HY'}=-0.345;
    $statpot{'f12HV'}=-0.123;
    $statpot{'f12IA'}=-0.388;
    $statpot{'f12IR'}=-0.151;
    $statpot{'f12IN'}=-0.093;
    $statpot{'f12ID'}=-0.104;
    $statpot{'f12IC'}=-0.437;
    $statpot{'f12IQ'}=-0.194;
    $statpot{'f12IE'}=0.141;
    $statpot{'f12IG'}=-0.295;
    $statpot{'f12IH'}=-0.271;
    $statpot{'f12II'}=-0.432;
    $statpot{'f12IL'}=-0.495;
    $statpot{'f12IK'}=-0.082;
    $statpot{'f12IM'}=-0.454;
    $statpot{'f12IF'}=-0.482;
    $statpot{'f12IP'}=-0.182;
    $statpot{'f12IS'}=-0.303;
    $statpot{'f12IT'}=-0.293;
    $statpot{'f12IW'}=-0.393;
    $statpot{'f12IY'}=-0.371;
    $statpot{'f12IV'}=-0.448;
    $statpot{'f12LA'}=-0.257;
    $statpot{'f12LR'}=-0.088;
    $statpot{'f12LN'}=-0.132;
    $statpot{'f12LD'}=-0.040;
    $statpot{'f12LC'}=-0.479;
    $statpot{'f12LQ'}=-0.137;
    $statpot{'f12LE'}=0.048;
    $statpot{'f12LG'}=-0.163;
    $statpot{'f12LH'}=-0.193;
    $statpot{'f12LI'}=-0.458;
    $statpot{'f12LL'}=-0.410;
    $statpot{'f12LK'}=-0.001;
    $statpot{'f12LM'}=-0.353;
    $statpot{'f12LF'}=-0.430;
    $statpot{'f12LP'}=-0.193;
    $statpot{'f12LS'}=-0.206;
    $statpot{'f12LT'}=-0.277;
    $statpot{'f12LW'}=-0.291;
    $statpot{'f12LY'}=-0.399;
    $statpot{'f12LV'}=-0.353;
    $statpot{'f12KA'}=0.442;
    $statpot{'f12KR'}=0.569;
    $statpot{'f12KN'}=0.636;
    $statpot{'f12KD'}=0.586;
    $statpot{'f12KC'}=0.412;
    $statpot{'f12KQ'}=0.534;
    $statpot{'f12KE'}=0.705;
    $statpot{'f12KG'}=0.569;
    $statpot{'f12KH'}=0.556;
    $statpot{'f12KI'}=0.185;
    $statpot{'f12KL'}=0.258;
    $statpot{'f12KK'}=0.694;
    $statpot{'f12KM'}=0.239;
    $statpot{'f12KF'}=0.277;
    $statpot{'f12KP'}=0.551;
    $statpot{'f12KS'}=0.528;
    $statpot{'f12KT'}=0.615;
    $statpot{'f12KW'}=0.310;
    $statpot{'f12KY'}=0.193;
    $statpot{'f12KV'}=0.317;
    $statpot{'f12MA'}=-0.299;
    $statpot{'f12MR'}=-0.168;
    $statpot{'f12MN'}=-0.188;
    $statpot{'f12MD'}=-0.170;
    $statpot{'f12MC'}=-0.552;
    $statpot{'f12MQ'}=0.105;
    $statpot{'f12ME'}=0.004;
    $statpot{'f12MG'}=-0.308;
    $statpot{'f12MH'}=-0.222;
    $statpot{'f12MI'}=-0.530;
    $statpot{'f12ML'}=-0.280;
    $statpot{'f12MK'}=-0.038;
    $statpot{'f12MM'}=-0.329;
    $statpot{'f12MF'}=-0.396;
    $statpot{'f12MP'}=-0.086;
    $statpot{'f12MS'}=-0.288;
    $statpot{'f12MT'}=-0.284;
    $statpot{'f12MW'}=-0.232;
    $statpot{'f12MY'}=-0.359;
    $statpot{'f12MV'}=-0.267;
    $statpot{'f12FA'}=-0.365;
    $statpot{'f12FR'}=-0.097;
    $statpot{'f12FN'}=-0.210;
    $statpot{'f12FD'}=-0.185;
    $statpot{'f12FC'}=-0.729;
    $statpot{'f12FQ'}=-0.208;
    $statpot{'f12FE'}=-0.112;
    $statpot{'f12FG'}=-0.362;
    $statpot{'f12FH'}=-0.297;
    $statpot{'f12FI'}=-0.515;
    $statpot{'f12FL'}=-0.462;
    $statpot{'f12FK'}=-0.044;
    $statpot{'f12FM'}=-0.487;
    $statpot{'f12FF'}=-0.647;
    $statpot{'f12FP'}=-0.233;
    $statpot{'f12FS'}=-0.298;
    $statpot{'f12FT'}=-0.312;
    $statpot{'f12FW'}=-0.618;
    $statpot{'f12FY'}=-0.545;
    $statpot{'f12FV'}=-0.551;
    $statpot{'f12PA'}=0.099;
    $statpot{'f12PR'}=0.126;
    $statpot{'f12PN'}=0.209;
    $statpot{'f12PD'}=0.480;
    $statpot{'f12PC'}=-0.104;
    $statpot{'f12PQ'}=0.255;
    $statpot{'f12PE'}=0.358;
    $statpot{'f12PG'}=0.343;
    $statpot{'f12PH'}=0.190;
    $statpot{'f12PI'}=-0.015;
    $statpot{'f12PL'}=0.005;
    $statpot{'f12PK'}=0.447;
    $statpot{'f12PM'}=0.008;
    $statpot{'f12PF'}=-0.082;
    $statpot{'f12PP'}=0.515;
    $statpot{'f12PS'}=0.135;
    $statpot{'f12PT'}=0.205;
    $statpot{'f12PW'}=0.002;
    $statpot{'f12PY'}=-0.021;
    $statpot{'f12PV'}=0.040;
    $statpot{'f12SA'}=-0.050;
    $statpot{'f12SR'}=0.208;
    $statpot{'f12SN'}=0.178;
    $statpot{'f12SD'}=0.374;
    $statpot{'f12SC'}=0.067;
    $statpot{'f12SQ'}=0.273;
    $statpot{'f12SE'}=0.508;
    $statpot{'f12SG'}=0.194;
    $statpot{'f12SH'}=0.009;
    $statpot{'f12SI'}=-0.107;
    $statpot{'f12SL'}=0.003;
    $statpot{'f12SK'}=0.454;
    $statpot{'f12SM'}=-0.138;
    $statpot{'f12SF'}=-0.096;
    $statpot{'f12SP'}=0.217;
    $statpot{'f12SS'}=0.116;
    $statpot{'f12ST'}=0.135;
    $statpot{'f12SW'}=-0.348;
    $statpot{'f12SY'}=-0.059;
    $statpot{'f12SV'}=-0.097;
    $statpot{'f12TA'}=-0.005;
    $statpot{'f12TR'}=0.246;
    $statpot{'f12TN'}=0.301;
    $statpot{'f12TD'}=0.287;
    $statpot{'f12TC'}=-0.243;
    $statpot{'f12TQ'}=0.094;
    $statpot{'f12TE'}=0.532;
    $statpot{'f12TG'}=0.069;
    $statpot{'f12TH'}=0.185;
    $statpot{'f12TI'}=-0.151;
    $statpot{'f12TL'}=-0.114;
    $statpot{'f12TK'}=0.418;
    $statpot{'f12TM'}=-0.071;
    $statpot{'f12TF'}=-0.190;
    $statpot{'f12TP'}=0.096;
    $statpot{'f12TS'}=0.130;
    $statpot{'f12TT'}=0.047;
    $statpot{'f12TW'}=-0.041;
    $statpot{'f12TY'}=-0.056;
    $statpot{'f12TV'}=-0.096;
    $statpot{'f12WA'}=-0.199;
    $statpot{'f12WR'}=-0.191;
    $statpot{'f12WN'}=-0.122;
    $statpot{'f12WD'}=-0.293;
    $statpot{'f12WC'}=-0.627;
    $statpot{'f12WQ'}=-0.123;
    $statpot{'f12WE'}=-0.082;
    $statpot{'f12WG'}=-0.039;
    $statpot{'f12WH'}=-0.343;
    $statpot{'f12WI'}=-0.331;
    $statpot{'f12WL'}=-0.261;
    $statpot{'f12WK'}=0.044;
    $statpot{'f12WM'}=-0.270;
    $statpot{'f12WF'}=-0.585;
    $statpot{'f12WP'}=-0.178;
    $statpot{'f12WS'}=-0.372;
    $statpot{'f12WT'}=-0.283;
    $statpot{'f12WW'}=-0.362;
    $statpot{'f12WY'}=-0.513;
    $statpot{'f12WV'}=-0.313;
    $statpot{'f12YA'}=-0.238;
    $statpot{'f12YR'}=-0.118;
    $statpot{'f12YN'}=-0.146;
    $statpot{'f12YD'}=-0.030;
    $statpot{'f12YC'}=-0.554;
    $statpot{'f12YQ'}=-0.036;
    $statpot{'f12YE'}=0.040;
    $statpot{'f12YG'}=-0.228;
    $statpot{'f12YH'}=-0.301;
    $statpot{'f12YI'}=-0.365;
    $statpot{'f12YL'}=-0.346;
    $statpot{'f12YK'}=-0.040;
    $statpot{'f12YM'}=-0.441;
    $statpot{'f12YF'}=-0.534;
    $statpot{'f12YP'}=-0.188;
    $statpot{'f12YS'}=-0.227;
    $statpot{'f12YT'}=-0.194;
    $statpot{'f12YW'}=-0.556;
    $statpot{'f12YY'}=-0.312;
    $statpot{'f12YV'}=-0.290;
    $statpot{'f12VA'}=-0.319;
    $statpot{'f12VR'}=-0.174;
    $statpot{'f12VN'}=0.003;
    $statpot{'f12VD'}=0.018;
    $statpot{'f12VC'}=-0.379;
    $statpot{'f12VQ'}=-0.157;
    $statpot{'f12VE'}=0.041;
    $statpot{'f12VG'}=-0.174;
    $statpot{'f12VH'}=-0.198;
    $statpot{'f12VI'}=-0.391;
    $statpot{'f12VL'}=-0.322;
    $statpot{'f12VK'}=0.023;
    $statpot{'f12VM'}=-0.347;
    $statpot{'f12VF'}=-0.517;
    $statpot{'f12VP'}=-0.107;
    $statpot{'f12VS'}=-0.257;
    $statpot{'f12VT'}=-0.204;
    $statpot{'f12VW'}=-0.361;
    $statpot{'f12VY'}=-0.277;
    $statpot{'f12VV'}=-0.288;
    $statpot{'a12AA'}=0.050;
    $statpot{'a12AR'}=0.015;
    $statpot{'a12AN'}=0.019;
    $statpot{'a12AD'}=0.107;
    $statpot{'a12AC'}=-0.148;
    $statpot{'a12AQ'}=0.062;
    $statpot{'a12AE'}=0.188;
    $statpot{'a12AG'}=-0.037;
    $statpot{'a12AH'}=0.033;
    $statpot{'a12AI'}=-0.033;
    $statpot{'a12AL'}=0.002;
    $statpot{'a12AK'}=0.118;
    $statpot{'a12AM'}=-0.003;
    $statpot{'a12AF'}=-0.108;
    $statpot{'a12AP'}=-0.081;
    $statpot{'a12AS'}=0.029;
    $statpot{'a12AT'}=0.037;
    $statpot{'a12AW'}=0.053;
    $statpot{'a12AY'}=-0.030;
    $statpot{'a12AV'}=-0.083;
    $statpot{'a12RA'}=-0.004;
    $statpot{'a12RR'}=0.008;
    $statpot{'a12RN'}=0.332;
    $statpot{'a12RD'}=0.202;
    $statpot{'a12RC'}=-0.083;
    $statpot{'a12RQ'}=0.090;
    $statpot{'a12RE'}=0.180;
    $statpot{'a12RG'}=-0.090;
    $statpot{'a12RH'}=0.019;
    $statpot{'a12RI'}=-0.096;
    $statpot{'a12RL'}=-0.253;
    $statpot{'a12RK'}=0.128;
    $statpot{'a12RM'}=-0.298;
    $statpot{'a12RF'}=-0.099;
    $statpot{'a12RP'}=-0.157;
    $statpot{'a12RS'}=0.047;
    $statpot{'a12RT'}=0.038;
    $statpot{'a12RW'}=-0.387;
    $statpot{'a12RY'}=0.043;
    $statpot{'a12RV'}=-0.289;
    $statpot{'a12NA'}=-0.140;
    $statpot{'a12NR'}=0.244;
    $statpot{'a12NN'}=0.206;
    $statpot{'a12ND'}=0.201;
    $statpot{'a12NC'}=-0.263;
    $statpot{'a12NQ'}=0.191;
    $statpot{'a12NE'}=0.256;
    $statpot{'a12NG'}=0.018;
    $statpot{'a12NH'}=-0.230;
    $statpot{'a12NI'}=-0.410;
    $statpot{'a12NL'}=-0.195;
    $statpot{'a12NK'}=0.197;
    $statpot{'a12NM'}=-0.279;
    $statpot{'a12NF'}=-0.420;
    $statpot{'a12NP'}=-0.014;
    $statpot{'a12NS'}=-0.001;
    $statpot{'a12NT'}=0.109;
    $statpot{'a12NW'}=-0.065;
    $statpot{'a12NY'}=-0.280;
    $statpot{'a12NV'}=-0.164;
    $statpot{'a12DA'}=-0.049;
    $statpot{'a12DR'}=0.052;
    $statpot{'a12DN'}=0.177;
    $statpot{'a12DD'}=0.314;
    $statpot{'a12DC'}=-0.408;
    $statpot{'a12DQ'}=0.351;
    $statpot{'a12DE'}=0.184;
    $statpot{'a12DG'}=0.037;
    $statpot{'a12DH'}=0.076;
    $statpot{'a12DI'}=-0.266;
    $statpot{'a12DL'}=-0.315;
    $statpot{'a12DK'}=0.240;
    $statpot{'a12DM'}=-0.233;
    $statpot{'a12DF'}=-0.393;
    $statpot{'a12DP'}=0.105;
    $statpot{'a12DS'}=0.192;
    $statpot{'a12DT'}=0.115;
    $statpot{'a12DW'}=-0.281;
    $statpot{'a12DY'}=-0.265;
    $statpot{'a12DV'}=-0.222;
    $statpot{'a12CA'}=0.030;
    $statpot{'a12CR'}=0.044;
    $statpot{'a12CN'}=-0.048;
    $statpot{'a12CD'}=-0.102;
    $statpot{'a12CC'}=0.458;
    $statpot{'a12CQ'}=-0.205;
    $statpot{'a12CE'}=0.074;
    $statpot{'a12CG'}=0.011;
    $statpot{'a12CH'}=-0.140;
    $statpot{'a12CI'}=0.027;
    $statpot{'a12CL'}=0.057;
    $statpot{'a12CK'}=0.406;
    $statpot{'a12CM'}=-0.228;
    $statpot{'a12CF'}=-0.324;
    $statpot{'a12CP'}=-0.173;
    $statpot{'a12CS'}=-0.050;
    $statpot{'a12CT'}=-0.073;
    $statpot{'a12CW'}=-0.175;
    $statpot{'a12CY'}=-0.270;
    $statpot{'a12CV'}=0.084;
    $statpot{'a12QA'}=0.054;
    $statpot{'a12QR'}=0.170;
    $statpot{'a12QN'}=0.211;
    $statpot{'a12QD'}=0.324;
    $statpot{'a12QC'}=-0.263;
    $statpot{'a12QQ'}=0.129;
    $statpot{'a12QE'}=0.307;
    $statpot{'a12QG'}=-0.017;
    $statpot{'a12QH'}=0.039;
    $statpot{'a12QI'}=-0.242;
    $statpot{'a12QL'}=-0.244;
    $statpot{'a12QK'}=0.156;
    $statpot{'a12QM'}=-0.139;
    $statpot{'a12QF'}=-0.249;
    $statpot{'a12QP'}=0.117;
    $statpot{'a12QS'}=0.025;
    $statpot{'a12QT'}=0.059;
    $statpot{'a12QW'}=-0.384;
    $statpot{'a12QY'}=0.145;
    $statpot{'a12QV'}=-0.303;
    $statpot{'a12EA'}=0.009;
    $statpot{'a12ER'}=0.118;
    $statpot{'a12EN'}=0.245;
    $statpot{'a12ED'}=0.245;
    $statpot{'a12EC'}=-0.110;
    $statpot{'a12EQ'}=0.212;
    $statpot{'a12EE'}=0.342;
    $statpot{'a12EG'}=-0.036;
    $statpot{'a12EH'}=0.162;
    $statpot{'a12EI'}=-0.026;
    $statpot{'a12EL'}=-0.235;
    $statpot{'a12EK'}=0.249;
    $statpot{'a12EM'}=-0.041;
    $statpot{'a12EF'}=-0.260;
    $statpot{'a12EP'}=-0.008;
    $statpot{'a12ES'}=0.066;
    $statpot{'a12ET'}=0.080;
    $statpot{'a12EW'}=-0.265;
    $statpot{'a12EY'}=-0.057;
    $statpot{'a12EV'}=-0.102;
    $statpot{'a12GA'}=-0.109;
    $statpot{'a12GR'}=-0.043;
    $statpot{'a12GN'}=0.052;
    $statpot{'a12GD'}=0.095;
    $statpot{'a12GC'}=-0.153;
    $statpot{'a12GQ'}=0.010;
    $statpot{'a12GE'}=0.019;
    $statpot{'a12GG'}=0.096;
    $statpot{'a12GH'}=0.012;
    $statpot{'a12GI'}=-0.326;
    $statpot{'a12GL'}=-0.287;
    $statpot{'a12GK'}=0.122;
    $statpot{'a12GM'}=-0.384;
    $statpot{'a12GF'}=-0.384;
    $statpot{'a12GP'}=0.077;
    $statpot{'a12GS'}=0.056;
    $statpot{'a12GT'}=-0.090;
    $statpot{'a12GW'}=-0.117;
    $statpot{'a12GY'}=-0.142;
    $statpot{'a12GV'}=-0.233;
    $statpot{'a12HA'}=0.007;
    $statpot{'a12HR'}=0.025;
    $statpot{'a12HN'}=-0.101;
    $statpot{'a12HD'}=0.218;
    $statpot{'a12HC'}=-0.125;
    $statpot{'a12HQ'}=0.289;
    $statpot{'a12HE'}=0.227;
    $statpot{'a12HG'}=-0.049;
    $statpot{'a12HH'}=-0.042;
    $statpot{'a12HI'}=-0.195;
    $statpot{'a12HL'}=-0.210;
    $statpot{'a12HK'}=0.119;
    $statpot{'a12HM'}=-0.201;
    $statpot{'a12HF'}=-0.160;
    $statpot{'a12HP'}=-0.112;
    $statpot{'a12HS'}=-0.079;
    $statpot{'a12HT'}=0.189;
    $statpot{'a12HW'}=0.458;
    $statpot{'a12HY'}=-0.044;
    $statpot{'a12HV'}=-0.032;
    $statpot{'a12IA'}=0.095;
    $statpot{'a12IR'}=0.103;
    $statpot{'a12IN'}=-0.190;
    $statpot{'a12ID'}=0.007;
    $statpot{'a12IC'}=0.071;
    $statpot{'a12IQ'}=0.013;
    $statpot{'a12IE'}=0.259;
    $statpot{'a12IG'}=-0.111;
    $statpot{'a12IH'}=-0.010;
    $statpot{'a12II'}=0.054;
    $statpot{'a12IL'}=0.091;
    $statpot{'a12IK'}=0.095;
    $statpot{'a12IM'}=-0.139;
    $statpot{'a12IF'}=-0.022;
    $statpot{'a12IP'}=-0.033;
    $statpot{'a12IS'}=0.054;
    $statpot{'a12IT'}=0.028;
    $statpot{'a12IW'}=0.015;
    $statpot{'a12IY'}=0.008;
    $statpot{'a12IV'}=-0.029;
    $statpot{'a12LA'}=0.081;
    $statpot{'a12LR'}=-0.043;
    $statpot{'a12LN'}=0.017;
    $statpot{'a12LD'}=-0.042;
    $statpot{'a12LC'}=0.327;
    $statpot{'a12LQ'}=0.002;
    $statpot{'a12LE'}=0.024;
    $statpot{'a12LG'}=-0.115;
    $statpot{'a12LH'}=-0.027;
    $statpot{'a12LI'}=0.006;
    $statpot{'a12LL'}=0.155;
    $statpot{'a12LK'}=0.040;
    $statpot{'a12LM'}=0.089;
    $statpot{'a12LF'}=-0.075;
    $statpot{'a12LP'}=-0.127;
    $statpot{'a12LS'}=0.061;
    $statpot{'a12LT'}=0.023;
    $statpot{'a12LW'}=0.049;
    $statpot{'a12LY'}=-0.033;
    $statpot{'a12LV'}=0.030;
    $statpot{'a12KA'}=-0.027;
    $statpot{'a12KR'}=0.084;
    $statpot{'a12KN'}=0.123;
    $statpot{'a12KD'}=0.318;
    $statpot{'a12KC'}=-0.063;
    $statpot{'a12KQ'}=0.146;
    $statpot{'a12KE'}=0.236;
    $statpot{'a12KG'}=0.041;
    $statpot{'a12KH'}=-0.075;
    $statpot{'a12KI'}=-0.219;
    $statpot{'a12KL'}=-0.234;
    $statpot{'a12KK'}=0.311;
    $statpot{'a12KM'}=-0.178;
    $statpot{'a12KF'}=-0.314;
    $statpot{'a12KP'}=0.039;
    $statpot{'a12KS'}=0.233;
    $statpot{'a12KT'}=0.010;
    $statpot{'a12KW'}=-0.219;
    $statpot{'a12KY'}=-0.195;
    $statpot{'a12KV'}=-0.089;
    $statpot{'a12MA'}=0.136;
    $statpot{'a12MR'}=-0.223;
    $statpot{'a12MN'}=-0.221;
    $statpot{'a12MD'}=0.017;
    $statpot{'a12MC'}=-0.247;
    $statpot{'a12MQ'}=-0.133;
    $statpot{'a12ME'}=0.143;
    $statpot{'a12MG'}=-0.193;
    $statpot{'a12MH'}=-0.005;
    $statpot{'a12MI'}=0.016;
    $statpot{'a12ML'}=-0.046;
    $statpot{'a12MK'}=0.147;
    $statpot{'a12MM'}=-0.090;
    $statpot{'a12MF'}=-0.196;
    $statpot{'a12MP'}=0.049;
    $statpot{'a12MS'}=0.005;
    $statpot{'a12MT'}=0.127;
    $statpot{'a12MW'}=0.139;
    $statpot{'a12MY'}=-0.105;
    $statpot{'a12MV'}=-0.126;
    $statpot{'a12FA'}=0.112;
    $statpot{'a12FR'}=-0.046;
    $statpot{'a12FN'}=-0.194;
    $statpot{'a12FD'}=-0.021;
    $statpot{'a12FC'}=-0.017;
    $statpot{'a12FQ'}=0.097;
    $statpot{'a12FE'}=0.183;
    $statpot{'a12FG'}=-0.162;
    $statpot{'a12FH'}=-0.053;
    $statpot{'a12FI'}=0.051;
    $statpot{'a12FL'}=-0.011;
    $statpot{'a12FK'}=0.009;
    $statpot{'a12FM'}=-0.028;
    $statpot{'a12FF'}=-0.017;
    $statpot{'a12FP'}=-0.209;
    $statpot{'a12FS'}=0.060;
    $statpot{'a12FT'}=-0.110;
    $statpot{'a12FW'}=0.016;
    $statpot{'a12FY'}=-0.027;
    $statpot{'a12FV'}=-0.019;
    $statpot{'a12PA'}=-0.134;
    $statpot{'a12PR'}=-0.106;
    $statpot{'a12PN'}=0.091;
    $statpot{'a12PD'}=0.115;
    $statpot{'a12PC'}=-0.166;
    $statpot{'a12PQ'}=0.117;
    $statpot{'a12PE'}=0.112;
    $statpot{'a12PG'}=0.050;
    $statpot{'a12PH'}=-0.198;
    $statpot{'a12PI'}=-0.246;
    $statpot{'a12PL'}=-0.356;
    $statpot{'a12PK'}=0.129;
    $statpot{'a12PM'}=-0.078;
    $statpot{'a12PF'}=-0.383;
    $statpot{'a12PP'}=-0.063;
    $statpot{'a12PS'}=0.118;
    $statpot{'a12PT'}=-0.206;
    $statpot{'a12PW'}=-0.324;
    $statpot{'a12PY'}=-0.246;
    $statpot{'a12PV'}=-0.191;
    $statpot{'a12SA'}=-0.059;
    $statpot{'a12SR'}=-0.019;
    $statpot{'a12SN'}=0.056;
    $statpot{'a12SD'}=0.313;
    $statpot{'a12SC'}=-0.316;
    $statpot{'a12SQ'}=0.038;
    $statpot{'a12SE'}=0.082;
    $statpot{'a12SG'}=-0.020;
    $statpot{'a12SH'}=-0.076;
    $statpot{'a12SI'}=-0.233;
    $statpot{'a12SL'}=-0.220;
    $statpot{'a12SK'}=0.310;
    $statpot{'a12SM'}=-0.214;
    $statpot{'a12SF'}=-0.232;
    $statpot{'a12SP'}=0.023;
    $statpot{'a12SS'}=0.069;
    $statpot{'a12ST'}=0.101;
    $statpot{'a12SW'}=-0.178;
    $statpot{'a12SY'}=-0.237;
    $statpot{'a12SV'}=-0.253;
    $statpot{'a12TA'}=-0.095;
    $statpot{'a12TR'}=-0.007;
    $statpot{'a12TN'}=0.108;
    $statpot{'a12TD'}=0.120;
    $statpot{'a12TC'}=-0.200;
    $statpot{'a12TQ'}=0.139;
    $statpot{'a12TE'}=0.143;
    $statpot{'a12TG'}=-0.097;
    $statpot{'a12TH'}=-0.060;
    $statpot{'a12TI'}=-0.185;
    $statpot{'a12TL'}=-0.213;
    $statpot{'a12TK'}=0.177;
    $statpot{'a12TM'}=-0.196;
    $statpot{'a12TF'}=-0.279;
    $statpot{'a12TP'}=-0.100;
    $statpot{'a12TS'}=0.107;
    $statpot{'a12TT'}=0.012;
    $statpot{'a12TW'}=-0.320;
    $statpot{'a12TY'}=-0.306;
    $statpot{'a12TV'}=-0.147;
    $statpot{'a12WA'}=-0.023;
    $statpot{'a12WR'}=-0.018;
    $statpot{'a12WN'}=0.051;
    $statpot{'a12WD'}=0.090;
    $statpot{'a12WC'}=0.042;
    $statpot{'a12WQ'}=-0.123;
    $statpot{'a12WE'}=-0.047;
    $statpot{'a12WG'}=-0.021;
    $statpot{'a12WH'}=0.286;
    $statpot{'a12WI'}=-0.095;
    $statpot{'a12WL'}=-0.007;
    $statpot{'a12WK'}=0.046;
    $statpot{'a12WM'}=0.214;
    $statpot{'a12WF'}=-0.058;
    $statpot{'a12WP'}=-0.120;
    $statpot{'a12WS'}=-0.141;
    $statpot{'a12WT'}=-0.014;
    $statpot{'a12WW'}=-0.282;
    $statpot{'a12WY'}=-0.012;
    $statpot{'a12WV'}=0.006;
    $statpot{'a12YA'}=-0.005;
    $statpot{'a12YR'}=0.088;
    $statpot{'a12YN'}=0.031;
    $statpot{'a12YD'}=-0.060;
    $statpot{'a12YC'}=-0.117;
    $statpot{'a12YQ'}=0.317;
    $statpot{'a12YE'}=0.313;
    $statpot{'a12YG'}=-0.012;
    $statpot{'a12YH'}=-0.115;
    $statpot{'a12YI'}=-0.003;
    $statpot{'a12YL'}=-0.127;
    $statpot{'a12YK'}=0.072;
    $statpot{'a12YM'}=0.048;
    $statpot{'a12YF'}=-0.051;
    $statpot{'a12YP'}=-0.034;
    $statpot{'a12YS'}=-0.018;
    $statpot{'a12YT'}=-0.143;
    $statpot{'a12YW'}=0.083;
    $statpot{'a12YY'}=-0.096;
    $statpot{'a12YV'}=-0.004;
    $statpot{'a12VA'}=0.070;
    $statpot{'a12VR'}=-0.013;
    $statpot{'a12VN'}=-0.045;
    $statpot{'a12VD'}=0.057;
    $statpot{'a12VC'}=-0.050;
    $statpot{'a12VQ'}=-0.022;
    $statpot{'a12VE'}=0.201;
    $statpot{'a12VG'}=-0.014;
    $statpot{'a12VH'}=0.088;
    $statpot{'a12VI'}=-0.136;
    $statpot{'a12VL'}=-0.028;
    $statpot{'a12VK'}=0.266;
    $statpot{'a12VM'}=0.008;
    $statpot{'a12VF'}=-0.091;
    $statpot{'a12VP'}=-0.009;
    $statpot{'a12VS'}=-0.038;
    $statpot{'a12VT'}=0.005;
    $statpot{'a12VW'}=0.098;
    $statpot{'a12VY'}=-0.026;
    $statpot{'a12VV'}=0.019;
    $statpot{'p13AA'}=-0.064;
    $statpot{'p13AR'}=0.025;
    $statpot{'p13AN'}=0.042;
    $statpot{'p13AD'}=0.180;
    $statpot{'p13AC'}=-0.086;
    $statpot{'p13AQ'}=-0.010;
    $statpot{'p13AE'}=0.135;
    $statpot{'p13AG'}=0.096;
    $statpot{'p13AH'}=0.033;
    $statpot{'p13AI'}=-0.120;
    $statpot{'p13AL'}=-0.127;
    $statpot{'p13AK'}=0.201;
    $statpot{'p13AM'}=-0.144;
    $statpot{'p13AF'}=-0.132;
    $statpot{'p13AP'}=0.133;
    $statpot{'p13AS'}=-0.033;
    $statpot{'p13AT'}=-0.027;
    $statpot{'p13AW'}=-0.164;
    $statpot{'p13AY'}=-0.143;
    $statpot{'p13AV'}=-0.158;
    $statpot{'p13RA'}=0.025;
    $statpot{'p13RR'}=0.130;
    $statpot{'p13RN'}=0.106;
    $statpot{'p13RD'}=0.104;
    $statpot{'p13RC'}=-0.007;
    $statpot{'p13RQ'}=0.148;
    $statpot{'p13RE'}=0.149;
    $statpot{'p13RG'}=0.139;
    $statpot{'p13RH'}=-0.006;
    $statpot{'p13RI'}=-0.188;
    $statpot{'p13RL'}=-0.039;
    $statpot{'p13RK'}=0.216;
    $statpot{'p13RM'}=-0.003;
    $statpot{'p13RF'}=-0.075;
    $statpot{'p13RP'}=0.138;
    $statpot{'p13RS'}=0.087;
    $statpot{'p13RT'}=0.069;
    $statpot{'p13RW'}=-0.182;
    $statpot{'p13RY'}=-0.014;
    $statpot{'p13RV'}=-0.069;
    $statpot{'p13NA'}=0.042;
    $statpot{'p13NR'}=0.106;
    $statpot{'p13NN'}=0.082;
    $statpot{'p13ND'}=0.151;
    $statpot{'p13NC'}=-0.016;
    $statpot{'p13NQ'}=0.180;
    $statpot{'p13NE'}=0.197;
    $statpot{'p13NG'}=0.140;
    $statpot{'p13NH'}=0.046;
    $statpot{'p13NI'}=-0.117;
    $statpot{'p13NL'}=0.005;
    $statpot{'p13NK'}=0.289;
    $statpot{'p13NM'}=-0.143;
    $statpot{'p13NF'}=0.008;
    $statpot{'p13NP'}=0.110;
    $statpot{'p13NS'}=0.105;
    $statpot{'p13NT'}=0.097;
    $statpot{'p13NW'}=0.077;
    $statpot{'p13NY'}=-0.018;
    $statpot{'p13NV'}=0.007;
    $statpot{'p13DA'}=0.180;
    $statpot{'p13DR'}=0.104;
    $statpot{'p13DN'}=0.151;
    $statpot{'p13DD'}=0.199;
    $statpot{'p13DC'}=0.026;
    $statpot{'p13DQ'}=0.146;
    $statpot{'p13DE'}=0.278;
    $statpot{'p13DG'}=0.287;
    $statpot{'p13DH'}=0.027;
    $statpot{'p13DI'}=0.014;
    $statpot{'p13DL'}=0.014;
    $statpot{'p13DK'}=0.260;
    $statpot{'p13DM'}=0.027;
    $statpot{'p13DF'}=0.002;
    $statpot{'p13DP'}=0.197;
    $statpot{'p13DS'}=0.143;
    $statpot{'p13DT'}=0.141;
    $statpot{'p13DW'}=0.097;
    $statpot{'p13DY'}=0.015;
    $statpot{'p13DV'}=0.027;
    $statpot{'p13CA'}=-0.086;
    $statpot{'p13CR'}=-0.007;
    $statpot{'p13CN'}=-0.016;
    $statpot{'p13CD'}=0.026;
    $statpot{'p13CC'}=-0.036;
    $statpot{'p13CQ'}=0.027;
    $statpot{'p13CE'}=0.125;
    $statpot{'p13CG'}=0.056;
    $statpot{'p13CH'}=-0.061;
    $statpot{'p13CI'}=-0.264;
    $statpot{'p13CL'}=-0.301;
    $statpot{'p13CK'}=0.164;
    $statpot{'p13CM'}=-0.234;
    $statpot{'p13CF'}=-0.365;
    $statpot{'p13CP'}=0.087;
    $statpot{'p13CS'}=-0.086;
    $statpot{'p13CT'}=-0.076;
    $statpot{'p13CW'}=-0.239;
    $statpot{'p13CY'}=-0.299;
    $statpot{'p13CV'}=-0.166;
    $statpot{'p13QA'}=-0.010;
    $statpot{'p13QR'}=0.148;
    $statpot{'p13QN'}=0.180;
    $statpot{'p13QD'}=0.146;
    $statpot{'p13QC'}=0.027;
    $statpot{'p13QQ'}=0.199;
    $statpot{'p13QE'}=0.189;
    $statpot{'p13QG'}=0.141;
    $statpot{'p13QH'}=0.101;
    $statpot{'p13QI'}=-0.065;
    $statpot{'p13QL'}=-0.096;
    $statpot{'p13QK'}=0.274;
    $statpot{'p13QM'}=-0.016;
    $statpot{'p13QF'}=-0.019;
    $statpot{'p13QP'}=0.116;
    $statpot{'p13QS'}=0.076;
    $statpot{'p13QT'}=0.049;
    $statpot{'p13QW'}=0.028;
    $statpot{'p13QY'}=0.010;
    $statpot{'p13QV'}=-0.012;
    $statpot{'p13EA'}=0.135;
    $statpot{'p13ER'}=0.149;
    $statpot{'p13EN'}=0.197;
    $statpot{'p13ED'}=0.278;
    $statpot{'p13EC'}=0.125;
    $statpot{'p13EQ'}=0.189;
    $statpot{'p13EE'}=0.204;
    $statpot{'p13EG'}=0.226;
    $statpot{'p13EH'}=0.171;
    $statpot{'p13EI'}=-0.021;
    $statpot{'p13EL'}=0.087;
    $statpot{'p13EK'}=0.181;
    $statpot{'p13EM'}=0.131;
    $statpot{'p13EF'}=0.090;
    $statpot{'p13EP'}=0.156;
    $statpot{'p13ES'}=0.185;
    $statpot{'p13ET'}=0.190;
    $statpot{'p13EW'}=-0.026;
    $statpot{'p13EY'}=0.052;
    $statpot{'p13EV'}=0.039;
    $statpot{'p13GA'}=0.096;
    $statpot{'p13GR'}=0.139;
    $statpot{'p13GN'}=0.140;
    $statpot{'p13GD'}=0.287;
    $statpot{'p13GC'}=0.056;
    $statpot{'p13GQ'}=0.141;
    $statpot{'p13GE'}=0.226;
    $statpot{'p13GG'}=0.224;
    $statpot{'p13GH'}=-0.028;
    $statpot{'p13GI'}=-0.061;
    $statpot{'p13GL'}=0.000;
    $statpot{'p13GK'}=0.319;
    $statpot{'p13GM'}=0.041;
    $statpot{'p13GF'}=-0.020;
    $statpot{'p13GP'}=0.123;
    $statpot{'p13GS'}=0.097;
    $statpot{'p13GT'}=0.121;
    $statpot{'p13GW'}=0.020;
    $statpot{'p13GY'}=-0.021;
    $statpot{'p13GV'}=-0.025;
    $statpot{'p13HA'}=0.033;
    $statpot{'p13HR'}=-0.006;
    $statpot{'p13HN'}=0.046;
    $statpot{'p13HD'}=0.027;
    $statpot{'p13HC'}=-0.061;
    $statpot{'p13HQ'}=0.101;
    $statpot{'p13HE'}=0.171;
    $statpot{'p13HG'}=-0.028;
    $statpot{'p13HH'}=0.087;
    $statpot{'p13HI'}=-0.168;
    $statpot{'p13HL'}=-0.102;
    $statpot{'p13HK'}=0.115;
    $statpot{'p13HM'}=-0.236;
    $statpot{'p13HF'}=-0.268;
    $statpot{'p13HP'}=0.172;
    $statpot{'p13HS'}=0.029;
    $statpot{'p13HT'}=0.055;
    $statpot{'p13HW'}=-0.296;
    $statpot{'p13HY'}=-0.194;
    $statpot{'p13HV'}=-0.207;
    $statpot{'p13IA'}=-0.120;
    $statpot{'p13IR'}=-0.188;
    $statpot{'p13IN'}=-0.117;
    $statpot{'p13ID'}=0.014;
    $statpot{'p13IC'}=-0.264;
    $statpot{'p13IQ'}=-0.065;
    $statpot{'p13IE'}=-0.021;
    $statpot{'p13IG'}=-0.061;
    $statpot{'p13IH'}=-0.168;
    $statpot{'p13II'}=-0.210;
    $statpot{'p13IL'}=-0.143;
    $statpot{'p13IK'}=0.067;
    $statpot{'p13IM'}=-0.225;
    $statpot{'p13IF'}=-0.243;
    $statpot{'p13IP'}=-0.028;
    $statpot{'p13IS'}=-0.092;
    $statpot{'p13IT'}=-0.156;
    $statpot{'p13IW'}=-0.169;
    $statpot{'p13IY'}=-0.248;
    $statpot{'p13IV'}=-0.272;
    $statpot{'p13LA'}=-0.127;
    $statpot{'p13LR'}=-0.039;
    $statpot{'p13LN'}=0.005;
    $statpot{'p13LD'}=0.014;
    $statpot{'p13LC'}=-0.301;
    $statpot{'p13LQ'}=-0.096;
    $statpot{'p13LE'}=0.087;
    $statpot{'p13LG'}=0.000;
    $statpot{'p13LH'}=-0.102;
    $statpot{'p13LI'}=-0.143;
    $statpot{'p13LL'}=-0.175;
    $statpot{'p13LK'}=0.039;
    $statpot{'p13LM'}=-0.163;
    $statpot{'p13LF'}=-0.208;
    $statpot{'p13LP'}=0.054;
    $statpot{'p13LS'}=-0.083;
    $statpot{'p13LT'}=-0.071;
    $statpot{'p13LW'}=-0.290;
    $statpot{'p13LY'}=-0.218;
    $statpot{'p13LV'}=-0.184;
    $statpot{'p13KA'}=0.201;
    $statpot{'p13KR'}=0.216;
    $statpot{'p13KN'}=0.289;
    $statpot{'p13KD'}=0.260;
    $statpot{'p13KC'}=0.164;
    $statpot{'p13KQ'}=0.274;
    $statpot{'p13KE'}=0.181;
    $statpot{'p13KG'}=0.319;
    $statpot{'p13KH'}=0.115;
    $statpot{'p13KI'}=0.067;
    $statpot{'p13KL'}=0.039;
    $statpot{'p13KK'}=0.198;
    $statpot{'p13KM'}=0.177;
    $statpot{'p13KF'}=0.040;
    $statpot{'p13KP'}=0.210;
    $statpot{'p13KS'}=0.227;
    $statpot{'p13KT'}=0.054;
    $statpot{'p13KW'}=0.104;
    $statpot{'p13KY'}=0.165;
    $statpot{'p13KV'}=0.036;
    $statpot{'p13MA'}=-0.144;
    $statpot{'p13MR'}=-0.003;
    $statpot{'p13MN'}=-0.143;
    $statpot{'p13MD'}=0.027;
    $statpot{'p13MC'}=-0.234;
    $statpot{'p13MQ'}=-0.016;
    $statpot{'p13ME'}=0.131;
    $statpot{'p13MG'}=0.041;
    $statpot{'p13MH'}=-0.236;
    $statpot{'p13MI'}=-0.225;
    $statpot{'p13ML'}=-0.163;
    $statpot{'p13MK'}=0.177;
    $statpot{'p13MM'}=0.004;
    $statpot{'p13MF'}=-0.278;
    $statpot{'p13MP'}=0.067;
    $statpot{'p13MS'}=-0.126;
    $statpot{'p13MT'}=-0.231;
    $statpot{'p13MW'}=-0.356;
    $statpot{'p13MY'}=-0.315;
    $statpot{'p13MV'}=-0.156;
    $statpot{'p13FA'}=-0.132;
    $statpot{'p13FR'}=-0.075;
    $statpot{'p13FN'}=0.008;
    $statpot{'p13FD'}=0.002;
    $statpot{'p13FC'}=-0.365;
    $statpot{'p13FQ'}=-0.019;
    $statpot{'p13FE'}=0.090;
    $statpot{'p13FG'}=-0.020;
    $statpot{'p13FH'}=-0.268;
    $statpot{'p13FI'}=-0.243;
    $statpot{'p13FL'}=-0.208;
    $statpot{'p13FK'}=0.040;
    $statpot{'p13FM'}=-0.278;
    $statpot{'p13FF'}=-0.327;
    $statpot{'p13FP'}=0.021;
    $statpot{'p13FS'}=-0.190;
    $statpot{'p13FT'}=-0.142;
    $statpot{'p13FW'}=-0.386;
    $statpot{'p13FY'}=-0.266;
    $statpot{'p13FV'}=-0.313;
    $statpot{'p13PA'}=0.133;
    $statpot{'p13PR'}=0.138;
    $statpot{'p13PN'}=0.110;
    $statpot{'p13PD'}=0.197;
    $statpot{'p13PC'}=0.087;
    $statpot{'p13PQ'}=0.116;
    $statpot{'p13PE'}=0.156;
    $statpot{'p13PG'}=0.123;
    $statpot{'p13PH'}=0.172;
    $statpot{'p13PI'}=-0.028;
    $statpot{'p13PL'}=0.054;
    $statpot{'p13PK'}=0.210;
    $statpot{'p13PM'}=0.067;
    $statpot{'p13PF'}=0.021;
    $statpot{'p13PP'}=0.082;
    $statpot{'p13PS'}=0.089;
    $statpot{'p13PT'}=0.053;
    $statpot{'p13PW'}=0.004;
    $statpot{'p13PY'}=0.039;
    $statpot{'p13PV'}=0.035;
    $statpot{'p13SA'}=-0.033;
    $statpot{'p13SR'}=0.087;
    $statpot{'p13SN'}=0.105;
    $statpot{'p13SD'}=0.143;
    $statpot{'p13SC'}=-0.086;
    $statpot{'p13SQ'}=0.076;
    $statpot{'p13SE'}=0.185;
    $statpot{'p13SG'}=0.097;
    $statpot{'p13SH'}=0.029;
    $statpot{'p13SI'}=-0.092;
    $statpot{'p13SL'}=-0.083;
    $statpot{'p13SK'}=0.227;
    $statpot{'p13SM'}=-0.126;
    $statpot{'p13SF'}=-0.190;
    $statpot{'p13SP'}=0.089;
    $statpot{'p13SS'}=0.058;
    $statpot{'p13ST'}=0.006;
    $statpot{'p13SW'}=-0.093;
    $statpot{'p13SY'}=-0.011;
    $statpot{'p13SV'}=-0.151;
    $statpot{'p13TA'}=-0.027;
    $statpot{'p13TR'}=0.069;
    $statpot{'p13TN'}=0.097;
    $statpot{'p13TD'}=0.141;
    $statpot{'p13TC'}=-0.076;
    $statpot{'p13TQ'}=0.049;
    $statpot{'p13TE'}=0.190;
    $statpot{'p13TG'}=0.121;
    $statpot{'p13TH'}=0.055;
    $statpot{'p13TI'}=-0.156;
    $statpot{'p13TL'}=-0.071;
    $statpot{'p13TK'}=0.054;
    $statpot{'p13TM'}=-0.231;
    $statpot{'p13TF'}=-0.142;
    $statpot{'p13TP'}=0.053;
    $statpot{'p13TS'}=0.006;
    $statpot{'p13TT'}=-0.022;
    $statpot{'p13TW'}=-0.219;
    $statpot{'p13TY'}=-0.154;
    $statpot{'p13TV'}=-0.176;
    $statpot{'p13WA'}=-0.164;
    $statpot{'p13WR'}=-0.182;
    $statpot{'p13WN'}=0.077;
    $statpot{'p13WD'}=0.097;
    $statpot{'p13WC'}=-0.239;
    $statpot{'p13WQ'}=0.028;
    $statpot{'p13WE'}=-0.026;
    $statpot{'p13WG'}=0.020;
    $statpot{'p13WH'}=-0.296;
    $statpot{'p13WI'}=-0.169;
    $statpot{'p13WL'}=-0.290;
    $statpot{'p13WK'}=0.104;
    $statpot{'p13WM'}=-0.356;
    $statpot{'p13WF'}=-0.386;
    $statpot{'p13WP'}=0.004;
    $statpot{'p13WS'}=-0.093;
    $statpot{'p13WT'}=-0.219;
    $statpot{'p13WW'}=-0.350;
    $statpot{'p13WY'}=-0.248;
    $statpot{'p13WV'}=-0.206;
    $statpot{'p13YA'}=-0.143;
    $statpot{'p13YR'}=-0.014;
    $statpot{'p13YN'}=-0.018;
    $statpot{'p13YD'}=0.015;
    $statpot{'p13YC'}=-0.299;
    $statpot{'p13YQ'}=0.010;
    $statpot{'p13YE'}=0.052;
    $statpot{'p13YG'}=-0.021;
    $statpot{'p13YH'}=-0.194;
    $statpot{'p13YI'}=-0.248;
    $statpot{'p13YL'}=-0.218;
    $statpot{'p13YK'}=0.165;
    $statpot{'p13YM'}=-0.315;
    $statpot{'p13YF'}=-0.266;
    $statpot{'p13YP'}=0.039;
    $statpot{'p13YS'}=-0.011;
    $statpot{'p13YT'}=-0.154;
    $statpot{'p13YW'}=-0.248;
    $statpot{'p13YY'}=-0.237;
    $statpot{'p13YV'}=-0.238;
    $statpot{'p13VA'}=-0.158;
    $statpot{'p13VR'}=-0.069;
    $statpot{'p13VN'}=0.007;
    $statpot{'p13VD'}=0.027;
    $statpot{'p13VC'}=-0.166;
    $statpot{'p13VQ'}=-0.012;
    $statpot{'p13VE'}=0.039;
    $statpot{'p13VG'}=-0.025;
    $statpot{'p13VH'}=-0.207;
    $statpot{'p13VI'}=-0.272;
    $statpot{'p13VL'}=-0.184;
    $statpot{'p13VK'}=0.036;
    $statpot{'p13VM'}=-0.156;
    $statpot{'p13VF'}=-0.313;
    $statpot{'p13VP'}=0.035;
    $statpot{'p13VS'}=-0.151;
    $statpot{'p13VT'}=-0.176;
    $statpot{'p13VW'}=-0.206;
    $statpot{'p13VY'}=-0.238;
    $statpot{'p13VV'}=-0.180;
    $statpot{'f13AA'}=-0.171;
    $statpot{'f13AR'}=0.065;
    $statpot{'f13AN'}=-0.007;
    $statpot{'f13AD'}=0.160;
    $statpot{'f13AC'}=-0.332;
    $statpot{'f13AQ'}=0.099;
    $statpot{'f13AE'}=0.129;
    $statpot{'f13AG'}=0.018;
    $statpot{'f13AH'}=-0.136;
    $statpot{'f13AI'}=-0.318;
    $statpot{'f13AL'}=-0.226;
    $statpot{'f13AK'}=0.238;
    $statpot{'f13AM'}=-0.335;
    $statpot{'f13AF'}=-0.299;
    $statpot{'f13AP'}=0.016;
    $statpot{'f13AS'}=-0.089;
    $statpot{'f13AT'}=-0.102;
    $statpot{'f13AW'}=-0.210;
    $statpot{'f13AY'}=-0.234;
    $statpot{'f13AV'}=-0.282;
    $statpot{'f13RA'}=0.119;
    $statpot{'f13RR'}=0.341;
    $statpot{'f13RN'}=0.201;
    $statpot{'f13RD'}=0.438;
    $statpot{'f13RC'}=0.085;
    $statpot{'f13RQ'}=0.299;
    $statpot{'f13RE'}=0.445;
    $statpot{'f13RG'}=0.363;
    $statpot{'f13RH'}=0.137;
    $statpot{'f13RI'}=0.019;
    $statpot{'f13RL'}=0.115;
    $statpot{'f13RK'}=0.412;
    $statpot{'f13RM'}=0.070;
    $statpot{'f13RF'}=-0.007;
    $statpot{'f13RP'}=0.231;
    $statpot{'f13RS'}=0.240;
    $statpot{'f13RT'}=0.185;
    $statpot{'f13RW'}=0.190;
    $statpot{'f13RY'}=-0.070;
    $statpot{'f13RV'}=0.049;
    $statpot{'f13NA'}=0.048;
    $statpot{'f13NR'}=0.271;
    $statpot{'f13NN'}=0.415;
    $statpot{'f13ND'}=0.430;
    $statpot{'f13NC'}=0.243;
    $statpot{'f13NQ'}=0.615;
    $statpot{'f13NE'}=0.503;
    $statpot{'f13NG'}=0.343;
    $statpot{'f13NH'}=0.370;
    $statpot{'f13NI'}=0.027;
    $statpot{'f13NL'}=0.099;
    $statpot{'f13NK'}=0.491;
    $statpot{'f13NM'}=0.009;
    $statpot{'f13NF'}=-0.108;
    $statpot{'f13NP'}=0.436;
    $statpot{'f13NS'}=0.247;
    $statpot{'f13NT'}=0.355;
    $statpot{'f13NW'}=-0.050;
    $statpot{'f13NY'}=0.076;
    $statpot{'f13NV'}=-0.005;
    $statpot{'f13DA'}=0.244;
    $statpot{'f13DR'}=0.525;
    $statpot{'f13DN'}=0.408;
    $statpot{'f13DD'}=0.521;
    $statpot{'f13DC'}=-0.094;
    $statpot{'f13DQ'}=0.373;
    $statpot{'f13DE'}=0.591;
    $statpot{'f13DG'}=0.493;
    $statpot{'f13DH'}=0.269;
    $statpot{'f13DI'}=0.213;
    $statpot{'f13DL'}=0.200;
    $statpot{'f13DK'}=0.706;
    $statpot{'f13DM'}=0.329;
    $statpot{'f13DF'}=0.193;
    $statpot{'f13DP'}=0.446;
    $statpot{'f13DS'}=0.408;
    $statpot{'f13DT'}=0.353;
    $statpot{'f13DW'}=0.040;
    $statpot{'f13DY'}=0.108;
    $statpot{'f13DV'}=0.112;
    $statpot{'f13CA'}=-0.392;
    $statpot{'f13CR'}=-0.128;
    $statpot{'f13CN'}=0.021;
    $statpot{'f13CD'}=-0.201;
    $statpot{'f13CC'}=-0.254;
    $statpot{'f13CQ'}=-0.183;
    $statpot{'f13CE'}=0.033;
    $statpot{'f13CG'}=-0.169;
    $statpot{'f13CH'}=-0.207;
    $statpot{'f13CI'}=-0.379;
    $statpot{'f13CL'}=-0.275;
    $statpot{'f13CK'}=0.005;
    $statpot{'f13CM'}=-0.486;
    $statpot{'f13CF'}=-0.478;
    $statpot{'f13CP'}=-0.105;
    $statpot{'f13CS'}=-0.217;
    $statpot{'f13CT'}=-0.187;
    $statpot{'f13CW'}=-0.441;
    $statpot{'f13CY'}=-0.378;
    $statpot{'f13CV'}=-0.525;
    $statpot{'f13QA'}=0.128;
    $statpot{'f13QR'}=0.281;
    $statpot{'f13QN'}=0.540;
    $statpot{'f13QD'}=0.352;
    $statpot{'f13QC'}=-0.087;
    $statpot{'f13QQ'}=0.277;
    $statpot{'f13QE'}=0.595;
    $statpot{'f13QG'}=0.330;
    $statpot{'f13QH'}=0.170;
    $statpot{'f13QI'}=0.034;
    $statpot{'f13QL'}=0.034;
    $statpot{'f13QK'}=0.591;
    $statpot{'f13QM'}=0.201;
    $statpot{'f13QF'}=0.059;
    $statpot{'f13QP'}=0.336;
    $statpot{'f13QS'}=0.181;
    $statpot{'f13QT'}=0.206;
    $statpot{'f13QW'}=0.102;
    $statpot{'f13QY'}=0.076;
    $statpot{'f13QV'}=-0.003;
    $statpot{'f13EA'}=0.325;
    $statpot{'f13ER'}=0.590;
    $statpot{'f13EN'}=0.579;
    $statpot{'f13ED'}=0.565;
    $statpot{'f13EC'}=0.129;
    $statpot{'f13EQ'}=0.543;
    $statpot{'f13EE'}=0.606;
    $statpot{'f13EG'}=0.585;
    $statpot{'f13EH'}=0.245;
    $statpot{'f13EI'}=0.182;
    $statpot{'f13EL'}=0.333;
    $statpot{'f13EK'}=0.778;
    $statpot{'f13EM'}=0.401;
    $statpot{'f13EF'}=0.290;
    $statpot{'f13EP'}=0.515;
    $statpot{'f13ES'}=0.419;
    $statpot{'f13ET'}=0.400;
    $statpot{'f13EW'}=0.237;
    $statpot{'f13EY'}=0.202;
    $statpot{'f13EV'}=0.319;
    $statpot{'f13GA'}=0.064;
    $statpot{'f13GR'}=0.345;
    $statpot{'f13GN'}=0.289;
    $statpot{'f13GD'}=0.393;
    $statpot{'f13GC'}=-0.120;
    $statpot{'f13GQ'}=0.297;
    $statpot{'f13GE'}=0.431;
    $statpot{'f13GG'}=0.168;
    $statpot{'f13GH'}=0.089;
    $statpot{'f13GI'}=-0.097;
    $statpot{'f13GL'}=-0.059;
    $statpot{'f13GK'}=0.515;
    $statpot{'f13GM'}=-0.061;
    $statpot{'f13GF'}=-0.097;
    $statpot{'f13GP'}=0.212;
    $statpot{'f13GS'}=0.130;
    $statpot{'f13GT'}=0.069;
    $statpot{'f13GW'}=-0.049;
    $statpot{'f13GY'}=-0.104;
    $statpot{'f13GV'}=-0.091;
    $statpot{'f13HA'}=-0.106;
    $statpot{'f13HR'}=0.160;
    $statpot{'f13HN'}=0.251;
    $statpot{'f13HD'}=0.259;
    $statpot{'f13HC'}=-0.289;
    $statpot{'f13HQ'}=0.108;
    $statpot{'f13HE'}=0.250;
    $statpot{'f13HG'}=0.154;
    $statpot{'f13HH'}=-0.165;
    $statpot{'f13HI'}=-0.228;
    $statpot{'f13HL'}=-0.124;
    $statpot{'f13HK'}=0.216;
    $statpot{'f13HM'}=-0.333;
    $statpot{'f13HF'}=-0.274;
    $statpot{'f13HP'}=0.083;
    $statpot{'f13HS'}=0.057;
    $statpot{'f13HT'}=0.011;
    $statpot{'f13HW'}=-0.334;
    $statpot{'f13HY'}=-0.278;
    $statpot{'f13HV'}=-0.099;
    $statpot{'f13IA'}=-0.361;
    $statpot{'f13IR'}=-0.093;
    $statpot{'f13IN'}=-0.232;
    $statpot{'f13ID'}=0.005;
    $statpot{'f13IC'}=-0.340;
    $statpot{'f13IQ'}=-0.186;
    $statpot{'f13IE'}=-0.071;
    $statpot{'f13IG'}=-0.141;
    $statpot{'f13IH'}=-0.428;
    $statpot{'f13II'}=-0.373;
    $statpot{'f13IL'}=-0.350;
    $statpot{'f13IK'}=-0.045;
    $statpot{'f13IM'}=-0.407;
    $statpot{'f13IF'}=-0.568;
    $statpot{'f13IP'}=-0.180;
    $statpot{'f13IS'}=-0.246;
    $statpot{'f13IT'}=-0.315;
    $statpot{'f13IW'}=-0.400;
    $statpot{'f13IY'}=-0.403;
    $statpot{'f13IV'}=-0.350;
    $statpot{'f13LA'}=-0.313;
    $statpot{'f13LR'}=-0.077;
    $statpot{'f13LN'}=-0.151;
    $statpot{'f13LD'}=-0.061;
    $statpot{'f13LC'}=-0.346;
    $statpot{'f13LQ'}=-0.115;
    $statpot{'f13LE'}=0.033;
    $statpot{'f13LG'}=-0.210;
    $statpot{'f13LH'}=-0.219;
    $statpot{'f13LI'}=-0.317;
    $statpot{'f13LL'}=-0.344;
    $statpot{'f13LK'}=0.023;
    $statpot{'f13LM'}=-0.423;
    $statpot{'f13LF'}=-0.422;
    $statpot{'f13LP'}=-0.164;
    $statpot{'f13LS'}=-0.236;
    $statpot{'f13LT'}=-0.172;
    $statpot{'f13LW'}=-0.256;
    $statpot{'f13LY'}=-0.428;
    $statpot{'f13LV'}=-0.325;
    $statpot{'f13KA'}=0.326;
    $statpot{'f13KR'}=0.455;
    $statpot{'f13KN'}=0.573;
    $statpot{'f13KD'}=0.594;
    $statpot{'f13KC'}=0.143;
    $statpot{'f13KQ'}=0.566;
    $statpot{'f13KE'}=0.803;
    $statpot{'f13KG'}=0.662;
    $statpot{'f13KH'}=0.403;
    $statpot{'f13KI'}=0.187;
    $statpot{'f13KL'}=0.243;
    $statpot{'f13KK'}=0.770;
    $statpot{'f13KM'}=0.165;
    $statpot{'f13KF'}=0.266;
    $statpot{'f13KP'}=0.638;
    $statpot{'f13KS'}=0.587;
    $statpot{'f13KT'}=0.483;
    $statpot{'f13KW'}=0.103;
    $statpot{'f13KY'}=0.339;
    $statpot{'f13KV'}=0.201;
    $statpot{'f13MA'}=-0.447;
    $statpot{'f13MR'}=-0.091;
    $statpot{'f13MN'}=-0.132;
    $statpot{'f13MD'}=-0.043;
    $statpot{'f13MC'}=-0.524;
    $statpot{'f13MQ'}=0.041;
    $statpot{'f13ME'}=0.225;
    $statpot{'f13MG'}=-0.138;
    $statpot{'f13MH'}=-0.394;
    $statpot{'f13MI'}=-0.419;
    $statpot{'f13ML'}=-0.384;
    $statpot{'f13MK'}=-0.008;
    $statpot{'f13MM'}=-0.439;
    $statpot{'f13MF'}=-0.486;
    $statpot{'f13MP'}=-0.125;
    $statpot{'f13MS'}=-0.268;
    $statpot{'f13MT'}=-0.174;
    $statpot{'f13MW'}=-0.409;
    $statpot{'f13MY'}=-0.427;
    $statpot{'f13MV'}=-0.342;
    $statpot{'f13FA'}=-0.385;
    $statpot{'f13FR'}=-0.168;
    $statpot{'f13FN'}=-0.199;
    $statpot{'f13FD'}=-0.093;
    $statpot{'f13FC'}=-0.500;
    $statpot{'f13FQ'}=-0.250;
    $statpot{'f13FE'}=0.120;
    $statpot{'f13FG'}=-0.196;
    $statpot{'f13FH'}=-0.274;
    $statpot{'f13FI'}=-0.545;
    $statpot{'f13FL'}=-0.449;
    $statpot{'f13FK'}=0.047;
    $statpot{'f13FM'}=-0.480;
    $statpot{'f13FF'}=-0.462;
    $statpot{'f13FP'}=-0.280;
    $statpot{'f13FS'}=-0.295;
    $statpot{'f13FT'}=-0.374;
    $statpot{'f13FW'}=-0.485;
    $statpot{'f13FY'}=-0.358;
    $statpot{'f13FV'}=-0.493;
    $statpot{'f13PA'}=0.101;
    $statpot{'f13PR'}=0.242;
    $statpot{'f13PN'}=0.344;
    $statpot{'f13PD'}=0.434;
    $statpot{'f13PC'}=-0.056;
    $statpot{'f13PQ'}=0.383;
    $statpot{'f13PE'}=0.446;
    $statpot{'f13PG'}=0.240;
    $statpot{'f13PH'}=0.105;
    $statpot{'f13PI'}=0.022;
    $statpot{'f13PL'}=0.031;
    $statpot{'f13PK'}=0.582;
    $statpot{'f13PM'}=-0.008;
    $statpot{'f13PF'}=-0.126;
    $statpot{'f13PP'}=0.249;
    $statpot{'f13PS'}=0.195;
    $statpot{'f13PT'}=0.215;
    $statpot{'f13PW'}=0.308;
    $statpot{'f13PY'}=0.087;
    $statpot{'f13PV'}=0.016;
    $statpot{'f13SA'}=-0.023;
    $statpot{'f13SR'}=0.263;
    $statpot{'f13SN'}=0.244;
    $statpot{'f13SD'}=0.320;
    $statpot{'f13SC'}=-0.145;
    $statpot{'f13SQ'}=0.194;
    $statpot{'f13SE'}=0.385;
    $statpot{'f13SG'}=0.145;
    $statpot{'f13SH'}=0.049;
    $statpot{'f13SI'}=-0.080;
    $statpot{'f13SL'}=-0.090;
    $statpot{'f13SK'}=0.497;
    $statpot{'f13SM'}=-0.133;
    $statpot{'f13SF'}=-0.055;
    $statpot{'f13SP'}=0.170;
    $statpot{'f13SS'}=0.131;
    $statpot{'f13ST'}=0.100;
    $statpot{'f13SW'}=-0.072;
    $statpot{'f13SY'}=-0.102;
    $statpot{'f13SV'}=0.010;
    $statpot{'f13TA'}=-0.009;
    $statpot{'f13TR'}=0.147;
    $statpot{'f13TN'}=0.275;
    $statpot{'f13TD'}=0.276;
    $statpot{'f13TC'}=-0.156;
    $statpot{'f13TQ'}=0.212;
    $statpot{'f13TE'}=0.287;
    $statpot{'f13TG'}=0.127;
    $statpot{'f13TH'}=0.075;
    $statpot{'f13TI'}=-0.171;
    $statpot{'f13TL'}=-0.026;
    $statpot{'f13TK'}=0.440;
    $statpot{'f13TM'}=-0.059;
    $statpot{'f13TF'}=-0.222;
    $statpot{'f13TP'}=0.209;
    $statpot{'f13TS'}=0.061;
    $statpot{'f13TT'}=0.059;
    $statpot{'f13TW'}=-0.043;
    $statpot{'f13TY'}=-0.067;
    $statpot{'f13TV'}=-0.116;
    $statpot{'f13WA'}=-0.325;
    $statpot{'f13WR'}=-0.167;
    $statpot{'f13WN'}=-0.181;
    $statpot{'f13WD'}=-0.205;
    $statpot{'f13WC'}=-0.603;
    $statpot{'f13WQ'}=-0.043;
    $statpot{'f13WE'}=-0.009;
    $statpot{'f13WG'}=-0.168;
    $statpot{'f13WH'}=-0.418;
    $statpot{'f13WI'}=-0.270;
    $statpot{'f13WL'}=-0.271;
    $statpot{'f13WK'}=-0.164;
    $statpot{'f13WM'}=-0.295;
    $statpot{'f13WF'}=-0.437;
    $statpot{'f13WP'}=0.072;
    $statpot{'f13WS'}=-0.275;
    $statpot{'f13WT'}=-0.273;
    $statpot{'f13WW'}=-0.900;
    $statpot{'f13WY'}=-0.279;
    $statpot{'f13WV'}=-0.372;
    $statpot{'f13YA'}=-0.295;
    $statpot{'f13YR'}=-0.131;
    $statpot{'f13YN'}=-0.048;
    $statpot{'f13YD'}=-0.065;
    $statpot{'f13YC'}=-0.322;
    $statpot{'f13YQ'}=-0.158;
    $statpot{'f13YE'}=-0.053;
    $statpot{'f13YG'}=-0.188;
    $statpot{'f13YH'}=-0.192;
    $statpot{'f13YI'}=-0.399;
    $statpot{'f13YL'}=-0.383;
    $statpot{'f13YK'}=0.207;
    $statpot{'f13YM'}=-0.320;
    $statpot{'f13YF'}=-0.347;
    $statpot{'f13YP'}=0.047;
    $statpot{'f13YS'}=-0.237;
    $statpot{'f13YT'}=-0.243;
    $statpot{'f13YW'}=-0.368;
    $statpot{'f13YY'}=-0.319;
    $statpot{'f13YV'}=-0.425;
    $statpot{'f13VA'}=-0.313;
    $statpot{'f13VR'}=-0.032;
    $statpot{'f13VN'}=-0.140;
    $statpot{'f13VD'}=-0.060;
    $statpot{'f13VC'}=-0.507;
    $statpot{'f13VQ'}=-0.138;
    $statpot{'f13VE'}=0.111;
    $statpot{'f13VG'}=-0.192;
    $statpot{'f13VH'}=-0.241;
    $statpot{'f13VI'}=-0.329;
    $statpot{'f13VL'}=-0.316;
    $statpot{'f13VK'}=0.030;
    $statpot{'f13VM'}=-0.378;
    $statpot{'f13VF'}=-0.498;
    $statpot{'f13VP'}=-0.171;
    $statpot{'f13VS'}=-0.200;
    $statpot{'f13VT'}=-0.244;
    $statpot{'f13VW'}=-0.361;
    $statpot{'f13VY'}=-0.400;
    $statpot{'f13VV'}=-0.388;
    $statpot{'a13AA'}=0.044;
    $statpot{'a13AR'}=-0.023;
    $statpot{'a13AN'}=0.026;
    $statpot{'a13AD'}=0.068;
    $statpot{'a13AC'}=-0.106;
    $statpot{'a13AQ'}=0.088;
    $statpot{'a13AE'}=0.076;
    $statpot{'a13AG'}=0.013;
    $statpot{'a13AH'}=-0.020;
    $statpot{'a13AI'}=-0.089;
    $statpot{'a13AL'}=-0.045;
    $statpot{'a13AK'}=0.065;
    $statpot{'a13AM'}=-0.150;
    $statpot{'a13AF'}=-0.103;
    $statpot{'a13AP'}=-0.009;
    $statpot{'a13AS'}=-0.067;
    $statpot{'a13AT'}=0.028;
    $statpot{'a13AW'}=0.017;
    $statpot{'a13AY'}=-0.013;
    $statpot{'a13AV'}=-0.053;
    $statpot{'a13RA'}=-0.081;
    $statpot{'a13RR'}=0.126;
    $statpot{'a13RN'}=0.193;
    $statpot{'a13RD'}=0.134;
    $statpot{'a13RC'}=-0.211;
    $statpot{'a13RQ'}=-0.033;
    $statpot{'a13RE'}=0.105;
    $statpot{'a13RG'}=0.131;
    $statpot{'a13RH'}=-0.070;
    $statpot{'a13RI'}=-0.132;
    $statpot{'a13RL'}=-0.189;
    $statpot{'a13RK'}=0.020;
    $statpot{'a13RM'}=-0.177;
    $statpot{'a13RF'}=-0.221;
    $statpot{'a13RP'}=-0.040;
    $statpot{'a13RS'}=0.094;
    $statpot{'a13RT'}=-0.092;
    $statpot{'a13RW'}=-0.185;
    $statpot{'a13RY'}=-0.156;
    $statpot{'a13RV'}=-0.173;
    $statpot{'a13NA'}=-0.040;
    $statpot{'a13NR'}=0.115;
    $statpot{'a13NN'}=0.195;
    $statpot{'a13ND'}=0.170;
    $statpot{'a13NC'}=-0.205;
    $statpot{'a13NQ'}=0.196;
    $statpot{'a13NE'}=0.138;
    $statpot{'a13NG'}=0.025;
    $statpot{'a13NH'}=0.121;
    $statpot{'a13NI'}=-0.339;
    $statpot{'a13NL'}=-0.280;
    $statpot{'a13NK'}=0.194;
    $statpot{'a13NM'}=-0.207;
    $statpot{'a13NF'}=-0.239;
    $statpot{'a13NP'}=0.063;
    $statpot{'a13NS'}=0.047;
    $statpot{'a13NT'}=-0.005;
    $statpot{'a13NW'}=-0.042;
    $statpot{'a13NY'}=-0.197;
    $statpot{'a13NV'}=-0.183;
    $statpot{'a13DA'}=-0.018;
    $statpot{'a13DR'}=0.062;
    $statpot{'a13DN'}=0.192;
    $statpot{'a13DD'}=0.206;
    $statpot{'a13DC'}=-0.129;
    $statpot{'a13DQ'}=0.141;
    $statpot{'a13DE'}=0.238;
    $statpot{'a13DG'}=0.170;
    $statpot{'a13DH'}=0.173;
    $statpot{'a13DI'}=-0.237;
    $statpot{'a13DL'}=-0.239;
    $statpot{'a13DK'}=0.083;
    $statpot{'a13DM'}=-0.236;
    $statpot{'a13DF'}=-0.256;
    $statpot{'a13DP'}=0.047;
    $statpot{'a13DS'}=0.084;
    $statpot{'a13DT'}=0.029;
    $statpot{'a13DW'}=-0.397;
    $statpot{'a13DY'}=-0.219;
    $statpot{'a13DV'}=-0.271;
    $statpot{'a13CA'}=-0.011;
    $statpot{'a13CR'}=0.018;
    $statpot{'a13CN'}=-0.011;
    $statpot{'a13CD'}=0.006;
    $statpot{'a13CC'}=-0.191;
    $statpot{'a13CQ'}=-0.084;
    $statpot{'a13CE'}=0.061;
    $statpot{'a13CG'}=-0.022;
    $statpot{'a13CH'}=-0.009;
    $statpot{'a13CI'}=0.028;
    $statpot{'a13CL'}=0.092;
    $statpot{'a13CK'}=-0.092;
    $statpot{'a13CM'}=0.054;
    $statpot{'a13CF'}=0.044;
    $statpot{'a13CP'}=-0.139;
    $statpot{'a13CS'}=-0.022;
    $statpot{'a13CT'}=0.031;
    $statpot{'a13CW'}=-0.097;
    $statpot{'a13CY'}=0.129;
    $statpot{'a13CV'}=-0.137;
    $statpot{'a13QA'}=0.053;
    $statpot{'a13QR'}=-0.017;
    $statpot{'a13QN'}=0.259;
    $statpot{'a13QD'}=0.161;
    $statpot{'a13QC'}=-0.192;
    $statpot{'a13QQ'}=-0.091;
    $statpot{'a13QE'}=0.124;
    $statpot{'a13QG'}=0.043;
    $statpot{'a13QH'}=0.070;
    $statpot{'a13QI'}=-0.270;
    $statpot{'a13QL'}=-0.234;
    $statpot{'a13QK'}=0.067;
    $statpot{'a13QM'}=-0.085;
    $statpot{'a13QF'}=-0.176;
    $statpot{'a13QP'}=0.030;
    $statpot{'a13QS'}=-0.004;
    $statpot{'a13QT'}=0.129;
    $statpot{'a13QW'}=-0.192;
    $statpot{'a13QY'}=-0.150;
    $statpot{'a13QV'}=-0.162;
    $statpot{'a13EA'}=-0.114;
    $statpot{'a13ER'}=-0.008;
    $statpot{'a13EN'}=0.078;
    $statpot{'a13ED'}=0.261;
    $statpot{'a13EC'}=-0.044;
    $statpot{'a13EQ'}=0.167;
    $statpot{'a13EE'}=0.154;
    $statpot{'a13EG'}=0.098;
    $statpot{'a13EH'}=0.211;
    $statpot{'a13EI'}=-0.166;
    $statpot{'a13EL'}=-0.261;
    $statpot{'a13EK'}=0.288;
    $statpot{'a13EM'}=-0.089;
    $statpot{'a13EF'}=-0.182;
    $statpot{'a13EP'}=0.272;
    $statpot{'a13ES'}=0.082;
    $statpot{'a13ET'}=-0.012;
    $statpot{'a13EW'}=-0.055;
    $statpot{'a13EY'}=-0.166;
    $statpot{'a13EV'}=-0.158;
    $statpot{'a13GA'}=-0.040;
    $statpot{'a13GR'}=0.149;
    $statpot{'a13GN'}=0.075;
    $statpot{'a13GD'}=0.267;
    $statpot{'a13GC'}=-0.083;
    $statpot{'a13GQ'}=0.075;
    $statpot{'a13GE'}=0.233;
    $statpot{'a13GG'}=0.026;
    $statpot{'a13GH'}=-0.016;
    $statpot{'a13GI'}=-0.171;
    $statpot{'a13GL'}=-0.135;
    $statpot{'a13GK'}=0.277;
    $statpot{'a13GM'}=-0.164;
    $statpot{'a13GF'}=-0.155;
    $statpot{'a13GP'}=0.061;
    $statpot{'a13GS'}=-0.022;
    $statpot{'a13GT'}=0.123;
    $statpot{'a13GW'}=-0.193;
    $statpot{'a13GY'}=-0.084;
    $statpot{'a13GV'}=-0.157;
    $statpot{'a13HA'}=-0.060;
    $statpot{'a13HR'}=-0.092;
    $statpot{'a13HN'}=0.247;
    $statpot{'a13HD'}=0.184;
    $statpot{'a13HC'}=0.118;
    $statpot{'a13HQ'}=0.143;
    $statpot{'a13HE'}=0.206;
    $statpot{'a13HG'}=-0.082;
    $statpot{'a13HH'}=0.088;
    $statpot{'a13HI'}=-0.220;
    $statpot{'a13HL'}=-0.175;
    $statpot{'a13HK'}=0.155;
    $statpot{'a13HM'}=-0.141;
    $statpot{'a13HF'}=0.058;
    $statpot{'a13HP'}=-0.049;
    $statpot{'a13HS'}=0.018;
    $statpot{'a13HT'}=-0.057;
    $statpot{'a13HW'}=-0.294;
    $statpot{'a13HY'}=-0.107;
    $statpot{'a13HV'}=-0.192;
    $statpot{'a13IA'}=-0.017;
    $statpot{'a13IR'}=0.002;
    $statpot{'a13IN'}=-0.054;
    $statpot{'a13ID'}=-0.039;
    $statpot{'a13IC'}=-0.039;
    $statpot{'a13IQ'}=-0.020;
    $statpot{'a13IE'}=0.124;
    $statpot{'a13IG'}=-0.119;
    $statpot{'a13IH'}=0.100;
    $statpot{'a13II'}=0.216;
    $statpot{'a13IL'}=0.137;
    $statpot{'a13IK'}=0.120;
    $statpot{'a13IM'}=0.009;
    $statpot{'a13IF'}=0.122;
    $statpot{'a13IP'}=-0.047;
    $statpot{'a13IS'}=-0.112;
    $statpot{'a13IT'}=0.034;
    $statpot{'a13IW'}=0.105;
    $statpot{'a13IY'}=-0.004;
    $statpot{'a13IV'}=0.115;
    $statpot{'a13LA'}=0.099;
    $statpot{'a13LR'}=0.024;
    $statpot{'a13LN'}=-0.012;
    $statpot{'a13LD'}=0.030;
    $statpot{'a13LC'}=0.226;
    $statpot{'a13LQ'}=-0.073;
    $statpot{'a13LE'}=0.012;
    $statpot{'a13LG'}=0.070;
    $statpot{'a13LH'}=-0.051;
    $statpot{'a13LI'}=0.073;
    $statpot{'a13LL'}=0.127;
    $statpot{'a13LK'}=0.079;
    $statpot{'a13LM'}=0.128;
    $statpot{'a13LF'}=0.149;
    $statpot{'a13LP'}=0.059;
    $statpot{'a13LS'}=-0.052;
    $statpot{'a13LT'}=-0.059;
    $statpot{'a13LW'}=0.094;
    $statpot{'a13LY'}=0.070;
    $statpot{'a13LV'}=0.083;
    $statpot{'a13KA'}=-0.018;
    $statpot{'a13KR'}=-0.013;
    $statpot{'a13KN'}=0.127;
    $statpot{'a13KD'}=0.163;
    $statpot{'a13KC'}=-0.218;
    $statpot{'a13KQ'}=0.086;
    $statpot{'a13KE'}=0.270;
    $statpot{'a13KG'}=0.155;
    $statpot{'a13KH'}=-0.020;
    $statpot{'a13KI'}=-0.140;
    $statpot{'a13KL'}=-0.147;
    $statpot{'a13KK'}=0.280;
    $statpot{'a13KM'}=-0.184;
    $statpot{'a13KF'}=-0.225;
    $statpot{'a13KP'}=0.080;
    $statpot{'a13KS'}=0.059;
    $statpot{'a13KT'}=-0.013;
    $statpot{'a13KW'}=-0.314;
    $statpot{'a13KY'}=0.026;
    $statpot{'a13KV'}=-0.188;
    $statpot{'a13MA'}=0.047;
    $statpot{'a13MR'}=0.007;
    $statpot{'a13MN'}=-0.048;
    $statpot{'a13MD'}=0.143;
    $statpot{'a13MC'}=0.137;
    $statpot{'a13MQ'}=0.090;
    $statpot{'a13ME'}=0.069;
    $statpot{'a13MG'}=-0.072;
    $statpot{'a13MH'}=-0.042;
    $statpot{'a13MI'}=0.032;
    $statpot{'a13ML'}=0.051;
    $statpot{'a13MK'}=-0.007;
    $statpot{'a13MM'}=-0.049;
    $statpot{'a13MF'}=0.001;
    $statpot{'a13MP'}=-0.153;
    $statpot{'a13MS'}=-0.094;
    $statpot{'a13MT'}=0.021;
    $statpot{'a13MW'}=0.095;
    $statpot{'a13MY'}=0.022;
    $statpot{'a13MV'}=0.089;
    $statpot{'a13FA'}=0.042;
    $statpot{'a13FR'}=-0.030;
    $statpot{'a13FN'}=-0.132;
    $statpot{'a13FD'}=0.041;
    $statpot{'a13FC'}=0.091;
    $statpot{'a13FQ'}=0.248;
    $statpot{'a13FE'}=-0.029;
    $statpot{'a13FG'}=-0.028;
    $statpot{'a13FH'}=0.060;
    $statpot{'a13FI'}=0.068;
    $statpot{'a13FL'}=0.210;
    $statpot{'a13FK'}=-0.024;
    $statpot{'a13FM'}=-0.011;
    $statpot{'a13FF'}=0.010;
    $statpot{'a13FP'}=0.074;
    $statpot{'a13FS'}=0.090;
    $statpot{'a13FT'}=-0.111;
    $statpot{'a13FW'}=-0.051;
    $statpot{'a13FY'}=-0.024;
    $statpot{'a13FV'}=0.001;
    $statpot{'a13PA'}=-0.103;
    $statpot{'a13PR'}=-0.051;
    $statpot{'a13PN'}=0.145;
    $statpot{'a13PD'}=0.057;
    $statpot{'a13PC'}=-0.190;
    $statpot{'a13PQ'}=-0.010;
    $statpot{'a13PE'}=0.344;
    $statpot{'a13PG'}=0.031;
    $statpot{'a13PH'}=-0.072;
    $statpot{'a13PI'}=-0.275;
    $statpot{'a13PL'}=-0.183;
    $statpot{'a13PK'}=0.120;
    $statpot{'a13PM'}=-0.276;
    $statpot{'a13PF'}=-0.148;
    $statpot{'a13PP'}=0.145;
    $statpot{'a13PS'}=0.033;
    $statpot{'a13PT'}=0.059;
    $statpot{'a13PW'}=-0.238;
    $statpot{'a13PY'}=-0.150;
    $statpot{'a13PV'}=-0.255;
    $statpot{'a13SA'}=-0.144;
    $statpot{'a13SR'}=0.072;
    $statpot{'a13SN'}=0.049;
    $statpot{'a13SD'}=0.167;
    $statpot{'a13SC'}=-0.112;
    $statpot{'a13SQ'}=-0.016;
    $statpot{'a13SE'}=0.113;
    $statpot{'a13SG'}=-0.036;
    $statpot{'a13SH'}=0.027;
    $statpot{'a13SI'}=-0.305;
    $statpot{'a13SL'}=-0.234;
    $statpot{'a13SK'}=0.127;
    $statpot{'a13SM'}=-0.261;
    $statpot{'a13SF'}=-0.229;
    $statpot{'a13SP'}=0.059;
    $statpot{'a13SS'}=0.028;
    $statpot{'a13ST'}=-0.020;
    $statpot{'a13SW'}=-0.199;
    $statpot{'a13SY'}=-0.209;
    $statpot{'a13SV'}=-0.218;
    $statpot{'a13TA'}=-0.089;
    $statpot{'a13TR'}=-0.056;
    $statpot{'a13TN'}=0.065;
    $statpot{'a13TD'}=0.101;
    $statpot{'a13TC'}=-0.010;
    $statpot{'a13TQ'}=0.122;
    $statpot{'a13TE'}=0.089;
    $statpot{'a13TG'}=0.053;
    $statpot{'a13TH'}=-0.125;
    $statpot{'a13TI'}=-0.175;
    $statpot{'a13TL'}=-0.229;
    $statpot{'a13TK'}=0.019;
    $statpot{'a13TM'}=-0.130;
    $statpot{'a13TF'}=-0.311;
    $statpot{'a13TP'}=0.066;
    $statpot{'a13TS'}=0.022;
    $statpot{'a13TT'}=0.001;
    $statpot{'a13TW'}=-0.354;
    $statpot{'a13TY'}=-0.072;
    $statpot{'a13TV'}=-0.172;
    $statpot{'a13WA'}=0.220;
    $statpot{'a13WR'}=0.253;
    $statpot{'a13WN'}=0.139;
    $statpot{'a13WD'}=-0.156;
    $statpot{'a13WC'}=0.223;
    $statpot{'a13WQ'}=-0.043;
    $statpot{'a13WE'}=0.235;
    $statpot{'a13WG'}=-0.054;
    $statpot{'a13WH'}=-0.180;
    $statpot{'a13WI'}=-0.116;
    $statpot{'a13WL'}=0.121;
    $statpot{'a13WK'}=-0.037;
    $statpot{'a13WM'}=-0.099;
    $statpot{'a13WF'}=-0.133;
    $statpot{'a13WP'}=-0.033;
    $statpot{'a13WS'}=0.066;
    $statpot{'a13WT'}=-0.101;
    $statpot{'a13WW'}=-0.073;
    $statpot{'a13WY'}=-0.253;
    $statpot{'a13WV'}=-0.082;
    $statpot{'a13YA'}=0.088;
    $statpot{'a13YR'}=-0.084;
    $statpot{'a13YN'}=-0.072;
    $statpot{'a13YD'}=-0.038;
    $statpot{'a13YC'}=0.032;
    $statpot{'a13YQ'}=0.141;
    $statpot{'a13YE'}=0.115;
    $statpot{'a13YG'}=0.030;
    $statpot{'a13YH'}=-0.218;
    $statpot{'a13YI'}=-0.011;
    $statpot{'a13YL'}=-0.015;
    $statpot{'a13YK'}=0.158;
    $statpot{'a13YM'}=-0.156;
    $statpot{'a13YF'}=-0.043;
    $statpot{'a13YP'}=-0.110;
    $statpot{'a13YS'}=-0.040;
    $statpot{'a13YT'}=0.186;
    $statpot{'a13YW'}=-0.133;
    $statpot{'a13YY'}=0.115;
    $statpot{'a13YV'}=0.076;
    $statpot{'a13VA'}=-0.002;
    $statpot{'a13VR'}=-0.085;
    $statpot{'a13VN'}=-0.026;
    $statpot{'a13VD'}=-0.101;
    $statpot{'a13VC'}=-0.167;
    $statpot{'a13VQ'}=0.001;
    $statpot{'a13VE'}=0.036;
    $statpot{'a13VG'}=-0.028;
    $statpot{'a13VH'}=-0.005;
    $statpot{'a13VI'}=0.074;
    $statpot{'a13VL'}=0.067;
    $statpot{'a13VK'}=-0.022;
    $statpot{'a13VM'}=0.159;
    $statpot{'a13VF'}=0.010;
    $statpot{'a13VP'}=-0.042;
    $statpot{'a13VS'}=0.036;
    $statpot{'a13VT'}=-0.001;
    $statpot{'a13VW'}=-0.098;
    $statpot{'a13VY'}=0.029;
    $statpot{'a13VV'}=-0.032;
    $statpot{'p14AA'}=-0.044;
    $statpot{'p14AR'}=0.025;
    $statpot{'p14AN'}=0.059;
    $statpot{'p14AD'}=0.038;
    $statpot{'p14AC'}=-0.090;
    $statpot{'p14AQ'}=-0.019;
    $statpot{'p14AE'}=0.149;
    $statpot{'p14AG'}=0.037;
    $statpot{'p14AH'}=-0.048;
    $statpot{'p14AI'}=-0.179;
    $statpot{'p14AL'}=-0.083;
    $statpot{'p14AK'}=0.142;
    $statpot{'p14AM'}=-0.116;
    $statpot{'p14AF'}=-0.157;
    $statpot{'p14AP'}=0.054;
    $statpot{'p14AS'}=-0.085;
    $statpot{'p14AT'}=-0.051;
    $statpot{'p14AW'}=-0.135;
    $statpot{'p14AY'}=-0.147;
    $statpot{'p14AV'}=-0.155;
    $statpot{'p14RA'}=0.025;
    $statpot{'p14RR'}=0.109;
    $statpot{'p14RN'}=0.147;
    $statpot{'p14RD'}=0.106;
    $statpot{'p14RC'}=-0.059;
    $statpot{'p14RQ'}=0.124;
    $statpot{'p14RE'}=0.243;
    $statpot{'p14RG'}=0.153;
    $statpot{'p14RH'}=0.010;
    $statpot{'p14RI'}=-0.047;
    $statpot{'p14RL'}=-0.013;
    $statpot{'p14RK'}=0.229;
    $statpot{'p14RM'}=-0.114;
    $statpot{'p14RF'}=-0.079;
    $statpot{'p14RP'}=0.153;
    $statpot{'p14RS'}=-0.012;
    $statpot{'p14RT'}=0.039;
    $statpot{'p14RW'}=-0.017;
    $statpot{'p14RY'}=-0.059;
    $statpot{'p14RV'}=-0.054;
    $statpot{'p14NA'}=0.059;
    $statpot{'p14NR'}=0.147;
    $statpot{'p14NN'}=0.149;
    $statpot{'p14ND'}=0.186;
    $statpot{'p14NC'}=0.014;
    $statpot{'p14NQ'}=0.087;
    $statpot{'p14NE'}=0.196;
    $statpot{'p14NG'}=0.111;
    $statpot{'p14NH'}=0.023;
    $statpot{'p14NI'}=-0.112;
    $statpot{'p14NL'}=-0.047;
    $statpot{'p14NK'}=0.195;
    $statpot{'p14NM'}=-0.099;
    $statpot{'p14NF'}=-0.069;
    $statpot{'p14NP'}=0.061;
    $statpot{'p14NS'}=0.015;
    $statpot{'p14NT'}=0.016;
    $statpot{'p14NW'}=-0.069;
    $statpot{'p14NY'}=0.014;
    $statpot{'p14NV'}=-0.039;
    $statpot{'p14DA'}=0.038;
    $statpot{'p14DR'}=0.106;
    $statpot{'p14DN'}=0.186;
    $statpot{'p14DD'}=0.202;
    $statpot{'p14DC'}=-0.064;
    $statpot{'p14DQ'}=0.136;
    $statpot{'p14DE'}=0.217;
    $statpot{'p14DG'}=0.188;
    $statpot{'p14DH'}=0.168;
    $statpot{'p14DI'}=-0.017;
    $statpot{'p14DL'}=0.019;
    $statpot{'p14DK'}=0.146;
    $statpot{'p14DM'}=0.007;
    $statpot{'p14DF'}=-0.037;
    $statpot{'p14DP'}=0.205;
    $statpot{'p14DS'}=0.152;
    $statpot{'p14DT'}=0.081;
    $statpot{'p14DW'}=0.013;
    $statpot{'p14DY'}=-0.006;
    $statpot{'p14DV'}=0.025;
    $statpot{'p14CA'}=-0.090;
    $statpot{'p14CR'}=-0.059;
    $statpot{'p14CN'}=0.014;
    $statpot{'p14CD'}=-0.064;
    $statpot{'p14CC'}=-0.083;
    $statpot{'p14CQ'}=-0.091;
    $statpot{'p14CE'}=0.035;
    $statpot{'p14CG'}=-0.021;
    $statpot{'p14CH'}=-0.221;
    $statpot{'p14CI'}=-0.156;
    $statpot{'p14CL'}=-0.171;
    $statpot{'p14CK'}=0.174;
    $statpot{'p14CM'}=-0.121;
    $statpot{'p14CF'}=-0.222;
    $statpot{'p14CP'}=-0.007;
    $statpot{'p14CS'}=-0.101;
    $statpot{'p14CT'}=-0.061;
    $statpot{'p14CW'}=-0.259;
    $statpot{'p14CY'}=-0.226;
    $statpot{'p14CV'}=-0.160;
    $statpot{'p14QA'}=-0.019;
    $statpot{'p14QR'}=0.124;
    $statpot{'p14QN'}=0.087;
    $statpot{'p14QD'}=0.136;
    $statpot{'p14QC'}=-0.091;
    $statpot{'p14QQ'}=-0.038;
    $statpot{'p14QE'}=0.185;
    $statpot{'p14QG'}=0.166;
    $statpot{'p14QH'}=0.137;
    $statpot{'p14QI'}=-0.090;
    $statpot{'p14QL'}=-0.054;
    $statpot{'p14QK'}=0.189;
    $statpot{'p14QM'}=-0.039;
    $statpot{'p14QF'}=-0.106;
    $statpot{'p14QP'}=0.174;
    $statpot{'p14QS'}=0.035;
    $statpot{'p14QT'}=0.020;
    $statpot{'p14QW'}=-0.048;
    $statpot{'p14QY'}=-0.039;
    $statpot{'p14QV'}=-0.025;
    $statpot{'p14EA'}=0.149;
    $statpot{'p14ER'}=0.243;
    $statpot{'p14EN'}=0.196;
    $statpot{'p14ED'}=0.217;
    $statpot{'p14EC'}=0.035;
    $statpot{'p14EQ'}=0.185;
    $statpot{'p14EE'}=0.168;
    $statpot{'p14EG'}=0.252;
    $statpot{'p14EH'}=0.160;
    $statpot{'p14EI'}=0.058;
    $statpot{'p14EL'}=0.103;
    $statpot{'p14EK'}=0.166;
    $statpot{'p14EM'}=0.182;
    $statpot{'p14EF'}=0.050;
    $statpot{'p14EP'}=0.217;
    $statpot{'p14ES'}=0.117;
    $statpot{'p14ET'}=0.167;
    $statpot{'p14EW'}=0.050;
    $statpot{'p14EY'}=0.084;
    $statpot{'p14EV'}=0.091;
    $statpot{'p14GA'}=0.037;
    $statpot{'p14GR'}=0.153;
    $statpot{'p14GN'}=0.111;
    $statpot{'p14GD'}=0.188;
    $statpot{'p14GC'}=-0.021;
    $statpot{'p14GQ'}=0.166;
    $statpot{'p14GE'}=0.252;
    $statpot{'p14GG'}=0.254;
    $statpot{'p14GH'}=0.087;
    $statpot{'p14GI'}=-0.068;
    $statpot{'p14GL'}=0.002;
    $statpot{'p14GK'}=0.279;
    $statpot{'p14GM'}=0.037;
    $statpot{'p14GF'}=-0.018;
    $statpot{'p14GP'}=0.165;
    $statpot{'p14GS'}=0.066;
    $statpot{'p14GT'}=0.094;
    $statpot{'p14GW'}=-0.012;
    $statpot{'p14GY'}=0.013;
    $statpot{'p14GV'}=-0.028;
    $statpot{'p14HA'}=-0.048;
    $statpot{'p14HR'}=0.010;
    $statpot{'p14HN'}=0.023;
    $statpot{'p14HD'}=0.168;
    $statpot{'p14HC'}=-0.221;
    $statpot{'p14HQ'}=0.137;
    $statpot{'p14HE'}=0.160;
    $statpot{'p14HG'}=0.087;
    $statpot{'p14HH'}=0.071;
    $statpot{'p14HI'}=-0.206;
    $statpot{'p14HL'}=-0.150;
    $statpot{'p14HK'}=0.102;
    $statpot{'p14HM'}=-0.118;
    $statpot{'p14HF'}=-0.202;
    $statpot{'p14HP'}=0.065;
    $statpot{'p14HS'}=0.029;
    $statpot{'p14HT'}=-0.031;
    $statpot{'p14HW'}=-0.119;
    $statpot{'p14HY'}=-0.160;
    $statpot{'p14HV'}=-0.153;
    $statpot{'p14IA'}=-0.179;
    $statpot{'p14IR'}=-0.047;
    $statpot{'p14IN'}=-0.112;
    $statpot{'p14ID'}=-0.017;
    $statpot{'p14IC'}=-0.156;
    $statpot{'p14IQ'}=-0.090;
    $statpot{'p14IE'}=0.058;
    $statpot{'p14IG'}=-0.068;
    $statpot{'p14IH'}=-0.206;
    $statpot{'p14II'}=-0.213;
    $statpot{'p14IL'}=-0.127;
    $statpot{'p14IK'}=0.011;
    $statpot{'p14IM'}=-0.162;
    $statpot{'p14IF'}=-0.243;
    $statpot{'p14IP'}=-0.045;
    $statpot{'p14IS'}=-0.127;
    $statpot{'p14IT'}=-0.128;
    $statpot{'p14IW'}=-0.200;
    $statpot{'p14IY'}=-0.245;
    $statpot{'p14IV'}=-0.204;
    $statpot{'p14LA'}=-0.083;
    $statpot{'p14LR'}=-0.013;
    $statpot{'p14LN'}=-0.047;
    $statpot{'p14LD'}=0.019;
    $statpot{'p14LC'}=-0.171;
    $statpot{'p14LQ'}=-0.054;
    $statpot{'p14LE'}=0.103;
    $statpot{'p14LG'}=0.002;
    $statpot{'p14LH'}=-0.150;
    $statpot{'p14LI'}=-0.127;
    $statpot{'p14LL'}=-0.088;
    $statpot{'p14LK'}=0.062;
    $statpot{'p14LM'}=-0.181;
    $statpot{'p14LF'}=-0.195;
    $statpot{'p14LP'}=0.052;
    $statpot{'p14LS'}=-0.081;
    $statpot{'p14LT'}=-0.074;
    $statpot{'p14LW'}=-0.230;
    $statpot{'p14LY'}=-0.221;
    $statpot{'p14LV'}=-0.135;
    $statpot{'p14KA'}=0.142;
    $statpot{'p14KR'}=0.229;
    $statpot{'p14KN'}=0.195;
    $statpot{'p14KD'}=0.146;
    $statpot{'p14KC'}=0.174;
    $statpot{'p14KQ'}=0.189;
    $statpot{'p14KE'}=0.166;
    $statpot{'p14KG'}=0.279;
    $statpot{'p14KH'}=0.102;
    $statpot{'p14KI'}=0.011;
    $statpot{'p14KL'}=0.062;
    $statpot{'p14KK'}=0.228;
    $statpot{'p14KM'}=0.104;
    $statpot{'p14KF'}=0.061;
    $statpot{'p14KP'}=0.158;
    $statpot{'p14KS'}=0.147;
    $statpot{'p14KT'}=0.115;
    $statpot{'p14KW'}=0.127;
    $statpot{'p14KY'}=0.117;
    $statpot{'p14KV'}=0.044;
    $statpot{'p14MA'}=-0.116;
    $statpot{'p14MR'}=-0.114;
    $statpot{'p14MN'}=-0.099;
    $statpot{'p14MD'}=0.007;
    $statpot{'p14MC'}=-0.121;
    $statpot{'p14MQ'}=-0.039;
    $statpot{'p14ME'}=0.182;
    $statpot{'p14MG'}=0.037;
    $statpot{'p14MH'}=-0.118;
    $statpot{'p14MI'}=-0.162;
    $statpot{'p14ML'}=-0.181;
    $statpot{'p14MK'}=0.104;
    $statpot{'p14MM'}=-0.081;
    $statpot{'p14MF'}=-0.335;
    $statpot{'p14MP'}=0.003;
    $statpot{'p14MS'}=-0.079;
    $statpot{'p14MT'}=-0.226;
    $statpot{'p14MW'}=-0.289;
    $statpot{'p14MY'}=-0.198;
    $statpot{'p14MV'}=-0.260;
    $statpot{'p14FA'}=-0.157;
    $statpot{'p14FR'}=-0.079;
    $statpot{'p14FN'}=-0.069;
    $statpot{'p14FD'}=-0.037;
    $statpot{'p14FC'}=-0.222;
    $statpot{'p14FQ'}=-0.106;
    $statpot{'p14FE'}=0.050;
    $statpot{'p14FG'}=-0.018;
    $statpot{'p14FH'}=-0.202;
    $statpot{'p14FI'}=-0.243;
    $statpot{'p14FL'}=-0.195;
    $statpot{'p14FK'}=0.061;
    $statpot{'p14FM'}=-0.335;
    $statpot{'p14FF'}=-0.228;
    $statpot{'p14FP'}=-0.062;
    $statpot{'p14FS'}=-0.188;
    $statpot{'p14FT'}=-0.088;
    $statpot{'p14FW'}=-0.355;
    $statpot{'p14FY'}=-0.252;
    $statpot{'p14FV'}=-0.221;
    $statpot{'p14PA'}=0.054;
    $statpot{'p14PR'}=0.153;
    $statpot{'p14PN'}=0.061;
    $statpot{'p14PD'}=0.205;
    $statpot{'p14PC'}=-0.007;
    $statpot{'p14PQ'}=0.174;
    $statpot{'p14PE'}=0.217;
    $statpot{'p14PG'}=0.165;
    $statpot{'p14PH'}=0.065;
    $statpot{'p14PI'}=-0.045;
    $statpot{'p14PL'}=0.052;
    $statpot{'p14PK'}=0.158;
    $statpot{'p14PM'}=0.003;
    $statpot{'p14PF'}=-0.062;
    $statpot{'p14PP'}=0.265;
    $statpot{'p14PS'}=0.069;
    $statpot{'p14PT'}=0.050;
    $statpot{'p14PW'}=0.108;
    $statpot{'p14PY'}=0.078;
    $statpot{'p14PV'}=0.015;
    $statpot{'p14SA'}=-0.085;
    $statpot{'p14SR'}=-0.012;
    $statpot{'p14SN'}=0.015;
    $statpot{'p14SD'}=0.152;
    $statpot{'p14SC'}=-0.101;
    $statpot{'p14SQ'}=0.035;
    $statpot{'p14SE'}=0.117;
    $statpot{'p14SG'}=0.066;
    $statpot{'p14SH'}=0.029;
    $statpot{'p14SI'}=-0.127;
    $statpot{'p14SL'}=-0.081;
    $statpot{'p14SK'}=0.147;
    $statpot{'p14SM'}=-0.079;
    $statpot{'p14SF'}=-0.188;
    $statpot{'p14SP'}=0.069;
    $statpot{'p14SS'}=0.054;
    $statpot{'p14ST'}=-0.049;
    $statpot{'p14SW'}=-0.016;
    $statpot{'p14SY'}=-0.122;
    $statpot{'p14SV'}=-0.118;
    $statpot{'p14TA'}=-0.051;
    $statpot{'p14TR'}=0.039;
    $statpot{'p14TN'}=0.016;
    $statpot{'p14TD'}=0.081;
    $statpot{'p14TC'}=-0.061;
    $statpot{'p14TQ'}=0.020;
    $statpot{'p14TE'}=0.167;
    $statpot{'p14TG'}=0.094;
    $statpot{'p14TH'}=-0.031;
    $statpot{'p14TI'}=-0.128;
    $statpot{'p14TL'}=-0.074;
    $statpot{'p14TK'}=0.115;
    $statpot{'p14TM'}=-0.226;
    $statpot{'p14TF'}=-0.088;
    $statpot{'p14TP'}=0.050;
    $statpot{'p14TS'}=-0.049;
    $statpot{'p14TT'}=0.023;
    $statpot{'p14TW'}=-0.179;
    $statpot{'p14TY'}=-0.083;
    $statpot{'p14TV'}=-0.129;
    $statpot{'p14WA'}=-0.135;
    $statpot{'p14WR'}=-0.017;
    $statpot{'p14WN'}=-0.069;
    $statpot{'p14WD'}=0.013;
    $statpot{'p14WC'}=-0.259;
    $statpot{'p14WQ'}=-0.048;
    $statpot{'p14WE'}=0.050;
    $statpot{'p14WG'}=-0.012;
    $statpot{'p14WH'}=-0.119;
    $statpot{'p14WI'}=-0.200;
    $statpot{'p14WL'}=-0.230;
    $statpot{'p14WK'}=0.127;
    $statpot{'p14WM'}=-0.289;
    $statpot{'p14WF'}=-0.355;
    $statpot{'p14WP'}=0.108;
    $statpot{'p14WS'}=-0.016;
    $statpot{'p14WT'}=-0.179;
    $statpot{'p14WW'}=0.023;
    $statpot{'p14WY'}=-0.143;
    $statpot{'p14WV'}=-0.161;
    $statpot{'p14YA'}=-0.147;
    $statpot{'p14YR'}=-0.059;
    $statpot{'p14YN'}=0.014;
    $statpot{'p14YD'}=-0.006;
    $statpot{'p14YC'}=-0.226;
    $statpot{'p14YQ'}=-0.039;
    $statpot{'p14YE'}=0.084;
    $statpot{'p14YG'}=0.013;
    $statpot{'p14YH'}=-0.160;
    $statpot{'p14YI'}=-0.245;
    $statpot{'p14YL'}=-0.221;
    $statpot{'p14YK'}=0.117;
    $statpot{'p14YM'}=-0.198;
    $statpot{'p14YF'}=-0.252;
    $statpot{'p14YP'}=0.078;
    $statpot{'p14YS'}=-0.122;
    $statpot{'p14YT'}=-0.083;
    $statpot{'p14YW'}=-0.143;
    $statpot{'p14YY'}=-0.174;
    $statpot{'p14YV'}=-0.239;
    $statpot{'p14VA'}=-0.155;
    $statpot{'p14VR'}=-0.054;
    $statpot{'p14VN'}=-0.039;
    $statpot{'p14VD'}=0.025;
    $statpot{'p14VC'}=-0.160;
    $statpot{'p14VQ'}=-0.025;
    $statpot{'p14VE'}=0.091;
    $statpot{'p14VG'}=-0.028;
    $statpot{'p14VH'}=-0.153;
    $statpot{'p14VI'}=-0.204;
    $statpot{'p14VL'}=-0.135;
    $statpot{'p14VK'}=0.044;
    $statpot{'p14VM'}=-0.260;
    $statpot{'p14VF'}=-0.221;
    $statpot{'p14VP'}=0.015;
    $statpot{'p14VS'}=-0.118;
    $statpot{'p14VT'}=-0.129;
    $statpot{'p14VW'}=-0.161;
    $statpot{'p14VY'}=-0.239;
    $statpot{'p14VV'}=-0.189;
    $statpot{'f14AA'}=-0.104;
    $statpot{'f14AR'}=0.116;
    $statpot{'f14AN'}=0.064;
    $statpot{'f14AD'}=0.187;
    $statpot{'f14AC'}=-0.275;
    $statpot{'f14AQ'}=-0.018;
    $statpot{'f14AE'}=0.126;
    $statpot{'f14AG'}=0.039;
    $statpot{'f14AH'}=-0.135;
    $statpot{'f14AI'}=-0.258;
    $statpot{'f14AL'}=-0.217;
    $statpot{'f14AK'}=0.189;
    $statpot{'f14AM'}=-0.268;
    $statpot{'f14AF'}=-0.257;
    $statpot{'f14AP'}=0.044;
    $statpot{'f14AS'}=-0.086;
    $statpot{'f14AT'}=-0.135;
    $statpot{'f14AW'}=-0.112;
    $statpot{'f14AY'}=-0.153;
    $statpot{'f14AV'}=-0.300;
    $statpot{'f14RA'}=0.141;
    $statpot{'f14RR'}=0.271;
    $statpot{'f14RN'}=0.380;
    $statpot{'f14RD'}=0.348;
    $statpot{'f14RC'}=0.288;
    $statpot{'f14RQ'}=0.219;
    $statpot{'f14RE'}=0.357;
    $statpot{'f14RG'}=0.416;
    $statpot{'f14RH'}=0.199;
    $statpot{'f14RI'}=-0.069;
    $statpot{'f14RL'}=0.066;
    $statpot{'f14RK'}=0.497;
    $statpot{'f14RM'}=-0.101;
    $statpot{'f14RF'}=-0.005;
    $statpot{'f14RP'}=0.498;
    $statpot{'f14RS'}=0.175;
    $statpot{'f14RT'}=0.196;
    $statpot{'f14RW'}=0.043;
    $statpot{'f14RY'}=-0.008;
    $statpot{'f14RV'}=-0.016;
    $statpot{'f14NA'}=0.189;
    $statpot{'f14NR'}=0.233;
    $statpot{'f14NN'}=0.203;
    $statpot{'f14ND'}=0.349;
    $statpot{'f14NC'}=0.062;
    $statpot{'f14NQ'}=0.366;
    $statpot{'f14NE'}=0.440;
    $statpot{'f14NG'}=0.284;
    $statpot{'f14NH'}=0.024;
    $statpot{'f14NI'}=-0.021;
    $statpot{'f14NL'}=-0.020;
    $statpot{'f14NK'}=0.595;
    $statpot{'f14NM'}=-0.063;
    $statpot{'f14NF'}=-0.063;
    $statpot{'f14NP'}=0.221;
    $statpot{'f14NS'}=0.124;
    $statpot{'f14NT'}=0.251;
    $statpot{'f14NW'}=0.047;
    $statpot{'f14NY'}=-0.044;
    $statpot{'f14NV'}=0.018;
    $statpot{'f14DA'}=0.288;
    $statpot{'f14DR'}=0.577;
    $statpot{'f14DN'}=0.488;
    $statpot{'f14DD'}=0.636;
    $statpot{'f14DC'}=0.037;
    $statpot{'f14DQ'}=0.415;
    $statpot{'f14DE'}=0.554;
    $statpot{'f14DG'}=0.477;
    $statpot{'f14DH'}=0.261;
    $statpot{'f14DI'}=0.131;
    $statpot{'f14DL'}=0.211;
    $statpot{'f14DK'}=0.706;
    $statpot{'f14DM'}=0.147;
    $statpot{'f14DF'}=0.057;
    $statpot{'f14DP'}=0.530;
    $statpot{'f14DS'}=0.369;
    $statpot{'f14DT'}=0.357;
    $statpot{'f14DW'}=-0.070;
    $statpot{'f14DY'}=0.102;
    $statpot{'f14DV'}=0.148;
    $statpot{'f14CA'}=-0.312;
    $statpot{'f14CR'}=-0.011;
    $statpot{'f14CN'}=0.055;
    $statpot{'f14CD'}=-0.056;
    $statpot{'f14CC'}=-0.383;
    $statpot{'f14CQ'}=-0.193;
    $statpot{'f14CE'}=0.044;
    $statpot{'f14CG'}=-0.183;
    $statpot{'f14CH'}=-0.243;
    $statpot{'f14CI'}=-0.564;
    $statpot{'f14CL'}=-0.395;
    $statpot{'f14CK'}=-0.007;
    $statpot{'f14CM'}=-0.619;
    $statpot{'f14CF'}=-0.414;
    $statpot{'f14CP'}=-0.051;
    $statpot{'f14CS'}=-0.103;
    $statpot{'f14CT'}=-0.345;
    $statpot{'f14CW'}=-0.544;
    $statpot{'f14CY'}=-0.451;
    $statpot{'f14CV'}=-0.371;
    $statpot{'f14QA'}=-0.013;
    $statpot{'f14QR'}=0.309;
    $statpot{'f14QN'}=0.266;
    $statpot{'f14QD'}=0.320;
    $statpot{'f14QC'}=-0.007;
    $statpot{'f14QQ'}=0.281;
    $statpot{'f14QE'}=0.496;
    $statpot{'f14QG'}=0.333;
    $statpot{'f14QH'}=0.058;
    $statpot{'f14QI'}=-0.014;
    $statpot{'f14QL'}=0.093;
    $statpot{'f14QK'}=0.571;
    $statpot{'f14QM'}=0.268;
    $statpot{'f14QF'}=-0.055;
    $statpot{'f14QP'}=0.429;
    $statpot{'f14QS'}=0.060;
    $statpot{'f14QT'}=0.228;
    $statpot{'f14QW'}=-0.055;
    $statpot{'f14QY'}=0.039;
    $statpot{'f14QV'}=0.047;
    $statpot{'f14EA'}=0.362;
    $statpot{'f14ER'}=0.440;
    $statpot{'f14EN'}=0.556;
    $statpot{'f14ED'}=0.607;
    $statpot{'f14EC'}=0.111;
    $statpot{'f14EQ'}=0.388;
    $statpot{'f14EE'}=0.701;
    $statpot{'f14EG'}=0.555;
    $statpot{'f14EH'}=0.246;
    $statpot{'f14EI'}=0.185;
    $statpot{'f14EL'}=0.188;
    $statpot{'f14EK'}=0.686;
    $statpot{'f14EM'}=0.174;
    $statpot{'f14EF'}=0.204;
    $statpot{'f14EP'}=0.412;
    $statpot{'f14ES'}=0.477;
    $statpot{'f14ET'}=0.435;
    $statpot{'f14EW'}=0.156;
    $statpot{'f14EY'}=0.235;
    $statpot{'f14EV'}=0.279;
    $statpot{'f14GA'}=0.063;
    $statpot{'f14GR'}=0.305;
    $statpot{'f14GN'}=0.276;
    $statpot{'f14GD'}=0.463;
    $statpot{'f14GC'}=-0.102;
    $statpot{'f14GQ'}=0.235;
    $statpot{'f14GE'}=0.451;
    $statpot{'f14GG'}=0.322;
    $statpot{'f14GH'}=0.064;
    $statpot{'f14GI'}=-0.116;
    $statpot{'f14GL'}=0.037;
    $statpot{'f14GK'}=0.500;
    $statpot{'f14GM'}=-0.098;
    $statpot{'f14GF'}=-0.083;
    $statpot{'f14GP'}=0.325;
    $statpot{'f14GS'}=0.239;
    $statpot{'f14GT'}=0.143;
    $statpot{'f14GW'}=-0.024;
    $statpot{'f14GY'}=0.040;
    $statpot{'f14GV'}=0.003;
    $statpot{'f14HA'}=-0.129;
    $statpot{'f14HR'}=0.173;
    $statpot{'f14HN'}=0.075;
    $statpot{'f14HD'}=0.217;
    $statpot{'f14HC'}=-0.230;
    $statpot{'f14HQ'}=0.123;
    $statpot{'f14HE'}=0.218;
    $statpot{'f14HG'}=0.053;
    $statpot{'f14HH'}=-0.181;
    $statpot{'f14HI'}=-0.189;
    $statpot{'f14HL'}=-0.226;
    $statpot{'f14HK'}=0.344;
    $statpot{'f14HM'}=-0.163;
    $statpot{'f14HF'}=-0.165;
    $statpot{'f14HP'}=0.008;
    $statpot{'f14HS'}=0.079;
    $statpot{'f14HT'}=-0.038;
    $statpot{'f14HW'}=-0.255;
    $statpot{'f14HY'}=-0.141;
    $statpot{'f14HV'}=-0.229;
    $statpot{'f14IA'}=-0.263;
    $statpot{'f14IR'}=-0.120;
    $statpot{'f14IN'}=-0.215;
    $statpot{'f14ID'}=-0.092;
    $statpot{'f14IC'}=-0.526;
    $statpot{'f14IQ'}=-0.176;
    $statpot{'f14IE'}=-0.044;
    $statpot{'f14IG'}=-0.260;
    $statpot{'f14IH'}=-0.296;
    $statpot{'f14II'}=-0.456;
    $statpot{'f14IL'}=-0.417;
    $statpot{'f14IK'}=-0.097;
    $statpot{'f14IM'}=-0.358;
    $statpot{'f14IF'}=-0.411;
    $statpot{'f14IP'}=-0.149;
    $statpot{'f14IS'}=-0.280;
    $statpot{'f14IT'}=-0.334;
    $statpot{'f14IW'}=-0.316;
    $statpot{'f14IY'}=-0.417;
    $statpot{'f14IV'}=-0.463;
    $statpot{'f14LA'}=-0.254;
    $statpot{'f14LR'}=-0.105;
    $statpot{'f14LN'}=-0.198;
    $statpot{'f14LD'}=-0.066;
    $statpot{'f14LC'}=-0.456;
    $statpot{'f14LQ'}=-0.077;
    $statpot{'f14LE'}=-0.012;
    $statpot{'f14LG'}=-0.134;
    $statpot{'f14LH'}=-0.382;
    $statpot{'f14LI'}=-0.411;
    $statpot{'f14LL'}=-0.208;
    $statpot{'f14LK'}=0.015;
    $statpot{'f14LM'}=-0.407;
    $statpot{'f14LF'}=-0.331;
    $statpot{'f14LP'}=-0.112;
    $statpot{'f14LS'}=-0.191;
    $statpot{'f14LT'}=-0.289;
    $statpot{'f14LW'}=-0.419;
    $statpot{'f14LY'}=-0.287;
    $statpot{'f14LV'}=-0.379;
    $statpot{'f14KA'}=0.375;
    $statpot{'f14KR'}=0.545;
    $statpot{'f14KN'}=0.644;
    $statpot{'f14KD'}=0.648;
    $statpot{'f14KC'}=0.007;
    $statpot{'f14KQ'}=0.576;
    $statpot{'f14KE'}=0.686;
    $statpot{'f14KG'}=0.573;
    $statpot{'f14KH'}=0.343;
    $statpot{'f14KI'}=0.154;
    $statpot{'f14KL'}=0.251;
    $statpot{'f14KK'}=0.719;
    $statpot{'f14KM'}=0.225;
    $statpot{'f14KF'}=0.311;
    $statpot{'f14KP'}=0.540;
    $statpot{'f14KS'}=0.569;
    $statpot{'f14KT'}=0.457;
    $statpot{'f14KW'}=0.231;
    $statpot{'f14KY'}=0.184;
    $statpot{'f14KV'}=0.257;
    $statpot{'f14MA'}=-0.414;
    $statpot{'f14MR'}=-0.180;
    $statpot{'f14MN'}=-0.164;
    $statpot{'f14MD'}=-0.059;
    $statpot{'f14MC'}=-0.630;
    $statpot{'f14MQ'}=0.003;
    $statpot{'f14ME'}=0.129;
    $statpot{'f14MG'}=-0.179;
    $statpot{'f14MH'}=-0.255;
    $statpot{'f14MI'}=-0.333;
    $statpot{'f14ML'}=-0.365;
    $statpot{'f14MK'}=0.106;
    $statpot{'f14MM'}=-0.371;
    $statpot{'f14MF'}=-0.387;
    $statpot{'f14MP'}=-0.159;
    $statpot{'f14MS'}=-0.194;
    $statpot{'f14MT'}=-0.226;
    $statpot{'f14MW'}=-0.430;
    $statpot{'f14MY'}=-0.398;
    $statpot{'f14MV'}=-0.391;
    $statpot{'f14FA'}=-0.279;
    $statpot{'f14FR'}=-0.143;
    $statpot{'f14FN'}=-0.243;
    $statpot{'f14FD'}=-0.168;
    $statpot{'f14FC'}=-0.539;
    $statpot{'f14FQ'}=-0.212;
    $statpot{'f14FE'}=-0.086;
    $statpot{'f14FG'}=-0.176;
    $statpot{'f14FH'}=-0.320;
    $statpot{'f14FI'}=-0.338;
    $statpot{'f14FL'}=-0.331;
    $statpot{'f14FK'}=0.013;
    $statpot{'f14FM'}=-0.365;
    $statpot{'f14FF'}=-0.450;
    $statpot{'f14FP'}=-0.130;
    $statpot{'f14FS'}=-0.273;
    $statpot{'f14FT'}=-0.341;
    $statpot{'f14FW'}=-0.466;
    $statpot{'f14FY'}=-0.347;
    $statpot{'f14FV'}=-0.306;
    $statpot{'f14PA'}=0.190;
    $statpot{'f14PR'}=0.422;
    $statpot{'f14PN'}=0.256;
    $statpot{'f14PD'}=0.439;
    $statpot{'f14PC'}=0.049;
    $statpot{'f14PQ'}=0.408;
    $statpot{'f14PE'}=0.342;
    $statpot{'f14PG'}=0.393;
    $statpot{'f14PH'}=0.159;
    $statpot{'f14PI'}=0.011;
    $statpot{'f14PL'}=0.090;
    $statpot{'f14PK'}=0.451;
    $statpot{'f14PM'}=0.079;
    $statpot{'f14PF'}=0.090;
    $statpot{'f14PP'}=0.296;
    $statpot{'f14PS'}=0.330;
    $statpot{'f14PT'}=0.208;
    $statpot{'f14PW'}=0.222;
    $statpot{'f14PY'}=0.126;
    $statpot{'f14PV'}=0.058;
    $statpot{'f14SA'}=-0.013;
    $statpot{'f14SR'}=0.149;
    $statpot{'f14SN'}=0.134;
    $statpot{'f14SD'}=0.279;
    $statpot{'f14SC'}=-0.060;
    $statpot{'f14SQ'}=0.045;
    $statpot{'f14SE'}=0.386;
    $statpot{'f14SG'}=0.237;
    $statpot{'f14SH'}=0.045;
    $statpot{'f14SI'}=-0.106;
    $statpot{'f14SL'}=-0.061;
    $statpot{'f14SK'}=0.485;
    $statpot{'f14SM'}=-0.182;
    $statpot{'f14SF'}=-0.137;
    $statpot{'f14SP'}=0.333;
    $statpot{'f14SS'}=0.098;
    $statpot{'f14ST'}=0.116;
    $statpot{'f14SW'}=-0.185;
    $statpot{'f14SY'}=-0.134;
    $statpot{'f14SV'}=-0.106;
    $statpot{'f14TA'}=-0.084;
    $statpot{'f14TR'}=0.114;
    $statpot{'f14TN'}=0.153;
    $statpot{'f14TD'}=0.326;
    $statpot{'f14TC'}=-0.282;
    $statpot{'f14TQ'}=0.173;
    $statpot{'f14TE'}=0.303;
    $statpot{'f14TG'}=0.149;
    $statpot{'f14TH'}=0.055;
    $statpot{'f14TI'}=-0.168;
    $statpot{'f14TL'}=-0.115;
    $statpot{'f14TK'}=0.353;
    $statpot{'f14TM'}=-0.162;
    $statpot{'f14TF'}=-0.176;
    $statpot{'f14TP'}=0.083;
    $statpot{'f14TS'}=0.092;
    $statpot{'f14TT'}=0.228;
    $statpot{'f14TW'}=-0.199;
    $statpot{'f14TY'}=-0.136;
    $statpot{'f14TV'}=-0.159;
    $statpot{'f14WA'}=-0.242;
    $statpot{'f14WR'}=-0.034;
    $statpot{'f14WN'}=-0.101;
    $statpot{'f14WD'}=-0.264;
    $statpot{'f14WC'}=-0.459;
    $statpot{'f14WQ'}=-0.137;
    $statpot{'f14WE'}=0.035;
    $statpot{'f14WG'}=-0.142;
    $statpot{'f14WH'}=-0.352;
    $statpot{'f14WI'}=-0.243;
    $statpot{'f14WL'}=-0.404;
    $statpot{'f14WK'}=0.102;
    $statpot{'f14WM'}=-0.520;
    $statpot{'f14WF'}=-0.477;
    $statpot{'f14WP'}=-0.063;
    $statpot{'f14WS'}=-0.236;
    $statpot{'f14WT'}=-0.289;
    $statpot{'f14WW'}=-0.418;
    $statpot{'f14WY'}=-0.419;
    $statpot{'f14WV'}=-0.364;
    $statpot{'f14YA'}=-0.192;
    $statpot{'f14YR'}=-0.214;
    $statpot{'f14YN'}=-0.143;
    $statpot{'f14YD'}=-0.105;
    $statpot{'f14YC'}=-0.399;
    $statpot{'f14YQ'}=-0.154;
    $statpot{'f14YE'}=0.065;
    $statpot{'f14YG'}=-0.066;
    $statpot{'f14YH'}=-0.269;
    $statpot{'f14YI'}=-0.388;
    $statpot{'f14YL'}=-0.231;
    $statpot{'f14YK'}=0.158;
    $statpot{'f14YM'}=-0.478;
    $statpot{'f14YF'}=-0.358;
    $statpot{'f14YP'}=-0.159;
    $statpot{'f14YS'}=-0.187;
    $statpot{'f14YT'}=-0.277;
    $statpot{'f14YW'}=-0.322;
    $statpot{'f14YY'}=-0.364;
    $statpot{'f14YV'}=-0.306;
    $statpot{'f14VA'}=-0.329;
    $statpot{'f14VR'}=-0.134;
    $statpot{'f14VN'}=-0.144;
    $statpot{'f14VD'}=-0.036;
    $statpot{'f14VC'}=-0.405;
    $statpot{'f14VQ'}=-0.149;
    $statpot{'f14VE'}=0.035;
    $statpot{'f14VG'}=-0.102;
    $statpot{'f14VH'}=-0.278;
    $statpot{'f14VI'}=-0.415;
    $statpot{'f14VL'}=-0.336;
    $statpot{'f14VK'}=0.054;
    $statpot{'f14VM'}=-0.399;
    $statpot{'f14VF'}=-0.348;
    $statpot{'f14VP'}=-0.089;
    $statpot{'f14VS'}=-0.250;
    $statpot{'f14VT'}=-0.291;
    $statpot{'f14VW'}=-0.322;
    $statpot{'f14VY'}=-0.363;
    $statpot{'f14VV'}=-0.263;
    $statpot{'a14AA'}=0.004;
    $statpot{'a14AR'}=-0.082;
    $statpot{'a14AN'}=0.029;
    $statpot{'a14AD'}=-0.043;
    $statpot{'a14AC'}=-0.084;
    $statpot{'a14AQ'}=-0.057;
    $statpot{'a14AE'}=0.051;
    $statpot{'a14AG'}=0.038;
    $statpot{'a14AH'}=0.082;
    $statpot{'a14AI'}=0.006;
    $statpot{'a14AL'}=0.006;
    $statpot{'a14AK'}=0.108;
    $statpot{'a14AM'}=-0.148;
    $statpot{'a14AF'}=0.023;
    $statpot{'a14AP'}=0.014;
    $statpot{'a14AS'}=-0.030;
    $statpot{'a14AT'}=0.057;
    $statpot{'a14AW'}=-0.060;
    $statpot{'a14AY'}=-0.026;
    $statpot{'a14AV'}=-0.089;
    $statpot{'a14RA'}=-0.105;
    $statpot{'a14RR'}=-0.054;
    $statpot{'a14RN'}=-0.059;
    $statpot{'a14RD'}=0.117;
    $statpot{'a14RC'}=-0.189;
    $statpot{'a14RQ'}=0.242;
    $statpot{'a14RE'}=0.205;
    $statpot{'a14RG'}=0.017;
    $statpot{'a14RH'}=0.098;
    $statpot{'a14RI'}=-0.048;
    $statpot{'a14RL'}=-0.133;
    $statpot{'a14RK'}=0.045;
    $statpot{'a14RM'}=-0.206;
    $statpot{'a14RF'}=-0.182;
    $statpot{'a14RP'}=0.013;
    $statpot{'a14RS'}=-0.044;
    $statpot{'a14RT'}=-0.023;
    $statpot{'a14RW'}=-0.119;
    $statpot{'a14RY'}=-0.220;
    $statpot{'a14RV'}=-0.113;
    $statpot{'a14NA'}=-0.087;
    $statpot{'a14NR'}=0.056;
    $statpot{'a14NN'}=0.219;
    $statpot{'a14ND'}=0.138;
    $statpot{'a14NC'}=0.012;
    $statpot{'a14NQ'}=0.050;
    $statpot{'a14NE'}=0.234;
    $statpot{'a14NG'}=0.123;
    $statpot{'a14NH'}=0.141;
    $statpot{'a14NI'}=-0.241;
    $statpot{'a14NL'}=-0.209;
    $statpot{'a14NK'}=0.229;
    $statpot{'a14NM'}=-0.073;
    $statpot{'a14NF'}=-0.315;
    $statpot{'a14NP'}=0.084;
    $statpot{'a14NS'}=0.004;
    $statpot{'a14NT'}=-0.049;
    $statpot{'a14NW'}=-0.044;
    $statpot{'a14NY'}=-0.117;
    $statpot{'a14NV'}=-0.270;
    $statpot{'a14DA'}=-0.124;
    $statpot{'a14DR'}=-0.045;
    $statpot{'a14DN'}=0.032;
    $statpot{'a14DD'}=0.083;
    $statpot{'a14DC'}=0.004;
    $statpot{'a14DQ'}=0.144;
    $statpot{'a14DE'}=0.234;
    $statpot{'a14DG'}=0.148;
    $statpot{'a14DH'}=0.039;
    $statpot{'a14DI'}=-0.270;
    $statpot{'a14DL'}=-0.247;
    $statpot{'a14DK'}=0.178;
    $statpot{'a14DM'}=-0.282;
    $statpot{'a14DF'}=-0.278;
    $statpot{'a14DP'}=0.145;
    $statpot{'a14DS'}=-0.006;
    $statpot{'a14DT'}=-0.029;
    $statpot{'a14DW'}=-0.209;
    $statpot{'a14DY'}=-0.200;
    $statpot{'a14DV'}=-0.229;
    $statpot{'a14CA'}=-0.035;
    $statpot{'a14CR'}=0.061;
    $statpot{'a14CN'}=0.018;
    $statpot{'a14CD'}=0.106;
    $statpot{'a14CC'}=-0.040;
    $statpot{'a14CQ'}=-0.056;
    $statpot{'a14CE'}=-0.037;
    $statpot{'a14CG'}=-0.084;
    $statpot{'a14CH'}=0.043;
    $statpot{'a14CI'}=0.105;
    $statpot{'a14CL'}=-0.064;
    $statpot{'a14CK'}=-0.113;
    $statpot{'a14CM'}=-0.156;
    $statpot{'a14CF'}=0.028;
    $statpot{'a14CP'}=-0.202;
    $statpot{'a14CS'}=-0.175;
    $statpot{'a14CT'}=0.280;
    $statpot{'a14CW'}=0.062;
    $statpot{'a14CY'}=0.005;
    $statpot{'a14CV'}=-0.078;
    $statpot{'a14QA'}=-0.063;
    $statpot{'a14QR'}=0.152;
    $statpot{'a14QN'}=0.134;
    $statpot{'a14QD'}=0.229;
    $statpot{'a14QC'}=-0.237;
    $statpot{'a14QQ'}=0.005;
    $statpot{'a14QE'}=0.011;
    $statpot{'a14QG'}=0.073;
    $statpot{'a14QH'}=0.023;
    $statpot{'a14QI'}=-0.143;
    $statpot{'a14QL'}=-0.124;
    $statpot{'a14QK'}=0.154;
    $statpot{'a14QM'}=-0.132;
    $statpot{'a14QF'}=-0.120;
    $statpot{'a14QP'}=0.081;
    $statpot{'a14QS'}=0.005;
    $statpot{'a14QT'}=-0.098;
    $statpot{'a14QW'}=-0.078;
    $statpot{'a14QY'}=-0.193;
    $statpot{'a14QV'}=-0.236;
    $statpot{'a14EA'}=-0.145;
    $statpot{'a14ER'}=0.133;
    $statpot{'a14EN'}=0.143;
    $statpot{'a14ED'}=0.194;
    $statpot{'a14EC'}=-0.098;
    $statpot{'a14EQ'}=0.090;
    $statpot{'a14EE'}=0.205;
    $statpot{'a14EG'}=0.122;
    $statpot{'a14EH'}=0.104;
    $statpot{'a14EI'}=-0.140;
    $statpot{'a14EL'}=-0.200;
    $statpot{'a14EK'}=0.157;
    $statpot{'a14EM'}=-0.064;
    $statpot{'a14EF'}=-0.151;
    $statpot{'a14EP'}=0.139;
    $statpot{'a14ES'}=0.074;
    $statpot{'a14ET'}=0.049;
    $statpot{'a14EW'}=-0.115;
    $statpot{'a14EY'}=-0.102;
    $statpot{'a14EV'}=-0.226;
    $statpot{'a14GA'}=0.013;
    $statpot{'a14GR'}=0.107;
    $statpot{'a14GN'}=0.130;
    $statpot{'a14GD'}=0.159;
    $statpot{'a14GC'}=-0.168;
    $statpot{'a14GQ'}=0.162;
    $statpot{'a14GE'}=0.204;
    $statpot{'a14GG'}=0.185;
    $statpot{'a14GH'}=0.070;
    $statpot{'a14GI'}=-0.175;
    $statpot{'a14GL'}=-0.142;
    $statpot{'a14GK'}=0.230;
    $statpot{'a14GM'}=-0.119;
    $statpot{'a14GF'}=-0.033;
    $statpot{'a14GP'}=0.073;
    $statpot{'a14GS'}=0.014;
    $statpot{'a14GT'}=0.066;
    $statpot{'a14GW'}=-0.113;
    $statpot{'a14GY'}=0.006;
    $statpot{'a14GV'}=-0.118;
    $statpot{'a14HA'}=0.073;
    $statpot{'a14HR'}=0.124;
    $statpot{'a14HN'}=0.084;
    $statpot{'a14HD'}=0.079;
    $statpot{'a14HC'}=0.026;
    $statpot{'a14HQ'}=-0.040;
    $statpot{'a14HE'}=0.131;
    $statpot{'a14HG'}=0.083;
    $statpot{'a14HH'}=-0.173;
    $statpot{'a14HI'}=-0.114;
    $statpot{'a14HL'}=-0.205;
    $statpot{'a14HK'}=0.134;
    $statpot{'a14HM'}=-0.150;
    $statpot{'a14HF'}=-0.283;
    $statpot{'a14HP'}=0.022;
    $statpot{'a14HS'}=0.026;
    $statpot{'a14HT'}=0.064;
    $statpot{'a14HW'}=-0.129;
    $statpot{'a14HY'}=-0.260;
    $statpot{'a14HV'}=-0.285;
    $statpot{'a14IA'}=0.015;
    $statpot{'a14IR'}=0.012;
    $statpot{'a14IN'}=-0.037;
    $statpot{'a14ID'}=-0.070;
    $statpot{'a14IC'}=0.036;
    $statpot{'a14IQ'}=0.039;
    $statpot{'a14IE'}=0.086;
    $statpot{'a14IG'}=-0.003;
    $statpot{'a14IH'}=0.025;
    $statpot{'a14II'}=0.112;
    $statpot{'a14IL'}=0.068;
    $statpot{'a14IK'}=0.035;
    $statpot{'a14IM'}=0.010;
    $statpot{'a14IF'}=0.199;
    $statpot{'a14IP'}=-0.079;
    $statpot{'a14IS'}=-0.044;
    $statpot{'a14IT'}=0.026;
    $statpot{'a14IW'}=0.203;
    $statpot{'a14IY'}=0.049;
    $statpot{'a14IV'}=0.130;
    $statpot{'a14LA'}=0.060;
    $statpot{'a14LR'}=0.049;
    $statpot{'a14LN'}=-0.021;
    $statpot{'a14LD'}=-0.000;
    $statpot{'a14LC'}=0.031;
    $statpot{'a14LQ'}=0.052;
    $statpot{'a14LE'}=-0.020;
    $statpot{'a14LG'}=0.044;
    $statpot{'a14LH'}=-0.001;
    $statpot{'a14LI'}=0.057;
    $statpot{'a14LL'}=0.179;
    $statpot{'a14LK'}=0.078;
    $statpot{'a14LM'}=0.162;
    $statpot{'a14LF'}=0.161;
    $statpot{'a14LP'}=0.063;
    $statpot{'a14LS'}=-0.079;
    $statpot{'a14LT'}=0.032;
    $statpot{'a14LW'}=0.009;
    $statpot{'a14LY'}=0.106;
    $statpot{'a14LV'}=0.160;
    $statpot{'a14KA'}=-0.050;
    $statpot{'a14KR'}=0.013;
    $statpot{'a14KN'}=0.194;
    $statpot{'a14KD'}=0.216;
    $statpot{'a14KC'}=-0.125;
    $statpot{'a14KQ'}=0.151;
    $statpot{'a14KE'}=0.156;
    $statpot{'a14KG'}=0.173;
    $statpot{'a14KH'}=0.135;
    $statpot{'a14KI'}=-0.205;
    $statpot{'a14KL'}=-0.138;
    $statpot{'a14KK'}=0.094;
    $statpot{'a14KM'}=-0.183;
    $statpot{'a14KF'}=-0.247;
    $statpot{'a14KP'}=0.080;
    $statpot{'a14KS'}=0.096;
    $statpot{'a14KT'}=-0.035;
    $statpot{'a14KW'}=-0.087;
    $statpot{'a14KY'}=-0.017;
    $statpot{'a14KV'}=-0.205;
    $statpot{'a14MA'}=0.073;
    $statpot{'a14MR'}=-0.121;
    $statpot{'a14MN'}=0.047;
    $statpot{'a14MD'}=-0.103;
    $statpot{'a14MC'}=-0.136;
    $statpot{'a14MQ'}=0.116;
    $statpot{'a14ME'}=-0.023;
    $statpot{'a14MG'}=-0.024;
    $statpot{'a14MH'}=-0.040;
    $statpot{'a14MI'}=-0.027;
    $statpot{'a14ML'}=0.087;
    $statpot{'a14MK'}=-0.088;
    $statpot{'a14MM'}=-0.062;
    $statpot{'a14MF'}=0.117;
    $statpot{'a14MP'}=0.058;
    $statpot{'a14MS'}=-0.012;
    $statpot{'a14MT'}=0.056;
    $statpot{'a14MW'}=-0.399;
    $statpot{'a14MY'}=-0.102;
    $statpot{'a14MV'}=-0.035;
    $statpot{'a14FA'}=0.055;
    $statpot{'a14FR'}=-0.038;
    $statpot{'a14FN'}=-0.137;
    $statpot{'a14FD'}=-0.061;
    $statpot{'a14FC'}=0.267;
    $statpot{'a14FQ'}=0.067;
    $statpot{'a14FE'}=0.146;
    $statpot{'a14FG'}=0.083;
    $statpot{'a14FH'}=-0.110;
    $statpot{'a14FI'}=0.068;
    $statpot{'a14FL'}=0.161;
    $statpot{'a14FK'}=-0.007;
    $statpot{'a14FM'}=0.079;
    $statpot{'a14FF'}=0.008;
    $statpot{'a14FP'}=0.088;
    $statpot{'a14FS'}=-0.082;
    $statpot{'a14FT'}=0.022;
    $statpot{'a14FW'}=0.021;
    $statpot{'a14FY'}=0.002;
    $statpot{'a14FV'}=0.099;
    $statpot{'a14PA'}=-0.123;
    $statpot{'a14PR'}=0.067;
    $statpot{'a14PN'}=0.051;
    $statpot{'a14PD'}=0.217;
    $statpot{'a14PC'}=-0.283;
    $statpot{'a14PQ'}=0.097;
    $statpot{'a14PE'}=0.201;
    $statpot{'a14PG'}=0.017;
    $statpot{'a14PH'}=-0.120;
    $statpot{'a14PI'}=-0.238;
    $statpot{'a14PL'}=-0.151;
    $statpot{'a14PK'}=0.146;
    $statpot{'a14PM'}=-0.197;
    $statpot{'a14PF'}=-0.148;
    $statpot{'a14PP'}=0.164;
    $statpot{'a14PS'}=-0.002;
    $statpot{'a14PT'}=-0.112;
    $statpot{'a14PW'}=-0.115;
    $statpot{'a14PY'}=-0.227;
    $statpot{'a14PV'}=-0.179;
    $statpot{'a14SA'}=-0.109;
    $statpot{'a14SR'}=-0.022;
    $statpot{'a14SN'}=-0.005;
    $statpot{'a14SD'}=0.065;
    $statpot{'a14SC'}=-0.214;
    $statpot{'a14SQ'}=0.020;
    $statpot{'a14SE'}=0.145;
    $statpot{'a14SG'}=0.014;
    $statpot{'a14SH'}=0.062;
    $statpot{'a14SI'}=-0.241;
    $statpot{'a14SL'}=-0.216;
    $statpot{'a14SK'}=0.155;
    $statpot{'a14SM'}=-0.027;
    $statpot{'a14SF'}=-0.233;
    $statpot{'a14SP'}=-0.004;
    $statpot{'a14SS'}=0.074;
    $statpot{'a14ST'}=-0.027;
    $statpot{'a14SW'}=-0.272;
    $statpot{'a14SY'}=-0.076;
    $statpot{'a14SV'}=-0.207;
    $statpot{'a14TA'}=-0.007;
    $statpot{'a14TR'}=0.054;
    $statpot{'a14TN'}=0.034;
    $statpot{'a14TD'}=-0.007;
    $statpot{'a14TC'}=0.171;
    $statpot{'a14TQ'}=-0.053;
    $statpot{'a14TE'}=0.159;
    $statpot{'a14TG'}=0.060;
    $statpot{'a14TH'}=-0.035;
    $statpot{'a14TI'}=-0.186;
    $statpot{'a14TL'}=-0.181;
    $statpot{'a14TK'}=0.039;
    $statpot{'a14TM'}=-0.030;
    $statpot{'a14TF'}=-0.187;
    $statpot{'a14TP'}=-0.002;
    $statpot{'a14TS'}=-0.005;
    $statpot{'a14TT'}=-0.104;
    $statpot{'a14TW'}=-0.143;
    $statpot{'a14TY'}=-0.171;
    $statpot{'a14TV'}=-0.195;
    $statpot{'a14WA'}=0.112;
    $statpot{'a14WR'}=-0.043;
    $statpot{'a14WN'}=0.121;
    $statpot{'a14WD'}=0.012;
    $statpot{'a14WC'}=-0.080;
    $statpot{'a14WQ'}=0.014;
    $statpot{'a14WE'}=-0.004;
    $statpot{'a14WG'}=0.016;
    $statpot{'a14WH'}=0.000;
    $statpot{'a14WI'}=0.083;
    $statpot{'a14WL'}=-0.015;
    $statpot{'a14WK'}=0.024;
    $statpot{'a14WM'}=-0.289;
    $statpot{'a14WF'}=0.041;
    $statpot{'a14WP'}=0.177;
    $statpot{'a14WS'}=-0.221;
    $statpot{'a14WT'}=-0.034;
    $statpot{'a14WW'}=-0.172;
    $statpot{'a14WY'}=0.255;
    $statpot{'a14WV'}=0.207;
    $statpot{'a14YA'}=0.025;
    $statpot{'a14YR'}=0.002;
    $statpot{'a14YN'}=-0.009;
    $statpot{'a14YD'}=0.001;
    $statpot{'a14YC'}=-0.072;
    $statpot{'a14YQ'}=0.004;
    $statpot{'a14YE'}=0.055;
    $statpot{'a14YG'}=0.129;
    $statpot{'a14YH'}=-0.123;
    $statpot{'a14YI'}=0.000;
    $statpot{'a14YL'}=0.022;
    $statpot{'a14YK'}=0.006;
    $statpot{'a14YM'}=0.026;
    $statpot{'a14YF'}=0.020;
    $statpot{'a14YP'}=0.061;
    $statpot{'a14YS'}=-0.013;
    $statpot{'a14YT'}=-0.002;
    $statpot{'a14YW'}=0.078;
    $statpot{'a14YY'}=-0.056;
    $statpot{'a14YV'}=-0.010;
    $statpot{'a14VA'}=-0.048;
    $statpot{'a14VR'}=0.020;
    $statpot{'a14VN'}=-0.118;
    $statpot{'a14VD'}=-0.066;
    $statpot{'a14VC'}=-0.027;
    $statpot{'a14VQ'}=-0.043;
    $statpot{'a14VE'}=-0.025;
    $statpot{'a14VG'}=-0.006;
    $statpot{'a14VH'}=-0.233;
    $statpot{'a14VI'}=0.040;
    $statpot{'a14VL'}=0.086;
    $statpot{'a14VK'}=-0.041;
    $statpot{'a14VM'}=-0.021;
    $statpot{'a14VF'}=0.174;
    $statpot{'a14VP'}=-0.032;
    $statpot{'a14VS'}=-0.042;
    $statpot{'a14VT'}=-0.036;
    $statpot{'a14VW'}=0.135;
    $statpot{'a14VY'}=0.079;
    $statpot{'a14VV'}=0.004;
    $statpot{'p15AA'}=-0.044;
    $statpot{'p15AR'}=0.019;
    $statpot{'p15AN'}=0.001;
    $statpot{'p15AD'}=0.082;
    $statpot{'p15AC'}=-0.108;
    $statpot{'p15AQ'}=0.006;
    $statpot{'p15AE'}=0.103;
    $statpot{'p15AG'}=0.056;
    $statpot{'p15AH'}=0.033;
    $statpot{'p15AI'}=-0.109;
    $statpot{'p15AL'}=-0.152;
    $statpot{'p15AK'}=0.143;
    $statpot{'p15AM'}=-0.097;
    $statpot{'p15AF'}=-0.164;
    $statpot{'p15AP'}=0.042;
    $statpot{'p15AS'}=-0.044;
    $statpot{'p15AT'}=-0.078;
    $statpot{'p15AW'}=-0.178;
    $statpot{'p15AY'}=-0.067;
    $statpot{'p15AV'}=-0.134;
    $statpot{'p15RA'}=0.019;
    $statpot{'p15RR'}=0.064;
    $statpot{'p15RN'}=0.071;
    $statpot{'p15RD'}=0.135;
    $statpot{'p15RC'}=0.024;
    $statpot{'p15RQ'}=0.096;
    $statpot{'p15RE'}=0.145;
    $statpot{'p15RG'}=0.114;
    $statpot{'p15RH'}=-0.007;
    $statpot{'p15RI'}=-0.070;
    $statpot{'p15RL'}=-0.058;
    $statpot{'p15RK'}=0.180;
    $statpot{'p15RM'}=0.017;
    $statpot{'p15RF'}=-0.016;
    $statpot{'p15RP'}=0.132;
    $statpot{'p15RS'}=0.063;
    $statpot{'p15RT'}=0.097;
    $statpot{'p15RW'}=-0.058;
    $statpot{'p15RY'}=-0.006;
    $statpot{'p15RV'}=-0.110;
    $statpot{'p15NA'}=0.001;
    $statpot{'p15NR'}=0.071;
    $statpot{'p15NN'}=0.094;
    $statpot{'p15ND'}=0.169;
    $statpot{'p15NC'}=-0.029;
    $statpot{'p15NQ'}=0.076;
    $statpot{'p15NE'}=0.203;
    $statpot{'p15NG'}=0.075;
    $statpot{'p15NH'}=-0.000;
    $statpot{'p15NI'}=-0.138;
    $statpot{'p15NL'}=-0.009;
    $statpot{'p15NK'}=0.212;
    $statpot{'p15NM'}=0.054;
    $statpot{'p15NF'}=0.079;
    $statpot{'p15NP'}=0.116;
    $statpot{'p15NS'}=0.049;
    $statpot{'p15NT'}=0.108;
    $statpot{'p15NW'}=-0.105;
    $statpot{'p15NY'}=0.082;
    $statpot{'p15NV'}=-0.084;
    $statpot{'p15DA'}=0.082;
    $statpot{'p15DR'}=0.135;
    $statpot{'p15DN'}=0.169;
    $statpot{'p15DD'}=0.227;
    $statpot{'p15DC'}=0.046;
    $statpot{'p15DQ'}=0.123;
    $statpot{'p15DE'}=0.192;
    $statpot{'p15DG'}=0.197;
    $statpot{'p15DH'}=0.046;
    $statpot{'p15DI'}=-0.035;
    $statpot{'p15DL'}=0.020;
    $statpot{'p15DK'}=0.197;
    $statpot{'p15DM'}=0.037;
    $statpot{'p15DF'}=-0.014;
    $statpot{'p15DP'}=0.162;
    $statpot{'p15DS'}=0.144;
    $statpot{'p15DT'}=0.074;
    $statpot{'p15DW'}=0.044;
    $statpot{'p15DY'}=0.023;
    $statpot{'p15DV'}=-0.037;
    $statpot{'p15CA'}=-0.108;
    $statpot{'p15CR'}=0.024;
    $statpot{'p15CN'}=-0.029;
    $statpot{'p15CD'}=0.046;
    $statpot{'p15CC'}=0.323;
    $statpot{'p15CQ'}=-0.084;
    $statpot{'p15CE'}=0.063;
    $statpot{'p15CG'}=-0.027;
    $statpot{'p15CH'}=-0.104;
    $statpot{'p15CI'}=-0.198;
    $statpot{'p15CL'}=-0.167;
    $statpot{'p15CK'}=0.065;
    $statpot{'p15CM'}=-0.017;
    $statpot{'p15CF'}=-0.314;
    $statpot{'p15CP'}=0.012;
    $statpot{'p15CS'}=-0.152;
    $statpot{'p15CT'}=-0.085;
    $statpot{'p15CW'}=-0.267;
    $statpot{'p15CY'}=-0.165;
    $statpot{'p15CV'}=-0.239;
    $statpot{'p15QA'}=0.006;
    $statpot{'p15QR'}=0.096;
    $statpot{'p15QN'}=0.076;
    $statpot{'p15QD'}=0.123;
    $statpot{'p15QC'}=-0.084;
    $statpot{'p15QQ'}=0.244;
    $statpot{'p15QE'}=0.156;
    $statpot{'p15QG'}=0.184;
    $statpot{'p15QH'}=0.092;
    $statpot{'p15QI'}=-0.039;
    $statpot{'p15QL'}=-0.014;
    $statpot{'p15QK'}=0.239;
    $statpot{'p15QM'}=-0.071;
    $statpot{'p15QF'}=-0.032;
    $statpot{'p15QP'}=0.129;
    $statpot{'p15QS'}=0.047;
    $statpot{'p15QT'}=0.048;
    $statpot{'p15QW'}=-0.075;
    $statpot{'p15QY'}=-0.081;
    $statpot{'p15QV'}=-0.029;
    $statpot{'p15EA'}=0.103;
    $statpot{'p15ER'}=0.145;
    $statpot{'p15EN'}=0.203;
    $statpot{'p15ED'}=0.192;
    $statpot{'p15EC'}=0.063;
    $statpot{'p15EQ'}=0.156;
    $statpot{'p15EE'}=0.263;
    $statpot{'p15EG'}=0.207;
    $statpot{'p15EH'}=0.105;
    $statpot{'p15EI'}=0.062;
    $statpot{'p15EL'}=0.091;
    $statpot{'p15EK'}=0.240;
    $statpot{'p15EM'}=0.039;
    $statpot{'p15EF'}=0.079;
    $statpot{'p15EP'}=0.122;
    $statpot{'p15ES'}=0.043;
    $statpot{'p15ET'}=0.044;
    $statpot{'p15EW'}=-0.035;
    $statpot{'p15EY'}=0.045;
    $statpot{'p15EV'}=0.026;
    $statpot{'p15GA'}=0.056;
    $statpot{'p15GR'}=0.114;
    $statpot{'p15GN'}=0.075;
    $statpot{'p15GD'}=0.197;
    $statpot{'p15GC'}=-0.027;
    $statpot{'p15GQ'}=0.184;
    $statpot{'p15GE'}=0.207;
    $statpot{'p15GG'}=0.194;
    $statpot{'p15GH'}=0.082;
    $statpot{'p15GI'}=-0.025;
    $statpot{'p15GL'}=0.056;
    $statpot{'p15GK'}=0.274;
    $statpot{'p15GM'}=-0.045;
    $statpot{'p15GF'}=0.007;
    $statpot{'p15GP'}=0.127;
    $statpot{'p15GS'}=0.103;
    $statpot{'p15GT'}=0.096;
    $statpot{'p15GW'}=0.010;
    $statpot{'p15GY'}=0.025;
    $statpot{'p15GV'}=-0.048;
    $statpot{'p15HA'}=0.033;
    $statpot{'p15HR'}=-0.007;
    $statpot{'p15HN'}=-0.000;
    $statpot{'p15HD'}=0.046;
    $statpot{'p15HC'}=-0.104;
    $statpot{'p15HQ'}=0.092;
    $statpot{'p15HE'}=0.105;
    $statpot{'p15HG'}=0.082;
    $statpot{'p15HH'}=-0.015;
    $statpot{'p15HI'}=-0.158;
    $statpot{'p15HL'}=-0.121;
    $statpot{'p15HK'}=0.130;
    $statpot{'p15HM'}=-0.245;
    $statpot{'p15HF'}=-0.188;
    $statpot{'p15HP'}=0.133;
    $statpot{'p15HS'}=-0.108;
    $statpot{'p15HT'}=0.018;
    $statpot{'p15HW'}=-0.020;
    $statpot{'p15HY'}=-0.128;
    $statpot{'p15HV'}=-0.156;
    $statpot{'p15IA'}=-0.109;
    $statpot{'p15IR'}=-0.070;
    $statpot{'p15IN'}=-0.138;
    $statpot{'p15ID'}=-0.035;
    $statpot{'p15IC'}=-0.198;
    $statpot{'p15IQ'}=-0.039;
    $statpot{'p15IE'}=0.062;
    $statpot{'p15IG'}=-0.025;
    $statpot{'p15IH'}=-0.158;
    $statpot{'p15II'}=-0.225;
    $statpot{'p15IL'}=-0.132;
    $statpot{'p15IK'}=0.020;
    $statpot{'p15IM'}=-0.210;
    $statpot{'p15IF'}=-0.218;
    $statpot{'p15IP'}=-0.035;
    $statpot{'p15IS'}=-0.053;
    $statpot{'p15IT'}=-0.202;
    $statpot{'p15IW'}=-0.258;
    $statpot{'p15IY'}=-0.226;
    $statpot{'p15IV'}=-0.206;
    $statpot{'p15LA'}=-0.152;
    $statpot{'p15LR'}=-0.058;
    $statpot{'p15LN'}=-0.009;
    $statpot{'p15LD'}=0.020;
    $statpot{'p15LC'}=-0.167;
    $statpot{'p15LQ'}=-0.014;
    $statpot{'p15LE'}=0.091;
    $statpot{'p15LG'}=0.056;
    $statpot{'p15LH'}=-0.121;
    $statpot{'p15LI'}=-0.132;
    $statpot{'p15LL'}=-0.085;
    $statpot{'p15LK'}=0.050;
    $statpot{'p15LM'}=-0.203;
    $statpot{'p15LF'}=-0.138;
    $statpot{'p15LP'}=0.001;
    $statpot{'p15LS'}=-0.084;
    $statpot{'p15LT'}=-0.088;
    $statpot{'p15LW'}=-0.134;
    $statpot{'p15LY'}=-0.165;
    $statpot{'p15LV'}=-0.185;
    $statpot{'p15KA'}=0.143;
    $statpot{'p15KR'}=0.180;
    $statpot{'p15KN'}=0.212;
    $statpot{'p15KD'}=0.197;
    $statpot{'p15KC'}=0.065;
    $statpot{'p15KQ'}=0.239;
    $statpot{'p15KE'}=0.240;
    $statpot{'p15KG'}=0.274;
    $statpot{'p15KH'}=0.130;
    $statpot{'p15KI'}=0.020;
    $statpot{'p15KL'}=0.050;
    $statpot{'p15KK'}=0.212;
    $statpot{'p15KM'}=0.056;
    $statpot{'p15KF'}=-0.016;
    $statpot{'p15KP'}=0.147;
    $statpot{'p15KS'}=0.166;
    $statpot{'p15KT'}=0.189;
    $statpot{'p15KW'}=0.041;
    $statpot{'p15KY'}=0.173;
    $statpot{'p15KV'}=0.021;
    $statpot{'p15MA'}=-0.097;
    $statpot{'p15MR'}=0.017;
    $statpot{'p15MN'}=0.054;
    $statpot{'p15MD'}=0.037;
    $statpot{'p15MC'}=-0.017;
    $statpot{'p15MQ'}=-0.071;
    $statpot{'p15ME'}=0.039;
    $statpot{'p15MG'}=-0.045;
    $statpot{'p15MH'}=-0.245;
    $statpot{'p15MI'}=-0.210;
    $statpot{'p15ML'}=-0.203;
    $statpot{'p15MK'}=0.056;
    $statpot{'p15MM'}=-0.319;
    $statpot{'p15MF'}=-0.246;
    $statpot{'p15MP'}=0.013;
    $statpot{'p15MS'}=-0.202;
    $statpot{'p15MT'}=-0.068;
    $statpot{'p15MW'}=-0.271;
    $statpot{'p15MY'}=-0.178;
    $statpot{'p15MV'}=-0.211;
    $statpot{'p15FA'}=-0.164;
    $statpot{'p15FR'}=-0.016;
    $statpot{'p15FN'}=0.079;
    $statpot{'p15FD'}=-0.014;
    $statpot{'p15FC'}=-0.314;
    $statpot{'p15FQ'}=-0.032;
    $statpot{'p15FE'}=0.079;
    $statpot{'p15FG'}=0.007;
    $statpot{'p15FH'}=-0.188;
    $statpot{'p15FI'}=-0.218;
    $statpot{'p15FL'}=-0.138;
    $statpot{'p15FK'}=-0.016;
    $statpot{'p15FM'}=-0.246;
    $statpot{'p15FF'}=-0.227;
    $statpot{'p15FP'}=-0.037;
    $statpot{'p15FS'}=-0.080;
    $statpot{'p15FT'}=-0.195;
    $statpot{'p15FW'}=-0.256;
    $statpot{'p15FY'}=-0.161;
    $statpot{'p15FV'}=-0.128;
    $statpot{'p15PA'}=0.042;
    $statpot{'p15PR'}=0.132;
    $statpot{'p15PN'}=0.116;
    $statpot{'p15PD'}=0.162;
    $statpot{'p15PC'}=0.012;
    $statpot{'p15PQ'}=0.129;
    $statpot{'p15PE'}=0.122;
    $statpot{'p15PG'}=0.127;
    $statpot{'p15PH'}=0.133;
    $statpot{'p15PI'}=-0.035;
    $statpot{'p15PL'}=0.001;
    $statpot{'p15PK'}=0.147;
    $statpot{'p15PM'}=0.013;
    $statpot{'p15PF'}=-0.037;
    $statpot{'p15PP'}=0.090;
    $statpot{'p15PS'}=-0.001;
    $statpot{'p15PT'}=0.072;
    $statpot{'p15PW'}=0.109;
    $statpot{'p15PY'}=0.064;
    $statpot{'p15PV'}=-0.046;
    $statpot{'p15SA'}=-0.044;
    $statpot{'p15SR'}=0.063;
    $statpot{'p15SN'}=0.049;
    $statpot{'p15SD'}=0.144;
    $statpot{'p15SC'}=-0.152;
    $statpot{'p15SQ'}=0.047;
    $statpot{'p15SE'}=0.043;
    $statpot{'p15SG'}=0.103;
    $statpot{'p15SH'}=-0.108;
    $statpot{'p15SI'}=-0.053;
    $statpot{'p15SL'}=-0.084;
    $statpot{'p15SK'}=0.166;
    $statpot{'p15SM'}=-0.202;
    $statpot{'p15SF'}=-0.080;
    $statpot{'p15SP'}=-0.001;
    $statpot{'p15SS'}=0.056;
    $statpot{'p15ST'}=-0.051;
    $statpot{'p15SW'}=-0.033;
    $statpot{'p15SY'}=-0.028;
    $statpot{'p15SV'}=-0.093;
    $statpot{'p15TA'}=-0.078;
    $statpot{'p15TR'}=0.097;
    $statpot{'p15TN'}=0.108;
    $statpot{'p15TD'}=0.074;
    $statpot{'p15TC'}=-0.085;
    $statpot{'p15TQ'}=0.048;
    $statpot{'p15TE'}=0.044;
    $statpot{'p15TG'}=0.096;
    $statpot{'p15TH'}=0.018;
    $statpot{'p15TI'}=-0.202;
    $statpot{'p15TL'}=-0.088;
    $statpot{'p15TK'}=0.189;
    $statpot{'p15TM'}=-0.068;
    $statpot{'p15TF'}=-0.195;
    $statpot{'p15TP'}=0.072;
    $statpot{'p15TS'}=-0.051;
    $statpot{'p15TT'}=-0.078;
    $statpot{'p15TW'}=-0.135;
    $statpot{'p15TY'}=-0.102;
    $statpot{'p15TV'}=-0.115;
    $statpot{'p15WA'}=-0.178;
    $statpot{'p15WR'}=-0.058;
    $statpot{'p15WN'}=-0.105;
    $statpot{'p15WD'}=0.044;
    $statpot{'p15WC'}=-0.267;
    $statpot{'p15WQ'}=-0.075;
    $statpot{'p15WE'}=-0.035;
    $statpot{'p15WG'}=0.010;
    $statpot{'p15WH'}=-0.020;
    $statpot{'p15WI'}=-0.258;
    $statpot{'p15WL'}=-0.134;
    $statpot{'p15WK'}=0.041;
    $statpot{'p15WM'}=-0.271;
    $statpot{'p15WF'}=-0.256;
    $statpot{'p15WP'}=0.109;
    $statpot{'p15WS'}=-0.033;
    $statpot{'p15WT'}=-0.135;
    $statpot{'p15WW'}=-0.085;
    $statpot{'p15WY'}=-0.202;
    $statpot{'p15WV'}=-0.232;
    $statpot{'p15YA'}=-0.067;
    $statpot{'p15YR'}=-0.006;
    $statpot{'p15YN'}=0.082;
    $statpot{'p15YD'}=0.023;
    $statpot{'p15YC'}=-0.165;
    $statpot{'p15YQ'}=-0.081;
    $statpot{'p15YE'}=0.045;
    $statpot{'p15YG'}=0.025;
    $statpot{'p15YH'}=-0.128;
    $statpot{'p15YI'}=-0.226;
    $statpot{'p15YL'}=-0.165;
    $statpot{'p15YK'}=0.173;
    $statpot{'p15YM'}=-0.178;
    $statpot{'p15YF'}=-0.161;
    $statpot{'p15YP'}=0.064;
    $statpot{'p15YS'}=-0.028;
    $statpot{'p15YT'}=-0.102;
    $statpot{'p15YW'}=-0.202;
    $statpot{'p15YY'}=-0.196;
    $statpot{'p15YV'}=-0.169;
    $statpot{'p15VA'}=-0.134;
    $statpot{'p15VR'}=-0.110;
    $statpot{'p15VN'}=-0.084;
    $statpot{'p15VD'}=-0.037;
    $statpot{'p15VC'}=-0.239;
    $statpot{'p15VQ'}=-0.029;
    $statpot{'p15VE'}=0.026;
    $statpot{'p15VG'}=-0.048;
    $statpot{'p15VH'}=-0.156;
    $statpot{'p15VI'}=-0.206;
    $statpot{'p15VL'}=-0.185;
    $statpot{'p15VK'}=0.021;
    $statpot{'p15VM'}=-0.211;
    $statpot{'p15VF'}=-0.128;
    $statpot{'p15VP'}=-0.046;
    $statpot{'p15VS'}=-0.093;
    $statpot{'p15VT'}=-0.115;
    $statpot{'p15VW'}=-0.232;
    $statpot{'p15VY'}=-0.169;
    $statpot{'p15VV'}=-0.177;
    $statpot{'f15AA'}=-0.134;
    $statpot{'f15AR'}=-0.022;
    $statpot{'f15AN'}=0.024;
    $statpot{'f15AD'}=0.100;
    $statpot{'f15AC'}=-0.325;
    $statpot{'f15AQ'}=0.146;
    $statpot{'f15AE'}=0.091;
    $statpot{'f15AG'}=0.026;
    $statpot{'f15AH'}=-0.038;
    $statpot{'f15AI'}=-0.230;
    $statpot{'f15AL'}=-0.178;
    $statpot{'f15AK'}=0.208;
    $statpot{'f15AM'}=-0.301;
    $statpot{'f15AF'}=-0.234;
    $statpot{'f15AP'}=0.081;
    $statpot{'f15AS'}=-0.001;
    $statpot{'f15AT'}=-0.005;
    $statpot{'f15AW'}=-0.144;
    $statpot{'f15AY'}=-0.147;
    $statpot{'f15AV'}=-0.187;
    $statpot{'f15RA'}=0.063;
    $statpot{'f15RR'}=0.250;
    $statpot{'f15RN'}=0.305;
    $statpot{'f15RD'}=0.226;
    $statpot{'f15RC'}=-0.222;
    $statpot{'f15RQ'}=0.251;
    $statpot{'f15RE'}=0.487;
    $statpot{'f15RG'}=0.351;
    $statpot{'f15RH'}=0.174;
    $statpot{'f15RI'}=-0.030;
    $statpot{'f15RL'}=-0.028;
    $statpot{'f15RK'}=0.349;
    $statpot{'f15RM'}=-0.139;
    $statpot{'f15RF'}=-0.037;
    $statpot{'f15RP'}=0.224;
    $statpot{'f15RS'}=0.213;
    $statpot{'f15RT'}=0.194;
    $statpot{'f15RW'}=0.037;
    $statpot{'f15RY'}=-0.058;
    $statpot{'f15RV'}=0.021;
    $statpot{'f15NA'}=0.116;
    $statpot{'f15NR'}=0.256;
    $statpot{'f15NN'}=0.243;
    $statpot{'f15ND'}=0.345;
    $statpot{'f15NC'}=0.026;
    $statpot{'f15NQ'}=0.270;
    $statpot{'f15NE'}=0.423;
    $statpot{'f15NG'}=0.397;
    $statpot{'f15NH'}=0.128;
    $statpot{'f15NI'}=-0.012;
    $statpot{'f15NL'}=-0.085;
    $statpot{'f15NK'}=0.508;
    $statpot{'f15NM'}=0.047;
    $statpot{'f15NF'}=-0.061;
    $statpot{'f15NP'}=0.326;
    $statpot{'f15NS'}=0.219;
    $statpot{'f15NT'}=0.207;
    $statpot{'f15NW'}=0.056;
    $statpot{'f15NY'}=-0.050;
    $statpot{'f15NV'}=0.057;
    $statpot{'f15DA'}=0.260;
    $statpot{'f15DR'}=0.301;
    $statpot{'f15DN'}=0.431;
    $statpot{'f15DD'}=0.585;
    $statpot{'f15DC'}=0.160;
    $statpot{'f15DQ'}=0.480;
    $statpot{'f15DE'}=0.636;
    $statpot{'f15DG'}=0.384;
    $statpot{'f15DH'}=0.342;
    $statpot{'f15DI'}=0.143;
    $statpot{'f15DL'}=0.197;
    $statpot{'f15DK'}=0.615;
    $statpot{'f15DM'}=0.125;
    $statpot{'f15DF'}=0.208;
    $statpot{'f15DP'}=0.489;
    $statpot{'f15DS'}=0.388;
    $statpot{'f15DT'}=0.355;
    $statpot{'f15DW'}=-0.022;
    $statpot{'f15DY'}=0.165;
    $statpot{'f15DV'}=0.128;
    $statpot{'f15CA'}=-0.421;
    $statpot{'f15CR'}=-0.235;
    $statpot{'f15CN'}=-0.274;
    $statpot{'f15CD'}=0.000;
    $statpot{'f15CC'}=-0.369;
    $statpot{'f15CQ'}=-0.331;
    $statpot{'f15CE'}=-0.086;
    $statpot{'f15CG'}=-0.225;
    $statpot{'f15CH'}=0.100;
    $statpot{'f15CI'}=-0.332;
    $statpot{'f15CL'}=-0.464;
    $statpot{'f15CK'}=-0.088;
    $statpot{'f15CM'}=-0.518;
    $statpot{'f15CF'}=-0.663;
    $statpot{'f15CP'}=-0.088;
    $statpot{'f15CS'}=-0.317;
    $statpot{'f15CT'}=-0.293;
    $statpot{'f15CW'}=-0.455;
    $statpot{'f15CY'}=-0.367;
    $statpot{'f15CV'}=-0.380;
    $statpot{'f15QA'}=0.195;
    $statpot{'f15QR'}=0.287;
    $statpot{'f15QN'}=0.277;
    $statpot{'f15QD'}=0.404;
    $statpot{'f15QC'}=-0.335;
    $statpot{'f15QQ'}=0.399;
    $statpot{'f15QE'}=0.482;
    $statpot{'f15QG'}=0.176;
    $statpot{'f15QH'}=0.105;
    $statpot{'f15QI'}=-0.015;
    $statpot{'f15QL'}=0.047;
    $statpot{'f15QK'}=0.384;
    $statpot{'f15QM'}=0.169;
    $statpot{'f15QF'}=-0.019;
    $statpot{'f15QP'}=0.234;
    $statpot{'f15QS'}=0.114;
    $statpot{'f15QT'}=0.187;
    $statpot{'f15QW'}=-0.107;
    $statpot{'f15QY'}=-0.086;
    $statpot{'f15QV'}=-0.010;
    $statpot{'f15EA'}=0.240;
    $statpot{'f15ER'}=0.503;
    $statpot{'f15EN'}=0.466;
    $statpot{'f15ED'}=0.591;
    $statpot{'f15EC'}=0.045;
    $statpot{'f15EQ'}=0.479;
    $statpot{'f15EE'}=0.586;
    $statpot{'f15EG'}=0.428;
    $statpot{'f15EH'}=0.177;
    $statpot{'f15EI'}=0.221;
    $statpot{'f15EL'}=0.225;
    $statpot{'f15EK'}=0.716;
    $statpot{'f15EM'}=0.201;
    $statpot{'f15EF'}=0.176;
    $statpot{'f15EP'}=0.556;
    $statpot{'f15ES'}=0.410;
    $statpot{'f15ET'}=0.315;
    $statpot{'f15EW'}=0.203;
    $statpot{'f15EY'}=0.283;
    $statpot{'f15EV'}=0.222;
    $statpot{'f15GA'}=0.121;
    $statpot{'f15GR'}=0.313;
    $statpot{'f15GN'}=0.316;
    $statpot{'f15GD'}=0.347;
    $statpot{'f15GC'}=-0.128;
    $statpot{'f15GQ'}=0.178;
    $statpot{'f15GE'}=0.426;
    $statpot{'f15GG'}=0.204;
    $statpot{'f15GH'}=0.118;
    $statpot{'f15GI'}=0.016;
    $statpot{'f15GL'}=-0.004;
    $statpot{'f15GK'}=0.443;
    $statpot{'f15GM'}=-0.021;
    $statpot{'f15GF'}=-0.172;
    $statpot{'f15GP'}=0.308;
    $statpot{'f15GS'}=0.205;
    $statpot{'f15GT'}=0.145;
    $statpot{'f15GW'}=-0.057;
    $statpot{'f15GY'}=-0.020;
    $statpot{'f15GV'}=0.015;
    $statpot{'f15HA'}=-0.068;
    $statpot{'f15HR'}=0.116;
    $statpot{'f15HN'}=0.079;
    $statpot{'f15HD'}=0.143;
    $statpot{'f15HC'}=0.074;
    $statpot{'f15HQ'}=0.064;
    $statpot{'f15HE'}=0.151;
    $statpot{'f15HG'}=0.103;
    $statpot{'f15HH'}=0.012;
    $statpot{'f15HI'}=-0.193;
    $statpot{'f15HL'}=-0.177;
    $statpot{'f15HK'}=0.310;
    $statpot{'f15HM'}=-0.238;
    $statpot{'f15HF'}=-0.272;
    $statpot{'f15HP'}=0.033;
    $statpot{'f15HS'}=0.017;
    $statpot{'f15HT'}=-0.182;
    $statpot{'f15HW'}=-0.235;
    $statpot{'f15HY'}=-0.172;
    $statpot{'f15HV'}=-0.181;
    $statpot{'f15IA'}=-0.300;
    $statpot{'f15IR'}=-0.149;
    $statpot{'f15IN'}=-0.161;
    $statpot{'f15ID'}=-0.166;
    $statpot{'f15IC'}=-0.438;
    $statpot{'f15IQ'}=-0.170;
    $statpot{'f15IE'}=-0.010;
    $statpot{'f15IG'}=-0.169;
    $statpot{'f15IH'}=-0.342;
    $statpot{'f15II'}=-0.340;
    $statpot{'f15IL'}=-0.417;
    $statpot{'f15IK'}=-0.060;
    $statpot{'f15IM'}=-0.445;
    $statpot{'f15IF'}=-0.393;
    $statpot{'f15IP'}=-0.150;
    $statpot{'f15IS'}=-0.309;
    $statpot{'f15IT'}=-0.278;
    $statpot{'f15IW'}=-0.392;
    $statpot{'f15IY'}=-0.299;
    $statpot{'f15IV'}=-0.371;
    $statpot{'f15LA'}=-0.256;
    $statpot{'f15LR'}=-0.186;
    $statpot{'f15LN'}=-0.231;
    $statpot{'f15LD'}=-0.067;
    $statpot{'f15LC'}=-0.526;
    $statpot{'f15LQ'}=-0.141;
    $statpot{'f15LE'}=-0.046;
    $statpot{'f15LG'}=-0.193;
    $statpot{'f15LH'}=-0.231;
    $statpot{'f15LI'}=-0.431;
    $statpot{'f15LL'}=-0.342;
    $statpot{'f15LK'}=0.004;
    $statpot{'f15LM'}=-0.405;
    $statpot{'f15LF'}=-0.443;
    $statpot{'f15LP'}=-0.132;
    $statpot{'f15LS'}=-0.260;
    $statpot{'f15LT'}=-0.196;
    $statpot{'f15LW'}=-0.376;
    $statpot{'f15LY'}=-0.350;
    $statpot{'f15LV'}=-0.363;
    $statpot{'f15KA'}=0.297;
    $statpot{'f15KR'}=0.541;
    $statpot{'f15KN'}=0.401;
    $statpot{'f15KD'}=0.587;
    $statpot{'f15KC'}=0.107;
    $statpot{'f15KQ'}=0.353;
    $statpot{'f15KE'}=0.627;
    $statpot{'f15KG'}=0.505;
    $statpot{'f15KH'}=0.469;
    $statpot{'f15KI'}=0.213;
    $statpot{'f15KL'}=0.253;
    $statpot{'f15KK'}=0.707;
    $statpot{'f15KM'}=0.126;
    $statpot{'f15KF'}=0.151;
    $statpot{'f15KP'}=0.520;
    $statpot{'f15KS'}=0.352;
    $statpot{'f15KT'}=0.327;
    $statpot{'f15KW'}=0.272;
    $statpot{'f15KY'}=0.282;
    $statpot{'f15KV'}=0.259;
    $statpot{'f15MA'}=-0.308;
    $statpot{'f15MR'}=-0.268;
    $statpot{'f15MN'}=-0.126;
    $statpot{'f15MD'}=-0.116;
    $statpot{'f15MC'}=-0.331;
    $statpot{'f15MQ'}=0.066;
    $statpot{'f15ME'}=0.008;
    $statpot{'f15MG'}=-0.141;
    $statpot{'f15MH'}=-0.323;
    $statpot{'f15MI'}=-0.441;
    $statpot{'f15ML'}=-0.408;
    $statpot{'f15MK'}=-0.050;
    $statpot{'f15MM'}=-0.291;
    $statpot{'f15MF'}=-0.388;
    $statpot{'f15MP'}=-0.166;
    $statpot{'f15MS'}=-0.113;
    $statpot{'f15MT'}=-0.190;
    $statpot{'f15MW'}=-0.534;
    $statpot{'f15MY'}=-0.292;
    $statpot{'f15MV'}=-0.360;
    $statpot{'f15FA'}=-0.333;
    $statpot{'f15FR'}=-0.172;
    $statpot{'f15FN'}=-0.225;
    $statpot{'f15FD'}=-0.062;
    $statpot{'f15FC'}=-0.663;
    $statpot{'f15FQ'}=-0.123;
    $statpot{'f15FE'}=-0.111;
    $statpot{'f15FG'}=-0.263;
    $statpot{'f15FH'}=-0.340;
    $statpot{'f15FI'}=-0.326;
    $statpot{'f15FL'}=-0.447;
    $statpot{'f15FK'}=-0.097;
    $statpot{'f15FM'}=-0.377;
    $statpot{'f15FF'}=-0.393;
    $statpot{'f15FP'}=-0.090;
    $statpot{'f15FS'}=-0.297;
    $statpot{'f15FT'}=-0.347;
    $statpot{'f15FW'}=-0.426;
    $statpot{'f15FY'}=-0.461;
    $statpot{'f15FV'}=-0.338;
    $statpot{'f15PA'}=0.220;
    $statpot{'f15PR'}=0.361;
    $statpot{'f15PN'}=0.294;
    $statpot{'f15PD'}=0.526;
    $statpot{'f15PC'}=0.003;
    $statpot{'f15PQ'}=0.323;
    $statpot{'f15PE'}=0.540;
    $statpot{'f15PG'}=0.286;
    $statpot{'f15PH'}=0.137;
    $statpot{'f15PI'}=0.061;
    $statpot{'f15PL'}=0.086;
    $statpot{'f15PK'}=0.488;
    $statpot{'f15PM'}=0.066;
    $statpot{'f15PF'}=0.165;
    $statpot{'f15PP'}=0.319;
    $statpot{'f15PS'}=0.414;
    $statpot{'f15PT'}=0.216;
    $statpot{'f15PW'}=0.055;
    $statpot{'f15PY'}=0.092;
    $statpot{'f15PV'}=0.003;
    $statpot{'f15SA'}=0.076;
    $statpot{'f15SR'}=0.212;
    $statpot{'f15SN'}=0.258;
    $statpot{'f15SD'}=0.315;
    $statpot{'f15SC'}=-0.193;
    $statpot{'f15SQ'}=0.202;
    $statpot{'f15SE'}=0.444;
    $statpot{'f15SG'}=0.231;
    $statpot{'f15SH'}=-0.004;
    $statpot{'f15SI'}=-0.153;
    $statpot{'f15SL'}=-0.091;
    $statpot{'f15SK'}=0.376;
    $statpot{'f15SM'}=-0.029;
    $statpot{'f15SF'}=-0.157;
    $statpot{'f15SP'}=0.234;
    $statpot{'f15SS'}=0.202;
    $statpot{'f15ST'}=0.045;
    $statpot{'f15SW'}=-0.095;
    $statpot{'f15SY'}=0.017;
    $statpot{'f15SV'}=-0.110;
    $statpot{'f15TA'}=0.055;
    $statpot{'f15TR'}=0.224;
    $statpot{'f15TN'}=0.091;
    $statpot{'f15TD'}=0.277;
    $statpot{'f15TC'}=-0.258;
    $statpot{'f15TQ'}=0.149;
    $statpot{'f15TE'}=0.266;
    $statpot{'f15TG'}=0.163;
    $statpot{'f15TH'}=-0.108;
    $statpot{'f15TI'}=-0.142;
    $statpot{'f15TL'}=-0.070;
    $statpot{'f15TK'}=0.354;
    $statpot{'f15TM'}=-0.105;
    $statpot{'f15TF'}=-0.195;
    $statpot{'f15TP'}=0.128;
    $statpot{'f15TS'}=0.068;
    $statpot{'f15TT'}=0.047;
    $statpot{'f15TW'}=-0.124;
    $statpot{'f15TY'}=-0.039;
    $statpot{'f15TV'}=-0.167;
    $statpot{'f15WA'}=-0.179;
    $statpot{'f15WR'}=-0.130;
    $statpot{'f15WN'}=-0.050;
    $statpot{'f15WD'}=-0.210;
    $statpot{'f15WC'}=-0.340;
    $statpot{'f15WQ'}=-0.137;
    $statpot{'f15WE'}=0.022;
    $statpot{'f15WG'}=-0.101;
    $statpot{'f15WH'}=-0.345;
    $statpot{'f15WI'}=-0.382;
    $statpot{'f15WL'}=-0.376;
    $statpot{'f15WK'}=0.190;
    $statpot{'f15WM'}=-0.421;
    $statpot{'f15WF'}=-0.532;
    $statpot{'f15WP'}=-0.092;
    $statpot{'f15WS'}=-0.145;
    $statpot{'f15WT'}=-0.254;
    $statpot{'f15WW'}=-0.200;
    $statpot{'f15WY'}=-0.442;
    $statpot{'f15WV'}=-0.274;
    $statpot{'f15YA'}=-0.206;
    $statpot{'f15YR'}=-0.180;
    $statpot{'f15YN'}=-0.148;
    $statpot{'f15YD'}=-0.046;
    $statpot{'f15YC'}=-0.390;
    $statpot{'f15YQ'}=-0.152;
    $statpot{'f15YE'}=0.088;
    $statpot{'f15YG'}=-0.101;
    $statpot{'f15YH'}=-0.233;
    $statpot{'f15YI'}=-0.215;
    $statpot{'f15YL'}=-0.296;
    $statpot{'f15YK'}=0.162;
    $statpot{'f15YM'}=-0.321;
    $statpot{'f15YF'}=-0.429;
    $statpot{'f15YP'}=0.057;
    $statpot{'f15YS'}=-0.124;
    $statpot{'f15YT'}=-0.145;
    $statpot{'f15YW'}=-0.491;
    $statpot{'f15YY'}=-0.390;
    $statpot{'f15YV'}=-0.296;
    $statpot{'f15VA'}=-0.152;
    $statpot{'f15VR'}=-0.141;
    $statpot{'f15VN'}=-0.082;
    $statpot{'f15VD'}=-0.124;
    $statpot{'f15VC'}=-0.333;
    $statpot{'f15VQ'}=-0.112;
    $statpot{'f15VE'}=0.058;
    $statpot{'f15VG'}=-0.131;
    $statpot{'f15VH'}=-0.292;
    $statpot{'f15VI'}=-0.357;
    $statpot{'f15VL'}=-0.330;
    $statpot{'f15VK'}=0.049;
    $statpot{'f15VM'}=-0.339;
    $statpot{'f15VF'}=-0.372;
    $statpot{'f15VP'}=-0.037;
    $statpot{'f15VS'}=-0.216;
    $statpot{'f15VT'}=-0.259;
    $statpot{'f15VW'}=-0.399;
    $statpot{'f15VY'}=-0.238;
    $statpot{'f15VV'}=-0.355;
    $statpot{'a15AA'}=-0.010;
    $statpot{'a15AR'}=-0.055;
    $statpot{'a15AN'}=0.030;
    $statpot{'a15AD'}=-0.038;
    $statpot{'a15AC'}=-0.058;
    $statpot{'a15AQ'}=0.002;
    $statpot{'a15AE'}=0.041;
    $statpot{'a15AG'}=0.136;
    $statpot{'a15AH'}=-0.023;
    $statpot{'a15AI'}=-0.067;
    $statpot{'a15AL'}=-0.019;
    $statpot{'a15AK'}=0.049;
    $statpot{'a15AM'}=0.065;
    $statpot{'a15AF'}=-0.027;
    $statpot{'a15AP'}=0.125;
    $statpot{'a15AS'}=0.008;
    $statpot{'a15AT'}=-0.012;
    $statpot{'a15AW'}=0.042;
    $statpot{'a15AY'}=0.034;
    $statpot{'a15AV'}=0.000;
    $statpot{'a15RA'}=-0.130;
    $statpot{'a15RR'}=-0.067;
    $statpot{'a15RN'}=0.038;
    $statpot{'a15RD'}=0.060;
    $statpot{'a15RC'}=0.010;
    $statpot{'a15RQ'}=-0.043;
    $statpot{'a15RE'}=0.055;
    $statpot{'a15RG'}=0.121;
    $statpot{'a15RH'}=0.063;
    $statpot{'a15RI'}=-0.185;
    $statpot{'a15RL'}=-0.141;
    $statpot{'a15RK'}=0.067;
    $statpot{'a15RM'}=-0.222;
    $statpot{'a15RF'}=-0.087;
    $statpot{'a15RP'}=0.092;
    $statpot{'a15RS'}=-0.040;
    $statpot{'a15RT'}=-0.094;
    $statpot{'a15RW'}=-0.094;
    $statpot{'a15RY'}=-0.180;
    $statpot{'a15RV'}=-0.250;
    $statpot{'a15NA'}=-0.052;
    $statpot{'a15NR'}=0.075;
    $statpot{'a15NN'}=0.194;
    $statpot{'a15ND'}=0.137;
    $statpot{'a15NC'}=-0.153;
    $statpot{'a15NQ'}=0.059;
    $statpot{'a15NE'}=0.009;
    $statpot{'a15NG'}=0.117;
    $statpot{'a15NH'}=-0.140;
    $statpot{'a15NI'}=-0.214;
    $statpot{'a15NL'}=-0.189;
    $statpot{'a15NK'}=0.079;
    $statpot{'a15NM'}=-0.124;
    $statpot{'a15NF'}=-0.085;
    $statpot{'a15NP'}=0.091;
    $statpot{'a15NS'}=-0.025;
    $statpot{'a15NT'}=-0.124;
    $statpot{'a15NW'}=0.003;
    $statpot{'a15NY'}=-0.161;
    $statpot{'a15NV'}=-0.133;
    $statpot{'a15DA'}=-0.156;
    $statpot{'a15DR'}=0.002;
    $statpot{'a15DN'}=0.075;
    $statpot{'a15DD'}=0.166;
    $statpot{'a15DC'}=-0.112;
    $statpot{'a15DQ'}=0.089;
    $statpot{'a15DE'}=0.097;
    $statpot{'a15DG'}=0.170;
    $statpot{'a15DH'}=-0.105;
    $statpot{'a15DI'}=-0.283;
    $statpot{'a15DL'}=-0.180;
    $statpot{'a15DK'}=0.177;
    $statpot{'a15DM'}=-0.233;
    $statpot{'a15DF'}=-0.148;
    $statpot{'a15DP'}=0.182;
    $statpot{'a15DS'}=0.041;
    $statpot{'a15DT'}=0.042;
    $statpot{'a15DW'}=-0.270;
    $statpot{'a15DY'}=-0.042;
    $statpot{'a15DV'}=-0.257;
    $statpot{'a15CA'}=0.077;
    $statpot{'a15CR'}=0.026;
    $statpot{'a15CN'}=0.158;
    $statpot{'a15CD'}=0.018;
    $statpot{'a15CC'}=-0.042;
    $statpot{'a15CQ'}=-0.202;
    $statpot{'a15CE'}=-0.031;
    $statpot{'a15CG'}=0.122;
    $statpot{'a15CH'}=0.341;
    $statpot{'a15CI'}=0.141;
    $statpot{'a15CL'}=0.020;
    $statpot{'a15CK'}=0.189;
    $statpot{'a15CM'}=0.259;
    $statpot{'a15CF'}=-0.103;
    $statpot{'a15CP'}=-0.187;
    $statpot{'a15CS'}=0.135;
    $statpot{'a15CT'}=-0.056;
    $statpot{'a15CW'}=-0.062;
    $statpot{'a15CY'}=0.123;
    $statpot{'a15CV'}=-0.006;
    $statpot{'a15QA'}=-0.037;
    $statpot{'a15QR'}=-0.067;
    $statpot{'a15QN'}=0.054;
    $statpot{'a15QD'}=0.140;
    $statpot{'a15QC'}=-0.198;
    $statpot{'a15QQ'}=-0.106;
    $statpot{'a15QE'}=0.064;
    $statpot{'a15QG'}=0.148;
    $statpot{'a15QH'}=-0.088;
    $statpot{'a15QI'}=-0.110;
    $statpot{'a15QL'}=-0.189;
    $statpot{'a15QK'}=-0.046;
    $statpot{'a15QM'}=-0.064;
    $statpot{'a15QF'}=-0.147;
    $statpot{'a15QP'}=0.079;
    $statpot{'a15QS'}=-0.060;
    $statpot{'a15QT'}=-0.109;
    $statpot{'a15QW'}=-0.026;
    $statpot{'a15QY'}=-0.096;
    $statpot{'a15QV'}=-0.138;
    $statpot{'a15EA'}=-0.082;
    $statpot{'a15ER'}=0.045;
    $statpot{'a15EN'}=-0.017;
    $statpot{'a15ED'}=0.124;
    $statpot{'a15EC'}=-0.148;
    $statpot{'a15EQ'}=0.066;
    $statpot{'a15EE'}=0.188;
    $statpot{'a15EG'}=0.127;
    $statpot{'a15EH'}=0.062;
    $statpot{'a15EI'}=-0.219;
    $statpot{'a15EL'}=-0.210;
    $statpot{'a15EK'}=0.066;
    $statpot{'a15EM'}=-0.155;
    $statpot{'a15EF'}=-0.179;
    $statpot{'a15EP'}=0.100;
    $statpot{'a15ES'}=0.073;
    $statpot{'a15ET'}=-0.006;
    $statpot{'a15EW'}=-0.016;
    $statpot{'a15EY'}=-0.098;
    $statpot{'a15EV'}=-0.143;
    $statpot{'a15GA'}=0.041;
    $statpot{'a15GR'}=0.152;
    $statpot{'a15GN'}=0.180;
    $statpot{'a15GD'}=0.200;
    $statpot{'a15GC'}=0.006;
    $statpot{'a15GQ'}=0.147;
    $statpot{'a15GE'}=0.130;
    $statpot{'a15GG'}=0.250;
    $statpot{'a15GH'}=-0.018;
    $statpot{'a15GI'}=-0.133;
    $statpot{'a15GL'}=-0.054;
    $statpot{'a15GK'}=0.172;
    $statpot{'a15GM'}=-0.116;
    $statpot{'a15GF'}=-0.069;
    $statpot{'a15GP'}=0.092;
    $statpot{'a15GS'}=0.064;
    $statpot{'a15GT'}=0.120;
    $statpot{'a15GW'}=0.068;
    $statpot{'a15GY'}=-0.007;
    $statpot{'a15GV'}=-0.092;
    $statpot{'a15HA'}=0.008;
    $statpot{'a15HR'}=0.115;
    $statpot{'a15HN'}=-0.104;
    $statpot{'a15HD'}=0.040;
    $statpot{'a15HC'}=0.371;
    $statpot{'a15HQ'}=-0.055;
    $statpot{'a15HE'}=0.085;
    $statpot{'a15HG'}=-0.005;
    $statpot{'a15HH'}=0.092;
    $statpot{'a15HI'}=-0.159;
    $statpot{'a15HL'}=-0.043;
    $statpot{'a15HK'}=0.088;
    $statpot{'a15HM'}=-0.136;
    $statpot{'a15HF'}=-0.017;
    $statpot{'a15HP'}=-0.016;
    $statpot{'a15HS'}=-0.058;
    $statpot{'a15HT'}=-0.070;
    $statpot{'a15HW'}=-0.161;
    $statpot{'a15HY'}=-0.115;
    $statpot{'a15HV'}=-0.119;
    $statpot{'a15IA'}=0.021;
    $statpot{'a15IR'}=-0.074;
    $statpot{'a15IN'}=-0.081;
    $statpot{'a15ID'}=-0.026;
    $statpot{'a15IC'}=0.325;
    $statpot{'a15IQ'}=0.047;
    $statpot{'a15IE'}=-0.041;
    $statpot{'a15IG'}=0.052;
    $statpot{'a15IH'}=0.016;
    $statpot{'a15II'}=0.116;
    $statpot{'a15IL'}=0.142;
    $statpot{'a15IK'}=-0.018;
    $statpot{'a15IM'}=0.065;
    $statpot{'a15IF'}=0.193;
    $statpot{'a15IP'}=-0.016;
    $statpot{'a15IS'}=-0.031;
    $statpot{'a15IT'}=-0.080;
    $statpot{'a15IW'}=0.146;
    $statpot{'a15IY'}=0.158;
    $statpot{'a15IV'}=0.043;
    $statpot{'a15LA'}=0.080;
    $statpot{'a15LR'}=0.021;
    $statpot{'a15LN'}=-0.043;
    $statpot{'a15LD'}=0.044;
    $statpot{'a15LC'}=0.125;
    $statpot{'a15LQ'}=-0.019;
    $statpot{'a15LE'}=0.010;
    $statpot{'a15LG'}=0.162;
    $statpot{'a15LH'}=0.019;
    $statpot{'a15LI'}=0.165;
    $statpot{'a15LL'}=0.298;
    $statpot{'a15LK'}=-0.020;
    $statpot{'a15LM'}=0.134;
    $statpot{'a15LF'}=0.174;
    $statpot{'a15LP'}=0.067;
    $statpot{'a15LS'}=-0.007;
    $statpot{'a15LT'}=-0.021;
    $statpot{'a15LW'}=-0.014;
    $statpot{'a15LY'}=0.155;
    $statpot{'a15LV'}=0.124;
    $statpot{'a15KA'}=-0.020;
    $statpot{'a15KR'}=-0.052;
    $statpot{'a15KN'}=0.150;
    $statpot{'a15KD'}=0.195;
    $statpot{'a15KC'}=-0.007;
    $statpot{'a15KQ'}=-0.027;
    $statpot{'a15KE'}=0.114;
    $statpot{'a15KG'}=0.127;
    $statpot{'a15KH'}=-0.018;
    $statpot{'a15KI'}=-0.232;
    $statpot{'a15KL'}=-0.208;
    $statpot{'a15KK'}=0.065;
    $statpot{'a15KM'}=-0.137;
    $statpot{'a15KF'}=-0.183;
    $statpot{'a15KP'}=0.096;
    $statpot{'a15KS'}=0.057;
    $statpot{'a15KT'}=-0.041;
    $statpot{'a15KW'}=-0.114;
    $statpot{'a15KY'}=-0.087;
    $statpot{'a15KV'}=-0.232;
    $statpot{'a15MA'}=0.074;
    $statpot{'a15MR'}=-0.088;
    $statpot{'a15MN'}=0.044;
    $statpot{'a15MD'}=-0.027;
    $statpot{'a15MC'}=-0.044;
    $statpot{'a15MQ'}=0.022;
    $statpot{'a15ME'}=0.004;
    $statpot{'a15MG'}=0.006;
    $statpot{'a15MH'}=-0.037;
    $statpot{'a15MI'}=0.057;
    $statpot{'a15ML'}=0.140;
    $statpot{'a15MK'}=0.019;
    $statpot{'a15MM'}=0.110;
    $statpot{'a15MF'}=0.054;
    $statpot{'a15MP'}=0.062;
    $statpot{'a15MS'}=0.038;
    $statpot{'a15MT'}=0.034;
    $statpot{'a15MW'}=0.088;
    $statpot{'a15MY'}=0.011;
    $statpot{'a15MV'}=-0.108;
    $statpot{'a15FA'}=0.106;
    $statpot{'a15FR'}=0.056;
    $statpot{'a15FN'}=0.095;
    $statpot{'a15FD'}=0.086;
    $statpot{'a15FC'}=-0.105;
    $statpot{'a15FQ'}=-0.051;
    $statpot{'a15FE'}=0.077;
    $statpot{'a15FG'}=0.041;
    $statpot{'a15FH'}=0.073;
    $statpot{'a15FI'}=0.085;
    $statpot{'a15FL'}=0.182;
    $statpot{'a15FK'}=0.030;
    $statpot{'a15FM'}=0.036;
    $statpot{'a15FF'}=0.312;
    $statpot{'a15FP'}=0.056;
    $statpot{'a15FS'}=-0.037;
    $statpot{'a15FT'}=0.000;
    $statpot{'a15FW'}=0.152;
    $statpot{'a15FY'}=0.145;
    $statpot{'a15FV'}=-0.013;
    $statpot{'a15PA'}=-0.001;
    $statpot{'a15PR'}=-0.013;
    $statpot{'a15PN'}=0.116;
    $statpot{'a15PD'}=0.158;
    $statpot{'a15PC'}=-0.258;
    $statpot{'a15PQ'}=0.011;
    $statpot{'a15PE'}=0.110;
    $statpot{'a15PG'}=0.108;
    $statpot{'a15PH'}=-0.103;
    $statpot{'a15PI'}=-0.208;
    $statpot{'a15PL'}=-0.144;
    $statpot{'a15PK'}=0.116;
    $statpot{'a15PM'}=-0.166;
    $statpot{'a15PF'}=-0.169;
    $statpot{'a15PP'}=0.036;
    $statpot{'a15PS'}=0.009;
    $statpot{'a15PT'}=-0.080;
    $statpot{'a15PW'}=-0.100;
    $statpot{'a15PY'}=0.038;
    $statpot{'a15PV'}=-0.120;
    $statpot{'a15SA'}=-0.062;
    $statpot{'a15SR'}=-0.039;
    $statpot{'a15SN'}=-0.053;
    $statpot{'a15SD'}=0.094;
    $statpot{'a15SC'}=-0.021;
    $statpot{'a15SQ'}=-0.124;
    $statpot{'a15SE'}=0.049;
    $statpot{'a15SG'}=0.043;
    $statpot{'a15SH'}=-0.039;
    $statpot{'a15SI'}=-0.199;
    $statpot{'a15SL'}=-0.184;
    $statpot{'a15SK'}=0.040;
    $statpot{'a15SM'}=-0.049;
    $statpot{'a15SF'}=-0.186;
    $statpot{'a15SP'}=0.143;
    $statpot{'a15SS'}=-0.014;
    $statpot{'a15ST'}=-0.042;
    $statpot{'a15SW'}=-0.020;
    $statpot{'a15SY'}=-0.054;
    $statpot{'a15SV'}=-0.220;
    $statpot{'a15TA'}=-0.067;
    $statpot{'a15TR'}=-0.116;
    $statpot{'a15TN'}=-0.037;
    $statpot{'a15TD'}=0.100;
    $statpot{'a15TC'}=-0.095;
    $statpot{'a15TQ'}=-0.081;
    $statpot{'a15TE'}=0.030;
    $statpot{'a15TG'}=0.103;
    $statpot{'a15TH'}=-0.143;
    $statpot{'a15TI'}=-0.218;
    $statpot{'a15TL'}=-0.149;
    $statpot{'a15TK'}=-0.059;
    $statpot{'a15TM'}=-0.061;
    $statpot{'a15TF'}=-0.174;
    $statpot{'a15TP'}=-0.011;
    $statpot{'a15TS'}=-0.061;
    $statpot{'a15TT'}=-0.066;
    $statpot{'a15TW'}=-0.242;
    $statpot{'a15TY'}=-0.044;
    $statpot{'a15TV'}=-0.173;
    $statpot{'a15WA'}=0.085;
    $statpot{'a15WR'}=0.073;
    $statpot{'a15WN'}=0.107;
    $statpot{'a15WD'}=-0.104;
    $statpot{'a15WC'}=-0.199;
    $statpot{'a15WQ'}=0.006;
    $statpot{'a15WE'}=0.152;
    $statpot{'a15WG'}=0.118;
    $statpot{'a15WH'}=-0.032;
    $statpot{'a15WI'}=0.130;
    $statpot{'a15WL'}=-0.015;
    $statpot{'a15WK'}=-0.057;
    $statpot{'a15WM'}=-0.091;
    $statpot{'a15WF'}=0.356;
    $statpot{'a15WP'}=0.039;
    $statpot{'a15WS'}=0.033;
    $statpot{'a15WT'}=-0.118;
    $statpot{'a15WW'}=0.078;
    $statpot{'a15WY'}=0.071;
    $statpot{'a15WV'}=-0.070;
    $statpot{'a15YA'}=0.108;
    $statpot{'a15YR'}=-0.062;
    $statpot{'a15YN'}=-0.070;
    $statpot{'a15YD'}=0.162;
    $statpot{'a15YC'}=0.160;
    $statpot{'a15YQ'}=-0.030;
    $statpot{'a15YE'}=0.056;
    $statpot{'a15YG'}=0.079;
    $statpot{'a15YH'}=-0.048;
    $statpot{'a15YI'}=0.044;
    $statpot{'a15YL'}=0.075;
    $statpot{'a15YK'}=0.001;
    $statpot{'a15YM'}=0.052;
    $statpot{'a15YF'}=0.092;
    $statpot{'a15YP'}=0.071;
    $statpot{'a15YS'}=0.090;
    $statpot{'a15YT'}=0.069;
    $statpot{'a15YW'}=0.158;
    $statpot{'a15YY'}=0.126;
    $statpot{'a15YV'}=0.136;
    $statpot{'a15VA'}=-0.040;
    $statpot{'a15VR'}=-0.109;
    $statpot{'a15VN'}=-0.007;
    $statpot{'a15VD'}=-0.048;
    $statpot{'a15VC'}=-0.069;
    $statpot{'a15VQ'}=-0.043;
    $statpot{'a15VE'}=-0.014;
    $statpot{'a15VG'}=0.056;
    $statpot{'a15VH'}=0.009;
    $statpot{'a15VI'}=0.024;
    $statpot{'a15VL'}=0.073;
    $statpot{'a15VK'}=-0.084;
    $statpot{'a15VM'}=-0.134;
    $statpot{'a15VF'}=0.034;
    $statpot{'a15VP'}=-0.085;
    $statpot{'a15VS'}=-0.118;
    $statpot{'a15VT'}=-0.076;
    $statpot{'a15VW'}=0.102;
    $statpot{'a15VY'}=0.056;
    $statpot{'a15VV'}=0.030;
    $statpot{'p16AA'}=-0.058;
    $statpot{'p16AR'}=0.000;
    $statpot{'p16AN'}=0.025;
    $statpot{'p16AD'}=0.091;
    $statpot{'p16AC'}=-0.125;
    $statpot{'p16AQ'}=-0.010;
    $statpot{'p16AE'}=0.048;
    $statpot{'p16AG'}=0.043;
    $statpot{'p16AH'}=-0.025;
    $statpot{'p16AI'}=-0.121;
    $statpot{'p16AL'}=-0.054;
    $statpot{'p16AK'}=0.089;
    $statpot{'p16AM'}=-0.078;
    $statpot{'p16AF'}=-0.040;
    $statpot{'p16AP'}=0.038;
    $statpot{'p16AS'}=-0.068;
    $statpot{'p16AT'}=-0.012;
    $statpot{'p16AW'}=-0.029;
    $statpot{'p16AY'}=-0.116;
    $statpot{'p16AV'}=-0.115;
    $statpot{'p16RA'}=0.000;
    $statpot{'p16RR'}=0.041;
    $statpot{'p16RN'}=0.028;
    $statpot{'p16RD'}=0.136;
    $statpot{'p16RC'}=-0.121;
    $statpot{'p16RQ'}=0.057;
    $statpot{'p16RE'}=0.168;
    $statpot{'p16RG'}=0.146;
    $statpot{'p16RH'}=0.078;
    $statpot{'p16RI'}=-0.081;
    $statpot{'p16RL'}=-0.033;
    $statpot{'p16RK'}=0.205;
    $statpot{'p16RM'}=-0.076;
    $statpot{'p16RF'}=-0.031;
    $statpot{'p16RP'}=0.124;
    $statpot{'p16RS'}=0.027;
    $statpot{'p16RT'}=0.002;
    $statpot{'p16RW'}=-0.027;
    $statpot{'p16RY'}=0.005;
    $statpot{'p16RV'}=-0.083;
    $statpot{'p16NA'}=0.025;
    $statpot{'p16NR'}=0.028;
    $statpot{'p16NN'}=0.162;
    $statpot{'p16ND'}=0.158;
    $statpot{'p16NC'}=-0.149;
    $statpot{'p16NQ'}=0.050;
    $statpot{'p16NE'}=0.130;
    $statpot{'p16NG'}=0.087;
    $statpot{'p16NH'}=-0.064;
    $statpot{'p16NI'}=-0.031;
    $statpot{'p16NL'}=-0.074;
    $statpot{'p16NK'}=0.165;
    $statpot{'p16NM'}=-0.037;
    $statpot{'p16NF'}=-0.040;
    $statpot{'p16NP'}=0.124;
    $statpot{'p16NS'}=0.088;
    $statpot{'p16NT'}=0.011;
    $statpot{'p16NW'}=-0.064;
    $statpot{'p16NY'}=-0.011;
    $statpot{'p16NV'}=-0.044;
    $statpot{'p16DA'}=0.091;
    $statpot{'p16DR'}=0.136;
    $statpot{'p16DN'}=0.158;
    $statpot{'p16DD'}=0.136;
    $statpot{'p16DC'}=-0.038;
    $statpot{'p16DQ'}=0.090;
    $statpot{'p16DE'}=0.260;
    $statpot{'p16DG'}=0.188;
    $statpot{'p16DH'}=0.058;
    $statpot{'p16DI'}=0.037;
    $statpot{'p16DL'}=0.058;
    $statpot{'p16DK'}=0.190;
    $statpot{'p16DM'}=0.072;
    $statpot{'p16DF'}=-0.001;
    $statpot{'p16DP'}=0.088;
    $statpot{'p16DS'}=0.108;
    $statpot{'p16DT'}=0.146;
    $statpot{'p16DW'}=-0.100;
    $statpot{'p16DY'}=0.033;
    $statpot{'p16DV'}=-0.021;
    $statpot{'p16CA'}=-0.125;
    $statpot{'p16CR'}=-0.121;
    $statpot{'p16CN'}=-0.149;
    $statpot{'p16CD'}=-0.038;
    $statpot{'p16CC'}=0.336;
    $statpot{'p16CQ'}=-0.087;
    $statpot{'p16CE'}=0.044;
    $statpot{'p16CG'}=-0.082;
    $statpot{'p16CH'}=-0.176;
    $statpot{'p16CI'}=-0.160;
    $statpot{'p16CL'}=-0.116;
    $statpot{'p16CK'}=-0.017;
    $statpot{'p16CM'}=-0.333;
    $statpot{'p16CF'}=-0.290;
    $statpot{'p16CP'}=0.034;
    $statpot{'p16CS'}=-0.006;
    $statpot{'p16CT'}=-0.007;
    $statpot{'p16CW'}=-0.157;
    $statpot{'p16CY'}=-0.175;
    $statpot{'p16CV'}=-0.175;
    $statpot{'p16QA'}=-0.010;
    $statpot{'p16QR'}=0.057;
    $statpot{'p16QN'}=0.050;
    $statpot{'p16QD'}=0.090;
    $statpot{'p16QC'}=-0.087;
    $statpot{'p16QQ'}=0.067;
    $statpot{'p16QE'}=0.155;
    $statpot{'p16QG'}=0.112;
    $statpot{'p16QH'}=-0.095;
    $statpot{'p16QI'}=-0.043;
    $statpot{'p16QL'}=-0.018;
    $statpot{'p16QK'}=0.123;
    $statpot{'p16QM'}=-0.078;
    $statpot{'p16QF'}=-0.083;
    $statpot{'p16QP'}=0.139;
    $statpot{'p16QS'}=0.048;
    $statpot{'p16QT'}=0.022;
    $statpot{'p16QW'}=-0.006;
    $statpot{'p16QY'}=0.002;
    $statpot{'p16QV'}=-0.036;
    $statpot{'p16EA'}=0.048;
    $statpot{'p16ER'}=0.168;
    $statpot{'p16EN'}=0.130;
    $statpot{'p16ED'}=0.260;
    $statpot{'p16EC'}=0.044;
    $statpot{'p16EQ'}=0.155;
    $statpot{'p16EE'}=0.164;
    $statpot{'p16EG'}=0.192;
    $statpot{'p16EH'}=0.162;
    $statpot{'p16EI'}=0.015;
    $statpot{'p16EL'}=0.054;
    $statpot{'p16EK'}=0.284;
    $statpot{'p16EM'}=0.027;
    $statpot{'p16EF'}=0.024;
    $statpot{'p16EP'}=0.080;
    $statpot{'p16ES'}=0.113;
    $statpot{'p16ET'}=0.095;
    $statpot{'p16EW'}=0.114;
    $statpot{'p16EY'}=0.130;
    $statpot{'p16EV'}=0.031;
    $statpot{'p16GA'}=0.043;
    $statpot{'p16GR'}=0.146;
    $statpot{'p16GN'}=0.087;
    $statpot{'p16GD'}=0.188;
    $statpot{'p16GC'}=-0.082;
    $statpot{'p16GQ'}=0.112;
    $statpot{'p16GE'}=0.192;
    $statpot{'p16GG'}=0.195;
    $statpot{'p16GH'}=0.078;
    $statpot{'p16GI'}=-0.039;
    $statpot{'p16GL'}=0.017;
    $statpot{'p16GK'}=0.184;
    $statpot{'p16GM'}=0.049;
    $statpot{'p16GF'}=-0.049;
    $statpot{'p16GP'}=0.086;
    $statpot{'p16GS'}=0.069;
    $statpot{'p16GT'}=0.043;
    $statpot{'p16GW'}=-0.079;
    $statpot{'p16GY'}=0.047;
    $statpot{'p16GV'}=-0.043;
    $statpot{'p16HA'}=-0.025;
    $statpot{'p16HR'}=0.078;
    $statpot{'p16HN'}=-0.064;
    $statpot{'p16HD'}=0.058;
    $statpot{'p16HC'}=-0.176;
    $statpot{'p16HQ'}=-0.095;
    $statpot{'p16HE'}=0.162;
    $statpot{'p16HG'}=0.078;
    $statpot{'p16HH'}=0.039;
    $statpot{'p16HI'}=-0.161;
    $statpot{'p16HL'}=-0.100;
    $statpot{'p16HK'}=0.208;
    $statpot{'p16HM'}=-0.053;
    $statpot{'p16HF'}=-0.186;
    $statpot{'p16HP'}=0.088;
    $statpot{'p16HS'}=-0.094;
    $statpot{'p16HT'}=0.059;
    $statpot{'p16HW'}=-0.154;
    $statpot{'p16HY'}=-0.182;
    $statpot{'p16HV'}=-0.180;
    $statpot{'p16IA'}=-0.121;
    $statpot{'p16IR'}=-0.081;
    $statpot{'p16IN'}=-0.031;
    $statpot{'p16ID'}=0.037;
    $statpot{'p16IC'}=-0.160;
    $statpot{'p16IQ'}=-0.043;
    $statpot{'p16IE'}=0.015;
    $statpot{'p16IG'}=-0.039;
    $statpot{'p16IH'}=-0.161;
    $statpot{'p16II'}=-0.106;
    $statpot{'p16IL'}=-0.110;
    $statpot{'p16IK'}=0.018;
    $statpot{'p16IM'}=-0.139;
    $statpot{'p16IF'}=-0.146;
    $statpot{'p16IP'}=-0.055;
    $statpot{'p16IS'}=-0.085;
    $statpot{'p16IT'}=-0.079;
    $statpot{'p16IW'}=-0.178;
    $statpot{'p16IY'}=-0.180;
    $statpot{'p16IV'}=-0.132;
    $statpot{'p16LA'}=-0.054;
    $statpot{'p16LR'}=-0.033;
    $statpot{'p16LN'}=-0.074;
    $statpot{'p16LD'}=0.058;
    $statpot{'p16LC'}=-0.116;
    $statpot{'p16LQ'}=-0.018;
    $statpot{'p16LE'}=0.054;
    $statpot{'p16LG'}=0.017;
    $statpot{'p16LH'}=-0.100;
    $statpot{'p16LI'}=-0.110;
    $statpot{'p16LL'}=-0.070;
    $statpot{'p16LK'}=0.052;
    $statpot{'p16LM'}=-0.178;
    $statpot{'p16LF'}=-0.139;
    $statpot{'p16LP'}=-0.031;
    $statpot{'p16LS'}=-0.095;
    $statpot{'p16LT'}=-0.086;
    $statpot{'p16LW'}=-0.089;
    $statpot{'p16LY'}=-0.183;
    $statpot{'p16LV'}=-0.110;
    $statpot{'p16KA'}=0.089;
    $statpot{'p16KR'}=0.205;
    $statpot{'p16KN'}=0.165;
    $statpot{'p16KD'}=0.190;
    $statpot{'p16KC'}=-0.017;
    $statpot{'p16KQ'}=0.123;
    $statpot{'p16KE'}=0.284;
    $statpot{'p16KG'}=0.184;
    $statpot{'p16KH'}=0.208;
    $statpot{'p16KI'}=0.018;
    $statpot{'p16KL'}=0.052;
    $statpot{'p16KK'}=0.201;
    $statpot{'p16KM'}=0.111;
    $statpot{'p16KF'}=0.037;
    $statpot{'p16KP'}=0.205;
    $statpot{'p16KS'}=0.142;
    $statpot{'p16KT'}=0.045;
    $statpot{'p16KW'}=0.086;
    $statpot{'p16KY'}=0.119;
    $statpot{'p16KV'}=0.042;
    $statpot{'p16MA'}=-0.078;
    $statpot{'p16MR'}=-0.076;
    $statpot{'p16MN'}=-0.037;
    $statpot{'p16MD'}=0.072;
    $statpot{'p16MC'}=-0.333;
    $statpot{'p16MQ'}=-0.078;
    $statpot{'p16ME'}=0.027;
    $statpot{'p16MG'}=0.049;
    $statpot{'p16MH'}=-0.053;
    $statpot{'p16MI'}=-0.139;
    $statpot{'p16ML'}=-0.178;
    $statpot{'p16MK'}=0.111;
    $statpot{'p16MM'}=-0.150;
    $statpot{'p16MF'}=-0.264;
    $statpot{'p16MP'}=0.006;
    $statpot{'p16MS'}=-0.148;
    $statpot{'p16MT'}=-0.120;
    $statpot{'p16MW'}=-0.139;
    $statpot{'p16MY'}=-0.159;
    $statpot{'p16MV'}=-0.223;
    $statpot{'p16FA'}=-0.040;
    $statpot{'p16FR'}=-0.031;
    $statpot{'p16FN'}=-0.040;
    $statpot{'p16FD'}=-0.001;
    $statpot{'p16FC'}=-0.290;
    $statpot{'p16FQ'}=-0.083;
    $statpot{'p16FE'}=0.024;
    $statpot{'p16FG'}=-0.049;
    $statpot{'p16FH'}=-0.186;
    $statpot{'p16FI'}=-0.146;
    $statpot{'p16FL'}=-0.139;
    $statpot{'p16FK'}=0.037;
    $statpot{'p16FM'}=-0.264;
    $statpot{'p16FF'}=-0.246;
    $statpot{'p16FP'}=-0.043;
    $statpot{'p16FS'}=-0.112;
    $statpot{'p16FT'}=-0.089;
    $statpot{'p16FW'}=-0.011;
    $statpot{'p16FY'}=-0.195;
    $statpot{'p16FV'}=-0.109;
    $statpot{'p16PA'}=0.038;
    $statpot{'p16PR'}=0.124;
    $statpot{'p16PN'}=0.124;
    $statpot{'p16PD'}=0.088;
    $statpot{'p16PC'}=0.034;
    $statpot{'p16PQ'}=0.139;
    $statpot{'p16PE'}=0.080;
    $statpot{'p16PG'}=0.086;
    $statpot{'p16PH'}=0.088;
    $statpot{'p16PI'}=-0.055;
    $statpot{'p16PL'}=-0.031;
    $statpot{'p16PK'}=0.205;
    $statpot{'p16PM'}=0.006;
    $statpot{'p16PF'}=-0.043;
    $statpot{'p16PP'}=0.112;
    $statpot{'p16PS'}=0.026;
    $statpot{'p16PT'}=0.020;
    $statpot{'p16PW'}=0.029;
    $statpot{'p16PY'}=-0.109;
    $statpot{'p16PV'}=-0.063;
    $statpot{'p16SA'}=-0.068;
    $statpot{'p16SR'}=0.027;
    $statpot{'p16SN'}=0.088;
    $statpot{'p16SD'}=0.108;
    $statpot{'p16SC'}=-0.006;
    $statpot{'p16SQ'}=0.048;
    $statpot{'p16SE'}=0.113;
    $statpot{'p16SG'}=0.069;
    $statpot{'p16SH'}=-0.094;
    $statpot{'p16SI'}=-0.085;
    $statpot{'p16SL'}=-0.095;
    $statpot{'p16SK'}=0.142;
    $statpot{'p16SM'}=-0.148;
    $statpot{'p16SF'}=-0.112;
    $statpot{'p16SP'}=0.026;
    $statpot{'p16SS'}=-0.026;
    $statpot{'p16ST'}=-0.011;
    $statpot{'p16SW'}=-0.056;
    $statpot{'p16SY'}=-0.082;
    $statpot{'p16SV'}=-0.131;
    $statpot{'p16TA'}=-0.012;
    $statpot{'p16TR'}=0.002;
    $statpot{'p16TN'}=0.011;
    $statpot{'p16TD'}=0.146;
    $statpot{'p16TC'}=-0.007;
    $statpot{'p16TQ'}=0.022;
    $statpot{'p16TE'}=0.095;
    $statpot{'p16TG'}=0.043;
    $statpot{'p16TH'}=0.059;
    $statpot{'p16TI'}=-0.079;
    $statpot{'p16TL'}=-0.086;
    $statpot{'p16TK'}=0.045;
    $statpot{'p16TM'}=-0.120;
    $statpot{'p16TF'}=-0.089;
    $statpot{'p16TP'}=0.020;
    $statpot{'p16TS'}=-0.011;
    $statpot{'p16TT'}=-0.113;
    $statpot{'p16TW'}=-0.100;
    $statpot{'p16TY'}=-0.086;
    $statpot{'p16TV'}=-0.102;
    $statpot{'p16WA'}=-0.029;
    $statpot{'p16WR'}=-0.027;
    $statpot{'p16WN'}=-0.064;
    $statpot{'p16WD'}=-0.100;
    $statpot{'p16WC'}=-0.157;
    $statpot{'p16WQ'}=-0.006;
    $statpot{'p16WE'}=0.114;
    $statpot{'p16WG'}=-0.079;
    $statpot{'p16WH'}=-0.154;
    $statpot{'p16WI'}=-0.178;
    $statpot{'p16WL'}=-0.089;
    $statpot{'p16WK'}=0.086;
    $statpot{'p16WM'}=-0.139;
    $statpot{'p16WF'}=-0.011;
    $statpot{'p16WP'}=0.029;
    $statpot{'p16WS'}=-0.056;
    $statpot{'p16WT'}=-0.100;
    $statpot{'p16WW'}=-0.171;
    $statpot{'p16WY'}=-0.181;
    $statpot{'p16WV'}=-0.128;
    $statpot{'p16YA'}=-0.116;
    $statpot{'p16YR'}=0.005;
    $statpot{'p16YN'}=-0.011;
    $statpot{'p16YD'}=0.033;
    $statpot{'p16YC'}=-0.175;
    $statpot{'p16YQ'}=0.002;
    $statpot{'p16YE'}=0.130;
    $statpot{'p16YG'}=0.047;
    $statpot{'p16YH'}=-0.182;
    $statpot{'p16YI'}=-0.180;
    $statpot{'p16YL'}=-0.183;
    $statpot{'p16YK'}=0.119;
    $statpot{'p16YM'}=-0.159;
    $statpot{'p16YF'}=-0.195;
    $statpot{'p16YP'}=-0.109;
    $statpot{'p16YS'}=-0.082;
    $statpot{'p16YT'}=-0.086;
    $statpot{'p16YW'}=-0.181;
    $statpot{'p16YY'}=-0.206;
    $statpot{'p16YV'}=-0.103;
    $statpot{'p16VA'}=-0.115;
    $statpot{'p16VR'}=-0.083;
    $statpot{'p16VN'}=-0.044;
    $statpot{'p16VD'}=-0.021;
    $statpot{'p16VC'}=-0.175;
    $statpot{'p16VQ'}=-0.036;
    $statpot{'p16VE'}=0.031;
    $statpot{'p16VG'}=-0.043;
    $statpot{'p16VH'}=-0.180;
    $statpot{'p16VI'}=-0.132;
    $statpot{'p16VL'}=-0.110;
    $statpot{'p16VK'}=0.042;
    $statpot{'p16VM'}=-0.223;
    $statpot{'p16VF'}=-0.109;
    $statpot{'p16VP'}=-0.063;
    $statpot{'p16VS'}=-0.131;
    $statpot{'p16VT'}=-0.102;
    $statpot{'p16VW'}=-0.128;
    $statpot{'p16VY'}=-0.103;
    $statpot{'p16VV'}=-0.112;
    $statpot{'f16AA'}=-0.134;
    $statpot{'f16AR'}=0.016;
    $statpot{'f16AN'}=-0.009;
    $statpot{'f16AD'}=0.042;
    $statpot{'f16AC'}=-0.298;
    $statpot{'f16AQ'}=0.060;
    $statpot{'f16AE'}=0.202;
    $statpot{'f16AG'}=0.018;
    $statpot{'f16AH'}=-0.086;
    $statpot{'f16AI'}=-0.185;
    $statpot{'f16AL'}=-0.154;
    $statpot{'f16AK'}=0.187;
    $statpot{'f16AM'}=-0.215;
    $statpot{'f16AF'}=-0.283;
    $statpot{'f16AP'}=0.017;
    $statpot{'f16AS'}=-0.024;
    $statpot{'f16AT'}=-0.123;
    $statpot{'f16AW'}=-0.252;
    $statpot{'f16AY'}=-0.211;
    $statpot{'f16AV'}=-0.226;
    $statpot{'f16RA'}=0.137;
    $statpot{'f16RR'}=0.197;
    $statpot{'f16RN'}=0.237;
    $statpot{'f16RD'}=0.389;
    $statpot{'f16RC'}=-0.061;
    $statpot{'f16RQ'}=0.322;
    $statpot{'f16RE'}=0.404;
    $statpot{'f16RG'}=0.198;
    $statpot{'f16RH'}=0.218;
    $statpot{'f16RI'}=-0.028;
    $statpot{'f16RL'}=0.048;
    $statpot{'f16RK'}=0.371;
    $statpot{'f16RM'}=0.115;
    $statpot{'f16RF'}=-0.147;
    $statpot{'f16RP'}=0.428;
    $statpot{'f16RS'}=0.193;
    $statpot{'f16RT'}=0.115;
    $statpot{'f16RW'}=-0.027;
    $statpot{'f16RY'}=-0.073;
    $statpot{'f16RV'}=-0.031;
    $statpot{'f16NA'}=0.107;
    $statpot{'f16NR'}=0.133;
    $statpot{'f16NN'}=0.291;
    $statpot{'f16ND'}=0.392;
    $statpot{'f16NC'}=0.304;
    $statpot{'f16NQ'}=0.448;
    $statpot{'f16NE'}=0.478;
    $statpot{'f16NG'}=0.203;
    $statpot{'f16NH'}=0.095;
    $statpot{'f16NI'}=-0.071;
    $statpot{'f16NL'}=0.003;
    $statpot{'f16NK'}=0.550;
    $statpot{'f16NM'}=-0.024;
    $statpot{'f16NF'}=-0.190;
    $statpot{'f16NP'}=0.328;
    $statpot{'f16NS'}=0.161;
    $statpot{'f16NT'}=0.177;
    $statpot{'f16NW'}=0.017;
    $statpot{'f16NY'}=0.037;
    $statpot{'f16NV'}=0.040;
    $statpot{'f16DA'}=0.191;
    $statpot{'f16DR'}=0.422;
    $statpot{'f16DN'}=0.409;
    $statpot{'f16DD'}=0.396;
    $statpot{'f16DC'}=0.196;
    $statpot{'f16DQ'}=0.402;
    $statpot{'f16DE'}=0.574;
    $statpot{'f16DG'}=0.455;
    $statpot{'f16DH'}=0.183;
    $statpot{'f16DI'}=0.220;
    $statpot{'f16DL'}=0.194;
    $statpot{'f16DK'}=0.617;
    $statpot{'f16DM'}=0.133;
    $statpot{'f16DF'}=0.212;
    $statpot{'f16DP'}=0.436;
    $statpot{'f16DS'}=0.424;
    $statpot{'f16DT'}=0.406;
    $statpot{'f16DW'}=0.075;
    $statpot{'f16DY'}=0.120;
    $statpot{'f16DV'}=0.223;
    $statpot{'f16CA'}=-0.287;
    $statpot{'f16CR'}=-0.326;
    $statpot{'f16CN'}=0.058;
    $statpot{'f16CD'}=-0.038;
    $statpot{'f16CC'}=-0.661;
    $statpot{'f16CQ'}=-0.334;
    $statpot{'f16CE'}=-0.038;
    $statpot{'f16CG'}=-0.151;
    $statpot{'f16CH'}=-0.393;
    $statpot{'f16CI'}=-0.457;
    $statpot{'f16CL'}=-0.380;
    $statpot{'f16CK'}=0.131;
    $statpot{'f16CM'}=-0.523;
    $statpot{'f16CF'}=-0.517;
    $statpot{'f16CP'}=-0.134;
    $statpot{'f16CS'}=-0.188;
    $statpot{'f16CT'}=-0.223;
    $statpot{'f16CW'}=-0.585;
    $statpot{'f16CY'}=-0.374;
    $statpot{'f16CV'}=-0.479;
    $statpot{'f16QA'}=0.150;
    $statpot{'f16QR'}=0.308;
    $statpot{'f16QN'}=0.431;
    $statpot{'f16QD'}=0.341;
    $statpot{'f16QC'}=-0.151;
    $statpot{'f16QQ'}=0.380;
    $statpot{'f16QE'}=0.499;
    $statpot{'f16QG'}=0.287;
    $statpot{'f16QH'}=0.247;
    $statpot{'f16QI'}=0.036;
    $statpot{'f16QL'}=0.102;
    $statpot{'f16QK'}=0.524;
    $statpot{'f16QM'}=-0.077;
    $statpot{'f16QF'}=-0.142;
    $statpot{'f16QP'}=0.301;
    $statpot{'f16QS'}=0.234;
    $statpot{'f16QT'}=0.127;
    $statpot{'f16QW'}=-0.022;
    $statpot{'f16QY'}=-0.105;
    $statpot{'f16QV'}=0.020;
    $statpot{'f16EA'}=0.382;
    $statpot{'f16ER'}=0.533;
    $statpot{'f16EN'}=0.551;
    $statpot{'f16ED'}=0.540;
    $statpot{'f16EC'}=0.180;
    $statpot{'f16EQ'}=0.553;
    $statpot{'f16EE'}=0.565;
    $statpot{'f16EG'}=0.420;
    $statpot{'f16EH'}=0.381;
    $statpot{'f16EI'}=0.283;
    $statpot{'f16EL'}=0.240;
    $statpot{'f16EK'}=0.632;
    $statpot{'f16EM'}=0.241;
    $statpot{'f16EF'}=0.224;
    $statpot{'f16EP'}=0.478;
    $statpot{'f16ES'}=0.343;
    $statpot{'f16ET'}=0.364;
    $statpot{'f16EW'}=0.341;
    $statpot{'f16EY'}=0.284;
    $statpot{'f16EV'}=0.266;
    $statpot{'f16GA'}=0.111;
    $statpot{'f16GR'}=0.279;
    $statpot{'f16GN'}=0.149;
    $statpot{'f16GD'}=0.321;
    $statpot{'f16GC'}=-0.048;
    $statpot{'f16GQ'}=0.250;
    $statpot{'f16GE'}=0.369;
    $statpot{'f16GG'}=0.270;
    $statpot{'f16GH'}=-0.014;
    $statpot{'f16GI'}=-0.047;
    $statpot{'f16GL'}=-0.040;
    $statpot{'f16GK'}=0.404;
    $statpot{'f16GM'}=-0.016;
    $statpot{'f16GF'}=-0.007;
    $statpot{'f16GP'}=0.278;
    $statpot{'f16GS'}=0.171;
    $statpot{'f16GT'}=0.140;
    $statpot{'f16GW'}=-0.084;
    $statpot{'f16GY'}=-0.087;
    $statpot{'f16GV'}=-0.030;
    $statpot{'f16HA'}=-0.091;
    $statpot{'f16HR'}=0.173;
    $statpot{'f16HN'}=0.090;
    $statpot{'f16HD'}=0.185;
    $statpot{'f16HC'}=-0.459;
    $statpot{'f16HQ'}=0.035;
    $statpot{'f16HE'}=0.344;
    $statpot{'f16HG'}=-0.089;
    $statpot{'f16HH'}=-0.162;
    $statpot{'f16HI'}=-0.225;
    $statpot{'f16HL'}=-0.141;
    $statpot{'f16HK'}=0.152;
    $statpot{'f16HM'}=-0.457;
    $statpot{'f16HF'}=-0.295;
    $statpot{'f16HP'}=0.033;
    $statpot{'f16HS'}=0.003;
    $statpot{'f16HT'}=0.020;
    $statpot{'f16HW'}=-0.197;
    $statpot{'f16HY'}=-0.182;
    $statpot{'f16HV'}=-0.200;
    $statpot{'f16IA'}=-0.283;
    $statpot{'f16IR'}=-0.139;
    $statpot{'f16IN'}=-0.241;
    $statpot{'f16ID'}=-0.114;
    $statpot{'f16IC'}=-0.511;
    $statpot{'f16IQ'}=-0.144;
    $statpot{'f16IE'}=0.039;
    $statpot{'f16IG'}=-0.174;
    $statpot{'f16IH'}=-0.350;
    $statpot{'f16II'}=-0.338;
    $statpot{'f16IL'}=-0.389;
    $statpot{'f16IK'}=0.085;
    $statpot{'f16IM'}=-0.494;
    $statpot{'f16IF'}=-0.438;
    $statpot{'f16IP'}=-0.220;
    $statpot{'f16IS'}=-0.303;
    $statpot{'f16IT'}=-0.391;
    $statpot{'f16IW'}=-0.427;
    $statpot{'f16IY'}=-0.477;
    $statpot{'f16IV'}=-0.321;
    $statpot{'f16LA'}=-0.233;
    $statpot{'f16LR'}=-0.107;
    $statpot{'f16LN'}=-0.126;
    $statpot{'f16LD'}=-0.068;
    $statpot{'f16LC'}=-0.429;
    $statpot{'f16LQ'}=-0.052;
    $statpot{'f16LE'}=-0.025;
    $statpot{'f16LG'}=-0.169;
    $statpot{'f16LH'}=-0.321;
    $statpot{'f16LI'}=-0.364;
    $statpot{'f16LL'}=-0.362;
    $statpot{'f16LK'}=0.037;
    $statpot{'f16LM'}=-0.388;
    $statpot{'f16LF'}=-0.383;
    $statpot{'f16LP'}=-0.106;
    $statpot{'f16LS'}=-0.233;
    $statpot{'f16LT'}=-0.274;
    $statpot{'f16LW'}=-0.335;
    $statpot{'f16LY'}=-0.337;
    $statpot{'f16LV'}=-0.344;
    $statpot{'f16KA'}=0.351;
    $statpot{'f16KR'}=0.418;
    $statpot{'f16KN'}=0.618;
    $statpot{'f16KD'}=0.561;
    $statpot{'f16KC'}=0.359;
    $statpot{'f16KQ'}=0.611;
    $statpot{'f16KE'}=0.640;
    $statpot{'f16KG'}=0.567;
    $statpot{'f16KH'}=0.370;
    $statpot{'f16KI'}=0.267;
    $statpot{'f16KL'}=0.225;
    $statpot{'f16KK'}=0.608;
    $statpot{'f16KM'}=0.245;
    $statpot{'f16KF'}=0.215;
    $statpot{'f16KP'}=0.562;
    $statpot{'f16KS'}=0.397;
    $statpot{'f16KT'}=0.392;
    $statpot{'f16KW'}=0.307;
    $statpot{'f16KY'}=0.344;
    $statpot{'f16KV'}=0.287;
    $statpot{'f16MA'}=-0.245;
    $statpot{'f16MR'}=0.093;
    $statpot{'f16MN'}=-0.168;
    $statpot{'f16MD'}=-0.109;
    $statpot{'f16MC'}=-0.583;
    $statpot{'f16MQ'}=-0.340;
    $statpot{'f16ME'}=0.110;
    $statpot{'f16MG'}=-0.162;
    $statpot{'f16MH'}=-0.456;
    $statpot{'f16MI'}=-0.459;
    $statpot{'f16ML'}=-0.336;
    $statpot{'f16MK'}=0.145;
    $statpot{'f16MM'}=-0.331;
    $statpot{'f16MF'}=-0.341;
    $statpot{'f16MP'}=-0.082;
    $statpot{'f16MS'}=-0.300;
    $statpot{'f16MT'}=-0.144;
    $statpot{'f16MW'}=-0.461;
    $statpot{'f16MY'}=-0.378;
    $statpot{'f16MV'}=-0.301;
    $statpot{'f16FA'}=-0.353;
    $statpot{'f16FR'}=-0.230;
    $statpot{'f16FN'}=-0.281;
    $statpot{'f16FD'}=-0.098;
    $statpot{'f16FC'}=-0.583;
    $statpot{'f16FQ'}=-0.206;
    $statpot{'f16FE'}=-0.001;
    $statpot{'f16FG'}=-0.208;
    $statpot{'f16FH'}=-0.335;
    $statpot{'f16FI'}=-0.477;
    $statpot{'f16FL'}=-0.379;
    $statpot{'f16FK'}=0.020;
    $statpot{'f16FM'}=-0.431;
    $statpot{'f16FF'}=-0.446;
    $statpot{'f16FP'}=-0.208;
    $statpot{'f16FS'}=-0.360;
    $statpot{'f16FT'}=-0.157;
    $statpot{'f16FW'}=-0.384;
    $statpot{'f16FY'}=-0.485;
    $statpot{'f16FV'}=-0.391;
    $statpot{'f16PA'}=0.141;
    $statpot{'f16PR'}=0.473;
    $statpot{'f16PN'}=0.329;
    $statpot{'f16PD'}=0.398;
    $statpot{'f16PC'}=0.052;
    $statpot{'f16PQ'}=0.450;
    $statpot{'f16PE'}=0.469;
    $statpot{'f16PG'}=0.381;
    $statpot{'f16PH'}=0.107;
    $statpot{'f16PI'}=-0.032;
    $statpot{'f16PL'}=0.095;
    $statpot{'f16PK'}=0.475;
    $statpot{'f16PM'}=0.104;
    $statpot{'f16PF'}=0.031;
    $statpot{'f16PP'}=0.253;
    $statpot{'f16PS'}=0.250;
    $statpot{'f16PT'}=0.277;
    $statpot{'f16PW'}=-0.004;
    $statpot{'f16PY'}=0.147;
    $statpot{'f16PV'}=0.026;
    $statpot{'f16SA'}=0.081;
    $statpot{'f16SR'}=0.201;
    $statpot{'f16SN'}=0.127;
    $statpot{'f16SD'}=0.330;
    $statpot{'f16SC'}=-0.045;
    $statpot{'f16SQ'}=0.281;
    $statpot{'f16SE'}=0.304;
    $statpot{'f16SG'}=0.159;
    $statpot{'f16SH'}=0.039;
    $statpot{'f16SI'}=-0.103;
    $statpot{'f16SL'}=-0.041;
    $statpot{'f16SK'}=0.253;
    $statpot{'f16SM'}=-0.227;
    $statpot{'f16SF'}=-0.190;
    $statpot{'f16SP'}=0.223;
    $statpot{'f16SS'}=0.082;
    $statpot{'f16ST'}=0.159;
    $statpot{'f16SW'}=-0.072;
    $statpot{'f16SY'}=0.045;
    $statpot{'f16SV'}=-0.043;
    $statpot{'f16TA'}=-0.055;
    $statpot{'f16TR'}=0.173;
    $statpot{'f16TN'}=0.151;
    $statpot{'f16TD'}=0.402;
    $statpot{'f16TC'}=-0.215;
    $statpot{'f16TQ'}=0.028;
    $statpot{'f16TE'}=0.364;
    $statpot{'f16TG'}=0.064;
    $statpot{'f16TH'}=0.033;
    $statpot{'f16TI'}=-0.262;
    $statpot{'f16TL'}=-0.172;
    $statpot{'f16TK'}=0.358;
    $statpot{'f16TM'}=-0.099;
    $statpot{'f16TF'}=-0.049;
    $statpot{'f16TP'}=0.236;
    $statpot{'f16TS'}=0.167;
    $statpot{'f16TT'}=0.101;
    $statpot{'f16TW'}=-0.220;
    $statpot{'f16TY'}=-0.010;
    $statpot{'f16TV'}=-0.049;
    $statpot{'f16WA'}=-0.246;
    $statpot{'f16WR'}=-0.116;
    $statpot{'f16WN'}=-0.232;
    $statpot{'f16WD'}=-0.100;
    $statpot{'f16WC'}=-0.456;
    $statpot{'f16WQ'}=-0.146;
    $statpot{'f16WE'}=0.126;
    $statpot{'f16WG'}=-0.272;
    $statpot{'f16WH'}=-0.395;
    $statpot{'f16WI'}=-0.380;
    $statpot{'f16WL'}=-0.304;
    $statpot{'f16WK'}=0.182;
    $statpot{'f16WM'}=-0.371;
    $statpot{'f16WF'}=-0.460;
    $statpot{'f16WP'}=-0.075;
    $statpot{'f16WS'}=-0.149;
    $statpot{'f16WT'}=-0.327;
    $statpot{'f16WW'}=-0.372;
    $statpot{'f16WY'}=-0.594;
    $statpot{'f16WV'}=-0.311;
    $statpot{'f16YA'}=-0.184;
    $statpot{'f16YR'}=-0.172;
    $statpot{'f16YN'}=-0.142;
    $statpot{'f16YD'}=-0.075;
    $statpot{'f16YC'}=-0.458;
    $statpot{'f16YQ'}=-0.293;
    $statpot{'f16YE'}=0.088;
    $statpot{'f16YG'}=-0.190;
    $statpot{'f16YH'}=-0.195;
    $statpot{'f16YI'}=-0.426;
    $statpot{'f16YL'}=-0.298;
    $statpot{'f16YK'}=0.166;
    $statpot{'f16YM'}=-0.333;
    $statpot{'f16YF'}=-0.490;
    $statpot{'f16YP'}=-0.084;
    $statpot{'f16YS'}=-0.122;
    $statpot{'f16YT'}=-0.136;
    $statpot{'f16YW'}=-0.503;
    $statpot{'f16YY'}=-0.322;
    $statpot{'f16YV'}=-0.284;
    $statpot{'f16VA'}=-0.240;
    $statpot{'f16VR'}=-0.133;
    $statpot{'f16VN'}=-0.074;
    $statpot{'f16VD'}=-0.062;
    $statpot{'f16VC'}=-0.452;
    $statpot{'f16VQ'}=-0.097;
    $statpot{'f16VE'}=0.073;
    $statpot{'f16VG'}=-0.182;
    $statpot{'f16VH'}=-0.254;
    $statpot{'f16VI'}=-0.305;
    $statpot{'f16VL'}=-0.321;
    $statpot{'f16VK'}=0.041;
    $statpot{'f16VM'}=-0.286;
    $statpot{'f16VF'}=-0.349;
    $statpot{'f16VP'}=-0.073;
    $statpot{'f16VS'}=-0.211;
    $statpot{'f16VT'}=-0.247;
    $statpot{'f16VW'}=-0.334;
    $statpot{'f16VY'}=-0.279;
    $statpot{'f16VV'}=-0.280;
    $statpot{'a16AA'}=-0.019;
    $statpot{'a16AR'}=-0.007;
    $statpot{'a16AN'}=-0.042;
    $statpot{'a16AD'}=0.037;
    $statpot{'a16AC'}=0.147;
    $statpot{'a16AQ'}=0.042;
    $statpot{'a16AE'}=0.064;
    $statpot{'a16AG'}=0.066;
    $statpot{'a16AH'}=-0.036;
    $statpot{'a16AI'}=-0.089;
    $statpot{'a16AL'}=0.073;
    $statpot{'a16AK'}=0.016;
    $statpot{'a16AM'}=0.042;
    $statpot{'a16AF'}=-0.037;
    $statpot{'a16AP'}=0.039;
    $statpot{'a16AS'}=-0.007;
    $statpot{'a16AT'}=0.009;
    $statpot{'a16AW'}=0.045;
    $statpot{'a16AY'}=0.019;
    $statpot{'a16AV'}=-0.060;
    $statpot{'a16RA'}=-0.112;
    $statpot{'a16RR'}=-0.071;
    $statpot{'a16RN'}=-0.142;
    $statpot{'a16RD'}=-0.014;
    $statpot{'a16RC'}=-0.269;
    $statpot{'a16RQ'}=-0.061;
    $statpot{'a16RE'}=0.130;
    $statpot{'a16RG'}=0.009;
    $statpot{'a16RH'}=-0.001;
    $statpot{'a16RI'}=-0.117;
    $statpot{'a16RL'}=-0.057;
    $statpot{'a16RK'}=-0.105;
    $statpot{'a16RM'}=-0.071;
    $statpot{'a16RF'}=-0.032;
    $statpot{'a16RP'}=0.109;
    $statpot{'a16RS'}=-0.112;
    $statpot{'a16RT'}=-0.112;
    $statpot{'a16RW'}=-0.174;
    $statpot{'a16RY'}=-0.099;
    $statpot{'a16RV'}=-0.116;
    $statpot{'a16NA'}=-0.140;
    $statpot{'a16NR'}=-0.069;
    $statpot{'a16NN'}=-0.036;
    $statpot{'a16ND'}=0.053;
    $statpot{'a16NC'}=-0.142;
    $statpot{'a16NQ'}=0.005;
    $statpot{'a16NE'}=0.052;
    $statpot{'a16NG'}=0.036;
    $statpot{'a16NH'}=0.092;
    $statpot{'a16NI'}=-0.228;
    $statpot{'a16NL'}=-0.177;
    $statpot{'a16NK'}=0.058;
    $statpot{'a16NM'}=-0.155;
    $statpot{'a16NF'}=-0.098;
    $statpot{'a16NP'}=0.075;
    $statpot{'a16NS'}=-0.002;
    $statpot{'a16NT'}=-0.041;
    $statpot{'a16NW'}=-0.209;
    $statpot{'a16NY'}=-0.168;
    $statpot{'a16NV'}=-0.181;
    $statpot{'a16DA'}=-0.091;
    $statpot{'a16DR'}=-0.035;
    $statpot{'a16DN'}=0.042;
    $statpot{'a16DD'}=0.122;
    $statpot{'a16DC'}=-0.162;
    $statpot{'a16DQ'}=-0.024;
    $statpot{'a16DE'}=0.122;
    $statpot{'a16DG'}=0.118;
    $statpot{'a16DH'}=-0.080;
    $statpot{'a16DI'}=-0.260;
    $statpot{'a16DL'}=-0.144;
    $statpot{'a16DK'}=0.072;
    $statpot{'a16DM'}=-0.110;
    $statpot{'a16DF'}=-0.222;
    $statpot{'a16DP'}=0.150;
    $statpot{'a16DS'}=-0.001;
    $statpot{'a16DT'}=0.037;
    $statpot{'a16DW'}=-0.200;
    $statpot{'a16DY'}=-0.145;
    $statpot{'a16DV'}=-0.224;
    $statpot{'a16CA'}=0.132;
    $statpot{'a16CR'}=-0.010;
    $statpot{'a16CN'}=0.035;
    $statpot{'a16CD'}=0.025;
    $statpot{'a16CC'}=0.308;
    $statpot{'a16CQ'}=0.169;
    $statpot{'a16CE'}=0.060;
    $statpot{'a16CG'}=0.192;
    $statpot{'a16CH'}=-0.250;
    $statpot{'a16CI'}=-0.020;
    $statpot{'a16CL'}=0.020;
    $statpot{'a16CK'}=0.170;
    $statpot{'a16CM'}=0.046;
    $statpot{'a16CF'}=0.071;
    $statpot{'a16CP'}=-0.134;
    $statpot{'a16CS'}=0.098;
    $statpot{'a16CT'}=-0.070;
    $statpot{'a16CW'}=0.332;
    $statpot{'a16CY'}=0.274;
    $statpot{'a16CV'}=0.004;
    $statpot{'a16QA'}=-0.037;
    $statpot{'a16QR'}=-0.051;
    $statpot{'a16QN'}=0.015;
    $statpot{'a16QD'}=0.016;
    $statpot{'a16QC'}=-0.061;
    $statpot{'a16QQ'}=0.010;
    $statpot{'a16QE'}=0.096;
    $statpot{'a16QG'}=0.092;
    $statpot{'a16QH'}=-0.065;
    $statpot{'a16QI'}=-0.141;
    $statpot{'a16QL'}=-0.102;
    $statpot{'a16QK'}=0.032;
    $statpot{'a16QM'}=-0.255;
    $statpot{'a16QF'}=-0.116;
    $statpot{'a16QP'}=0.310;
    $statpot{'a16QS'}=-0.066;
    $statpot{'a16QT'}=-0.130;
    $statpot{'a16QW'}=-0.150;
    $statpot{'a16QY'}=-0.180;
    $statpot{'a16QV'}=-0.155;
    $statpot{'a16EA'}=-0.070;
    $statpot{'a16ER'}=0.044;
    $statpot{'a16EN'}=0.010;
    $statpot{'a16ED'}=0.143;
    $statpot{'a16EC'}=-0.127;
    $statpot{'a16EQ'}=0.063;
    $statpot{'a16EE'}=0.123;
    $statpot{'a16EG'}=0.066;
    $statpot{'a16EH'}=-0.007;
    $statpot{'a16EI'}=-0.103;
    $statpot{'a16EL'}=-0.141;
    $statpot{'a16EK'}=0.059;
    $statpot{'a16EM'}=-0.074;
    $statpot{'a16EF'}=-0.154;
    $statpot{'a16EP'}=0.088;
    $statpot{'a16ES'}=-0.023;
    $statpot{'a16ET'}=-0.040;
    $statpot{'a16EW'}=-0.127;
    $statpot{'a16EY'}=-0.084;
    $statpot{'a16EV'}=-0.167;
    $statpot{'a16GA'}=-0.021;
    $statpot{'a16GR'}=-0.049;
    $statpot{'a16GN'}=0.082;
    $statpot{'a16GD'}=0.223;
    $statpot{'a16GC'}=0.071;
    $statpot{'a16GQ'}=0.123;
    $statpot{'a16GE'}=0.104;
    $statpot{'a16GG'}=0.233;
    $statpot{'a16GH'}=0.038;
    $statpot{'a16GI'}=-0.174;
    $statpot{'a16GL'}=-0.099;
    $statpot{'a16GK'}=0.124;
    $statpot{'a16GM'}=-0.075;
    $statpot{'a16GF'}=-0.113;
    $statpot{'a16GP'}=0.104;
    $statpot{'a16GS'}=0.067;
    $statpot{'a16GT'}=-0.020;
    $statpot{'a16GW'}=-0.199;
    $statpot{'a16GY'}=-0.003;
    $statpot{'a16GV'}=-0.142;
    $statpot{'a16HA'}=-0.031;
    $statpot{'a16HR'}=0.035;
    $statpot{'a16HN'}=0.096;
    $statpot{'a16HD'}=-0.081;
    $statpot{'a16HC'}=-0.174;
    $statpot{'a16HQ'}=0.113;
    $statpot{'a16HE'}=0.017;
    $statpot{'a16HG'}=0.119;
    $statpot{'a16HH'}=-0.050;
    $statpot{'a16HI'}=-0.093;
    $statpot{'a16HL'}=-0.178;
    $statpot{'a16HK'}=0.208;
    $statpot{'a16HM'}=-0.205;
    $statpot{'a16HF'}=-0.081;
    $statpot{'a16HP'}=-0.145;
    $statpot{'a16HS'}=-0.039;
    $statpot{'a16HT'}=-0.064;
    $statpot{'a16HW'}=-0.168;
    $statpot{'a16HY'}=0.167;
    $statpot{'a16HV'}=-0.046;
    $statpot{'a16IA'}=0.032;
    $statpot{'a16IR'}=-0.008;
    $statpot{'a16IN'}=-0.066;
    $statpot{'a16ID'}=0.010;
    $statpot{'a16IC'}=0.065;
    $statpot{'a16IQ'}=0.029;
    $statpot{'a16IE'}=0.100;
    $statpot{'a16IG'}=-0.051;
    $statpot{'a16IH'}=0.065;
    $statpot{'a16II'}=0.210;
    $statpot{'a16IL'}=0.186;
    $statpot{'a16IK'}=0.009;
    $statpot{'a16IM'}=0.037;
    $statpot{'a16IF'}=0.154;
    $statpot{'a16IP'}=0.015;
    $statpot{'a16IS'}=-0.016;
    $statpot{'a16IT'}=0.005;
    $statpot{'a16IW'}=0.152;
    $statpot{'a16IY'}=0.147;
    $statpot{'a16IV'}=0.111;
    $statpot{'a16LA'}=0.180;
    $statpot{'a16LR'}=0.101;
    $statpot{'a16LN'}=-0.061;
    $statpot{'a16LD'}=0.087;
    $statpot{'a16LC'}=0.095;
    $statpot{'a16LQ'}=0.037;
    $statpot{'a16LE'}=0.084;
    $statpot{'a16LG'}=0.037;
    $statpot{'a16LH'}=0.023;
    $statpot{'a16LI'}=0.146;
    $statpot{'a16LL'}=0.226;
    $statpot{'a16LK'}=0.028;
    $statpot{'a16LM'}=0.194;
    $statpot{'a16LF'}=0.183;
    $statpot{'a16LP'}=0.063;
    $statpot{'a16LS'}=0.048;
    $statpot{'a16LT'}=0.022;
    $statpot{'a16LW'}=0.275;
    $statpot{'a16LY'}=0.156;
    $statpot{'a16LV'}=0.163;
    $statpot{'a16KA'}=-0.102;
    $statpot{'a16KR'}=-0.132;
    $statpot{'a16KN'}=0.021;
    $statpot{'a16KD'}=0.104;
    $statpot{'a16KC'}=-0.010;
    $statpot{'a16KQ'}=-0.016;
    $statpot{'a16KE'}=0.055;
    $statpot{'a16KG'}=0.019;
    $statpot{'a16KH'}=0.030;
    $statpot{'a16KI'}=-0.130;
    $statpot{'a16KL'}=-0.123;
    $statpot{'a16KK'}=0.027;
    $statpot{'a16KM'}=-0.024;
    $statpot{'a16KF'}=-0.150;
    $statpot{'a16KP'}=0.137;
    $statpot{'a16KS'}=-0.066;
    $statpot{'a16KT'}=-0.112;
    $statpot{'a16KW'}=-0.019;
    $statpot{'a16KY'}=-0.001;
    $statpot{'a16KV'}=-0.204;
    $statpot{'a16MA'}=0.082;
    $statpot{'a16MR'}=-0.052;
    $statpot{'a16MN'}=-0.015;
    $statpot{'a16MD'}=0.125;
    $statpot{'a16MC'}=0.158;
    $statpot{'a16MQ'}=0.024;
    $statpot{'a16ME'}=0.031;
    $statpot{'a16MG'}=0.084;
    $statpot{'a16MH'}=-0.205;
    $statpot{'a16MI'}=-0.020;
    $statpot{'a16ML'}=0.108;
    $statpot{'a16MK'}=0.057;
    $statpot{'a16MM'}=0.224;
    $statpot{'a16MF'}=0.070;
    $statpot{'a16MP'}=0.027;
    $statpot{'a16MS'}=0.016;
    $statpot{'a16MT'}=-0.021;
    $statpot{'a16MW'}=0.042;
    $statpot{'a16MY'}=-0.029;
    $statpot{'a16MV'}=0.050;
    $statpot{'a16FA'}=0.058;
    $statpot{'a16FR'}=0.063;
    $statpot{'a16FN'}=0.005;
    $statpot{'a16FD'}=0.034;
    $statpot{'a16FC'}=0.193;
    $statpot{'a16FQ'}=-0.051;
    $statpot{'a16FE'}=0.029;
    $statpot{'a16FG'}=0.100;
    $statpot{'a16FH'}=-0.030;
    $statpot{'a16FI'}=0.224;
    $statpot{'a16FL'}=0.175;
    $statpot{'a16FK'}=0.003;
    $statpot{'a16FM'}=0.219;
    $statpot{'a16FF'}=0.282;
    $statpot{'a16FP'}=0.017;
    $statpot{'a16FS'}=0.023;
    $statpot{'a16FT'}=-0.005;
    $statpot{'a16FW'}=-0.066;
    $statpot{'a16FY'}=0.119;
    $statpot{'a16FV'}=0.059;
    $statpot{'a16PA'}=-0.073;
    $statpot{'a16PR'}=0.079;
    $statpot{'a16PN'}=0.074;
    $statpot{'a16PD'}=0.178;
    $statpot{'a16PC'}=-0.280;
    $statpot{'a16PQ'}=0.184;
    $statpot{'a16PE'}=0.094;
    $statpot{'a16PG'}=0.025;
    $statpot{'a16PH'}=-0.200;
    $statpot{'a16PI'}=-0.176;
    $statpot{'a16PL'}=-0.129;
    $statpot{'a16PK'}=0.195;
    $statpot{'a16PM'}=-0.142;
    $statpot{'a16PF'}=-0.211;
    $statpot{'a16PP'}=0.139;
    $statpot{'a16PS'}=0.001;
    $statpot{'a16PT'}=-0.139;
    $statpot{'a16PW'}=-0.154;
    $statpot{'a16PY'}=-0.115;
    $statpot{'a16PV'}=-0.136;
    $statpot{'a16SA'}=-0.101;
    $statpot{'a16SR'}=-0.118;
    $statpot{'a16SN'}=0.025;
    $statpot{'a16SD'}=0.061;
    $statpot{'a16SC'}=-0.051;
    $statpot{'a16SQ'}=-0.098;
    $statpot{'a16SE'}=0.003;
    $statpot{'a16SG'}=0.077;
    $statpot{'a16SH'}=-0.071;
    $statpot{'a16SI'}=-0.222;
    $statpot{'a16SL'}=-0.152;
    $statpot{'a16SK'}=0.031;
    $statpot{'a16SM'}=-0.074;
    $statpot{'a16SF'}=-0.173;
    $statpot{'a16SP'}=0.022;
    $statpot{'a16SS'}=-0.015;
    $statpot{'a16ST'}=-0.103;
    $statpot{'a16SW'}=-0.167;
    $statpot{'a16SY'}=-0.115;
    $statpot{'a16SV'}=-0.237;
    $statpot{'a16TA'}=-0.061;
    $statpot{'a16TR'}=-0.154;
    $statpot{'a16TN'}=-0.021;
    $statpot{'a16TD'}=0.039;
    $statpot{'a16TC'}=-0.079;
    $statpot{'a16TQ'}=-0.051;
    $statpot{'a16TE'}=-0.041;
    $statpot{'a16TG'}=0.046;
    $statpot{'a16TH'}=-0.075;
    $statpot{'a16TI'}=-0.154;
    $statpot{'a16TL'}=-0.096;
    $statpot{'a16TK'}=-0.093;
    $statpot{'a16TM'}=-0.069;
    $statpot{'a16TF'}=-0.113;
    $statpot{'a16TP'}=-0.112;
    $statpot{'a16TS'}=-0.109;
    $statpot{'a16TT'}=-0.044;
    $statpot{'a16TW'}=-0.040;
    $statpot{'a16TY'}=-0.143;
    $statpot{'a16TV'}=-0.207;
    $statpot{'a16WA'}=0.038;
    $statpot{'a16WR'}=-0.095;
    $statpot{'a16WN'}=0.024;
    $statpot{'a16WD'}=-0.053;
    $statpot{'a16WC'}=0.091;
    $statpot{'a16WQ'}=-0.035;
    $statpot{'a16WE'}=0.030;
    $statpot{'a16WG'}=-0.008;
    $statpot{'a16WH'}=0.072;
    $statpot{'a16WI'}=0.079;
    $statpot{'a16WL'}=0.220;
    $statpot{'a16WK'}=0.075;
    $statpot{'a16WM'}=-0.086;
    $statpot{'a16WF'}=0.042;
    $statpot{'a16WP'}=-0.093;
    $statpot{'a16WS'}=-0.097;
    $statpot{'a16WT'}=0.094;
    $statpot{'a16WW'}=0.437;
    $statpot{'a16WY'}=0.088;
    $statpot{'a16WV'}=-0.011;
    $statpot{'a16YA'}=-0.014;
    $statpot{'a16YR'}=0.004;
    $statpot{'a16YN'}=-0.007;
    $statpot{'a16YD'}=0.028;
    $statpot{'a16YC'}=0.439;
    $statpot{'a16YQ'}=0.020;
    $statpot{'a16YE'}=0.073;
    $statpot{'a16YG'}=0.119;
    $statpot{'a16YH'}=0.185;
    $statpot{'a16YI'}=0.063;
    $statpot{'a16YL'}=0.098;
    $statpot{'a16YK'}=0.140;
    $statpot{'a16YM'}=-0.087;
    $statpot{'a16YF'}=0.131;
    $statpot{'a16YP'}=0.100;
    $statpot{'a16YS'}=0.042;
    $statpot{'a16YT'}=-0.025;
    $statpot{'a16YW'}=-0.059;
    $statpot{'a16YY'}=0.201;
    $statpot{'a16YV'}=0.092;
    $statpot{'a16VA'}=-0.043;
    $statpot{'a16VR'}=-0.015;
    $statpot{'a16VN'}=-0.086;
    $statpot{'a16VD'}=0.003;
    $statpot{'a16VC'}=-0.034;
    $statpot{'a16VQ'}=-0.050;
    $statpot{'a16VE'}=-0.022;
    $statpot{'a16VG'}=0.012;
    $statpot{'a16VH'}=0.018;
    $statpot{'a16VI'}=0.087;
    $statpot{'a16VL'}=0.127;
    $statpot{'a16VK'}=-0.025;
    $statpot{'a16VM'}=0.029;
    $statpot{'a16VF'}=-0.002;
    $statpot{'a16VP'}=-0.046;
    $statpot{'a16VS'}=-0.083;
    $statpot{'a16VT'}=-0.008;
    $statpot{'a16VW'}=0.021;
    $statpot{'a16VY'}=0.086;
    $statpot{'a16VV'}=0.058;
    $statpot{'p17AA'}=-0.042;
    $statpot{'p17AR'}=0.024;
    $statpot{'p17AN'}=-0.026;
    $statpot{'p17AD'}=0.065;
    $statpot{'p17AC'}=-0.124;
    $statpot{'p17AQ'}=0.005;
    $statpot{'p17AE'}=0.107;
    $statpot{'p17AG'}=0.024;
    $statpot{'p17AH'}=-0.043;
    $statpot{'p17AI'}=-0.034;
    $statpot{'p17AL'}=-0.016;
    $statpot{'p17AK'}=0.031;
    $statpot{'p17AM'}=-0.109;
    $statpot{'p17AF'}=-0.088;
    $statpot{'p17AP'}=0.038;
    $statpot{'p17AS'}=-0.069;
    $statpot{'p17AT'}=-0.073;
    $statpot{'p17AW'}=-0.118;
    $statpot{'p17AY'}=-0.085;
    $statpot{'p17AV'}=-0.096;
    $statpot{'p17RA'}=0.024;
    $statpot{'p17RR'}=0.176;
    $statpot{'p17RN'}=0.034;
    $statpot{'p17RD'}=0.108;
    $statpot{'p17RC'}=0.118;
    $statpot{'p17RQ'}=0.082;
    $statpot{'p17RE'}=0.187;
    $statpot{'p17RG'}=0.095;
    $statpot{'p17RH'}=-0.056;
    $statpot{'p17RI'}=-0.071;
    $statpot{'p17RL'}=-0.030;
    $statpot{'p17RK'}=0.131;
    $statpot{'p17RM'}=-0.062;
    $statpot{'p17RF'}=-0.065;
    $statpot{'p17RP'}=0.042;
    $statpot{'p17RS'}=0.057;
    $statpot{'p17RT'}=0.119;
    $statpot{'p17RW'}=-0.026;
    $statpot{'p17RY'}=-0.066;
    $statpot{'p17RV'}=-0.091;
    $statpot{'p17NA'}=-0.026;
    $statpot{'p17NR'}=0.034;
    $statpot{'p17NN'}=0.177;
    $statpot{'p17ND'}=0.125;
    $statpot{'p17NC'}=-0.018;
    $statpot{'p17NQ'}=0.062;
    $statpot{'p17NE'}=0.141;
    $statpot{'p17NG'}=0.054;
    $statpot{'p17NH'}=-0.067;
    $statpot{'p17NI'}=-0.104;
    $statpot{'p17NL'}=0.026;
    $statpot{'p17NK'}=0.186;
    $statpot{'p17NM'}=-0.142;
    $statpot{'p17NF'}=-0.012;
    $statpot{'p17NP'}=0.017;
    $statpot{'p17NS'}=0.024;
    $statpot{'p17NT'}=0.016;
    $statpot{'p17NW'}=-0.031;
    $statpot{'p17NY'}=-0.013;
    $statpot{'p17NV'}=-0.049;
    $statpot{'p17DA'}=0.065;
    $statpot{'p17DR'}=0.108;
    $statpot{'p17DN'}=0.125;
    $statpot{'p17DD'}=0.146;
    $statpot{'p17DC'}=-0.078;
    $statpot{'p17DQ'}=0.112;
    $statpot{'p17DE'}=0.166;
    $statpot{'p17DG'}=0.102;
    $statpot{'p17DH'}=0.141;
    $statpot{'p17DI'}=0.031;
    $statpot{'p17DL'}=0.017;
    $statpot{'p17DK'}=0.148;
    $statpot{'p17DM'}=-0.018;
    $statpot{'p17DF'}=-0.003;
    $statpot{'p17DP'}=0.066;
    $statpot{'p17DS'}=0.087;
    $statpot{'p17DT'}=0.088;
    $statpot{'p17DW'}=0.023;
    $statpot{'p17DY'}=0.004;
    $statpot{'p17DV'}=0.016;
    $statpot{'p17CA'}=-0.124;
    $statpot{'p17CR'}=0.118;
    $statpot{'p17CN'}=-0.018;
    $statpot{'p17CD'}=-0.078;
    $statpot{'p17CC'}=-0.114;
    $statpot{'p17CQ'}=-0.087;
    $statpot{'p17CE'}=0.034;
    $statpot{'p17CG'}=-0.007;
    $statpot{'p17CH'}=-0.208;
    $statpot{'p17CI'}=-0.144;
    $statpot{'p17CL'}=-0.161;
    $statpot{'p17CK'}=0.181;
    $statpot{'p17CM'}=-0.258;
    $statpot{'p17CF'}=-0.152;
    $statpot{'p17CP'}=-0.075;
    $statpot{'p17CS'}=-0.039;
    $statpot{'p17CT'}=-0.137;
    $statpot{'p17CW'}=-0.217;
    $statpot{'p17CY'}=-0.080;
    $statpot{'p17CV'}=-0.120;
    $statpot{'p17QA'}=0.005;
    $statpot{'p17QR'}=0.082;
    $statpot{'p17QN'}=0.062;
    $statpot{'p17QD'}=0.112;
    $statpot{'p17QC'}=-0.087;
    $statpot{'p17QQ'}=0.057;
    $statpot{'p17QE'}=0.139;
    $statpot{'p17QG'}=0.022;
    $statpot{'p17QH'}=0.032;
    $statpot{'p17QI'}=-0.079;
    $statpot{'p17QL'}=0.034;
    $statpot{'p17QK'}=0.228;
    $statpot{'p17QM'}=-0.127;
    $statpot{'p17QF'}=-0.053;
    $statpot{'p17QP'}=0.148;
    $statpot{'p17QS'}=0.058;
    $statpot{'p17QT'}=-0.089;
    $statpot{'p17QW'}=-0.001;
    $statpot{'p17QY'}=-0.025;
    $statpot{'p17QV'}=-0.106;
    $statpot{'p17EA'}=0.107;
    $statpot{'p17ER'}=0.187;
    $statpot{'p17EN'}=0.141;
    $statpot{'p17ED'}=0.166;
    $statpot{'p17EC'}=0.034;
    $statpot{'p17EQ'}=0.139;
    $statpot{'p17EE'}=0.207;
    $statpot{'p17EG'}=0.157;
    $statpot{'p17EH'}=0.086;
    $statpot{'p17EI'}=0.029;
    $statpot{'p17EL'}=0.109;
    $statpot{'p17EK'}=0.269;
    $statpot{'p17EM'}=0.108;
    $statpot{'p17EF'}=0.058;
    $statpot{'p17EP'}=0.122;
    $statpot{'p17ES'}=0.117;
    $statpot{'p17ET'}=0.092;
    $statpot{'p17EW'}=0.027;
    $statpot{'p17EY'}=0.043;
    $statpot{'p17EV'}=0.072;
    $statpot{'p17GA'}=0.024;
    $statpot{'p17GR'}=0.095;
    $statpot{'p17GN'}=0.054;
    $statpot{'p17GD'}=0.102;
    $statpot{'p17GC'}=-0.007;
    $statpot{'p17GQ'}=0.022;
    $statpot{'p17GE'}=0.157;
    $statpot{'p17GG'}=0.160;
    $statpot{'p17GH'}=-0.037;
    $statpot{'p17GI'}=-0.006;
    $statpot{'p17GL'}=0.008;
    $statpot{'p17GK'}=0.183;
    $statpot{'p17GM'}=-0.041;
    $statpot{'p17GF'}=0.010;
    $statpot{'p17GP'}=0.062;
    $statpot{'p17GS'}=0.010;
    $statpot{'p17GT'}=0.042;
    $statpot{'p17GW'}=0.024;
    $statpot{'p17GY'}=0.061;
    $statpot{'p17GV'}=-0.012;
    $statpot{'p17HA'}=-0.043;
    $statpot{'p17HR'}=-0.056;
    $statpot{'p17HN'}=-0.067;
    $statpot{'p17HD'}=0.141;
    $statpot{'p17HC'}=-0.208;
    $statpot{'p17HQ'}=0.032;
    $statpot{'p17HE'}=0.086;
    $statpot{'p17HG'}=-0.037;
    $statpot{'p17HH'}=-0.021;
    $statpot{'p17HI'}=-0.186;
    $statpot{'p17HL'}=-0.133;
    $statpot{'p17HK'}=0.197;
    $statpot{'p17HM'}=-0.134;
    $statpot{'p17HF'}=-0.189;
    $statpot{'p17HP'}=-0.012;
    $statpot{'p17HS'}=-0.058;
    $statpot{'p17HT'}=-0.055;
    $statpot{'p17HW'}=-0.088;
    $statpot{'p17HY'}=-0.139;
    $statpot{'p17HV'}=-0.142;
    $statpot{'p17IA'}=-0.034;
    $statpot{'p17IR'}=-0.071;
    $statpot{'p17IN'}=-0.104;
    $statpot{'p17ID'}=0.031;
    $statpot{'p17IC'}=-0.144;
    $statpot{'p17IQ'}=-0.079;
    $statpot{'p17IE'}=0.029;
    $statpot{'p17IG'}=-0.006;
    $statpot{'p17IH'}=-0.186;
    $statpot{'p17II'}=-0.051;
    $statpot{'p17IL'}=-0.024;
    $statpot{'p17IK'}=0.058;
    $statpot{'p17IM'}=-0.156;
    $statpot{'p17IF'}=-0.210;
    $statpot{'p17IP'}=-0.124;
    $statpot{'p17IS'}=-0.156;
    $statpot{'p17IT'}=-0.124;
    $statpot{'p17IW'}=-0.244;
    $statpot{'p17IY'}=-0.079;
    $statpot{'p17IV'}=-0.083;
    $statpot{'p17LA'}=-0.016;
    $statpot{'p17LR'}=-0.030;
    $statpot{'p17LN'}=0.026;
    $statpot{'p17LD'}=0.017;
    $statpot{'p17LC'}=-0.161;
    $statpot{'p17LQ'}=0.034;
    $statpot{'p17LE'}=0.109;
    $statpot{'p17LG'}=0.008;
    $statpot{'p17LH'}=-0.133;
    $statpot{'p17LI'}=-0.024;
    $statpot{'p17LL'}=-0.059;
    $statpot{'p17LK'}=0.133;
    $statpot{'p17LM'}=-0.120;
    $statpot{'p17LF'}=-0.082;
    $statpot{'p17LP'}=-0.022;
    $statpot{'p17LS'}=-0.101;
    $statpot{'p17LT'}=-0.124;
    $statpot{'p17LW'}=-0.101;
    $statpot{'p17LY'}=-0.083;
    $statpot{'p17LV'}=-0.070;
    $statpot{'p17KA'}=0.031;
    $statpot{'p17KR'}=0.131;
    $statpot{'p17KN'}=0.186;
    $statpot{'p17KD'}=0.148;
    $statpot{'p17KC'}=0.181;
    $statpot{'p17KQ'}=0.228;
    $statpot{'p17KE'}=0.269;
    $statpot{'p17KG'}=0.183;
    $statpot{'p17KH'}=0.197;
    $statpot{'p17KI'}=0.058;
    $statpot{'p17KL'}=0.133;
    $statpot{'p17KK'}=0.205;
    $statpot{'p17KM'}=0.029;
    $statpot{'p17KF'}=0.009;
    $statpot{'p17KP'}=0.223;
    $statpot{'p17KS'}=0.147;
    $statpot{'p17KT'}=0.124;
    $statpot{'p17KW'}=0.081;
    $statpot{'p17KY'}=0.080;
    $statpot{'p17KV'}=0.067;
    $statpot{'p17MA'}=-0.109;
    $statpot{'p17MR'}=-0.062;
    $statpot{'p17MN'}=-0.142;
    $statpot{'p17MD'}=-0.018;
    $statpot{'p17MC'}=-0.258;
    $statpot{'p17MQ'}=-0.127;
    $statpot{'p17ME'}=0.108;
    $statpot{'p17MG'}=-0.041;
    $statpot{'p17MH'}=-0.134;
    $statpot{'p17MI'}=-0.156;
    $statpot{'p17ML'}=-0.120;
    $statpot{'p17MK'}=0.029;
    $statpot{'p17MM'}=-0.119;
    $statpot{'p17MF'}=-0.252;
    $statpot{'p17MP'}=-0.126;
    $statpot{'p17MS'}=-0.169;
    $statpot{'p17MT'}=-0.108;
    $statpot{'p17MW'}=-0.126;
    $statpot{'p17MY'}=-0.214;
    $statpot{'p17MV'}=-0.155;
    $statpot{'p17FA'}=-0.088;
    $statpot{'p17FR'}=-0.065;
    $statpot{'p17FN'}=-0.012;
    $statpot{'p17FD'}=-0.003;
    $statpot{'p17FC'}=-0.152;
    $statpot{'p17FQ'}=-0.053;
    $statpot{'p17FE'}=0.058;
    $statpot{'p17FG'}=0.010;
    $statpot{'p17FH'}=-0.189;
    $statpot{'p17FI'}=-0.210;
    $statpot{'p17FL'}=-0.082;
    $statpot{'p17FK'}=0.009;
    $statpot{'p17FM'}=-0.252;
    $statpot{'p17FF'}=-0.153;
    $statpot{'p17FP'}=-0.052;
    $statpot{'p17FS'}=-0.132;
    $statpot{'p17FT'}=-0.124;
    $statpot{'p17FW'}=-0.201;
    $statpot{'p17FY'}=-0.209;
    $statpot{'p17FV'}=-0.190;
    $statpot{'p17PA'}=0.038;
    $statpot{'p17PR'}=0.042;
    $statpot{'p17PN'}=0.017;
    $statpot{'p17PD'}=0.066;
    $statpot{'p17PC'}=-0.075;
    $statpot{'p17PQ'}=0.148;
    $statpot{'p17PE'}=0.122;
    $statpot{'p17PG'}=0.062;
    $statpot{'p17PH'}=-0.012;
    $statpot{'p17PI'}=-0.124;
    $statpot{'p17PL'}=-0.022;
    $statpot{'p17PK'}=0.223;
    $statpot{'p17PM'}=-0.126;
    $statpot{'p17PF'}=-0.052;
    $statpot{'p17PP'}=-0.009;
    $statpot{'p17PS'}=0.034;
    $statpot{'p17PT'}=-0.036;
    $statpot{'p17PW'}=-0.070;
    $statpot{'p17PY'}=-0.002;
    $statpot{'p17PV'}=-0.049;
    $statpot{'p17SA'}=-0.069;
    $statpot{'p17SR'}=0.057;
    $statpot{'p17SN'}=0.024;
    $statpot{'p17SD'}=0.087;
    $statpot{'p17SC'}=-0.039;
    $statpot{'p17SQ'}=0.058;
    $statpot{'p17SE'}=0.117;
    $statpot{'p17SG'}=0.010;
    $statpot{'p17SH'}=-0.058;
    $statpot{'p17SI'}=-0.156;
    $statpot{'p17SL'}=-0.101;
    $statpot{'p17SK'}=0.147;
    $statpot{'p17SM'}=-0.169;
    $statpot{'p17SF'}=-0.132;
    $statpot{'p17SP'}=0.034;
    $statpot{'p17SS'}=-0.019;
    $statpot{'p17ST'}=-0.048;
    $statpot{'p17SW'}=-0.076;
    $statpot{'p17SY'}=-0.087;
    $statpot{'p17SV'}=-0.113;
    $statpot{'p17TA'}=-0.073;
    $statpot{'p17TR'}=0.119;
    $statpot{'p17TN'}=0.016;
    $statpot{'p17TD'}=0.088;
    $statpot{'p17TC'}=-0.137;
    $statpot{'p17TQ'}=-0.089;
    $statpot{'p17TE'}=0.092;
    $statpot{'p17TG'}=0.042;
    $statpot{'p17TH'}=-0.055;
    $statpot{'p17TI'}=-0.124;
    $statpot{'p17TL'}=-0.124;
    $statpot{'p17TK'}=0.124;
    $statpot{'p17TM'}=-0.108;
    $statpot{'p17TF'}=-0.124;
    $statpot{'p17TP'}=-0.036;
    $statpot{'p17TS'}=-0.048;
    $statpot{'p17TT'}=-0.034;
    $statpot{'p17TW'}=-0.101;
    $statpot{'p17TY'}=-0.043;
    $statpot{'p17TV'}=-0.087;
    $statpot{'p17WA'}=-0.118;
    $statpot{'p17WR'}=-0.026;
    $statpot{'p17WN'}=-0.031;
    $statpot{'p17WD'}=0.023;
    $statpot{'p17WC'}=-0.217;
    $statpot{'p17WQ'}=-0.001;
    $statpot{'p17WE'}=0.027;
    $statpot{'p17WG'}=0.024;
    $statpot{'p17WH'}=-0.088;
    $statpot{'p17WI'}=-0.244;
    $statpot{'p17WL'}=-0.101;
    $statpot{'p17WK'}=0.081;
    $statpot{'p17WM'}=-0.126;
    $statpot{'p17WF'}=-0.201;
    $statpot{'p17WP'}=-0.070;
    $statpot{'p17WS'}=-0.076;
    $statpot{'p17WT'}=-0.101;
    $statpot{'p17WW'}=-0.156;
    $statpot{'p17WY'}=-0.168;
    $statpot{'p17WV'}=-0.140;
    $statpot{'p17YA'}=-0.085;
    $statpot{'p17YR'}=-0.066;
    $statpot{'p17YN'}=-0.013;
    $statpot{'p17YD'}=0.004;
    $statpot{'p17YC'}=-0.080;
    $statpot{'p17YQ'}=-0.025;
    $statpot{'p17YE'}=0.043;
    $statpot{'p17YG'}=0.061;
    $statpot{'p17YH'}=-0.139;
    $statpot{'p17YI'}=-0.079;
    $statpot{'p17YL'}=-0.083;
    $statpot{'p17YK'}=0.080;
    $statpot{'p17YM'}=-0.214;
    $statpot{'p17YF'}=-0.209;
    $statpot{'p17YP'}=-0.002;
    $statpot{'p17YS'}=-0.087;
    $statpot{'p17YT'}=-0.043;
    $statpot{'p17YW'}=-0.168;
    $statpot{'p17YY'}=-0.192;
    $statpot{'p17YV'}=-0.176;
    $statpot{'p17VA'}=-0.096;
    $statpot{'p17VR'}=-0.091;
    $statpot{'p17VN'}=-0.049;
    $statpot{'p17VD'}=0.016;
    $statpot{'p17VC'}=-0.120;
    $statpot{'p17VQ'}=-0.106;
    $statpot{'p17VE'}=0.072;
    $statpot{'p17VG'}=-0.012;
    $statpot{'p17VH'}=-0.142;
    $statpot{'p17VI'}=-0.083;
    $statpot{'p17VL'}=-0.070;
    $statpot{'p17VK'}=0.067;
    $statpot{'p17VM'}=-0.155;
    $statpot{'p17VF'}=-0.190;
    $statpot{'p17VP'}=-0.049;
    $statpot{'p17VS'}=-0.113;
    $statpot{'p17VT'}=-0.087;
    $statpot{'p17VW'}=-0.140;
    $statpot{'p17VY'}=-0.176;
    $statpot{'p17VV'}=-0.043;
    $statpot{'f17AA'}=-0.076;
    $statpot{'f17AR'}=0.093;
    $statpot{'f17AN'}=0.058;
    $statpot{'f17AD'}=0.044;
    $statpot{'f17AC'}=-0.255;
    $statpot{'f17AQ'}=-0.037;
    $statpot{'f17AE'}=0.205;
    $statpot{'f17AG'}=-0.020;
    $statpot{'f17AH'}=-0.214;
    $statpot{'f17AI'}=-0.215;
    $statpot{'f17AL'}=-0.151;
    $statpot{'f17AK'}=0.187;
    $statpot{'f17AM'}=-0.237;
    $statpot{'f17AF'}=-0.228;
    $statpot{'f17AP'}=0.011;
    $statpot{'f17AS'}=0.007;
    $statpot{'f17AT'}=-0.094;
    $statpot{'f17AW'}=-0.213;
    $statpot{'f17AY'}=-0.162;
    $statpot{'f17AV'}=-0.097;
    $statpot{'f17RA'}=0.151;
    $statpot{'f17RR'}=0.354;
    $statpot{'f17RN'}=0.146;
    $statpot{'f17RD'}=0.394;
    $statpot{'f17RC'}=-0.085;
    $statpot{'f17RQ'}=0.273;
    $statpot{'f17RE'}=0.374;
    $statpot{'f17RG'}=0.244;
    $statpot{'f17RH'}=0.115;
    $statpot{'f17RI'}=-0.051;
    $statpot{'f17RL'}=0.055;
    $statpot{'f17RK'}=0.450;
    $statpot{'f17RM'}=-0.093;
    $statpot{'f17RF'}=-0.154;
    $statpot{'f17RP'}=0.292;
    $statpot{'f17RS'}=0.238;
    $statpot{'f17RT'}=0.125;
    $statpot{'f17RW'}=-0.003;
    $statpot{'f17RY'}=0.032;
    $statpot{'f17RV'}=0.030;
    $statpot{'f17NA'}=0.121;
    $statpot{'f17NR'}=0.192;
    $statpot{'f17NN'}=0.255;
    $statpot{'f17ND'}=0.429;
    $statpot{'f17NC'}=0.032;
    $statpot{'f17NQ'}=0.385;
    $statpot{'f17NE'}=0.467;
    $statpot{'f17NG'}=0.261;
    $statpot{'f17NH'}=-0.048;
    $statpot{'f17NI'}=0.001;
    $statpot{'f17NL'}=-0.012;
    $statpot{'f17NK'}=0.432;
    $statpot{'f17NM'}=-0.211;
    $statpot{'f17NF'}=-0.119;
    $statpot{'f17NP'}=0.318;
    $statpot{'f17NS'}=0.172;
    $statpot{'f17NT'}=0.186;
    $statpot{'f17NW'}=-0.088;
    $statpot{'f17NY'}=0.112;
    $statpot{'f17NV'}=0.034;
    $statpot{'f17DA'}=0.209;
    $statpot{'f17DR'}=0.366;
    $statpot{'f17DN'}=0.418;
    $statpot{'f17DD'}=0.478;
    $statpot{'f17DC'}=-0.013;
    $statpot{'f17DQ'}=0.388;
    $statpot{'f17DE'}=0.437;
    $statpot{'f17DG'}=0.438;
    $statpot{'f17DH'}=0.286;
    $statpot{'f17DI'}=0.254;
    $statpot{'f17DL'}=0.175;
    $statpot{'f17DK'}=0.585;
    $statpot{'f17DM'}=0.102;
    $statpot{'f17DF'}=0.065;
    $statpot{'f17DP'}=0.549;
    $statpot{'f17DS'}=0.292;
    $statpot{'f17DT'}=0.272;
    $statpot{'f17DW'}=0.031;
    $statpot{'f17DY'}=0.100;
    $statpot{'f17DV'}=0.130;
    $statpot{'f17CA'}=-0.181;
    $statpot{'f17CR'}=-0.275;
    $statpot{'f17CN'}=-0.156;
    $statpot{'f17CD'}=-0.158;
    $statpot{'f17CC'}=-0.227;
    $statpot{'f17CQ'}=-0.162;
    $statpot{'f17CE'}=0.091;
    $statpot{'f17CG'}=-0.211;
    $statpot{'f17CH'}=-0.256;
    $statpot{'f17CI'}=-0.438;
    $statpot{'f17CL'}=-0.410;
    $statpot{'f17CK'}=0.054;
    $statpot{'f17CM'}=-0.446;
    $statpot{'f17CF'}=-0.338;
    $statpot{'f17CP'}=-0.224;
    $statpot{'f17CS'}=-0.207;
    $statpot{'f17CT'}=-0.340;
    $statpot{'f17CW'}=-0.419;
    $statpot{'f17CY'}=-0.467;
    $statpot{'f17CV'}=-0.309;
    $statpot{'f17QA'}=-0.019;
    $statpot{'f17QR'}=0.267;
    $statpot{'f17QN'}=0.312;
    $statpot{'f17QD'}=0.383;
    $statpot{'f17QC'}=-0.151;
    $statpot{'f17QQ'}=0.067;
    $statpot{'f17QE'}=0.353;
    $statpot{'f17QG'}=0.326;
    $statpot{'f17QH'}=0.187;
    $statpot{'f17QI'}=-0.003;
    $statpot{'f17QL'}=0.042;
    $statpot{'f17QK'}=0.325;
    $statpot{'f17QM'}=0.062;
    $statpot{'f17QF'}=-0.080;
    $statpot{'f17QP'}=0.241;
    $statpot{'f17QS'}=0.275;
    $statpot{'f17QT'}=0.103;
    $statpot{'f17QW'}=-0.094;
    $statpot{'f17QY'}=-0.102;
    $statpot{'f17QV'}=0.055;
    $statpot{'f17EA'}=0.345;
    $statpot{'f17ER'}=0.402;
    $statpot{'f17EN'}=0.545;
    $statpot{'f17ED'}=0.500;
    $statpot{'f17EC'}=0.165;
    $statpot{'f17EQ'}=0.522;
    $statpot{'f17EE'}=0.767;
    $statpot{'f17EG'}=0.486;
    $statpot{'f17EH'}=0.379;
    $statpot{'f17EI'}=0.186;
    $statpot{'f17EL'}=0.289;
    $statpot{'f17EK'}=0.796;
    $statpot{'f17EM'}=0.241;
    $statpot{'f17EF'}=0.036;
    $statpot{'f17EP'}=0.493;
    $statpot{'f17ES'}=0.462;
    $statpot{'f17ET'}=0.497;
    $statpot{'f17EW'}=0.144;
    $statpot{'f17EY'}=0.264;
    $statpot{'f17EV'}=0.323;
    $statpot{'f17GA'}=0.045;
    $statpot{'f17GR'}=0.270;
    $statpot{'f17GN'}=0.217;
    $statpot{'f17GD'}=0.369;
    $statpot{'f17GC'}=-0.086;
    $statpot{'f17GQ'}=0.241;
    $statpot{'f17GE'}=0.358;
    $statpot{'f17GG'}=0.268;
    $statpot{'f17GH'}=0.099;
    $statpot{'f17GI'}=-0.004;
    $statpot{'f17GL'}=0.009;
    $statpot{'f17GK'}=0.367;
    $statpot{'f17GM'}=-0.055;
    $statpot{'f17GF'}=-0.101;
    $statpot{'f17GP'}=0.235;
    $statpot{'f17GS'}=0.170;
    $statpot{'f17GT'}=0.156;
    $statpot{'f17GW'}=0.025;
    $statpot{'f17GY'}=0.009;
    $statpot{'f17GV'}=-0.005;
    $statpot{'f17HA'}=-0.151;
    $statpot{'f17HR'}=-0.025;
    $statpot{'f17HN'}=-0.044;
    $statpot{'f17HD'}=0.116;
    $statpot{'f17HC'}=-0.326;
    $statpot{'f17HQ'}=-0.002;
    $statpot{'f17HE'}=0.270;
    $statpot{'f17HG'}=-0.042;
    $statpot{'f17HH'}=-0.130;
    $statpot{'f17HI'}=-0.299;
    $statpot{'f17HL'}=-0.266;
    $statpot{'f17HK'}=0.263;
    $statpot{'f17HM'}=-0.297;
    $statpot{'f17HF'}=-0.179;
    $statpot{'f17HP'}=0.154;
    $statpot{'f17HS'}=0.062;
    $statpot{'f17HT'}=-0.054;
    $statpot{'f17HW'}=-0.326;
    $statpot{'f17HY'}=-0.301;
    $statpot{'f17HV'}=-0.291;
    $statpot{'f17IA'}=-0.225;
    $statpot{'f17IR'}=-0.205;
    $statpot{'f17IN'}=-0.168;
    $statpot{'f17ID'}=-0.010;
    $statpot{'f17IC'}=-0.407;
    $statpot{'f17IQ'}=-0.104;
    $statpot{'f17IE'}=0.006;
    $statpot{'f17IG'}=-0.158;
    $statpot{'f17IH'}=-0.402;
    $statpot{'f17II'}=-0.311;
    $statpot{'f17IL'}=-0.347;
    $statpot{'f17IK'}=-0.064;
    $statpot{'f17IM'}=-0.408;
    $statpot{'f17IF'}=-0.398;
    $statpot{'f17IP'}=-0.155;
    $statpot{'f17IS'}=-0.306;
    $statpot{'f17IT'}=-0.265;
    $statpot{'f17IW'}=-0.374;
    $statpot{'f17IY'}=-0.328;
    $statpot{'f17IV'}=-0.283;
    $statpot{'f17LA'}=-0.218;
    $statpot{'f17LR'}=-0.132;
    $statpot{'f17LN'}=-0.156;
    $statpot{'f17LD'}=-0.119;
    $statpot{'f17LC'}=-0.400;
    $statpot{'f17LQ'}=-0.124;
    $statpot{'f17LE'}=0.045;
    $statpot{'f17LG'}=-0.118;
    $statpot{'f17LH'}=-0.380;
    $statpot{'f17LI'}=-0.339;
    $statpot{'f17LL'}=-0.277;
    $statpot{'f17LK'}=0.090;
    $statpot{'f17LM'}=-0.462;
    $statpot{'f17LF'}=-0.412;
    $statpot{'f17LP'}=-0.141;
    $statpot{'f17LS'}=-0.237;
    $statpot{'f17LT'}=-0.341;
    $statpot{'f17LW'}=-0.352;
    $statpot{'f17LY'}=-0.420;
    $statpot{'f17LV'}=-0.319;
    $statpot{'f17KA'}=0.340;
    $statpot{'f17KR'}=0.502;
    $statpot{'f17KN'}=0.549;
    $statpot{'f17KD'}=0.691;
    $statpot{'f17KC'}=0.200;
    $statpot{'f17KQ'}=0.363;
    $statpot{'f17KE'}=0.750;
    $statpot{'f17KG'}=0.424;
    $statpot{'f17KH'}=0.381;
    $statpot{'f17KI'}=0.177;
    $statpot{'f17KL'}=0.274;
    $statpot{'f17KK'}=0.574;
    $statpot{'f17KM'}=0.369;
    $statpot{'f17KF'}=0.251;
    $statpot{'f17KP'}=0.511;
    $statpot{'f17KS'}=0.419;
    $statpot{'f17KT'}=0.419;
    $statpot{'f17KW'}=0.279;
    $statpot{'f17KY'}=0.115;
    $statpot{'f17KV'}=0.308;
    $statpot{'f17MA'}=-0.240;
    $statpot{'f17MR'}=-0.100;
    $statpot{'f17MN'}=-0.270;
    $statpot{'f17MD'}=-0.039;
    $statpot{'f17MC'}=-0.403;
    $statpot{'f17MQ'}=-0.029;
    $statpot{'f17ME'}=0.060;
    $statpot{'f17MG'}=-0.170;
    $statpot{'f17MH'}=-0.261;
    $statpot{'f17MI'}=-0.370;
    $statpot{'f17ML'}=-0.440;
    $statpot{'f17MK'}=0.098;
    $statpot{'f17MM'}=-0.443;
    $statpot{'f17MF'}=-0.273;
    $statpot{'f17MP'}=-0.136;
    $statpot{'f17MS'}=-0.249;
    $statpot{'f17MT'}=-0.252;
    $statpot{'f17MW'}=-0.380;
    $statpot{'f17MY'}=-0.324;
    $statpot{'f17MV'}=-0.344;
    $statpot{'f17FA'}=-0.262;
    $statpot{'f17FR'}=-0.279;
    $statpot{'f17FN'}=-0.360;
    $statpot{'f17FD'}=-0.147;
    $statpot{'f17FC'}=-0.344;
    $statpot{'f17FQ'}=-0.241;
    $statpot{'f17FE'}=-0.143;
    $statpot{'f17FG'}=-0.261;
    $statpot{'f17FH'}=-0.329;
    $statpot{'f17FI'}=-0.408;
    $statpot{'f17FL'}=-0.401;
    $statpot{'f17FK'}=-0.029;
    $statpot{'f17FM'}=-0.286;
    $statpot{'f17FF'}=-0.536;
    $statpot{'f17FP'}=-0.144;
    $statpot{'f17FS'}=-0.252;
    $statpot{'f17FT'}=-0.218;
    $statpot{'f17FW'}=-0.511;
    $statpot{'f17FY'}=-0.448;
    $statpot{'f17FV'}=-0.436;
    $statpot{'f17PA'}=0.097;
    $statpot{'f17PR'}=0.274;
    $statpot{'f17PN'}=0.344;
    $statpot{'f17PD'}=0.450;
    $statpot{'f17PC'}=-0.016;
    $statpot{'f17PQ'}=0.259;
    $statpot{'f17PE'}=0.489;
    $statpot{'f17PG'}=0.228;
    $statpot{'f17PH'}=0.107;
    $statpot{'f17PI'}=0.065;
    $statpot{'f17PL'}=0.108;
    $statpot{'f17PK'}=0.462;
    $statpot{'f17PM'}=0.026;
    $statpot{'f17PF'}=-0.059;
    $statpot{'f17PP'}=0.388;
    $statpot{'f17PS'}=0.334;
    $statpot{'f17PT'}=0.108;
    $statpot{'f17PW'}=-0.009;
    $statpot{'f17PY'}=-0.023;
    $statpot{'f17PV'}=0.068;
    $statpot{'f17SA'}=0.094;
    $statpot{'f17SR'}=0.173;
    $statpot{'f17SN'}=0.140;
    $statpot{'f17SD'}=0.277;
    $statpot{'f17SC'}=-0.082;
    $statpot{'f17SQ'}=0.290;
    $statpot{'f17SE'}=0.338;
    $statpot{'f17SG'}=0.236;
    $statpot{'f17SH'}=0.091;
    $statpot{'f17SI'}=-0.089;
    $statpot{'f17SL'}=-0.073;
    $statpot{'f17SK'}=0.358;
    $statpot{'f17SM'}=-0.078;
    $statpot{'f17SF'}=-0.064;
    $statpot{'f17SP'}=0.326;
    $statpot{'f17SS'}=0.104;
    $statpot{'f17ST'}=0.213;
    $statpot{'f17SW'}=-0.064;
    $statpot{'f17SY'}=-0.039;
    $statpot{'f17SV'}=-0.031;
    $statpot{'f17TA'}=-0.081;
    $statpot{'f17TR'}=0.130;
    $statpot{'f17TN'}=0.161;
    $statpot{'f17TD'}=0.148;
    $statpot{'f17TC'}=-0.163;
    $statpot{'f17TQ'}=0.039;
    $statpot{'f17TE'}=0.321;
    $statpot{'f17TG'}=0.115;
    $statpot{'f17TH'}=-0.039;
    $statpot{'f17TI'}=-0.109;
    $statpot{'f17TL'}=-0.199;
    $statpot{'f17TK'}=0.286;
    $statpot{'f17TM'}=-0.095;
    $statpot{'f17TF'}=-0.019;
    $statpot{'f17TP'}=0.110;
    $statpot{'f17TS'}=0.174;
    $statpot{'f17TT'}=0.068;
    $statpot{'f17TW'}=-0.132;
    $statpot{'f17TY'}=-0.051;
    $statpot{'f17TV'}=-0.081;
    $statpot{'f17WA'}=-0.207;
    $statpot{'f17WR'}=-0.142;
    $statpot{'f17WN'}=-0.152;
    $statpot{'f17WD'}=-0.096;
    $statpot{'f17WC'}=-0.399;
    $statpot{'f17WQ'}=-0.158;
    $statpot{'f17WE'}=0.081;
    $statpot{'f17WG'}=-0.082;
    $statpot{'f17WH'}=-0.282;
    $statpot{'f17WI'}=-0.310;
    $statpot{'f17WL'}=-0.377;
    $statpot{'f17WK'}=0.089;
    $statpot{'f17WM'}=-0.504;
    $statpot{'f17WF'}=-0.533;
    $statpot{'f17WP'}=-0.180;
    $statpot{'f17WS'}=-0.242;
    $statpot{'f17WT'}=-0.157;
    $statpot{'f17WW'}=-0.371;
    $statpot{'f17WY'}=-0.467;
    $statpot{'f17WV'}=-0.271;
    $statpot{'f17YA'}=-0.181;
    $statpot{'f17YR'}=-0.087;
    $statpot{'f17YN'}=-0.096;
    $statpot{'f17YD'}=-0.018;
    $statpot{'f17YC'}=-0.438;
    $statpot{'f17YQ'}=-0.197;
    $statpot{'f17YE'}=0.126;
    $statpot{'f17YG'}=-0.157;
    $statpot{'f17YH'}=-0.404;
    $statpot{'f17YI'}=-0.339;
    $statpot{'f17YL'}=-0.378;
    $statpot{'f17YK'}=0.036;
    $statpot{'f17YM'}=-0.385;
    $statpot{'f17YF'}=-0.463;
    $statpot{'f17YP'}=-0.164;
    $statpot{'f17YS'}=-0.158;
    $statpot{'f17YT'}=-0.214;
    $statpot{'f17YW'}=-0.415;
    $statpot{'f17YY'}=-0.232;
    $statpot{'f17YV'}=-0.334;
    $statpot{'f17VA'}=-0.117;
    $statpot{'f17VR'}=-0.165;
    $statpot{'f17VN'}=-0.140;
    $statpot{'f17VD'}=-0.108;
    $statpot{'f17VC'}=-0.283;
    $statpot{'f17VQ'}=-0.116;
    $statpot{'f17VE'}=0.078;
    $statpot{'f17VG'}=-0.158;
    $statpot{'f17VH'}=-0.319;
    $statpot{'f17VI'}=-0.262;
    $statpot{'f17VL'}=-0.271;
    $statpot{'f17VK'}=0.100;
    $statpot{'f17VM'}=-0.401;
    $statpot{'f17VF'}=-0.401;
    $statpot{'f17VP'}=-0.098;
    $statpot{'f17VS'}=-0.171;
    $statpot{'f17VT'}=-0.242;
    $statpot{'f17VW'}=-0.275;
    $statpot{'f17VY'}=-0.320;
    $statpot{'f17VV'}=-0.207;
    $statpot{'a17AA'}=0.057;
    $statpot{'a17AR'}=0.037;
    $statpot{'a17AN'}=0.005;
    $statpot{'a17AD'}=0.031;
    $statpot{'a17AC'}=0.029;
    $statpot{'a17AQ'}=-0.121;
    $statpot{'a17AE'}=0.028;
    $statpot{'a17AG'}=0.018;
    $statpot{'a17AH'}=-0.095;
    $statpot{'a17AI'}=-0.007;
    $statpot{'a17AL'}=0.019;
    $statpot{'a17AK'}=0.044;
    $statpot{'a17AM'}=-0.005;
    $statpot{'a17AF'}=0.077;
    $statpot{'a17AP'}=-0.010;
    $statpot{'a17AS'}=-0.013;
    $statpot{'a17AT'}=-0.042;
    $statpot{'a17AW'}=0.050;
    $statpot{'a17AY'}=0.026;
    $statpot{'a17AV'}=0.026;
    $statpot{'a17RA'}=-0.016;
    $statpot{'a17RR'}=-0.164;
    $statpot{'a17RN'}=-0.121;
    $statpot{'a17RD'}=-0.020;
    $statpot{'a17RC'}=-0.298;
    $statpot{'a17RQ'}=-0.033;
    $statpot{'a17RE'}=-0.056;
    $statpot{'a17RG'}=0.020;
    $statpot{'a17RH'}=0.033;
    $statpot{'a17RI'}=-0.063;
    $statpot{'a17RL'}=-0.076;
    $statpot{'a17RK'}=-0.125;
    $statpot{'a17RM'}=0.029;
    $statpot{'a17RF'}=-0.026;
    $statpot{'a17RP'}=0.036;
    $statpot{'a17RS'}=-0.076;
    $statpot{'a17RT'}=-0.077;
    $statpot{'a17RW'}=-0.155;
    $statpot{'a17RY'}=-0.067;
    $statpot{'a17RV'}=-0.167;
    $statpot{'a17NA'}=-0.050;
    $statpot{'a17NR'}=-0.152;
    $statpot{'a17NN'}=-0.046;
    $statpot{'a17ND'}=0.083;
    $statpot{'a17NC'}=-0.008;
    $statpot{'a17NQ'}=-0.016;
    $statpot{'a17NE'}=0.110;
    $statpot{'a17NG'}=-0.013;
    $statpot{'a17NH'}=-0.117;
    $statpot{'a17NI'}=-0.099;
    $statpot{'a17NL'}=-0.116;
    $statpot{'a17NK'}=-0.004;
    $statpot{'a17NM'}=-0.132;
    $statpot{'a17NF'}=-0.244;
    $statpot{'a17NP'}=-0.009;
    $statpot{'a17NS'}=-0.089;
    $statpot{'a17NT'}=-0.104;
    $statpot{'a17NW'}=-0.013;
    $statpot{'a17NY'}=-0.163;
    $statpot{'a17NV'}=-0.206;
    $statpot{'a17DA'}=-0.108;
    $statpot{'a17DR'}=-0.001;
    $statpot{'a17DN'}=0.090;
    $statpot{'a17DD'}=0.053;
    $statpot{'a17DC'}=-0.056;
    $statpot{'a17DQ'}=0.024;
    $statpot{'a17DE'}=0.030;
    $statpot{'a17DG'}=0.015;
    $statpot{'a17DH'}=-0.166;
    $statpot{'a17DI'}=-0.155;
    $statpot{'a17DL'}=-0.115;
    $statpot{'a17DK'}=0.076;
    $statpot{'a17DM'}=-0.095;
    $statpot{'a17DF'}=-0.195;
    $statpot{'a17DP'}=0.036;
    $statpot{'a17DS'}=0.011;
    $statpot{'a17DT'}=-0.176;
    $statpot{'a17DW'}=-0.050;
    $statpot{'a17DY'}=-0.139;
    $statpot{'a17DV'}=-0.187;
    $statpot{'a17CA'}=-0.059;
    $statpot{'a17CR'}=-0.125;
    $statpot{'a17CN'}=0.195;
    $statpot{'a17CD'}=0.096;
    $statpot{'a17CC'}=-0.088;
    $statpot{'a17CQ'}=-0.001;
    $statpot{'a17CE'}=-0.075;
    $statpot{'a17CG'}=0.053;
    $statpot{'a17CH'}=-0.346;
    $statpot{'a17CI'}=0.119;
    $statpot{'a17CL'}=0.282;
    $statpot{'a17CK'}=-0.011;
    $statpot{'a17CM'}=0.232;
    $statpot{'a17CF'}=0.123;
    $statpot{'a17CP'}=-0.021;
    $statpot{'a17CS'}=-0.098;
    $statpot{'a17CT'}=0.193;
    $statpot{'a17CW'}=0.274;
    $statpot{'a17CY'}=0.087;
    $statpot{'a17CV'}=0.107;
    $statpot{'a17QA'}=-0.137;
    $statpot{'a17QR'}=-0.028;
    $statpot{'a17QN'}=0.032;
    $statpot{'a17QD'}=0.028;
    $statpot{'a17QC'}=-0.013;
    $statpot{'a17QQ'}=0.021;
    $statpot{'a17QE'}=0.031;
    $statpot{'a17QG'}=-0.007;
    $statpot{'a17QH'}=-0.134;
    $statpot{'a17QI'}=-0.067;
    $statpot{'a17QL'}=-0.119;
    $statpot{'a17QK'}=-0.046;
    $statpot{'a17QM'}=-0.066;
    $statpot{'a17QF'}=-0.106;
    $statpot{'a17QP'}=-0.000;
    $statpot{'a17QS'}=-0.035;
    $statpot{'a17QT'}=-0.085;
    $statpot{'a17QW'}=-0.134;
    $statpot{'a17QY'}=-0.070;
    $statpot{'a17QV'}=-0.155;
    $statpot{'a17EA'}=-0.077;
    $statpot{'a17ER'}=-0.073;
    $statpot{'a17EN'}=0.060;
    $statpot{'a17ED'}=-0.009;
    $statpot{'a17EC'}=-0.131;
    $statpot{'a17EQ'}=-0.072;
    $statpot{'a17EE'}=0.190;
    $statpot{'a17EG'}=0.014;
    $statpot{'a17EH'}=-0.145;
    $statpot{'a17EI'}=-0.107;
    $statpot{'a17EL'}=-0.125;
    $statpot{'a17EK'}=-0.020;
    $statpot{'a17EM'}=-0.087;
    $statpot{'a17EF'}=-0.208;
    $statpot{'a17EP'}=0.110;
    $statpot{'a17ES'}=-0.068;
    $statpot{'a17ET'}=-0.114;
    $statpot{'a17EW'}=-0.159;
    $statpot{'a17EY'}=-0.051;
    $statpot{'a17EV'}=-0.214;
    $statpot{'a17GA'}=-0.046;
    $statpot{'a17GR'}=0.001;
    $statpot{'a17GN'}=0.020;
    $statpot{'a17GD'}=0.062;
    $statpot{'a17GC'}=-0.081;
    $statpot{'a17GQ'}=0.057;
    $statpot{'a17GE'}=0.104;
    $statpot{'a17GG'}=0.142;
    $statpot{'a17GH'}=-0.002;
    $statpot{'a17GI'}=-0.124;
    $statpot{'a17GL'}=-0.044;
    $statpot{'a17GK'}=0.042;
    $statpot{'a17GM'}=-0.183;
    $statpot{'a17GF'}=-0.109;
    $statpot{'a17GP'}=0.017;
    $statpot{'a17GS'}=0.041;
    $statpot{'a17GT'}=-0.002;
    $statpot{'a17GW'}=-0.033;
    $statpot{'a17GY'}=-0.095;
    $statpot{'a17GV'}=-0.158;
    $statpot{'a17HA'}=-0.161;
    $statpot{'a17HR'}=0.178;
    $statpot{'a17HN'}=-0.121;
    $statpot{'a17HD'}=-0.047;
    $statpot{'a17HC'}=-0.283;
    $statpot{'a17HQ'}=0.021;
    $statpot{'a17HE'}=-0.077;
    $statpot{'a17HG'}=0.140;
    $statpot{'a17HH'}=-0.081;
    $statpot{'a17HI'}=-0.005;
    $statpot{'a17HL'}=-0.068;
    $statpot{'a17HK'}=0.081;
    $statpot{'a17HM'}=0.050;
    $statpot{'a17HF'}=-0.065;
    $statpot{'a17HP'}=-0.152;
    $statpot{'a17HS'}=-0.102;
    $statpot{'a17HT'}=-0.040;
    $statpot{'a17HW'}=-0.091;
    $statpot{'a17HY'}=-0.076;
    $statpot{'a17HV'}=-0.129;
    $statpot{'a17IA'}=0.005;
    $statpot{'a17IR'}=0.113;
    $statpot{'a17IN'}=0.073;
    $statpot{'a17ID'}=0.061;
    $statpot{'a17IC'}=0.069;
    $statpot{'a17IQ'}=0.033;
    $statpot{'a17IE'}=0.051;
    $statpot{'a17IG'}=0.034;
    $statpot{'a17IH'}=0.147;
    $statpot{'a17II'}=0.203;
    $statpot{'a17IL'}=0.220;
    $statpot{'a17IK'}=0.028;
    $statpot{'a17IM'}=0.249;
    $statpot{'a17IF'}=0.155;
    $statpot{'a17IP'}=0.017;
    $statpot{'a17IS'}=0.037;
    $statpot{'a17IT'}=0.057;
    $statpot{'a17IW'}=0.336;
    $statpot{'a17IY'}=0.253;
    $statpot{'a17IV'}=0.220;
    $statpot{'a17LA'}=0.105;
    $statpot{'a17LR'}=0.118;
    $statpot{'a17LN'}=0.026;
    $statpot{'a17LD'}=0.172;
    $statpot{'a17LC'}=0.265;
    $statpot{'a17LQ'}=0.042;
    $statpot{'a17LE'}=0.075;
    $statpot{'a17LG'}=0.092;
    $statpot{'a17LH'}=0.087;
    $statpot{'a17LI'}=0.206;
    $statpot{'a17LL'}=0.199;
    $statpot{'a17LK'}=0.071;
    $statpot{'a17LM'}=0.140;
    $statpot{'a17LF'}=0.259;
    $statpot{'a17LP'}=0.071;
    $statpot{'a17LS'}=0.035;
    $statpot{'a17LT'}=0.100;
    $statpot{'a17LW'}=0.252;
    $statpot{'a17LY'}=0.131;
    $statpot{'a17LV'}=0.208;
    $statpot{'a17KA'}=-0.071;
    $statpot{'a17KR'}=-0.151;
    $statpot{'a17KN'}=-0.069;
    $statpot{'a17KD'}=0.019;
    $statpot{'a17KC'}=-0.123;
    $statpot{'a17KQ'}=-0.070;
    $statpot{'a17KE'}=0.001;
    $statpot{'a17KG'}=0.002;
    $statpot{'a17KH'}=-0.003;
    $statpot{'a17KI'}=-0.177;
    $statpot{'a17KL'}=-0.077;
    $statpot{'a17KK'}=0.050;
    $statpot{'a17KM'}=-0.103;
    $statpot{'a17KF'}=-0.102;
    $statpot{'a17KP'}=0.087;
    $statpot{'a17KS'}=-0.053;
    $statpot{'a17KT'}=-0.048;
    $statpot{'a17KW'}=-0.175;
    $statpot{'a17KY'}=-0.108;
    $statpot{'a17KV'}=-0.170;
    $statpot{'a17MA'}=-0.001;
    $statpot{'a17MR'}=0.036;
    $statpot{'a17MN'}=-0.065;
    $statpot{'a17MD'}=0.037;
    $statpot{'a17MC'}=0.153;
    $statpot{'a17MQ'}=0.018;
    $statpot{'a17ME'}=0.065;
    $statpot{'a17MG'}=-0.070;
    $statpot{'a17MH'}=0.003;
    $statpot{'a17MI'}=0.180;
    $statpot{'a17ML'}=0.103;
    $statpot{'a17MK'}=0.107;
    $statpot{'a17MM'}=-0.040;
    $statpot{'a17MF'}=0.163;
    $statpot{'a17MP'}=0.092;
    $statpot{'a17MS'}=-0.004;
    $statpot{'a17MT'}=0.038;
    $statpot{'a17MW'}=0.202;
    $statpot{'a17MY'}=-0.074;
    $statpot{'a17MV'}=0.098;
    $statpot{'a17FA'}=0.124;
    $statpot{'a17FR'}=0.132;
    $statpot{'a17FN'}=0.016;
    $statpot{'a17FD'}=-0.002;
    $statpot{'a17FC'}=0.131;
    $statpot{'a17FQ'}=0.071;
    $statpot{'a17FE'}=-0.044;
    $statpot{'a17FG'}=0.074;
    $statpot{'a17FH'}=0.126;
    $statpot{'a17FI'}=0.171;
    $statpot{'a17FL'}=0.237;
    $statpot{'a17FK'}=0.142;
    $statpot{'a17FM'}=0.183;
    $statpot{'a17FF'}=0.222;
    $statpot{'a17FP'}=-0.068;
    $statpot{'a17FS'}=0.044;
    $statpot{'a17FT'}=0.101;
    $statpot{'a17FW'}=0.144;
    $statpot{'a17FY'}=0.067;
    $statpot{'a17FV'}=0.187;
    $statpot{'a17PA'}=-0.088;
    $statpot{'a17PR'}=0.050;
    $statpot{'a17PN'}=-0.027;
    $statpot{'a17PD'}=0.099;
    $statpot{'a17PC'}=-0.216;
    $statpot{'a17PQ'}=-0.014;
    $statpot{'a17PE'}=0.112;
    $statpot{'a17PG'}=0.022;
    $statpot{'a17PH'}=-0.118;
    $statpot{'a17PI'}=-0.192;
    $statpot{'a17PL'}=-0.168;
    $statpot{'a17PK'}=0.119;
    $statpot{'a17PM'}=-0.079;
    $statpot{'a17PF'}=-0.151;
    $statpot{'a17PP'}=0.092;
    $statpot{'a17PS'}=0.036;
    $statpot{'a17PT'}=-0.099;
    $statpot{'a17PW'}=-0.182;
    $statpot{'a17PY'}=-0.125;
    $statpot{'a17PV'}=-0.178;
    $statpot{'a17SA'}=-0.091;
    $statpot{'a17SR'}=-0.027;
    $statpot{'a17SN'}=-0.066;
    $statpot{'a17SD'}=0.022;
    $statpot{'a17SC'}=-0.211;
    $statpot{'a17SQ'}=-0.045;
    $statpot{'a17SE'}=0.009;
    $statpot{'a17SG'}=-0.012;
    $statpot{'a17SH'}=-0.126;
    $statpot{'a17SI'}=-0.199;
    $statpot{'a17SL'}=-0.141;
    $statpot{'a17SK'}=-0.015;
    $statpot{'a17SM'}=-0.184;
    $statpot{'a17SF'}=-0.155;
    $statpot{'a17SP'}=0.042;
    $statpot{'a17SS'}=-0.174;
    $statpot{'a17ST'}=-0.113;
    $statpot{'a17SW'}=-0.181;
    $statpot{'a17SY'}=-0.069;
    $statpot{'a17SV'}=-0.189;
    $statpot{'a17TA'}=-0.056;
    $statpot{'a17TR'}=-0.081;
    $statpot{'a17TN'}=-0.087;
    $statpot{'a17TD'}=-0.091;
    $statpot{'a17TC'}=-0.034;
    $statpot{'a17TQ'}=-0.031;
    $statpot{'a17TE'}=-0.006;
    $statpot{'a17TG'}=0.031;
    $statpot{'a17TH'}=-0.054;
    $statpot{'a17TI'}=-0.119;
    $statpot{'a17TL'}=-0.083;
    $statpot{'a17TK'}=0.042;
    $statpot{'a17TM'}=-0.136;
    $statpot{'a17TF'}=-0.113;
    $statpot{'a17TP'}=-0.101;
    $statpot{'a17TS'}=-0.086;
    $statpot{'a17TT'}=-0.109;
    $statpot{'a17TW'}=-0.095;
    $statpot{'a17TY'}=-0.113;
    $statpot{'a17TV'}=-0.160;
    $statpot{'a17WA'}=0.042;
    $statpot{'a17WR'}=-0.023;
    $statpot{'a17WN'}=0.056;
    $statpot{'a17WD'}=0.075;
    $statpot{'a17WC'}=0.238;
    $statpot{'a17WQ'}=-0.072;
    $statpot{'a17WE'}=-0.112;
    $statpot{'a17WG'}=0.074;
    $statpot{'a17WH'}=-0.142;
    $statpot{'a17WI'}=0.221;
    $statpot{'a17WL'}=0.298;
    $statpot{'a17WK'}=-0.040;
    $statpot{'a17WM'}=0.465;
    $statpot{'a17WF'}=0.182;
    $statpot{'a17WP'}=-0.018;
    $statpot{'a17WS'}=-0.001;
    $statpot{'a17WT'}=-0.070;
    $statpot{'a17WW'}=0.011;
    $statpot{'a17WY'}=0.054;
    $statpot{'a17WV'}=0.172;
    $statpot{'a17YA'}=0.049;
    $statpot{'a17YR'}=0.051;
    $statpot{'a17YN'}=0.019;
    $statpot{'a17YD'}=-0.039;
    $statpot{'a17YC'}=0.041;
    $statpot{'a17YQ'}=0.033;
    $statpot{'a17YE'}=0.061;
    $statpot{'a17YG'}=0.077;
    $statpot{'a17YH'}=0.064;
    $statpot{'a17YI'}=0.271;
    $statpot{'a17YL'}=0.064;
    $statpot{'a17YK'}=-0.044;
    $statpot{'a17YM'}=0.010;
    $statpot{'a17YF'}=0.090;
    $statpot{'a17YP'}=0.019;
    $statpot{'a17YS'}=0.056;
    $statpot{'a17YT'}=0.062;
    $statpot{'a17YW'}=-0.023;
    $statpot{'a17YY'}=0.041;
    $statpot{'a17YV'}=-0.001;
    $statpot{'a17VA'}=0.050;
    $statpot{'a17VR'}=0.024;
    $statpot{'a17VN'}=-0.053;
    $statpot{'a17VD'}=0.026;
    $statpot{'a17VC'}=0.073;
    $statpot{'a17VQ'}=0.003;
    $statpot{'a17VE'}=-0.040;
    $statpot{'a17VG'}=-0.007;
    $statpot{'a17VH'}=-0.096;
    $statpot{'a17VI'}=0.186;
    $statpot{'a17VL'}=0.132;
    $statpot{'a17VK'}=-0.021;
    $statpot{'a17VM'}=0.193;
    $statpot{'a17VF'}=0.129;
    $statpot{'a17VP'}=-0.027;
    $statpot{'a17VS'}=-0.058;
    $statpot{'a17VT'}=0.011;
    $statpot{'a17VW'}=0.179;
    $statpot{'a17VY'}=-0.019;
    $statpot{'a17VV'}=0.106;
    $statpot{'p18AA'}=-0.095;
    $statpot{'p18AR'}=0.013;
    $statpot{'p18AN'}=-0.024;
    $statpot{'p18AD'}=0.021;
    $statpot{'p18AC'}=-0.142;
    $statpot{'p18AQ'}=-0.010;
    $statpot{'p18AE'}=0.045;
    $statpot{'p18AG'}=-0.000;
    $statpot{'p18AH'}=-0.086;
    $statpot{'p18AI'}=-0.074;
    $statpot{'p18AL'}=-0.021;
    $statpot{'p18AK'}=0.038;
    $statpot{'p18AM'}=-0.156;
    $statpot{'p18AF'}=-0.103;
    $statpot{'p18AP'}=-0.012;
    $statpot{'p18AS'}=-0.100;
    $statpot{'p18AT'}=-0.043;
    $statpot{'p18AW'}=-0.070;
    $statpot{'p18AY'}=-0.114;
    $statpot{'p18AV'}=-0.093;
    $statpot{'p18RA'}=0.013;
    $statpot{'p18RR'}=0.137;
    $statpot{'p18RN'}=0.040;
    $statpot{'p18RD'}=0.169;
    $statpot{'p18RC'}=-0.071;
    $statpot{'p18RQ'}=0.115;
    $statpot{'p18RE'}=0.146;
    $statpot{'p18RG'}=0.119;
    $statpot{'p18RH'}=-0.021;
    $statpot{'p18RI'}=-0.045;
    $statpot{'p18RL'}=0.020;
    $statpot{'p18RK'}=0.203;
    $statpot{'p18RM'}=-0.063;
    $statpot{'p18RF'}=-0.092;
    $statpot{'p18RP'}=0.040;
    $statpot{'p18RS'}=-0.036;
    $statpot{'p18RT'}=0.045;
    $statpot{'p18RW'}=0.099;
    $statpot{'p18RY'}=-0.029;
    $statpot{'p18RV'}=-0.033;
    $statpot{'p18NA'}=-0.024;
    $statpot{'p18NR'}=0.040;
    $statpot{'p18NN'}=0.060;
    $statpot{'p18ND'}=0.120;
    $statpot{'p18NC'}=-0.078;
    $statpot{'p18NQ'}=0.007;
    $statpot{'p18NE'}=0.145;
    $statpot{'p18NG'}=0.077;
    $statpot{'p18NH'}=-0.075;
    $statpot{'p18NI'}=0.009;
    $statpot{'p18NL'}=-0.014;
    $statpot{'p18NK'}=0.222;
    $statpot{'p18NM'}=0.025;
    $statpot{'p18NF'}=-0.093;
    $statpot{'p18NP'}=0.027;
    $statpot{'p18NS'}=-0.008;
    $statpot{'p18NT'}=0.014;
    $statpot{'p18NW'}=0.014;
    $statpot{'p18NY'}=-0.019;
    $statpot{'p18NV'}=-0.053;
    $statpot{'p18DA'}=0.021;
    $statpot{'p18DR'}=0.169;
    $statpot{'p18DN'}=0.120;
    $statpot{'p18DD'}=0.057;
    $statpot{'p18DC'}=-0.057;
    $statpot{'p18DQ'}=0.114;
    $statpot{'p18DE'}=0.178;
    $statpot{'p18DG'}=0.156;
    $statpot{'p18DH'}=0.141;
    $statpot{'p18DI'}=0.041;
    $statpot{'p18DL'}=0.010;
    $statpot{'p18DK'}=0.234;
    $statpot{'p18DM'}=0.033;
    $statpot{'p18DF'}=-0.048;
    $statpot{'p18DP'}=0.109;
    $statpot{'p18DS'}=0.053;
    $statpot{'p18DT'}=0.065;
    $statpot{'p18DW'}=0.016;
    $statpot{'p18DY'}=-0.036;
    $statpot{'p18DV'}=-0.066;
    $statpot{'p18CA'}=-0.142;
    $statpot{'p18CR'}=-0.071;
    $statpot{'p18CN'}=-0.078;
    $statpot{'p18CD'}=-0.057;
    $statpot{'p18CC'}=-0.006;
    $statpot{'p18CQ'}=-0.072;
    $statpot{'p18CE'}=0.027;
    $statpot{'p18CG'}=0.034;
    $statpot{'p18CH'}=-0.120;
    $statpot{'p18CI'}=-0.179;
    $statpot{'p18CL'}=-0.058;
    $statpot{'p18CK'}=0.039;
    $statpot{'p18CM'}=-0.200;
    $statpot{'p18CF'}=-0.190;
    $statpot{'p18CP'}=-0.232;
    $statpot{'p18CS'}=-0.027;
    $statpot{'p18CT'}=-0.101;
    $statpot{'p18CW'}=-0.050;
    $statpot{'p18CY'}=-0.178;
    $statpot{'p18CV'}=-0.199;
    $statpot{'p18QA'}=-0.010;
    $statpot{'p18QR'}=0.115;
    $statpot{'p18QN'}=0.007;
    $statpot{'p18QD'}=0.114;
    $statpot{'p18QC'}=-0.072;
    $statpot{'p18QQ'}=0.264;
    $statpot{'p18QE'}=0.158;
    $statpot{'p18QG'}=0.085;
    $statpot{'p18QH'}=0.068;
    $statpot{'p18QI'}=-0.062;
    $statpot{'p18QL'}=0.061;
    $statpot{'p18QK'}=0.200;
    $statpot{'p18QM'}=-0.126;
    $statpot{'p18QF'}=-0.052;
    $statpot{'p18QP'}=0.031;
    $statpot{'p18QS'}=-0.012;
    $statpot{'p18QT'}=-0.005;
    $statpot{'p18QW'}=-0.089;
    $statpot{'p18QY'}=-0.086;
    $statpot{'p18QV'}=-0.084;
    $statpot{'p18EA'}=0.045;
    $statpot{'p18ER'}=0.146;
    $statpot{'p18EN'}=0.145;
    $statpot{'p18ED'}=0.178;
    $statpot{'p18EC'}=0.027;
    $statpot{'p18EQ'}=0.158;
    $statpot{'p18EE'}=0.234;
    $statpot{'p18EG'}=0.159;
    $statpot{'p18EH'}=0.106;
    $statpot{'p18EI'}=0.044;
    $statpot{'p18EL'}=0.132;
    $statpot{'p18EK'}=0.211;
    $statpot{'p18EM'}=0.042;
    $statpot{'p18EF'}=0.019;
    $statpot{'p18EP'}=0.052;
    $statpot{'p18ES'}=0.024;
    $statpot{'p18ET'}=0.105;
    $statpot{'p18EW'}=0.119;
    $statpot{'p18EY'}=0.035;
    $statpot{'p18EV'}=0.041;
    $statpot{'p18GA'}=-0.000;
    $statpot{'p18GR'}=0.119;
    $statpot{'p18GN'}=0.077;
    $statpot{'p18GD'}=0.156;
    $statpot{'p18GC'}=0.034;
    $statpot{'p18GQ'}=0.085;
    $statpot{'p18GE'}=0.159;
    $statpot{'p18GG'}=0.145;
    $statpot{'p18GH'}=-0.003;
    $statpot{'p18GI'}=-0.024;
    $statpot{'p18GL'}=0.003;
    $statpot{'p18GK'}=0.212;
    $statpot{'p18GM'}=-0.033;
    $statpot{'p18GF'}=-0.019;
    $statpot{'p18GP'}=0.054;
    $statpot{'p18GS'}=0.034;
    $statpot{'p18GT'}=0.056;
    $statpot{'p18GW'}=-0.011;
    $statpot{'p18GY'}=0.021;
    $statpot{'p18GV'}=-0.049;
    $statpot{'p18HA'}=-0.086;
    $statpot{'p18HR'}=-0.021;
    $statpot{'p18HN'}=-0.075;
    $statpot{'p18HD'}=0.141;
    $statpot{'p18HC'}=-0.120;
    $statpot{'p18HQ'}=0.068;
    $statpot{'p18HE'}=0.106;
    $statpot{'p18HG'}=-0.003;
    $statpot{'p18HH'}=-0.055;
    $statpot{'p18HI'}=-0.147;
    $statpot{'p18HL'}=-0.063;
    $statpot{'p18HK'}=0.092;
    $statpot{'p18HM'}=-0.182;
    $statpot{'p18HF'}=-0.144;
    $statpot{'p18HP'}=-0.060;
    $statpot{'p18HS'}=-0.075;
    $statpot{'p18HT'}=-0.090;
    $statpot{'p18HW'}=-0.066;
    $statpot{'p18HY'}=-0.173;
    $statpot{'p18HV'}=-0.143;
    $statpot{'p18IA'}=-0.074;
    $statpot{'p18IR'}=-0.045;
    $statpot{'p18IN'}=0.009;
    $statpot{'p18ID'}=0.041;
    $statpot{'p18IC'}=-0.179;
    $statpot{'p18IQ'}=-0.062;
    $statpot{'p18IE'}=0.044;
    $statpot{'p18IG'}=-0.024;
    $statpot{'p18IH'}=-0.147;
    $statpot{'p18II'}=-0.078;
    $statpot{'p18IL'}=-0.040;
    $statpot{'p18IK'}=0.125;
    $statpot{'p18IM'}=-0.113;
    $statpot{'p18IF'}=-0.071;
    $statpot{'p18IP'}=-0.018;
    $statpot{'p18IS'}=-0.099;
    $statpot{'p18IT'}=-0.094;
    $statpot{'p18IW'}=-0.174;
    $statpot{'p18IY'}=-0.168;
    $statpot{'p18IV'}=-0.073;
    $statpot{'p18LA'}=-0.021;
    $statpot{'p18LR'}=0.020;
    $statpot{'p18LN'}=-0.014;
    $statpot{'p18LD'}=0.010;
    $statpot{'p18LC'}=-0.058;
    $statpot{'p18LQ'}=0.061;
    $statpot{'p18LE'}=0.132;
    $statpot{'p18LG'}=0.003;
    $statpot{'p18LH'}=-0.063;
    $statpot{'p18LI'}=-0.040;
    $statpot{'p18LL'}=-0.017;
    $statpot{'p18LK'}=0.107;
    $statpot{'p18LM'}=-0.077;
    $statpot{'p18LF'}=-0.150;
    $statpot{'p18LP'}=0.030;
    $statpot{'p18LS'}=-0.104;
    $statpot{'p18LT'}=-0.087;
    $statpot{'p18LW'}=-0.122;
    $statpot{'p18LY'}=-0.117;
    $statpot{'p18LV'}=-0.019;
    $statpot{'p18KA'}=0.038;
    $statpot{'p18KR'}=0.203;
    $statpot{'p18KN'}=0.222;
    $statpot{'p18KD'}=0.234;
    $statpot{'p18KC'}=0.039;
    $statpot{'p18KQ'}=0.200;
    $statpot{'p18KE'}=0.211;
    $statpot{'p18KG'}=0.212;
    $statpot{'p18KH'}=0.092;
    $statpot{'p18KI'}=0.125;
    $statpot{'p18KL'}=0.107;
    $statpot{'p18KK'}=0.148;
    $statpot{'p18KM'}=0.056;
    $statpot{'p18KF'}=0.069;
    $statpot{'p18KP'}=0.159;
    $statpot{'p18KS'}=0.133;
    $statpot{'p18KT'}=0.141;
    $statpot{'p18KW'}=0.078;
    $statpot{'p18KY'}=0.084;
    $statpot{'p18KV'}=0.043;
    $statpot{'p18MA'}=-0.156;
    $statpot{'p18MR'}=-0.063;
    $statpot{'p18MN'}=0.025;
    $statpot{'p18MD'}=0.033;
    $statpot{'p18MC'}=-0.200;
    $statpot{'p18MQ'}=-0.126;
    $statpot{'p18ME'}=0.042;
    $statpot{'p18MG'}=-0.033;
    $statpot{'p18MH'}=-0.182;
    $statpot{'p18MI'}=-0.113;
    $statpot{'p18ML'}=-0.077;
    $statpot{'p18MK'}=0.056;
    $statpot{'p18MM'}=-0.212;
    $statpot{'p18MF'}=-0.150;
    $statpot{'p18MP'}=-0.092;
    $statpot{'p18MS'}=-0.106;
    $statpot{'p18MT'}=-0.057;
    $statpot{'p18MW'}=-0.183;
    $statpot{'p18MY'}=-0.185;
    $statpot{'p18MV'}=-0.141;
    $statpot{'p18FA'}=-0.103;
    $statpot{'p18FR'}=-0.092;
    $statpot{'p18FN'}=-0.093;
    $statpot{'p18FD'}=-0.048;
    $statpot{'p18FC'}=-0.190;
    $statpot{'p18FQ'}=-0.052;
    $statpot{'p18FE'}=0.019;
    $statpot{'p18FG'}=-0.019;
    $statpot{'p18FH'}=-0.144;
    $statpot{'p18FI'}=-0.071;
    $statpot{'p18FL'}=-0.150;
    $statpot{'p18FK'}=0.069;
    $statpot{'p18FM'}=-0.150;
    $statpot{'p18FF'}=-0.130;
    $statpot{'p18FP'}=-0.093;
    $statpot{'p18FS'}=-0.141;
    $statpot{'p18FT'}=-0.132;
    $statpot{'p18FW'}=-0.182;
    $statpot{'p18FY'}=-0.138;
    $statpot{'p18FV'}=-0.142;
    $statpot{'p18PA'}=-0.012;
    $statpot{'p18PR'}=0.040;
    $statpot{'p18PN'}=0.027;
    $statpot{'p18PD'}=0.109;
    $statpot{'p18PC'}=-0.232;
    $statpot{'p18PQ'}=0.031;
    $statpot{'p18PE'}=0.052;
    $statpot{'p18PG'}=0.054;
    $statpot{'p18PH'}=-0.060;
    $statpot{'p18PI'}=-0.018;
    $statpot{'p18PL'}=0.030;
    $statpot{'p18PK'}=0.159;
    $statpot{'p18PM'}=-0.092;
    $statpot{'p18PF'}=-0.093;
    $statpot{'p18PP'}=0.102;
    $statpot{'p18PS'}=-0.024;
    $statpot{'p18PT'}=0.003;
    $statpot{'p18PW'}=0.104;
    $statpot{'p18PY'}=-0.075;
    $statpot{'p18PV'}=-0.080;
    $statpot{'p18SA'}=-0.100;
    $statpot{'p18SR'}=-0.036;
    $statpot{'p18SN'}=-0.008;
    $statpot{'p18SD'}=0.053;
    $statpot{'p18SC'}=-0.027;
    $statpot{'p18SQ'}=-0.012;
    $statpot{'p18SE'}=0.024;
    $statpot{'p18SG'}=0.034;
    $statpot{'p18SH'}=-0.075;
    $statpot{'p18SI'}=-0.099;
    $statpot{'p18SL'}=-0.104;
    $statpot{'p18SK'}=0.133;
    $statpot{'p18SM'}=-0.106;
    $statpot{'p18SF'}=-0.141;
    $statpot{'p18SP'}=-0.024;
    $statpot{'p18SS'}=-0.069;
    $statpot{'p18ST'}=-0.047;
    $statpot{'p18SW'}=-0.094;
    $statpot{'p18SY'}=-0.083;
    $statpot{'p18SV'}=-0.132;
    $statpot{'p18TA'}=-0.043;
    $statpot{'p18TR'}=0.045;
    $statpot{'p18TN'}=0.014;
    $statpot{'p18TD'}=0.065;
    $statpot{'p18TC'}=-0.101;
    $statpot{'p18TQ'}=-0.005;
    $statpot{'p18TE'}=0.105;
    $statpot{'p18TG'}=0.056;
    $statpot{'p18TH'}=-0.090;
    $statpot{'p18TI'}=-0.094;
    $statpot{'p18TL'}=-0.087;
    $statpot{'p18TK'}=0.141;
    $statpot{'p18TM'}=-0.057;
    $statpot{'p18TF'}=-0.132;
    $statpot{'p18TP'}=0.003;
    $statpot{'p18TS'}=-0.047;
    $statpot{'p18TT'}=-0.035;
    $statpot{'p18TW'}=-0.003;
    $statpot{'p18TY'}=-0.043;
    $statpot{'p18TV'}=-0.086;
    $statpot{'p18WA'}=-0.070;
    $statpot{'p18WR'}=0.099;
    $statpot{'p18WN'}=0.014;
    $statpot{'p18WD'}=0.016;
    $statpot{'p18WC'}=-0.050;
    $statpot{'p18WQ'}=-0.089;
    $statpot{'p18WE'}=0.119;
    $statpot{'p18WG'}=-0.011;
    $statpot{'p18WH'}=-0.066;
    $statpot{'p18WI'}=-0.174;
    $statpot{'p18WL'}=-0.122;
    $statpot{'p18WK'}=0.078;
    $statpot{'p18WM'}=-0.183;
    $statpot{'p18WF'}=-0.182;
    $statpot{'p18WP'}=0.104;
    $statpot{'p18WS'}=-0.094;
    $statpot{'p18WT'}=-0.003;
    $statpot{'p18WW'}=-0.026;
    $statpot{'p18WY'}=-0.074;
    $statpot{'p18WV'}=-0.187;
    $statpot{'p18YA'}=-0.114;
    $statpot{'p18YR'}=-0.029;
    $statpot{'p18YN'}=-0.019;
    $statpot{'p18YD'}=-0.036;
    $statpot{'p18YC'}=-0.178;
    $statpot{'p18YQ'}=-0.086;
    $statpot{'p18YE'}=0.035;
    $statpot{'p18YG'}=0.021;
    $statpot{'p18YH'}=-0.173;
    $statpot{'p18YI'}=-0.168;
    $statpot{'p18YL'}=-0.117;
    $statpot{'p18YK'}=0.084;
    $statpot{'p18YM'}=-0.185;
    $statpot{'p18YF'}=-0.138;
    $statpot{'p18YP'}=-0.075;
    $statpot{'p18YS'}=-0.083;
    $statpot{'p18YT'}=-0.043;
    $statpot{'p18YW'}=-0.074;
    $statpot{'p18YY'}=-0.088;
    $statpot{'p18YV'}=-0.123;
    $statpot{'p18VA'}=-0.093;
    $statpot{'p18VR'}=-0.033;
    $statpot{'p18VN'}=-0.053;
    $statpot{'p18VD'}=-0.066;
    $statpot{'p18VC'}=-0.199;
    $statpot{'p18VQ'}=-0.084;
    $statpot{'p18VE'}=0.041;
    $statpot{'p18VG'}=-0.049;
    $statpot{'p18VH'}=-0.143;
    $statpot{'p18VI'}=-0.073;
    $statpot{'p18VL'}=-0.019;
    $statpot{'p18VK'}=0.043;
    $statpot{'p18VM'}=-0.141;
    $statpot{'p18VF'}=-0.142;
    $statpot{'p18VP'}=-0.080;
    $statpot{'p18VS'}=-0.132;
    $statpot{'p18VT'}=-0.086;
    $statpot{'p18VW'}=-0.187;
    $statpot{'p18VY'}=-0.123;
    $statpot{'p18VV'}=0.011;
    $statpot{'f18AA'}=-0.077;
    $statpot{'f18AR'}=0.028;
    $statpot{'f18AN'}=-0.062;
    $statpot{'f18AD'}=0.052;
    $statpot{'f18AC'}=-0.364;
    $statpot{'f18AQ'}=0.026;
    $statpot{'f18AE'}=0.144;
    $statpot{'f18AG'}=0.049;
    $statpot{'f18AH'}=-0.161;
    $statpot{'f18AI'}=-0.198;
    $statpot{'f18AL'}=-0.136;
    $statpot{'f18AK'}=0.157;
    $statpot{'f18AM'}=-0.249;
    $statpot{'f18AF'}=-0.249;
    $statpot{'f18AP'}=-0.025;
    $statpot{'f18AS'}=0.001;
    $statpot{'f18AT'}=-0.020;
    $statpot{'f18AW'}=-0.162;
    $statpot{'f18AY'}=-0.216;
    $statpot{'f18AV'}=-0.148;
    $statpot{'f18RA'}=0.076;
    $statpot{'f18RR'}=0.218;
    $statpot{'f18RN'}=0.280;
    $statpot{'f18RD'}=0.284;
    $statpot{'f18RC'}=0.030;
    $statpot{'f18RQ'}=0.287;
    $statpot{'f18RE'}=0.316;
    $statpot{'f18RG'}=0.267;
    $statpot{'f18RH'}=-0.009;
    $statpot{'f18RI'}=-0.059;
    $statpot{'f18RL'}=-0.057;
    $statpot{'f18RK'}=0.286;
    $statpot{'f18RM'}=0.026;
    $statpot{'f18RF'}=-0.087;
    $statpot{'f18RP'}=0.240;
    $statpot{'f18RS'}=0.240;
    $statpot{'f18RT'}=0.038;
    $statpot{'f18RW'}=-0.138;
    $statpot{'f18RY'}=-0.018;
    $statpot{'f18RV'}=0.033;
    $statpot{'f18NA'}=0.035;
    $statpot{'f18NR'}=0.236;
    $statpot{'f18NN'}=0.228;
    $statpot{'f18ND'}=0.383;
    $statpot{'f18NC'}=0.024;
    $statpot{'f18NQ'}=0.282;
    $statpot{'f18NE'}=0.422;
    $statpot{'f18NG'}=0.308;
    $statpot{'f18NH'}=0.143;
    $statpot{'f18NI'}=0.002;
    $statpot{'f18NL'}=-0.014;
    $statpot{'f18NK'}=0.425;
    $statpot{'f18NM'}=-0.055;
    $statpot{'f18NF'}=-0.068;
    $statpot{'f18NP'}=0.185;
    $statpot{'f18NS'}=0.090;
    $statpot{'f18NT'}=0.132;
    $statpot{'f18NW'}=0.002;
    $statpot{'f18NY'}=-0.058;
    $statpot{'f18NV'}=0.043;
    $statpot{'f18DA'}=0.221;
    $statpot{'f18DR'}=0.382;
    $statpot{'f18DN'}=0.334;
    $statpot{'f18DD'}=0.369;
    $statpot{'f18DC'}=0.098;
    $statpot{'f18DQ'}=0.414;
    $statpot{'f18DE'}=0.635;
    $statpot{'f18DG'}=0.379;
    $statpot{'f18DH'}=0.149;
    $statpot{'f18DI'}=0.176;
    $statpot{'f18DL'}=0.122;
    $statpot{'f18DK'}=0.562;
    $statpot{'f18DM'}=0.376;
    $statpot{'f18DF'}=0.150;
    $statpot{'f18DP'}=0.433;
    $statpot{'f18DS'}=0.354;
    $statpot{'f18DT'}=0.275;
    $statpot{'f18DW'}=-0.067;
    $statpot{'f18DY'}=0.092;
    $statpot{'f18DV'}=0.120;
    $statpot{'f18CA'}=-0.353;
    $statpot{'f18CR'}=-0.034;
    $statpot{'f18CN'}=-0.155;
    $statpot{'f18CD'}=-0.018;
    $statpot{'f18CC'}=-0.361;
    $statpot{'f18CQ'}=-0.146;
    $statpot{'f18CE'}=0.128;
    $statpot{'f18CG'}=-0.141;
    $statpot{'f18CH'}=-0.376;
    $statpot{'f18CI'}=-0.494;
    $statpot{'f18CL'}=-0.268;
    $statpot{'f18CK'}=-0.124;
    $statpot{'f18CM'}=-0.403;
    $statpot{'f18CF'}=-0.426;
    $statpot{'f18CP'}=-0.139;
    $statpot{'f18CS'}=-0.319;
    $statpot{'f18CT'}=-0.377;
    $statpot{'f18CW'}=-0.452;
    $statpot{'f18CY'}=-0.231;
    $statpot{'f18CV'}=-0.289;
    $statpot{'f18QA'}=0.121;
    $statpot{'f18QR'}=0.352;
    $statpot{'f18QN'}=0.314;
    $statpot{'f18QD'}=0.352;
    $statpot{'f18QC'}=-0.168;
    $statpot{'f18QQ'}=0.224;
    $statpot{'f18QE'}=0.401;
    $statpot{'f18QG'}=0.267;
    $statpot{'f18QH'}=0.141;
    $statpot{'f18QI'}=-0.074;
    $statpot{'f18QL'}=0.057;
    $statpot{'f18QK'}=0.458;
    $statpot{'f18QM'}=0.067;
    $statpot{'f18QF'}=0.022;
    $statpot{'f18QP'}=0.222;
    $statpot{'f18QS'}=0.186;
    $statpot{'f18QT'}=0.236;
    $statpot{'f18QW'}=-0.028;
    $statpot{'f18QY'}=0.024;
    $statpot{'f18QV'}=0.014;
    $statpot{'f18EA'}=0.362;
    $statpot{'f18ER'}=0.361;
    $statpot{'f18EN'}=0.449;
    $statpot{'f18ED'}=0.654;
    $statpot{'f18EC'}=0.380;
    $statpot{'f18EQ'}=0.464;
    $statpot{'f18EE'}=0.531;
    $statpot{'f18EG'}=0.508;
    $statpot{'f18EH'}=0.312;
    $statpot{'f18EI'}=0.243;
    $statpot{'f18EL'}=0.187;
    $statpot{'f18EK'}=0.657;
    $statpot{'f18EM'}=0.081;
    $statpot{'f18EF'}=0.189;
    $statpot{'f18EP'}=0.509;
    $statpot{'f18ES'}=0.360;
    $statpot{'f18ET'}=0.362;
    $statpot{'f18EW'}=0.183;
    $statpot{'f18EY'}=0.096;
    $statpot{'f18EV'}=0.280;
    $statpot{'f18GA'}=0.160;
    $statpot{'f18GR'}=0.246;
    $statpot{'f18GN'}=0.326;
    $statpot{'f18GD'}=0.236;
    $statpot{'f18GC'}=0.012;
    $statpot{'f18GQ'}=0.225;
    $statpot{'f18GE'}=0.390;
    $statpot{'f18GG'}=0.307;
    $statpot{'f18GH'}=0.079;
    $statpot{'f18GI'}=-0.067;
    $statpot{'f18GL'}=0.004;
    $statpot{'f18GK'}=0.423;
    $statpot{'f18GM'}=-0.146;
    $statpot{'f18GF'}=-0.137;
    $statpot{'f18GP'}=0.364;
    $statpot{'f18GS'}=0.159;
    $statpot{'f18GT'}=0.144;
    $statpot{'f18GW'}=-0.040;
    $statpot{'f18GY'}=-0.072;
    $statpot{'f18GV'}=0.008;
    $statpot{'f18HA'}=-0.240;
    $statpot{'f18HR'}=-0.056;
    $statpot{'f18HN'}=0.054;
    $statpot{'f18HD'}=0.032;
    $statpot{'f18HC'}=-0.238;
    $statpot{'f18HQ'}=0.086;
    $statpot{'f18HE'}=0.215;
    $statpot{'f18HG'}=-0.008;
    $statpot{'f18HH'}=-0.298;
    $statpot{'f18HI'}=-0.136;
    $statpot{'f18HL'}=-0.151;
    $statpot{'f18HK'}=0.053;
    $statpot{'f18HM'}=-0.296;
    $statpot{'f18HF'}=-0.253;
    $statpot{'f18HP'}=-0.004;
    $statpot{'f18HS'}=0.037;
    $statpot{'f18HT'}=-0.086;
    $statpot{'f18HW'}=-0.143;
    $statpot{'f18HY'}=-0.238;
    $statpot{'f18HV'}=-0.189;
    $statpot{'f18IA'}=-0.286;
    $statpot{'f18IR'}=-0.137;
    $statpot{'f18IN'}=-0.177;
    $statpot{'f18ID'}=-0.111;
    $statpot{'f18IC'}=-0.464;
    $statpot{'f18IQ'}=-0.194;
    $statpot{'f18IE'}=0.090;
    $statpot{'f18IG'}=-0.190;
    $statpot{'f18IH'}=-0.221;
    $statpot{'f18II'}=-0.365;
    $statpot{'f18IL'}=-0.285;
    $statpot{'f18IK'}=0.005;
    $statpot{'f18IM'}=-0.439;
    $statpot{'f18IF'}=-0.380;
    $statpot{'f18IP'}=-0.137;
    $statpot{'f18IS'}=-0.261;
    $statpot{'f18IT'}=-0.271;
    $statpot{'f18IW'}=-0.364;
    $statpot{'f18IY'}=-0.424;
    $statpot{'f18IV'}=-0.298;
    $statpot{'f18LA'}=-0.196;
    $statpot{'f18LR'}=-0.189;
    $statpot{'f18LN'}=-0.181;
    $statpot{'f18LD'}=-0.067;
    $statpot{'f18LC'}=-0.324;
    $statpot{'f18LQ'}=-0.084;
    $statpot{'f18LE'}=0.030;
    $statpot{'f18LG'}=-0.133;
    $statpot{'f18LH'}=-0.201;
    $statpot{'f18LI'}=-0.302;
    $statpot{'f18LL'}=-0.246;
    $statpot{'f18LK'}=0.051;
    $statpot{'f18LM'}=-0.379;
    $statpot{'f18LF'}=-0.354;
    $statpot{'f18LP'}=-0.103;
    $statpot{'f18LS'}=-0.222;
    $statpot{'f18LT'}=-0.242;
    $statpot{'f18LW'}=-0.343;
    $statpot{'f18LY'}=-0.316;
    $statpot{'f18LV'}=-0.307;
    $statpot{'f18KA'}=0.315;
    $statpot{'f18KR'}=0.349;
    $statpot{'f18KN'}=0.470;
    $statpot{'f18KD'}=0.599;
    $statpot{'f18KC'}=0.106;
    $statpot{'f18KQ'}=0.464;
    $statpot{'f18KE'}=0.730;
    $statpot{'f18KG'}=0.439;
    $statpot{'f18KH'}=0.217;
    $statpot{'f18KI'}=0.209;
    $statpot{'f18KL'}=0.219;
    $statpot{'f18KK'}=0.662;
    $statpot{'f18KM'}=0.314;
    $statpot{'f18KF'}=0.232;
    $statpot{'f18KP'}=0.535;
    $statpot{'f18KS'}=0.404;
    $statpot{'f18KT'}=0.429;
    $statpot{'f18KW'}=0.373;
    $statpot{'f18KY'}=0.213;
    $statpot{'f18KV'}=0.256;
    $statpot{'f18MA'}=-0.300;
    $statpot{'f18MR'}=-0.028;
    $statpot{'f18MN'}=-0.131;
    $statpot{'f18MD'}=0.172;
    $statpot{'f18MC'}=-0.412;
    $statpot{'f18MQ'}=-0.088;
    $statpot{'f18ME'}=-0.083;
    $statpot{'f18MG'}=-0.261;
    $statpot{'f18MH'}=-0.357;
    $statpot{'f18MI'}=-0.396;
    $statpot{'f18ML'}=-0.388;
    $statpot{'f18MK'}=0.039;
    $statpot{'f18MM'}=-0.402;
    $statpot{'f18MF'}=-0.423;
    $statpot{'f18MP'}=-0.135;
    $statpot{'f18MS'}=-0.247;
    $statpot{'f18MT'}=-0.104;
    $statpot{'f18MW'}=-0.365;
    $statpot{'f18MY'}=-0.362;
    $statpot{'f18MV'}=-0.343;
    $statpot{'f18FA'}=-0.294;
    $statpot{'f18FR'}=-0.284;
    $statpot{'f18FN'}=-0.175;
    $statpot{'f18FD'}=-0.113;
    $statpot{'f18FC'}=-0.453;
    $statpot{'f18FQ'}=-0.187;
    $statpot{'f18FE'}=-0.062;
    $statpot{'f18FG'}=-0.281;
    $statpot{'f18FH'}=-0.356;
    $statpot{'f18FI'}=-0.378;
    $statpot{'f18FL'}=-0.340;
    $statpot{'f18FK'}=0.040;
    $statpot{'f18FM'}=-0.398;
    $statpot{'f18FF'}=-0.487;
    $statpot{'f18FP'}=-0.114;
    $statpot{'f18FS'}=-0.326;
    $statpot{'f18FT'}=-0.247;
    $statpot{'f18FW'}=-0.311;
    $statpot{'f18FY'}=-0.434;
    $statpot{'f18FV'}=-0.331;
    $statpot{'f18PA'}=0.107;
    $statpot{'f18PR'}=0.276;
    $statpot{'f18PN'}=0.198;
    $statpot{'f18PD'}=0.434;
    $statpot{'f18PC'}=0.095;
    $statpot{'f18PQ'}=0.227;
    $statpot{'f18PE'}=0.447;
    $statpot{'f18PG'}=0.365;
    $statpot{'f18PH'}=0.084;
    $statpot{'f18PI'}=0.060;
    $statpot{'f18PL'}=0.100;
    $statpot{'f18PK'}=0.477;
    $statpot{'f18PM'}=0.076;
    $statpot{'f18PF'}=0.067;
    $statpot{'f18PP'}=0.371;
    $statpot{'f18PS'}=0.160;
    $statpot{'f18PT'}=0.219;
    $statpot{'f18PW'}=0.071;
    $statpot{'f18PY'}=0.032;
    $statpot{'f18PV'}=0.063;
    $statpot{'f18SA'}=0.028;
    $statpot{'f18SR'}=0.132;
    $statpot{'f18SN'}=0.117;
    $statpot{'f18SD'}=0.234;
    $statpot{'f18SC'}=-0.108;
    $statpot{'f18SQ'}=0.134;
    $statpot{'f18SE'}=0.278;
    $statpot{'f18SG'}=0.179;
    $statpot{'f18SH'}=0.210;
    $statpot{'f18SI'}=-0.093;
    $statpot{'f18SL'}=-0.060;
    $statpot{'f18SK'}=0.247;
    $statpot{'f18SM'}=-0.160;
    $statpot{'f18SF'}=-0.140;
    $statpot{'f18SP'}=0.148;
    $statpot{'f18SS'}=0.195;
    $statpot{'f18ST'}=0.126;
    $statpot{'f18SW'}=-0.046;
    $statpot{'f18SY'}=-0.103;
    $statpot{'f18SV'}=-0.039;
    $statpot{'f18TA'}=0.066;
    $statpot{'f18TR'}=0.037;
    $statpot{'f18TN'}=0.085;
    $statpot{'f18TD'}=0.253;
    $statpot{'f18TC'}=-0.241;
    $statpot{'f18TQ'}=0.182;
    $statpot{'f18TE'}=0.279;
    $statpot{'f18TG'}=0.130;
    $statpot{'f18TH'}=0.006;
    $statpot{'f18TI'}=-0.093;
    $statpot{'f18TL'}=-0.153;
    $statpot{'f18TK'}=0.283;
    $statpot{'f18TM'}=-0.049;
    $statpot{'f18TF'}=-0.091;
    $statpot{'f18TP'}=0.142;
    $statpot{'f18TS'}=0.093;
    $statpot{'f18TT'}=0.078;
    $statpot{'f18TW'}=-0.067;
    $statpot{'f18TY'}=-0.127;
    $statpot{'f18TV'}=-0.107;
    $statpot{'f18WA'}=-0.254;
    $statpot{'f18WR'}=-0.185;
    $statpot{'f18WN'}=-0.111;
    $statpot{'f18WD'}=-0.111;
    $statpot{'f18WC'}=-0.376;
    $statpot{'f18WQ'}=-0.118;
    $statpot{'f18WE'}=-0.074;
    $statpot{'f18WG'}=-0.168;
    $statpot{'f18WH'}=-0.325;
    $statpot{'f18WI'}=-0.334;
    $statpot{'f18WL'}=-0.345;
    $statpot{'f18WK'}=0.169;
    $statpot{'f18WM'}=-0.377;
    $statpot{'f18WF'}=-0.377;
    $statpot{'f18WP'}=-0.077;
    $statpot{'f18WS'}=-0.134;
    $statpot{'f18WT'}=-0.155;
    $statpot{'f18WW'}=-0.254;
    $statpot{'f18WY'}=-0.315;
    $statpot{'f18WV'}=-0.216;
    $statpot{'f18YA'}=-0.216;
    $statpot{'f18YR'}=-0.136;
    $statpot{'f18YN'}=-0.154;
    $statpot{'f18YD'}=-0.101;
    $statpot{'f18YC'}=-0.213;
    $statpot{'f18YQ'}=-0.002;
    $statpot{'f18YE'}=-0.045;
    $statpot{'f18YG'}=-0.141;
    $statpot{'f18YH'}=-0.214;
    $statpot{'f18YI'}=-0.434;
    $statpot{'f18YL'}=-0.308;
    $statpot{'f18YK'}=0.000;
    $statpot{'f18YM'}=-0.466;
    $statpot{'f18YF'}=-0.416;
    $statpot{'f18YP'}=-0.159;
    $statpot{'f18YS'}=-0.275;
    $statpot{'f18YT'}=-0.275;
    $statpot{'f18YW'}=-0.361;
    $statpot{'f18YY'}=-0.215;
    $statpot{'f18YV'}=-0.343;
    $statpot{'f18VA'}=-0.165;
    $statpot{'f18VR'}=-0.068;
    $statpot{'f18VN'}=-0.058;
    $statpot{'f18VD'}=-0.060;
    $statpot{'f18VC'}=-0.274;
    $statpot{'f18VQ'}=-0.108;
    $statpot{'f18VE'}=0.077;
    $statpot{'f18VG'}=-0.120;
    $statpot{'f18VH'}=-0.274;
    $statpot{'f18VI'}=-0.250;
    $statpot{'f18VL'}=-0.286;
    $statpot{'f18VK'}=0.065;
    $statpot{'f18VM'}=-0.348;
    $statpot{'f18VF'}=-0.334;
    $statpot{'f18VP'}=-0.087;
    $statpot{'f18VS'}=-0.184;
    $statpot{'f18VT'}=-0.178;
    $statpot{'f18VW'}=-0.191;
    $statpot{'f18VY'}=-0.314;
    $statpot{'f18VV'}=-0.190;
    $statpot{'a18AA'}=0.008;
    $statpot{'a18AR'}=-0.039;
    $statpot{'a18AN'}=0.017;
    $statpot{'a18AD'}=0.005;
    $statpot{'a18AC'}=0.049;
    $statpot{'a18AQ'}=0.058;
    $statpot{'a18AE'}=0.069;
    $statpot{'a18AG'}=0.092;
    $statpot{'a18AH'}=-0.153;
    $statpot{'a18AI'}=-0.030;
    $statpot{'a18AL'}=0.099;
    $statpot{'a18AK'}=0.031;
    $statpot{'a18AM'}=0.006;
    $statpot{'a18AF'}=0.095;
    $statpot{'a18AP'}=-0.067;
    $statpot{'a18AS'}=-0.036;
    $statpot{'a18AT'}=-0.049;
    $statpot{'a18AW'}=-0.086;
    $statpot{'a18AY'}=0.055;
    $statpot{'a18AV'}=-0.035;
    $statpot{'a18RA'}=-0.082;
    $statpot{'a18RR'}=-0.161;
    $statpot{'a18RN'}=-0.061;
    $statpot{'a18RD'}=-0.083;
    $statpot{'a18RC'}=0.025;
    $statpot{'a18RQ'}=-0.014;
    $statpot{'a18RE'}=0.005;
    $statpot{'a18RG'}=0.018;
    $statpot{'a18RH'}=-0.184;
    $statpot{'a18RI'}=-0.051;
    $statpot{'a18RL'}=-0.086;
    $statpot{'a18RK'}=-0.042;
    $statpot{'a18RM'}=0.060;
    $statpot{'a18RF'}=-0.189;
    $statpot{'a18RP'}=-0.057;
    $statpot{'a18RS'}=-0.147;
    $statpot{'a18RT'}=-0.020;
    $statpot{'a18RW'}=-0.080;
    $statpot{'a18RY'}=-0.168;
    $statpot{'a18RV'}=-0.141;
    $statpot{'a18NA'}=-0.076;
    $statpot{'a18NR'}=-0.030;
    $statpot{'a18NN'}=-0.025;
    $statpot{'a18ND'}=-0.065;
    $statpot{'a18NC'}=-0.200;
    $statpot{'a18NQ'}=-0.039;
    $statpot{'a18NE'}=0.060;
    $statpot{'a18NG'}=-0.006;
    $statpot{'a18NH'}=-0.113;
    $statpot{'a18NI'}=-0.188;
    $statpot{'a18NL'}=-0.122;
    $statpot{'a18NK'}=0.032;
    $statpot{'a18NM'}=-0.215;
    $statpot{'a18NF'}=-0.157;
    $statpot{'a18NP'}=-0.030;
    $statpot{'a18NS'}=-0.080;
    $statpot{'a18NT'}=-0.032;
    $statpot{'a18NW'}=-0.141;
    $statpot{'a18NY'}=-0.061;
    $statpot{'a18NV'}=-0.139;
    $statpot{'a18DA'}=-0.133;
    $statpot{'a18DR'}=-0.144;
    $statpot{'a18DN'}=-0.034;
    $statpot{'a18DD'}=0.086;
    $statpot{'a18DC'}=-0.083;
    $statpot{'a18DQ'}=-0.111;
    $statpot{'a18DE'}=0.047;
    $statpot{'a18DG'}=-0.038;
    $statpot{'a18DH'}=-0.122;
    $statpot{'a18DI'}=-0.168;
    $statpot{'a18DL'}=-0.145;
    $statpot{'a18DK'}=0.021;
    $statpot{'a18DM'}=-0.228;
    $statpot{'a18DF'}=-0.261;
    $statpot{'a18DP'}=-0.016;
    $statpot{'a18DS'}=-0.153;
    $statpot{'a18DT'}=-0.136;
    $statpot{'a18DW'}=-0.020;
    $statpot{'a18DY'}=-0.114;
    $statpot{'a18DV'}=-0.141;
    $statpot{'a18CA'}=0.031;
    $statpot{'a18CR'}=0.088;
    $statpot{'a18CN'}=-0.046;
    $statpot{'a18CD'}=0.017;
    $statpot{'a18CC'}=0.429;
    $statpot{'a18CQ'}=0.136;
    $statpot{'a18CE'}=0.047;
    $statpot{'a18CG'}=0.187;
    $statpot{'a18CH'}=0.186;
    $statpot{'a18CI'}=0.194;
    $statpot{'a18CL'}=0.160;
    $statpot{'a18CK'}=-0.053;
    $statpot{'a18CM'}=0.153;
    $statpot{'a18CF'}=0.177;
    $statpot{'a18CP'}=-0.082;
    $statpot{'a18CS'}=0.003;
    $statpot{'a18CT'}=0.048;
    $statpot{'a18CW'}=0.318;
    $statpot{'a18CY'}=0.287;
    $statpot{'a18CV'}=-0.032;
    $statpot{'a18QA'}=-0.031;
    $statpot{'a18QR'}=-0.058;
    $statpot{'a18QN'}=-0.060;
    $statpot{'a18QD'}=-0.074;
    $statpot{'a18QC'}=0.164;
    $statpot{'a18QQ'}=-0.026;
    $statpot{'a18QE'}=0.007;
    $statpot{'a18QG'}=-0.008;
    $statpot{'a18QH'}=-0.035;
    $statpot{'a18QI'}=-0.134;
    $statpot{'a18QL'}=-0.103;
    $statpot{'a18QK'}=-0.105;
    $statpot{'a18QM'}=-0.158;
    $statpot{'a18QF'}=-0.083;
    $statpot{'a18QP'}=-0.020;
    $statpot{'a18QS'}=-0.096;
    $statpot{'a18QT'}=-0.072;
    $statpot{'a18QW'}=-0.056;
    $statpot{'a18QY'}=0.040;
    $statpot{'a18QV'}=-0.142;
    $statpot{'a18EA'}=-0.100;
    $statpot{'a18ER'}=-0.027;
    $statpot{'a18EN'}=0.044;
    $statpot{'a18ED'}=0.038;
    $statpot{'a18EC'}=-0.133;
    $statpot{'a18EQ'}=-0.032;
    $statpot{'a18EE'}=0.144;
    $statpot{'a18EG'}=-0.026;
    $statpot{'a18EH'}=-0.135;
    $statpot{'a18EI'}=-0.058;
    $statpot{'a18EL'}=-0.051;
    $statpot{'a18EK'}=0.080;
    $statpot{'a18EM'}=-0.178;
    $statpot{'a18EF'}=-0.158;
    $statpot{'a18EP'}=-0.041;
    $statpot{'a18ES'}=-0.082;
    $statpot{'a18ET'}=-0.102;
    $statpot{'a18EW'}=-0.188;
    $statpot{'a18EY'}=-0.151;
    $statpot{'a18EV'}=-0.158;
    $statpot{'a18GA'}=-0.013;
    $statpot{'a18GR'}=0.035;
    $statpot{'a18GN'}=-0.016;
    $statpot{'a18GD'}=0.067;
    $statpot{'a18GC'}=0.016;
    $statpot{'a18GQ'}=0.024;
    $statpot{'a18GE'}=0.051;
    $statpot{'a18GG'}=0.084;
    $statpot{'a18GH'}=-0.023;
    $statpot{'a18GI'}=-0.119;
    $statpot{'a18GL'}=-0.061;
    $statpot{'a18GK'}=0.038;
    $statpot{'a18GM'}=-0.071;
    $statpot{'a18GF'}=-0.102;
    $statpot{'a18GP'}=0.072;
    $statpot{'a18GS'}=0.042;
    $statpot{'a18GT'}=-0.034;
    $statpot{'a18GW'}=-0.113;
    $statpot{'a18GY'}=0.051;
    $statpot{'a18GV'}=-0.063;
    $statpot{'a18HA'}=-0.069;
    $statpot{'a18HR'}=-0.145;
    $statpot{'a18HN'}=-0.043;
    $statpot{'a18HD'}=-0.028;
    $statpot{'a18HC'}=-0.006;
    $statpot{'a18HQ'}=0.012;
    $statpot{'a18HE'}=-0.070;
    $statpot{'a18HG'}=0.060;
    $statpot{'a18HH'}=-0.233;
    $statpot{'a18HI'}=-0.078;
    $statpot{'a18HL'}=0.084;
    $statpot{'a18HK'}=-0.041;
    $statpot{'a18HM'}=-0.070;
    $statpot{'a18HF'}=-0.027;
    $statpot{'a18HP'}=0.067;
    $statpot{'a18HS'}=0.039;
    $statpot{'a18HT'}=-0.030;
    $statpot{'a18HW'}=0.092;
    $statpot{'a18HY'}=0.213;
    $statpot{'a18HV'}=-0.065;
    $statpot{'a18IA'}=0.087;
    $statpot{'a18IR'}=0.033;
    $statpot{'a18IN'}=-0.021;
    $statpot{'a18ID'}=0.091;
    $statpot{'a18IC'}=0.142;
    $statpot{'a18IQ'}=-0.011;
    $statpot{'a18IE'}=0.071;
    $statpot{'a18IG'}=0.012;
    $statpot{'a18IH'}=0.018;
    $statpot{'a18II'}=0.156;
    $statpot{'a18IL'}=0.263;
    $statpot{'a18IK'}=0.049;
    $statpot{'a18IM'}=0.191;
    $statpot{'a18IF'}=0.184;
    $statpot{'a18IP'}=0.027;
    $statpot{'a18IS'}=0.065;
    $statpot{'a18IT'}=0.132;
    $statpot{'a18IW'}=0.161;
    $statpot{'a18IY'}=0.082;
    $statpot{'a18IV'}=0.131;
    $statpot{'a18LA'}=0.180;
    $statpot{'a18LR'}=0.059;
    $statpot{'a18LN'}=0.047;
    $statpot{'a18LD'}=0.024;
    $statpot{'a18LC'}=0.249;
    $statpot{'a18LQ'}=0.031;
    $statpot{'a18LE'}=0.091;
    $statpot{'a18LG'}=0.086;
    $statpot{'a18LH'}=0.149;
    $statpot{'a18LI'}=0.290;
    $statpot{'a18LL'}=0.264;
    $statpot{'a18LK'}=0.076;
    $statpot{'a18LM'}=0.187;
    $statpot{'a18LF'}=0.238;
    $statpot{'a18LP'}=0.071;
    $statpot{'a18LS'}=0.091;
    $statpot{'a18LT'}=0.074;
    $statpot{'a18LW'}=0.235;
    $statpot{'a18LY'}=0.144;
    $statpot{'a18LV'}=0.159;
    $statpot{'a18KA'}=-0.089;
    $statpot{'a18KR'}=-0.084;
    $statpot{'a18KN'}=0.004;
    $statpot{'a18KD'}=0.001;
    $statpot{'a18KC'}=-0.241;
    $statpot{'a18KQ'}=-0.107;
    $statpot{'a18KE'}=0.043;
    $statpot{'a18KG'}=0.027;
    $statpot{'a18KH'}=-0.164;
    $statpot{'a18KI'}=-0.121;
    $statpot{'a18KL'}=-0.066;
    $statpot{'a18KK'}=0.021;
    $statpot{'a18KM'}=-0.201;
    $statpot{'a18KF'}=-0.126;
    $statpot{'a18KP'}=0.021;
    $statpot{'a18KS'}=-0.117;
    $statpot{'a18KT'}=-0.033;
    $statpot{'a18KW'}=-0.049;
    $statpot{'a18KY'}=-0.109;
    $statpot{'a18KV'}=-0.125;
    $statpot{'a18MA'}=0.077;
    $statpot{'a18MR'}=0.120;
    $statpot{'a18MN'}=-0.148;
    $statpot{'a18MD'}=-0.098;
    $statpot{'a18MC'}=0.170;
    $statpot{'a18MQ'}=-0.018;
    $statpot{'a18ME'}=-0.030;
    $statpot{'a18MG'}=0.071;
    $statpot{'a18MH'}=0.012;
    $statpot{'a18MI'}=0.116;
    $statpot{'a18ML'}=0.205;
    $statpot{'a18MK'}=0.005;
    $statpot{'a18MM'}=-0.041;
    $statpot{'a18MF'}=0.222;
    $statpot{'a18MP'}=0.044;
    $statpot{'a18MS'}=-0.056;
    $statpot{'a18MT'}=0.111;
    $statpot{'a18MW'}=0.103;
    $statpot{'a18MY'}=0.041;
    $statpot{'a18MV'}=0.119;
    $statpot{'a18FA'}=0.161;
    $statpot{'a18FR'}=0.024;
    $statpot{'a18FN'}=-0.054;
    $statpot{'a18FD'}=-0.047;
    $statpot{'a18FC'}=0.228;
    $statpot{'a18FQ'}=0.140;
    $statpot{'a18FE'}=0.063;
    $statpot{'a18FG'}=0.069;
    $statpot{'a18FH'}=0.114;
    $statpot{'a18FI'}=0.180;
    $statpot{'a18FL'}=0.213;
    $statpot{'a18FK'}=0.027;
    $statpot{'a18FM'}=0.175;
    $statpot{'a18FF'}=0.211;
    $statpot{'a18FP'}=0.021;
    $statpot{'a18FS'}=0.065;
    $statpot{'a18FT'}=0.057;
    $statpot{'a18FW'}=0.143;
    $statpot{'a18FY'}=0.223;
    $statpot{'a18FV'}=0.247;
    $statpot{'a18PA'}=-0.181;
    $statpot{'a18PR'}=-0.083;
    $statpot{'a18PN'}=-0.040;
    $statpot{'a18PD'}=-0.017;
    $statpot{'a18PC'}=-0.269;
    $statpot{'a18PQ'}=-0.025;
    $statpot{'a18PE'}=-0.004;
    $statpot{'a18PG'}=0.071;
    $statpot{'a18PH'}=-0.018;
    $statpot{'a18PI'}=-0.162;
    $statpot{'a18PL'}=-0.126;
    $statpot{'a18PK'}=0.056;
    $statpot{'a18PM'}=-0.161;
    $statpot{'a18PF'}=-0.149;
    $statpot{'a18PP'}=-0.023;
    $statpot{'a18PS'}=0.022;
    $statpot{'a18PT'}=-0.118;
    $statpot{'a18PW'}=-0.194;
    $statpot{'a18PY'}=-0.151;
    $statpot{'a18PV'}=-0.179;
    $statpot{'a18SA'}=-0.061;
    $statpot{'a18SR'}=-0.070;
    $statpot{'a18SN'}=-0.100;
    $statpot{'a18SD'}=-0.078;
    $statpot{'a18SC'}=-0.213;
    $statpot{'a18SQ'}=-0.057;
    $statpot{'a18SE'}=-0.027;
    $statpot{'a18SG'}=0.025;
    $statpot{'a18SH'}=-0.102;
    $statpot{'a18SI'}=-0.124;
    $statpot{'a18SL'}=-0.090;
    $statpot{'a18SK'}=-0.016;
    $statpot{'a18SM'}=-0.150;
    $statpot{'a18SF'}=-0.150;
    $statpot{'a18SP'}=0.032;
    $statpot{'a18SS'}=-0.124;
    $statpot{'a18ST'}=-0.143;
    $statpot{'a18SW'}=-0.026;
    $statpot{'a18SY'}=-0.159;
    $statpot{'a18SV'}=-0.134;
    $statpot{'a18TA'}=-0.126;
    $statpot{'a18TR'}=-0.019;
    $statpot{'a18TN'}=0.007;
    $statpot{'a18TD'}=-0.122;
    $statpot{'a18TC'}=-0.119;
    $statpot{'a18TQ'}=-0.033;
    $statpot{'a18TE'}=-0.047;
    $statpot{'a18TG'}=-0.023;
    $statpot{'a18TH'}=-0.116;
    $statpot{'a18TI'}=-0.081;
    $statpot{'a18TL'}=-0.033;
    $statpot{'a18TK'}=0.066;
    $statpot{'a18TM'}=0.048;
    $statpot{'a18TF'}=-0.115;
    $statpot{'a18TP'}=-0.061;
    $statpot{'a18TS'}=-0.118;
    $statpot{'a18TT'}=-0.034;
    $statpot{'a18TW'}=-0.065;
    $statpot{'a18TY'}=-0.090;
    $statpot{'a18TV'}=-0.088;
    $statpot{'a18WA'}=0.020;
    $statpot{'a18WR'}=-0.029;
    $statpot{'a18WN'}=-0.040;
    $statpot{'a18WD'}=0.027;
    $statpot{'a18WC'}=0.190;
    $statpot{'a18WQ'}=0.034;
    $statpot{'a18WE'}=0.031;
    $statpot{'a18WG'}=0.014;
    $statpot{'a18WH'}=0.366;
    $statpot{'a18WI'}=0.113;
    $statpot{'a18WL'}=0.238;
    $statpot{'a18WK'}=0.102;
    $statpot{'a18WM'}=0.123;
    $statpot{'a18WF'}=0.253;
    $statpot{'a18WP'}=-0.069;
    $statpot{'a18WS'}=0.066;
    $statpot{'a18WT'}=0.025;
    $statpot{'a18WW'}=0.398;
    $statpot{'a18WY'}=0.076;
    $statpot{'a18WV'}=0.053;
    $statpot{'a18YA'}=0.055;
    $statpot{'a18YR'}=-0.057;
    $statpot{'a18YN'}=0.039;
    $statpot{'a18YD'}=0.067;
    $statpot{'a18YC'}=0.262;
    $statpot{'a18YQ'}=0.065;
    $statpot{'a18YE'}=-0.028;
    $statpot{'a18YG'}=0.134;
    $statpot{'a18YH'}=0.180;
    $statpot{'a18YI'}=0.097;
    $statpot{'a18YL'}=0.133;
    $statpot{'a18YK'}=0.071;
    $statpot{'a18YM'}=0.217;
    $statpot{'a18YF'}=0.191;
    $statpot{'a18YP'}=0.037;
    $statpot{'a18YS'}=0.026;
    $statpot{'a18YT'}=0.084;
    $statpot{'a18YW'}=0.143;
    $statpot{'a18YY'}=0.218;
    $statpot{'a18YV'}=0.105;
    $statpot{'a18VA'}=-0.016;
    $statpot{'a18VR'}=-0.048;
    $statpot{'a18VN'}=-0.050;
    $statpot{'a18VD'}=0.018;
    $statpot{'a18VC'}=-0.049;
    $statpot{'a18VQ'}=-0.028;
    $statpot{'a18VE'}=-0.003;
    $statpot{'a18VG'}=0.070;
    $statpot{'a18VH'}=0.036;
    $statpot{'a18VI'}=0.061;
    $statpot{'a18VL'}=0.128;
    $statpot{'a18VK'}=0.025;
    $statpot{'a18VM'}=0.126;
    $statpot{'a18VF'}=0.253;
    $statpot{'a18VP'}=-0.044;
    $statpot{'a18VS'}=0.013;
    $statpot{'a18VT'}=-0.012;
    $statpot{'a18VW'}=0.023;
    $statpot{'a18VY'}=0.062;
    $statpot{'a18VV'}=0.037;
    $statpot{'p19AA'}=-0.036;
    $statpot{'p19AR'}=0.031;
    $statpot{'p19AN'}=-0.074;
    $statpot{'p19AD'}=0.007;
    $statpot{'p19AC'}=-0.129;
    $statpot{'p19AQ'}=-0.009;
    $statpot{'p19AE'}=0.028;
    $statpot{'p19AG'}=0.062;
    $statpot{'p19AH'}=-0.057;
    $statpot{'p19AI'}=-0.048;
    $statpot{'p19AL'}=-0.036;
    $statpot{'p19AK'}=0.089;
    $statpot{'p19AM'}=-0.149;
    $statpot{'p19AF'}=-0.057;
    $statpot{'p19AP'}=-0.002;
    $statpot{'p19AS'}=-0.025;
    $statpot{'p19AT'}=-0.069;
    $statpot{'p19AW'}=-0.111;
    $statpot{'p19AY'}=-0.087;
    $statpot{'p19AV'}=-0.092;
    $statpot{'p19RA'}=0.031;
    $statpot{'p19RR'}=0.184;
    $statpot{'p19RN'}=-0.028;
    $statpot{'p19RD'}=0.124;
    $statpot{'p19RC'}=-0.044;
    $statpot{'p19RQ'}=0.048;
    $statpot{'p19RE'}=0.157;
    $statpot{'p19RG'}=0.096;
    $statpot{'p19RH'}=-0.008;
    $statpot{'p19RI'}=-0.071;
    $statpot{'p19RL'}=0.000;
    $statpot{'p19RK'}=0.102;
    $statpot{'p19RM'}=-0.039;
    $statpot{'p19RF'}=-0.041;
    $statpot{'p19RP'}=0.076;
    $statpot{'p19RS'}=0.014;
    $statpot{'p19RT'}=-0.018;
    $statpot{'p19RW'}=-0.132;
    $statpot{'p19RY'}=-0.049;
    $statpot{'p19RV'}=-0.082;
    $statpot{'p19NA'}=-0.074;
    $statpot{'p19NR'}=-0.028;
    $statpot{'p19NN'}=0.011;
    $statpot{'p19ND'}=0.052;
    $statpot{'p19NC'}=-0.050;
    $statpot{'p19NQ'}=0.113;
    $statpot{'p19NE'}=0.085;
    $statpot{'p19NG'}=0.041;
    $statpot{'p19NH'}=-0.106;
    $statpot{'p19NI'}=-0.066;
    $statpot{'p19NL'}=0.018;
    $statpot{'p19NK'}=0.111;
    $statpot{'p19NM'}=-0.075;
    $statpot{'p19NF'}=-0.029;
    $statpot{'p19NP'}=0.027;
    $statpot{'p19NS'}=0.003;
    $statpot{'p19NT'}=-0.005;
    $statpot{'p19NW'}=-0.047;
    $statpot{'p19NY'}=-0.081;
    $statpot{'p19NV'}=-0.007;
    $statpot{'p19DA'}=0.007;
    $statpot{'p19DR'}=0.124;
    $statpot{'p19DN'}=0.052;
    $statpot{'p19DD'}=0.197;
    $statpot{'p19DC'}=-0.044;
    $statpot{'p19DQ'}=0.088;
    $statpot{'p19DE'}=0.175;
    $statpot{'p19DG'}=0.145;
    $statpot{'p19DH'}=-0.021;
    $statpot{'p19DI'}=-0.033;
    $statpot{'p19DL'}=0.004;
    $statpot{'p19DK'}=0.142;
    $statpot{'p19DM'}=0.049;
    $statpot{'p19DF'}=0.030;
    $statpot{'p19DP'}=0.081;
    $statpot{'p19DS'}=0.043;
    $statpot{'p19DT'}=0.016;
    $statpot{'p19DW'}=0.022;
    $statpot{'p19DY'}=-0.039;
    $statpot{'p19DV'}=-0.008;
    $statpot{'p19CA'}=-0.129;
    $statpot{'p19CR'}=-0.044;
    $statpot{'p19CN'}=-0.050;
    $statpot{'p19CD'}=-0.044;
    $statpot{'p19CC'}=-0.021;
    $statpot{'p19CQ'}=-0.284;
    $statpot{'p19CE'}=-0.019;
    $statpot{'p19CG'}=0.042;
    $statpot{'p19CH'}=-0.229;
    $statpot{'p19CI'}=-0.065;
    $statpot{'p19CL'}=-0.123;
    $statpot{'p19CK'}=0.043;
    $statpot{'p19CM'}=-0.206;
    $statpot{'p19CF'}=-0.086;
    $statpot{'p19CP'}=0.021;
    $statpot{'p19CS'}=-0.042;
    $statpot{'p19CT'}=-0.161;
    $statpot{'p19CW'}=-0.022;
    $statpot{'p19CY'}=-0.156;
    $statpot{'p19CV'}=-0.174;
    $statpot{'p19QA'}=-0.009;
    $statpot{'p19QR'}=0.048;
    $statpot{'p19QN'}=0.113;
    $statpot{'p19QD'}=0.088;
    $statpot{'p19QC'}=-0.284;
    $statpot{'p19QQ'}=0.178;
    $statpot{'p19QE'}=0.149;
    $statpot{'p19QG'}=0.095;
    $statpot{'p19QH'}=0.137;
    $statpot{'p19QI'}=-0.050;
    $statpot{'p19QL'}=-0.013;
    $statpot{'p19QK'}=0.151;
    $statpot{'p19QM'}=-0.071;
    $statpot{'p19QF'}=-0.015;
    $statpot{'p19QP'}=0.016;
    $statpot{'p19QS'}=0.026;
    $statpot{'p19QT'}=-0.023;
    $statpot{'p19QW'}=-0.069;
    $statpot{'p19QY'}=0.048;
    $statpot{'p19QV'}=-0.143;
    $statpot{'p19EA'}=0.028;
    $statpot{'p19ER'}=0.157;
    $statpot{'p19EN'}=0.085;
    $statpot{'p19ED'}=0.175;
    $statpot{'p19EC'}=-0.019;
    $statpot{'p19EQ'}=0.149;
    $statpot{'p19EE'}=0.159;
    $statpot{'p19EG'}=0.111;
    $statpot{'p19EH'}=0.166;
    $statpot{'p19EI'}=0.062;
    $statpot{'p19EL'}=0.099;
    $statpot{'p19EK'}=0.192;
    $statpot{'p19EM'}=0.051;
    $statpot{'p19EF'}=0.087;
    $statpot{'p19EP'}=0.135;
    $statpot{'p19ES'}=0.052;
    $statpot{'p19ET'}=0.079;
    $statpot{'p19EW'}=0.041;
    $statpot{'p19EY'}=0.032;
    $statpot{'p19EV'}=0.006;
    $statpot{'p19GA'}=0.062;
    $statpot{'p19GR'}=0.096;
    $statpot{'p19GN'}=0.041;
    $statpot{'p19GD'}=0.145;
    $statpot{'p19GC'}=0.042;
    $statpot{'p19GQ'}=0.095;
    $statpot{'p19GE'}=0.111;
    $statpot{'p19GG'}=0.132;
    $statpot{'p19GH'}=-0.007;
    $statpot{'p19GI'}=0.028;
    $statpot{'p19GL'}=0.010;
    $statpot{'p19GK'}=0.181;
    $statpot{'p19GM'}=0.041;
    $statpot{'p19GF'}=-0.009;
    $statpot{'p19GP'}=0.131;
    $statpot{'p19GS'}=0.068;
    $statpot{'p19GT'}=0.045;
    $statpot{'p19GW'}=-0.046;
    $statpot{'p19GY'}=0.016;
    $statpot{'p19GV'}=0.015;
    $statpot{'p19HA'}=-0.057;
    $statpot{'p19HR'}=-0.008;
    $statpot{'p19HN'}=-0.106;
    $statpot{'p19HD'}=-0.021;
    $statpot{'p19HC'}=-0.229;
    $statpot{'p19HQ'}=0.137;
    $statpot{'p19HE'}=0.166;
    $statpot{'p19HG'}=-0.007;
    $statpot{'p19HH'}=0.032;
    $statpot{'p19HI'}=-0.171;
    $statpot{'p19HL'}=-0.065;
    $statpot{'p19HK'}=0.143;
    $statpot{'p19HM'}=-0.219;
    $statpot{'p19HF'}=-0.110;
    $statpot{'p19HP'}=0.014;
    $statpot{'p19HS'}=-0.105;
    $statpot{'p19HT'}=-0.093;
    $statpot{'p19HW'}=-0.085;
    $statpot{'p19HY'}=-0.165;
    $statpot{'p19HV'}=-0.192;
    $statpot{'p19IA'}=-0.048;
    $statpot{'p19IR'}=-0.071;
    $statpot{'p19IN'}=-0.066;
    $statpot{'p19ID'}=-0.033;
    $statpot{'p19IC'}=-0.065;
    $statpot{'p19IQ'}=-0.050;
    $statpot{'p19IE'}=0.062;
    $statpot{'p19IG'}=0.028;
    $statpot{'p19IH'}=-0.171;
    $statpot{'p19II'}=-0.048;
    $statpot{'p19IL'}=-0.029;
    $statpot{'p19IK'}=0.045;
    $statpot{'p19IM'}=-0.091;
    $statpot{'p19IF'}=-0.163;
    $statpot{'p19IP'}=-0.036;
    $statpot{'p19IS'}=-0.069;
    $statpot{'p19IT'}=-0.054;
    $statpot{'p19IW'}=-0.177;
    $statpot{'p19IY'}=-0.151;
    $statpot{'p19IV'}=-0.103;
    $statpot{'p19LA'}=-0.036;
    $statpot{'p19LR'}=0.000;
    $statpot{'p19LN'}=0.018;
    $statpot{'p19LD'}=0.004;
    $statpot{'p19LC'}=-0.123;
    $statpot{'p19LQ'}=-0.013;
    $statpot{'p19LE'}=0.099;
    $statpot{'p19LG'}=0.010;
    $statpot{'p19LH'}=-0.065;
    $statpot{'p19LI'}=-0.029;
    $statpot{'p19LL'}=0.053;
    $statpot{'p19LK'}=0.094;
    $statpot{'p19LM'}=-0.062;
    $statpot{'p19LF'}=-0.136;
    $statpot{'p19LP'}=0.035;
    $statpot{'p19LS'}=-0.075;
    $statpot{'p19LT'}=-0.068;
    $statpot{'p19LW'}=-0.184;
    $statpot{'p19LY'}=-0.104;
    $statpot{'p19LV'}=-0.032;
    $statpot{'p19KA'}=0.089;
    $statpot{'p19KR'}=0.102;
    $statpot{'p19KN'}=0.111;
    $statpot{'p19KD'}=0.142;
    $statpot{'p19KC'}=0.043;
    $statpot{'p19KQ'}=0.151;
    $statpot{'p19KE'}=0.192;
    $statpot{'p19KG'}=0.181;
    $statpot{'p19KH'}=0.143;
    $statpot{'p19KI'}=0.045;
    $statpot{'p19KL'}=0.094;
    $statpot{'p19KK'}=0.146;
    $statpot{'p19KM'}=0.100;
    $statpot{'p19KF'}=0.061;
    $statpot{'p19KP'}=0.057;
    $statpot{'p19KS'}=0.077;
    $statpot{'p19KT'}=0.066;
    $statpot{'p19KW'}=0.083;
    $statpot{'p19KY'}=0.088;
    $statpot{'p19KV'}=0.061;
    $statpot{'p19MA'}=-0.149;
    $statpot{'p19MR'}=-0.039;
    $statpot{'p19MN'}=-0.075;
    $statpot{'p19MD'}=0.049;
    $statpot{'p19MC'}=-0.206;
    $statpot{'p19MQ'}=-0.071;
    $statpot{'p19ME'}=0.051;
    $statpot{'p19MG'}=0.041;
    $statpot{'p19MH'}=-0.219;
    $statpot{'p19MI'}=-0.091;
    $statpot{'p19ML'}=-0.062;
    $statpot{'p19MK'}=0.100;
    $statpot{'p19MM'}=-0.214;
    $statpot{'p19MF'}=-0.079;
    $statpot{'p19MP'}=-0.072;
    $statpot{'p19MS'}=-0.145;
    $statpot{'p19MT'}=-0.137;
    $statpot{'p19MW'}=-0.258;
    $statpot{'p19MY'}=-0.132;
    $statpot{'p19MV'}=-0.087;
    $statpot{'p19FA'}=-0.057;
    $statpot{'p19FR'}=-0.041;
    $statpot{'p19FN'}=-0.029;
    $statpot{'p19FD'}=0.030;
    $statpot{'p19FC'}=-0.086;
    $statpot{'p19FQ'}=-0.015;
    $statpot{'p19FE'}=0.087;
    $statpot{'p19FG'}=-0.009;
    $statpot{'p19FH'}=-0.110;
    $statpot{'p19FI'}=-0.163;
    $statpot{'p19FL'}=-0.136;
    $statpot{'p19FK'}=0.061;
    $statpot{'p19FM'}=-0.079;
    $statpot{'p19FF'}=-0.155;
    $statpot{'p19FP'}=0.023;
    $statpot{'p19FS'}=-0.060;
    $statpot{'p19FT'}=-0.161;
    $statpot{'p19FW'}=-0.146;
    $statpot{'p19FY'}=-0.135;
    $statpot{'p19FV'}=-0.126;
    $statpot{'p19PA'}=-0.002;
    $statpot{'p19PR'}=0.076;
    $statpot{'p19PN'}=0.027;
    $statpot{'p19PD'}=0.081;
    $statpot{'p19PC'}=0.021;
    $statpot{'p19PQ'}=0.016;
    $statpot{'p19PE'}=0.135;
    $statpot{'p19PG'}=0.131;
    $statpot{'p19PH'}=0.014;
    $statpot{'p19PI'}=-0.036;
    $statpot{'p19PL'}=0.035;
    $statpot{'p19PK'}=0.057;
    $statpot{'p19PM'}=-0.072;
    $statpot{'p19PF'}=0.023;
    $statpot{'p19PP'}=0.115;
    $statpot{'p19PS'}=0.040;
    $statpot{'p19PT'}=0.024;
    $statpot{'p19PW'}=0.039;
    $statpot{'p19PY'}=-0.012;
    $statpot{'p19PV'}=-0.097;
    $statpot{'p19SA'}=-0.025;
    $statpot{'p19SR'}=0.014;
    $statpot{'p19SN'}=0.003;
    $statpot{'p19SD'}=0.043;
    $statpot{'p19SC'}=-0.042;
    $statpot{'p19SQ'}=0.026;
    $statpot{'p19SE'}=0.052;
    $statpot{'p19SG'}=0.068;
    $statpot{'p19SH'}=-0.105;
    $statpot{'p19SI'}=-0.069;
    $statpot{'p19SL'}=-0.075;
    $statpot{'p19SK'}=0.077;
    $statpot{'p19SM'}=-0.145;
    $statpot{'p19SF'}=-0.060;
    $statpot{'p19SP'}=0.040;
    $statpot{'p19SS'}=0.004;
    $statpot{'p19ST'}=-0.052;
    $statpot{'p19SW'}=-0.135;
    $statpot{'p19SY'}=-0.076;
    $statpot{'p19SV'}=-0.089;
    $statpot{'p19TA'}=-0.069;
    $statpot{'p19TR'}=-0.018;
    $statpot{'p19TN'}=-0.005;
    $statpot{'p19TD'}=0.016;
    $statpot{'p19TC'}=-0.161;
    $statpot{'p19TQ'}=-0.023;
    $statpot{'p19TE'}=0.079;
    $statpot{'p19TG'}=0.045;
    $statpot{'p19TH'}=-0.093;
    $statpot{'p19TI'}=-0.054;
    $statpot{'p19TL'}=-0.068;
    $statpot{'p19TK'}=0.066;
    $statpot{'p19TM'}=-0.137;
    $statpot{'p19TF'}=-0.161;
    $statpot{'p19TP'}=0.024;
    $statpot{'p19TS'}=-0.052;
    $statpot{'p19TT'}=0.005;
    $statpot{'p19TW'}=-0.065;
    $statpot{'p19TY'}=-0.069;
    $statpot{'p19TV'}=-0.084;
    $statpot{'p19WA'}=-0.111;
    $statpot{'p19WR'}=-0.132;
    $statpot{'p19WN'}=-0.047;
    $statpot{'p19WD'}=0.022;
    $statpot{'p19WC'}=-0.022;
    $statpot{'p19WQ'}=-0.069;
    $statpot{'p19WE'}=0.041;
    $statpot{'p19WG'}=-0.046;
    $statpot{'p19WH'}=-0.085;
    $statpot{'p19WI'}=-0.177;
    $statpot{'p19WL'}=-0.184;
    $statpot{'p19WK'}=0.083;
    $statpot{'p19WM'}=-0.258;
    $statpot{'p19WF'}=-0.146;
    $statpot{'p19WP'}=0.039;
    $statpot{'p19WS'}=-0.135;
    $statpot{'p19WT'}=-0.065;
    $statpot{'p19WW'}=-0.071;
    $statpot{'p19WY'}=-0.188;
    $statpot{'p19WV'}=-0.184;
    $statpot{'p19YA'}=-0.087;
    $statpot{'p19YR'}=-0.049;
    $statpot{'p19YN'}=-0.081;
    $statpot{'p19YD'}=-0.039;
    $statpot{'p19YC'}=-0.156;
    $statpot{'p19YQ'}=0.048;
    $statpot{'p19YE'}=0.032;
    $statpot{'p19YG'}=0.016;
    $statpot{'p19YH'}=-0.165;
    $statpot{'p19YI'}=-0.151;
    $statpot{'p19YL'}=-0.104;
    $statpot{'p19YK'}=0.088;
    $statpot{'p19YM'}=-0.132;
    $statpot{'p19YF'}=-0.135;
    $statpot{'p19YP'}=-0.012;
    $statpot{'p19YS'}=-0.076;
    $statpot{'p19YT'}=-0.069;
    $statpot{'p19YW'}=-0.188;
    $statpot{'p19YY'}=-0.221;
    $statpot{'p19YV'}=-0.098;
    $statpot{'p19VA'}=-0.092;
    $statpot{'p19VR'}=-0.082;
    $statpot{'p19VN'}=-0.007;
    $statpot{'p19VD'}=-0.008;
    $statpot{'p19VC'}=-0.174;
    $statpot{'p19VQ'}=-0.143;
    $statpot{'p19VE'}=0.006;
    $statpot{'p19VG'}=0.015;
    $statpot{'p19VH'}=-0.192;
    $statpot{'p19VI'}=-0.103;
    $statpot{'p19VL'}=-0.032;
    $statpot{'p19VK'}=0.061;
    $statpot{'p19VM'}=-0.087;
    $statpot{'p19VF'}=-0.126;
    $statpot{'p19VP'}=-0.097;
    $statpot{'p19VS'}=-0.089;
    $statpot{'p19VT'}=-0.084;
    $statpot{'p19VW'}=-0.184;
    $statpot{'p19VY'}=-0.098;
    $statpot{'p19VV'}=-0.062;
    $statpot{'f19AA'}=-0.058;
    $statpot{'f19AR'}=-0.009;
    $statpot{'f19AN'}=-0.048;
    $statpot{'f19AD'}=0.112;
    $statpot{'f19AC'}=-0.215;
    $statpot{'f19AQ'}=0.020;
    $statpot{'f19AE'}=0.156;
    $statpot{'f19AG'}=0.029;
    $statpot{'f19AH'}=-0.200;
    $statpot{'f19AI'}=-0.186;
    $statpot{'f19AL'}=-0.120;
    $statpot{'f19AK'}=0.216;
    $statpot{'f19AM'}=-0.246;
    $statpot{'f19AF'}=-0.165;
    $statpot{'f19AP'}=-0.015;
    $statpot{'f19AS'}=-0.072;
    $statpot{'f19AT'}=-0.121;
    $statpot{'f19AW'}=-0.195;
    $statpot{'f19AY'}=-0.197;
    $statpot{'f19AV'}=-0.193;
    $statpot{'f19RA'}=0.125;
    $statpot{'f19RR'}=0.255;
    $statpot{'f19RN'}=0.142;
    $statpot{'f19RD'}=0.299;
    $statpot{'f19RC'}=-0.107;
    $statpot{'f19RQ'}=0.182;
    $statpot{'f19RE'}=0.353;
    $statpot{'f19RG'}=0.219;
    $statpot{'f19RH'}=0.132;
    $statpot{'f19RI'}=-0.108;
    $statpot{'f19RL'}=0.023;
    $statpot{'f19RK'}=0.365;
    $statpot{'f19RM'}=-0.071;
    $statpot{'f19RF'}=-0.061;
    $statpot{'f19RP'}=0.300;
    $statpot{'f19RS'}=0.267;
    $statpot{'f19RT'}=0.062;
    $statpot{'f19RW'}=-0.014;
    $statpot{'f19RY'}=-0.134;
    $statpot{'f19RV'}=0.064;
    $statpot{'f19NA'}=0.071;
    $statpot{'f19NR'}=0.190;
    $statpot{'f19NN'}=0.203;
    $statpot{'f19ND'}=0.375;
    $statpot{'f19NC'}=-0.094;
    $statpot{'f19NQ'}=0.242;
    $statpot{'f19NE'}=0.330;
    $statpot{'f19NG'}=0.243;
    $statpot{'f19NH'}=-0.008;
    $statpot{'f19NI'}=-0.109;
    $statpot{'f19NL'}=-0.018;
    $statpot{'f19NK'}=0.511;
    $statpot{'f19NM'}=-0.018;
    $statpot{'f19NF'}=-0.081;
    $statpot{'f19NP'}=0.366;
    $statpot{'f19NS'}=0.209;
    $statpot{'f19NT'}=0.233;
    $statpot{'f19NW'}=-0.096;
    $statpot{'f19NY'}=-0.023;
    $statpot{'f19NV'}=0.030;
    $statpot{'f19DA'}=0.247;
    $statpot{'f19DR'}=0.345;
    $statpot{'f19DN'}=0.384;
    $statpot{'f19DD'}=0.465;
    $statpot{'f19DC'}=0.216;
    $statpot{'f19DQ'}=0.296;
    $statpot{'f19DE'}=0.561;
    $statpot{'f19DG'}=0.426;
    $statpot{'f19DH'}=0.240;
    $statpot{'f19DI'}=0.089;
    $statpot{'f19DL'}=0.101;
    $statpot{'f19DK'}=0.567;
    $statpot{'f19DM'}=0.144;
    $statpot{'f19DF'}=0.055;
    $statpot{'f19DP'}=0.417;
    $statpot{'f19DS'}=0.382;
    $statpot{'f19DT'}=0.312;
    $statpot{'f19DW'}=0.084;
    $statpot{'f19DY'}=0.076;
    $statpot{'f19DV'}=0.174;
    $statpot{'f19CA'}=-0.252;
    $statpot{'f19CR'}=-0.262;
    $statpot{'f19CN'}=-0.113;
    $statpot{'f19CD'}=-0.035;
    $statpot{'f19CC'}=-0.164;
    $statpot{'f19CQ'}=-0.135;
    $statpot{'f19CE'}=-0.080;
    $statpot{'f19CG'}=-0.128;
    $statpot{'f19CH'}=-0.208;
    $statpot{'f19CI'}=-0.564;
    $statpot{'f19CL'}=-0.285;
    $statpot{'f19CK'}=-0.114;
    $statpot{'f19CM'}=-0.458;
    $statpot{'f19CF'}=-0.408;
    $statpot{'f19CP'}=-0.101;
    $statpot{'f19CS'}=-0.124;
    $statpot{'f19CT'}=-0.164;
    $statpot{'f19CW'}=-0.575;
    $statpot{'f19CY'}=-0.330;
    $statpot{'f19CV'}=-0.314;
    $statpot{'f19QA'}=0.066;
    $statpot{'f19QR'}=0.222;
    $statpot{'f19QN'}=0.241;
    $statpot{'f19QD'}=0.232;
    $statpot{'f19QC'}=0.088;
    $statpot{'f19QQ'}=0.228;
    $statpot{'f19QE'}=0.330;
    $statpot{'f19QG'}=0.187;
    $statpot{'f19QH'}=0.050;
    $statpot{'f19QI'}=-0.037;
    $statpot{'f19QL'}=0.016;
    $statpot{'f19QK'}=0.458;
    $statpot{'f19QM'}=0.081;
    $statpot{'f19QF'}=-0.140;
    $statpot{'f19QP'}=0.187;
    $statpot{'f19QS'}=0.173;
    $statpot{'f19QT'}=0.205;
    $statpot{'f19QW'}=0.007;
    $statpot{'f19QY'}=0.027;
    $statpot{'f19QV'}=-0.034;
    $statpot{'f19EA'}=0.379;
    $statpot{'f19ER'}=0.402;
    $statpot{'f19EN'}=0.429;
    $statpot{'f19ED'}=0.582;
    $statpot{'f19EC'}=0.186;
    $statpot{'f19EQ'}=0.355;
    $statpot{'f19EE'}=0.510;
    $statpot{'f19EG'}=0.455;
    $statpot{'f19EH'}=0.454;
    $statpot{'f19EI'}=0.225;
    $statpot{'f19EL'}=0.175;
    $statpot{'f19EK'}=0.589;
    $statpot{'f19EM'}=0.165;
    $statpot{'f19EF'}=0.143;
    $statpot{'f19EP'}=0.497;
    $statpot{'f19ES'}=0.409;
    $statpot{'f19ET'}=0.357;
    $statpot{'f19EW'}=0.188;
    $statpot{'f19EY'}=0.122;
    $statpot{'f19EV'}=0.228;
    $statpot{'f19GA'}=0.109;
    $statpot{'f19GR'}=0.211;
    $statpot{'f19GN'}=0.162;
    $statpot{'f19GD'}=0.258;
    $statpot{'f19GC'}=-0.038;
    $statpot{'f19GQ'}=0.244;
    $statpot{'f19GE'}=0.377;
    $statpot{'f19GG'}=0.240;
    $statpot{'f19GH'}=0.155;
    $statpot{'f19GI'}=-0.024;
    $statpot{'f19GL'}=-0.008;
    $statpot{'f19GK'}=0.448;
    $statpot{'f19GM'}=-0.040;
    $statpot{'f19GF'}=-0.115;
    $statpot{'f19GP'}=0.279;
    $statpot{'f19GS'}=0.148;
    $statpot{'f19GT'}=0.115;
    $statpot{'f19GW'}=0.040;
    $statpot{'f19GY'}=-0.071;
    $statpot{'f19GV'}=0.010;
    $statpot{'f19HA'}=-0.161;
    $statpot{'f19HR'}=0.015;
    $statpot{'f19HN'}=-0.065;
    $statpot{'f19HD'}=0.111;
    $statpot{'f19HC'}=-0.207;
    $statpot{'f19HQ'}=0.021;
    $statpot{'f19HE'}=0.321;
    $statpot{'f19HG'}=0.103;
    $statpot{'f19HH'}=-0.070;
    $statpot{'f19HI'}=-0.033;
    $statpot{'f19HL'}=-0.177;
    $statpot{'f19HK'}=0.180;
    $statpot{'f19HM'}=-0.180;
    $statpot{'f19HF'}=-0.347;
    $statpot{'f19HP'}=0.102;
    $statpot{'f19HS'}=-0.045;
    $statpot{'f19HT'}=0.021;
    $statpot{'f19HW'}=-0.253;
    $statpot{'f19HY'}=-0.338;
    $statpot{'f19HV'}=-0.272;
    $statpot{'f19IA'}=-0.232;
    $statpot{'f19IR'}=-0.190;
    $statpot{'f19IN'}=-0.255;
    $statpot{'f19ID'}=-0.156;
    $statpot{'f19IC'}=-0.585;
    $statpot{'f19IQ'}=-0.225;
    $statpot{'f19IE'}=-0.020;
    $statpot{'f19IG'}=-0.186;
    $statpot{'f19IH'}=-0.196;
    $statpot{'f19II'}=-0.243;
    $statpot{'f19IL'}=-0.267;
    $statpot{'f19IK'}=-0.007;
    $statpot{'f19IM'}=-0.296;
    $statpot{'f19IF'}=-0.294;
    $statpot{'f19IP'}=-0.180;
    $statpot{'f19IS'}=-0.218;
    $statpot{'f19IT'}=-0.285;
    $statpot{'f19IW'}=-0.352;
    $statpot{'f19IY'}=-0.347;
    $statpot{'f19IV'}=-0.270;
    $statpot{'f19LA'}=-0.192;
    $statpot{'f19LR'}=-0.104;
    $statpot{'f19LN'}=-0.162;
    $statpot{'f19LD'}=-0.109;
    $statpot{'f19LC'}=-0.276;
    $statpot{'f19LQ'}=-0.103;
    $statpot{'f19LE'}=0.002;
    $statpot{'f19LG'}=-0.154;
    $statpot{'f19LH'}=-0.261;
    $statpot{'f19LI'}=-0.253;
    $statpot{'f19LL'}=-0.263;
    $statpot{'f19LK'}=-0.025;
    $statpot{'f19LM'}=-0.258;
    $statpot{'f19LF'}=-0.383;
    $statpot{'f19LP'}=-0.103;
    $statpot{'f19LS'}=-0.215;
    $statpot{'f19LT'}=-0.225;
    $statpot{'f19LW'}=-0.457;
    $statpot{'f19LY'}=-0.329;
    $statpot{'f19LV'}=-0.244;
    $statpot{'f19KA'}=0.277;
    $statpot{'f19KR'}=0.375;
    $statpot{'f19KN'}=0.564;
    $statpot{'f19KD'}=0.576;
    $statpot{'f19KC'}=0.143;
    $statpot{'f19KQ'}=0.455;
    $statpot{'f19KE'}=0.521;
    $statpot{'f19KG'}=0.488;
    $statpot{'f19KH'}=0.378;
    $statpot{'f19KI'}=0.218;
    $statpot{'f19KL'}=0.174;
    $statpot{'f19KK'}=0.578;
    $statpot{'f19KM'}=0.258;
    $statpot{'f19KF'}=0.211;
    $statpot{'f19KP'}=0.417;
    $statpot{'f19KS'}=0.414;
    $statpot{'f19KT'}=0.411;
    $statpot{'f19KW'}=0.242;
    $statpot{'f19KY'}=0.090;
    $statpot{'f19KV'}=0.265;
    $statpot{'f19MA'}=-0.297;
    $statpot{'f19MR'}=-0.202;
    $statpot{'f19MN'}=-0.200;
    $statpot{'f19MD'}=-0.080;
    $statpot{'f19MC'}=-0.365;
    $statpot{'f19MQ'}=-0.079;
    $statpot{'f19ME'}=0.020;
    $statpot{'f19MG'}=-0.159;
    $statpot{'f19MH'}=-0.291;
    $statpot{'f19MI'}=-0.294;
    $statpot{'f19ML'}=-0.313;
    $statpot{'f19MK'}=0.014;
    $statpot{'f19MM'}=-0.385;
    $statpot{'f19MF'}=-0.465;
    $statpot{'f19MP'}=-0.160;
    $statpot{'f19MS'}=-0.194;
    $statpot{'f19MT'}=-0.318;
    $statpot{'f19MW'}=-0.448;
    $statpot{'f19MY'}=-0.467;
    $statpot{'f19MV'}=-0.347;
    $statpot{'f19FA'}=-0.228;
    $statpot{'f19FR'}=-0.199;
    $statpot{'f19FN'}=-0.246;
    $statpot{'f19FD'}=-0.198;
    $statpot{'f19FC'}=-0.382;
    $statpot{'f19FQ'}=-0.236;
    $statpot{'f19FE'}=-0.111;
    $statpot{'f19FG'}=-0.239;
    $statpot{'f19FH'}=-0.288;
    $statpot{'f19FI'}=-0.310;
    $statpot{'f19FL'}=-0.386;
    $statpot{'f19FK'}=-0.025;
    $statpot{'f19FM'}=-0.415;
    $statpot{'f19FF'}=-0.386;
    $statpot{'f19FP'}=-0.183;
    $statpot{'f19FS'}=-0.250;
    $statpot{'f19FT'}=-0.291;
    $statpot{'f19FW'}=-0.362;
    $statpot{'f19FY'}=-0.367;
    $statpot{'f19FV'}=-0.336;
    $statpot{'f19PA'}=0.151;
    $statpot{'f19PR'}=0.325;
    $statpot{'f19PN'}=0.374;
    $statpot{'f19PD'}=0.313;
    $statpot{'f19PC'}=0.056;
    $statpot{'f19PQ'}=0.273;
    $statpot{'f19PE'}=0.391;
    $statpot{'f19PG'}=0.311;
    $statpot{'f19PH'}=0.276;
    $statpot{'f19PI'}=-0.006;
    $statpot{'f19PL'}=0.112;
    $statpot{'f19PK'}=0.400;
    $statpot{'f19PM'}=0.066;
    $statpot{'f19PF'}=0.050;
    $statpot{'f19PP'}=0.376;
    $statpot{'f19PS'}=0.155;
    $statpot{'f19PT'}=0.162;
    $statpot{'f19PW'}=0.235;
    $statpot{'f19PY'}=0.090;
    $statpot{'f19PV'}=0.110;
    $statpot{'f19SA'}=-0.017;
    $statpot{'f19SR'}=0.180;
    $statpot{'f19SN'}=0.100;
    $statpot{'f19SD'}=0.331;
    $statpot{'f19SC'}=-0.062;
    $statpot{'f19SQ'}=0.185;
    $statpot{'f19SE'}=0.322;
    $statpot{'f19SG'}=0.177;
    $statpot{'f19SH'}=-0.025;
    $statpot{'f19SI'}=-0.060;
    $statpot{'f19SL'}=-0.066;
    $statpot{'f19SK'}=0.310;
    $statpot{'f19SM'}=-0.124;
    $statpot{'f19SF'}=-0.030;
    $statpot{'f19SP'}=0.121;
    $statpot{'f19SS'}=0.129;
    $statpot{'f19ST'}=0.102;
    $statpot{'f19SW'}=-0.034;
    $statpot{'f19SY'}=-0.007;
    $statpot{'f19SV'}=-0.027;
    $statpot{'f19TA'}=-0.045;
    $statpot{'f19TR'}=0.034;
    $statpot{'f19TN'}=0.128;
    $statpot{'f19TD'}=0.188;
    $statpot{'f19TC'}=-0.052;
    $statpot{'f19TQ'}=0.085;
    $statpot{'f19TE'}=0.286;
    $statpot{'f19TG'}=0.068;
    $statpot{'f19TH'}=0.025;
    $statpot{'f19TI'}=-0.114;
    $statpot{'f19TL'}=-0.107;
    $statpot{'f19TK'}=0.265;
    $statpot{'f19TM'}=-0.162;
    $statpot{'f19TF'}=-0.061;
    $statpot{'f19TP'}=0.077;
    $statpot{'f19TS'}=0.119;
    $statpot{'f19TT'}=0.075;
    $statpot{'f19TW'}=-0.073;
    $statpot{'f19TY'}=-0.149;
    $statpot{'f19TV'}=-0.138;
    $statpot{'f19WA'}=-0.128;
    $statpot{'f19WR'}=-0.126;
    $statpot{'f19WN'}=-0.239;
    $statpot{'f19WD'}=0.004;
    $statpot{'f19WC'}=-0.676;
    $statpot{'f19WQ'}=-0.127;
    $statpot{'f19WE'}=0.146;
    $statpot{'f19WG'}=-0.106;
    $statpot{'f19WH'}=-0.361;
    $statpot{'f19WI'}=-0.468;
    $statpot{'f19WL'}=-0.364;
    $statpot{'f19WK'}=0.088;
    $statpot{'f19WM'}=-0.460;
    $statpot{'f19WF'}=-0.399;
    $statpot{'f19WP'}=-0.004;
    $statpot{'f19WS'}=-0.207;
    $statpot{'f19WT'}=-0.026;
    $statpot{'f19WW'}=-0.624;
    $statpot{'f19WY'}=-0.327;
    $statpot{'f19WV'}=-0.425;
    $statpot{'f19YA'}=-0.200;
    $statpot{'f19YR'}=-0.228;
    $statpot{'f19YN'}=-0.028;
    $statpot{'f19YD'}=-0.031;
    $statpot{'f19YC'}=-0.370;
    $statpot{'f19YQ'}=-0.141;
    $statpot{'f19YE'}=0.027;
    $statpot{'f19YG'}=-0.149;
    $statpot{'f19YH'}=-0.370;
    $statpot{'f19YI'}=-0.334;
    $statpot{'f19YL'}=-0.284;
    $statpot{'f19YK'}=-0.097;
    $statpot{'f19YM'}=-0.441;
    $statpot{'f19YF'}=-0.420;
    $statpot{'f19YP'}=-0.073;
    $statpot{'f19YS'}=-0.175;
    $statpot{'f19YT'}=-0.274;
    $statpot{'f19YW'}=-0.327;
    $statpot{'f19YY'}=-0.391;
    $statpot{'f19YV'}=-0.276;
    $statpot{'f19VA'}=-0.230;
    $statpot{'f19VR'}=-0.072;
    $statpot{'f19VN'}=-0.161;
    $statpot{'f19VD'}=0.030;
    $statpot{'f19VC'}=-0.286;
    $statpot{'f19VQ'}=-0.147;
    $statpot{'f19VE'}=0.030;
    $statpot{'f19VG'}=-0.104;
    $statpot{'f19VH'}=-0.309;
    $statpot{'f19VI'}=-0.244;
    $statpot{'f19VL'}=-0.243;
    $statpot{'f19VK'}=0.056;
    $statpot{'f19VM'}=-0.311;
    $statpot{'f19VF'}=-0.317;
    $statpot{'f19VP'}=-0.079;
    $statpot{'f19VS'}=-0.145;
    $statpot{'f19VT'}=-0.190;
    $statpot{'f19VW'}=-0.393;
    $statpot{'f19VY'}=-0.246;
    $statpot{'f19VV'}=-0.153;
    $statpot{'a19AA'}=-0.006;
    $statpot{'a19AR'}=0.016;
    $statpot{'a19AN'}=0.008;
    $statpot{'a19AD'}=-0.047;
    $statpot{'a19AC'}=0.059;
    $statpot{'a19AQ'}=0.042;
    $statpot{'a19AE'}=0.072;
    $statpot{'a19AG'}=-0.010;
    $statpot{'a19AH'}=-0.017;
    $statpot{'a19AI'}=-0.002;
    $statpot{'a19AL'}=0.080;
    $statpot{'a19AK'}=0.025;
    $statpot{'a19AM'}=-0.028;
    $statpot{'a19AF'}=-0.022;
    $statpot{'a19AP'}=0.014;
    $statpot{'a19AS'}=-0.069;
    $statpot{'a19AT'}=-0.038;
    $statpot{'a19AW'}=0.042;
    $statpot{'a19AY'}=0.028;
    $statpot{'a19AV'}=-0.015;
    $statpot{'a19RA'}=-0.105;
    $statpot{'a19RR'}=-0.146;
    $statpot{'a19RN'}=-0.061;
    $statpot{'a19RD'}=-0.075;
    $statpot{'a19RC'}=-0.208;
    $statpot{'a19RQ'}=-0.119;
    $statpot{'a19RE'}=-0.071;
    $statpot{'a19RG'}=-0.025;
    $statpot{'a19RH'}=-0.113;
    $statpot{'a19RI'}=-0.054;
    $statpot{'a19RL'}=-0.041;
    $statpot{'a19RK'}=-0.052;
    $statpot{'a19RM'}=-0.127;
    $statpot{'a19RF'}=-0.041;
    $statpot{'a19RP'}=-0.050;
    $statpot{'a19RS'}=-0.169;
    $statpot{'a19RT'}=-0.147;
    $statpot{'a19RW'}=-0.095;
    $statpot{'a19RY'}=-0.047;
    $statpot{'a19RV'}=-0.071;
    $statpot{'a19NA'}=-0.101;
    $statpot{'a19NR'}=-0.097;
    $statpot{'a19NN'}=-0.038;
    $statpot{'a19ND'}=-0.021;
    $statpot{'a19NC'}=0.011;
    $statpot{'a19NQ'}=-0.077;
    $statpot{'a19NE'}=0.023;
    $statpot{'a19NG'}=-0.034;
    $statpot{'a19NH'}=-0.165;
    $statpot{'a19NI'}=-0.126;
    $statpot{'a19NL'}=-0.067;
    $statpot{'a19NK'}=0.050;
    $statpot{'a19NM'}=-0.099;
    $statpot{'a19NF'}=-0.136;
    $statpot{'a19NP'}=-0.002;
    $statpot{'a19NS'}=-0.099;
    $statpot{'a19NT'}=-0.092;
    $statpot{'a19NW'}=-0.150;
    $statpot{'a19NY'}=-0.020;
    $statpot{'a19NV'}=-0.158;
    $statpot{'a19DA'}=-0.149;
    $statpot{'a19DR'}=-0.104;
    $statpot{'a19DN'}=-0.027;
    $statpot{'a19DD'}=-0.062;
    $statpot{'a19DC'}=-0.218;
    $statpot{'a19DQ'}=-0.052;
    $statpot{'a19DE'}=0.029;
    $statpot{'a19DG'}=-0.085;
    $statpot{'a19DH'}=-0.083;
    $statpot{'a19DI'}=-0.193;
    $statpot{'a19DL'}=-0.078;
    $statpot{'a19DK'}=0.021;
    $statpot{'a19DM'}=-0.209;
    $statpot{'a19DF'}=-0.209;
    $statpot{'a19DP'}=-0.099;
    $statpot{'a19DS'}=-0.084;
    $statpot{'a19DT'}=-0.134;
    $statpot{'a19DW'}=-0.027;
    $statpot{'a19DY'}=-0.005;
    $statpot{'a19DV'}=-0.127;
    $statpot{'a19CA'}=0.108;
    $statpot{'a19CR'}=-0.054;
    $statpot{'a19CN'}=0.031;
    $statpot{'a19CD'}=-0.027;
    $statpot{'a19CC'}=0.260;
    $statpot{'a19CQ'}=-0.069;
    $statpot{'a19CE'}=0.059;
    $statpot{'a19CG'}=0.092;
    $statpot{'a19CH'}=0.070;
    $statpot{'a19CI'}=0.074;
    $statpot{'a19CL'}=0.209;
    $statpot{'a19CK'}=0.201;
    $statpot{'a19CM'}=0.011;
    $statpot{'a19CF'}=0.224;
    $statpot{'a19CP'}=0.039;
    $statpot{'a19CS'}=0.149;
    $statpot{'a19CT'}=0.185;
    $statpot{'a19CW'}=-0.009;
    $statpot{'a19CY'}=0.161;
    $statpot{'a19CV'}=0.096;
    $statpot{'a19QA'}=-0.003;
    $statpot{'a19QR'}=-0.146;
    $statpot{'a19QN'}=-0.077;
    $statpot{'a19QD'}=-0.006;
    $statpot{'a19QC'}=-0.250;
    $statpot{'a19QQ'}=0.086;
    $statpot{'a19QE'}=-0.034;
    $statpot{'a19QG'}=0.013;
    $statpot{'a19QH'}=0.008;
    $statpot{'a19QI'}=-0.111;
    $statpot{'a19QL'}=-0.102;
    $statpot{'a19QK'}=-0.050;
    $statpot{'a19QM'}=-0.183;
    $statpot{'a19QF'}=0.029;
    $statpot{'a19QP'}=-0.044;
    $statpot{'a19QS'}=-0.054;
    $statpot{'a19QT'}=-0.189;
    $statpot{'a19QW'}=0.002;
    $statpot{'a19QY'}=-0.028;
    $statpot{'a19QV'}=-0.097;
    $statpot{'a19EA'}=-0.098;
    $statpot{'a19ER'}=-0.101;
    $statpot{'a19EN'}=-0.042;
    $statpot{'a19ED'}=0.016;
    $statpot{'a19EC'}=-0.168;
    $statpot{'a19EQ'}=-0.051;
    $statpot{'a19EE'}=0.111;
    $statpot{'a19EG'}=-0.040;
    $statpot{'a19EH'}=-0.079;
    $statpot{'a19EI'}=-0.155;
    $statpot{'a19EL'}=-0.087;
    $statpot{'a19EK'}=-0.044;
    $statpot{'a19EM'}=-0.105;
    $statpot{'a19EF'}=-0.207;
    $statpot{'a19EP'}=-0.074;
    $statpot{'a19ES'}=-0.025;
    $statpot{'a19ET'}=-0.050;
    $statpot{'a19EW'}=-0.027;
    $statpot{'a19EY'}=-0.111;
    $statpot{'a19EV'}=-0.166;
    $statpot{'a19GA'}=-0.081;
    $statpot{'a19GR'}=-0.018;
    $statpot{'a19GN'}=0.029;
    $statpot{'a19GD'}=0.028;
    $statpot{'a19GC'}=-0.004;
    $statpot{'a19GQ'}=-0.030;
    $statpot{'a19GE'}=0.013;
    $statpot{'a19GG'}=0.146;
    $statpot{'a19GH'}=0.057;
    $statpot{'a19GI'}=-0.079;
    $statpot{'a19GL'}=-0.032;
    $statpot{'a19GK'}=0.032;
    $statpot{'a19GM'}=-0.044;
    $statpot{'a19GF'}=-0.009;
    $statpot{'a19GP'}=0.071;
    $statpot{'a19GS'}=0.003;
    $statpot{'a19GT'}=-0.055;
    $statpot{'a19GW'}=0.015;
    $statpot{'a19GY'}=0.059;
    $statpot{'a19GV'}=-0.068;
    $statpot{'a19HA'}=-0.062;
    $statpot{'a19HR'}=-0.014;
    $statpot{'a19HN'}=-0.116;
    $statpot{'a19HD'}=0.018;
    $statpot{'a19HC'}=0.069;
    $statpot{'a19HQ'}=0.035;
    $statpot{'a19HE'}=0.006;
    $statpot{'a19HG'}=0.104;
    $statpot{'a19HH'}=0.029;
    $statpot{'a19HI'}=0.100;
    $statpot{'a19HL'}=0.032;
    $statpot{'a19HK'}=0.004;
    $statpot{'a19HM'}=-0.130;
    $statpot{'a19HF'}=0.105;
    $statpot{'a19HP'}=-0.005;
    $statpot{'a19HS'}=-0.061;
    $statpot{'a19HT'}=-0.133;
    $statpot{'a19HW'}=0.055;
    $statpot{'a19HY'}=0.009;
    $statpot{'a19HV'}=-0.034;
    $statpot{'a19IA'}=0.056;
    $statpot{'a19IR'}=0.038;
    $statpot{'a19IN'}=0.034;
    $statpot{'a19ID'}=0.034;
    $statpot{'a19IC'}=0.114;
    $statpot{'a19IQ'}=0.095;
    $statpot{'a19IE'}=0.053;
    $statpot{'a19IG'}=0.100;
    $statpot{'a19IH'}=0.320;
    $statpot{'a19II'}=0.142;
    $statpot{'a19IL'}=0.248;
    $statpot{'a19IK'}=0.047;
    $statpot{'a19IM'}=0.137;
    $statpot{'a19IF'}=0.214;
    $statpot{'a19IP'}=0.020;
    $statpot{'a19IS'}=-0.002;
    $statpot{'a19IT'}=0.162;
    $statpot{'a19IW'}=0.024;
    $statpot{'a19IY'}=0.036;
    $statpot{'a19IV'}=0.146;
    $statpot{'a19LA'}=0.177;
    $statpot{'a19LR'}=0.093;
    $statpot{'a19LN'}=0.085;
    $statpot{'a19LD'}=0.132;
    $statpot{'a19LC'}=0.196;
    $statpot{'a19LQ'}=0.013;
    $statpot{'a19LE'}=0.067;
    $statpot{'a19LG'}=0.132;
    $statpot{'a19LH'}=0.142;
    $statpot{'a19LI'}=0.226;
    $statpot{'a19LL'}=0.323;
    $statpot{'a19LK'}=0.090;
    $statpot{'a19LM'}=0.175;
    $statpot{'a19LF'}=0.247;
    $statpot{'a19LP'}=0.057;
    $statpot{'a19LS'}=0.052;
    $statpot{'a19LT'}=0.124;
    $statpot{'a19LW'}=0.336;
    $statpot{'a19LY'}=0.246;
    $statpot{'a19LV'}=0.144;
    $statpot{'a19KA'}=-0.022;
    $statpot{'a19KR'}=-0.058;
    $statpot{'a19KN'}=0.019;
    $statpot{'a19KD'}=0.016;
    $statpot{'a19KC'}=-0.054;
    $statpot{'a19KQ'}=-0.050;
    $statpot{'a19KE'}=-0.007;
    $statpot{'a19KG'}=0.006;
    $statpot{'a19KH'}=-0.130;
    $statpot{'a19KI'}=-0.141;
    $statpot{'a19KL'}=-0.089;
    $statpot{'a19KK'}=0.057;
    $statpot{'a19KM'}=-0.209;
    $statpot{'a19KF'}=-0.084;
    $statpot{'a19KP'}=0.018;
    $statpot{'a19KS'}=-0.115;
    $statpot{'a19KT'}=-0.101;
    $statpot{'a19KW'}=-0.053;
    $statpot{'a19KY'}=-0.109;
    $statpot{'a19KV'}=-0.220;
    $statpot{'a19MA'}=0.040;
    $statpot{'a19MR'}=0.014;
    $statpot{'a19MN'}=0.098;
    $statpot{'a19MD'}=-0.017;
    $statpot{'a19MC'}=-0.119;
    $statpot{'a19MQ'}=-0.045;
    $statpot{'a19ME'}=0.020;
    $statpot{'a19MG'}=0.090;
    $statpot{'a19MH'}=-0.004;
    $statpot{'a19MI'}=0.135;
    $statpot{'a19ML'}=0.266;
    $statpot{'a19MK'}=-0.024;
    $statpot{'a19MM'}=-0.009;
    $statpot{'a19MF'}=0.180;
    $statpot{'a19MP'}=-0.145;
    $statpot{'a19MS'}=-0.069;
    $statpot{'a19MT'}=-0.023;
    $statpot{'a19MW'}=-0.129;
    $statpot{'a19MY'}=0.091;
    $statpot{'a19MV'}=0.059;
    $statpot{'a19FA'}=0.057;
    $statpot{'a19FR'}=0.117;
    $statpot{'a19FN'}=0.040;
    $statpot{'a19FD'}=0.032;
    $statpot{'a19FC'}=0.179;
    $statpot{'a19FQ'}=0.150;
    $statpot{'a19FE'}=0.016;
    $statpot{'a19FG'}=0.144;
    $statpot{'a19FH'}=0.024;
    $statpot{'a19FI'}=0.239;
    $statpot{'a19FL'}=0.252;
    $statpot{'a19FK'}=0.126;
    $statpot{'a19FM'}=0.092;
    $statpot{'a19FF'}=0.304;
    $statpot{'a19FP'}=0.103;
    $statpot{'a19FS'}=0.063;
    $statpot{'a19FT'}=0.137;
    $statpot{'a19FW'}=0.203;
    $statpot{'a19FY'}=0.154;
    $statpot{'a19FV'}=0.166;
    $statpot{'a19PA'}=-0.133;
    $statpot{'a19PR'}=-0.067;
    $statpot{'a19PN'}=-0.007;
    $statpot{'a19PD'}=-0.033;
    $statpot{'a19PC'}=-0.106;
    $statpot{'a19PQ'}=-0.105;
    $statpot{'a19PE'}=-0.010;
    $statpot{'a19PG'}=0.046;
    $statpot{'a19PH'}=-0.136;
    $statpot{'a19PI'}=-0.156;
    $statpot{'a19PL'}=-0.146;
    $statpot{'a19PK'}=0.030;
    $statpot{'a19PM'}=-0.331;
    $statpot{'a19PF'}=-0.136;
    $statpot{'a19PP'}=0.043;
    $statpot{'a19PS'}=-0.064;
    $statpot{'a19PT'}=-0.153;
    $statpot{'a19PW'}=-0.274;
    $statpot{'a19PY'}=-0.171;
    $statpot{'a19PV'}=-0.207;
    $statpot{'a19SA'}=-0.121;
    $statpot{'a19SR'}=-0.111;
    $statpot{'a19SN'}=-0.017;
    $statpot{'a19SD'}=-0.053;
    $statpot{'a19SC'}=0.078;
    $statpot{'a19SQ'}=-0.063;
    $statpot{'a19SE'}=0.033;
    $statpot{'a19SG'}=-0.020;
    $statpot{'a19SH'}=-0.079;
    $statpot{'a19SI'}=-0.164;
    $statpot{'a19SL'}=-0.109;
    $statpot{'a19SK'}=-0.052;
    $statpot{'a19SM'}=-0.142;
    $statpot{'a19SF'}=-0.165;
    $statpot{'a19SP'}=-0.037;
    $statpot{'a19SS'}=-0.079;
    $statpot{'a19ST'}=-0.148;
    $statpot{'a19SW'}=-0.098;
    $statpot{'a19SY'}=-0.109;
    $statpot{'a19SV'}=-0.113;
    $statpot{'a19TA'}=-0.113;
    $statpot{'a19TR'}=-0.125;
    $statpot{'a19TN'}=-0.015;
    $statpot{'a19TD'}=-0.050;
    $statpot{'a19TC'}=0.053;
    $statpot{'a19TQ'}=-0.104;
    $statpot{'a19TE'}=-0.001;
    $statpot{'a19TG'}=-0.015;
    $statpot{'a19TH'}=-0.137;
    $statpot{'a19TI'}=-0.052;
    $statpot{'a19TL'}=-0.018;
    $statpot{'a19TK'}=-0.007;
    $statpot{'a19TM'}=-0.197;
    $statpot{'a19TF'}=-0.127;
    $statpot{'a19TP'}=-0.088;
    $statpot{'a19TS'}=-0.160;
    $statpot{'a19TT'}=-0.102;
    $statpot{'a19TW'}=0.024;
    $statpot{'a19TY'}=-0.113;
    $statpot{'a19TV'}=-0.134;
    $statpot{'a19WA'}=-0.036;
    $statpot{'a19WR'}=0.016;
    $statpot{'a19WN'}=-0.006;
    $statpot{'a19WD'}=0.046;
    $statpot{'a19WC'}=0.179;
    $statpot{'a19WQ'}=0.146;
    $statpot{'a19WE'}=0.006;
    $statpot{'a19WG'}=0.170;
    $statpot{'a19WH'}=0.217;
    $statpot{'a19WI'}=0.213;
    $statpot{'a19WL'}=0.163;
    $statpot{'a19WK'}=0.072;
    $statpot{'a19WM'}=-0.115;
    $statpot{'a19WF'}=0.266;
    $statpot{'a19WP'}=-0.104;
    $statpot{'a19WS'}=0.083;
    $statpot{'a19WT'}=-0.022;
    $statpot{'a19WW'}=-0.179;
    $statpot{'a19WY'}=0.164;
    $statpot{'a19WV'}=0.081;
    $statpot{'a19YA'}=0.032;
    $statpot{'a19YR'}=0.064;
    $statpot{'a19YN'}=-0.015;
    $statpot{'a19YD'}=0.101;
    $statpot{'a19YC'}=0.225;
    $statpot{'a19YQ'}=0.153;
    $statpot{'a19YE'}=-0.030;
    $statpot{'a19YG'}=0.155;
    $statpot{'a19YH'}=0.055;
    $statpot{'a19YI'}=0.017;
    $statpot{'a19YL'}=0.172;
    $statpot{'a19YK'}=0.068;
    $statpot{'a19YM'}=0.048;
    $statpot{'a19YF'}=0.246;
    $statpot{'a19YP'}=-0.028;
    $statpot{'a19YS'}=0.063;
    $statpot{'a19YT'}=0.028;
    $statpot{'a19YW'}=0.167;
    $statpot{'a19YY'}=0.143;
    $statpot{'a19YV'}=0.168;
    $statpot{'a19VA'}=0.031;
    $statpot{'a19VR'}=0.062;
    $statpot{'a19VN'}=0.023;
    $statpot{'a19VD'}=-0.009;
    $statpot{'a19VC'}=0.058;
    $statpot{'a19VQ'}=0.017;
    $statpot{'a19VE'}=-0.009;
    $statpot{'a19VG'}=0.047;
    $statpot{'a19VH'}=0.013;
    $statpot{'a19VI'}=0.109;
    $statpot{'a19VL'}=0.143;
    $statpot{'a19VK'}=-0.072;
    $statpot{'a19VM'}=0.008;
    $statpot{'a19VF'}=0.137;
    $statpot{'a19VP'}=-0.044;
    $statpot{'a19VS'}=0.005;
    $statpot{'a19VT'}=-0.080;
    $statpot{'a19VW'}=0.035;
    $statpot{'a19VY'}=0.124;
    $statpot{'a19VV'}=0.068;
    $statpot{'p20AA'}=-0.016;
    $statpot{'p20AR'}=-0.036;
    $statpot{'p20AN'}=-0.016;
    $statpot{'p20AD'}=-0.006;
    $statpot{'p20AC'}=-0.125;
    $statpot{'p20AQ'}=0.013;
    $statpot{'p20AE'}=0.106;
    $statpot{'p20AG'}=0.061;
    $statpot{'p20AH'}=-0.061;
    $statpot{'p20AI'}=-0.057;
    $statpot{'p20AL'}=-0.057;
    $statpot{'p20AK'}=0.099;
    $statpot{'p20AM'}=-0.183;
    $statpot{'p20AF'}=-0.081;
    $statpot{'p20AP'}=-0.007;
    $statpot{'p20AS'}=-0.011;
    $statpot{'p20AT'}=-0.059;
    $statpot{'p20AW'}=-0.050;
    $statpot{'p20AY'}=-0.103;
    $statpot{'p20AV'}=-0.030;
    $statpot{'p20RA'}=-0.036;
    $statpot{'p20RR'}=0.077;
    $statpot{'p20RN'}=0.014;
    $statpot{'p20RD'}=0.103;
    $statpot{'p20RC'}=-0.056;
    $statpot{'p20RQ'}=0.004;
    $statpot{'p20RE'}=0.116;
    $statpot{'p20RG'}=0.070;
    $statpot{'p20RH'}=-0.071;
    $statpot{'p20RI'}=-0.079;
    $statpot{'p20RL'}=-0.005;
    $statpot{'p20RK'}=0.093;
    $statpot{'p20RM'}=-0.100;
    $statpot{'p20RF'}=-0.045;
    $statpot{'p20RP'}=0.114;
    $statpot{'p20RS'}=0.038;
    $statpot{'p20RT'}=-0.016;
    $statpot{'p20RW'}=-0.044;
    $statpot{'p20RY'}=0.000;
    $statpot{'p20RV'}=0.002;
    $statpot{'p20NA'}=-0.016;
    $statpot{'p20NR'}=0.014;
    $statpot{'p20NN'}=0.074;
    $statpot{'p20ND'}=0.045;
    $statpot{'p20NC'}=-0.121;
    $statpot{'p20NQ'}=0.034;
    $statpot{'p20NE'}=0.100;
    $statpot{'p20NG'}=0.075;
    $statpot{'p20NH'}=-0.057;
    $statpot{'p20NI'}=-0.110;
    $statpot{'p20NL'}=-0.067;
    $statpot{'p20NK'}=0.060;
    $statpot{'p20NM'}=-0.051;
    $statpot{'p20NF'}=-0.062;
    $statpot{'p20NP'}=0.019;
    $statpot{'p20NS'}=-0.061;
    $statpot{'p20NT'}=-0.022;
    $statpot{'p20NW'}=0.005;
    $statpot{'p20NY'}=-0.141;
    $statpot{'p20NV'}=-0.118;
    $statpot{'p20DA'}=-0.006;
    $statpot{'p20DR'}=0.103;
    $statpot{'p20DN'}=0.045;
    $statpot{'p20DD'}=0.098;
    $statpot{'p20DC'}=0.091;
    $statpot{'p20DQ'}=0.054;
    $statpot{'p20DE'}=0.173;
    $statpot{'p20DG'}=0.140;
    $statpot{'p20DH'}=0.035;
    $statpot{'p20DI'}=0.026;
    $statpot{'p20DL'}=-0.019;
    $statpot{'p20DK'}=0.141;
    $statpot{'p20DM'}=-0.086;
    $statpot{'p20DF'}=-0.006;
    $statpot{'p20DP'}=0.057;
    $statpot{'p20DS'}=0.040;
    $statpot{'p20DT'}=0.031;
    $statpot{'p20DW'}=0.083;
    $statpot{'p20DY'}=-0.044;
    $statpot{'p20DV'}=-0.049;
    $statpot{'p20CA'}=-0.125;
    $statpot{'p20CR'}=-0.056;
    $statpot{'p20CN'}=-0.121;
    $statpot{'p20CD'}=0.091;
    $statpot{'p20CC'}=-0.157;
    $statpot{'p20CQ'}=-0.160;
    $statpot{'p20CE'}=-0.027;
    $statpot{'p20CG'}=-0.078;
    $statpot{'p20CH'}=-0.094;
    $statpot{'p20CI'}=-0.138;
    $statpot{'p20CL'}=-0.078;
    $statpot{'p20CK'}=0.011;
    $statpot{'p20CM'}=-0.328;
    $statpot{'p20CF'}=-0.067;
    $statpot{'p20CP'}=-0.146;
    $statpot{'p20CS'}=-0.012;
    $statpot{'p20CT'}=-0.079;
    $statpot{'p20CW'}=-0.035;
    $statpot{'p20CY'}=-0.045;
    $statpot{'p20CV'}=-0.141;
    $statpot{'p20QA'}=0.013;
    $statpot{'p20QR'}=0.004;
    $statpot{'p20QN'}=0.034;
    $statpot{'p20QD'}=0.054;
    $statpot{'p20QC'}=-0.160;
    $statpot{'p20QQ'}=0.091;
    $statpot{'p20QE'}=0.149;
    $statpot{'p20QG'}=0.064;
    $statpot{'p20QH'}=0.038;
    $statpot{'p20QI'}=-0.099;
    $statpot{'p20QL'}=-0.054;
    $statpot{'p20QK'}=0.149;
    $statpot{'p20QM'}=-0.052;
    $statpot{'p20QF'}=-0.083;
    $statpot{'p20QP'}=0.108;
    $statpot{'p20QS'}=-0.013;
    $statpot{'p20QT'}=-0.012;
    $statpot{'p20QW'}=-0.006;
    $statpot{'p20QY'}=0.043;
    $statpot{'p20QV'}=-0.047;
    $statpot{'p20EA'}=0.106;
    $statpot{'p20ER'}=0.116;
    $statpot{'p20EN'}=0.100;
    $statpot{'p20ED'}=0.173;
    $statpot{'p20EC'}=-0.027;
    $statpot{'p20EQ'}=0.149;
    $statpot{'p20EE'}=0.144;
    $statpot{'p20EG'}=0.157;
    $statpot{'p20EH'}=0.021;
    $statpot{'p20EI'}=0.031;
    $statpot{'p20EL'}=0.079;
    $statpot{'p20EK'}=0.228;
    $statpot{'p20EM'}=0.091;
    $statpot{'p20EF'}=0.112;
    $statpot{'p20EP'}=0.110;
    $statpot{'p20ES'}=0.105;
    $statpot{'p20ET'}=0.072;
    $statpot{'p20EW'}=0.068;
    $statpot{'p20EY'}=0.071;
    $statpot{'p20EV'}=0.046;
    $statpot{'p20GA'}=0.061;
    $statpot{'p20GR'}=0.070;
    $statpot{'p20GN'}=0.075;
    $statpot{'p20GD'}=0.140;
    $statpot{'p20GC'}=-0.078;
    $statpot{'p20GQ'}=0.064;
    $statpot{'p20GE'}=0.157;
    $statpot{'p20GG'}=0.128;
    $statpot{'p20GH'}=-0.053;
    $statpot{'p20GI'}=-0.019;
    $statpot{'p20GL'}=0.018;
    $statpot{'p20GK'}=0.164;
    $statpot{'p20GM'}=-0.050;
    $statpot{'p20GF'}=-0.031;
    $statpot{'p20GP'}=0.073;
    $statpot{'p20GS'}=0.027;
    $statpot{'p20GT'}=0.043;
    $statpot{'p20GW'}=0.059;
    $statpot{'p20GY'}=-0.054;
    $statpot{'p20GV'}=0.021;
    $statpot{'p20HA'}=-0.061;
    $statpot{'p20HR'}=-0.071;
    $statpot{'p20HN'}=-0.057;
    $statpot{'p20HD'}=0.035;
    $statpot{'p20HC'}=-0.094;
    $statpot{'p20HQ'}=0.038;
    $statpot{'p20HE'}=0.021;
    $statpot{'p20HG'}=-0.053;
    $statpot{'p20HH'}=-0.122;
    $statpot{'p20HI'}=-0.137;
    $statpot{'p20HL'}=-0.083;
    $statpot{'p20HK'}=0.069;
    $statpot{'p20HM'}=-0.000;
    $statpot{'p20HF'}=-0.051;
    $statpot{'p20HP'}=-0.017;
    $statpot{'p20HS'}=-0.048;
    $statpot{'p20HT'}=-0.030;
    $statpot{'p20HW'}=-0.174;
    $statpot{'p20HY'}=-0.028;
    $statpot{'p20HV'}=-0.115;
    $statpot{'p20IA'}=-0.057;
    $statpot{'p20IR'}=-0.079;
    $statpot{'p20IN'}=-0.110;
    $statpot{'p20ID'}=0.026;
    $statpot{'p20IC'}=-0.138;
    $statpot{'p20IQ'}=-0.099;
    $statpot{'p20IE'}=0.031;
    $statpot{'p20IG'}=-0.019;
    $statpot{'p20IH'}=-0.137;
    $statpot{'p20II'}=0.001;
    $statpot{'p20IL'}=-0.027;
    $statpot{'p20IK'}=0.047;
    $statpot{'p20IM'}=-0.104;
    $statpot{'p20IF'}=-0.050;
    $statpot{'p20IP'}=-0.047;
    $statpot{'p20IS'}=-0.083;
    $statpot{'p20IT'}=-0.116;
    $statpot{'p20IW'}=-0.071;
    $statpot{'p20IY'}=-0.054;
    $statpot{'p20IV'}=-0.068;
    $statpot{'p20LA'}=-0.057;
    $statpot{'p20LR'}=-0.005;
    $statpot{'p20LN'}=-0.067;
    $statpot{'p20LD'}=-0.019;
    $statpot{'p20LC'}=-0.078;
    $statpot{'p20LQ'}=-0.054;
    $statpot{'p20LE'}=0.079;
    $statpot{'p20LG'}=0.018;
    $statpot{'p20LH'}=-0.083;
    $statpot{'p20LI'}=-0.027;
    $statpot{'p20LL'}=0.038;
    $statpot{'p20LK'}=0.091;
    $statpot{'p20LM'}=-0.068;
    $statpot{'p20LF'}=-0.068;
    $statpot{'p20LP'}=-0.002;
    $statpot{'p20LS'}=-0.064;
    $statpot{'p20LT'}=-0.056;
    $statpot{'p20LW'}=-0.088;
    $statpot{'p20LY'}=-0.070;
    $statpot{'p20LV'}=-0.048;
    $statpot{'p20KA'}=0.099;
    $statpot{'p20KR'}=0.093;
    $statpot{'p20KN'}=0.060;
    $statpot{'p20KD'}=0.141;
    $statpot{'p20KC'}=0.011;
    $statpot{'p20KQ'}=0.149;
    $statpot{'p20KE'}=0.228;
    $statpot{'p20KG'}=0.164;
    $statpot{'p20KH'}=0.069;
    $statpot{'p20KI'}=0.047;
    $statpot{'p20KL'}=0.091;
    $statpot{'p20KK'}=0.211;
    $statpot{'p20KM'}=0.050;
    $statpot{'p20KF'}=0.033;
    $statpot{'p20KP'}=0.138;
    $statpot{'p20KS'}=0.049;
    $statpot{'p20KT'}=0.009;
    $statpot{'p20KW'}=0.190;
    $statpot{'p20KY'}=0.074;
    $statpot{'p20KV'}=0.012;
    $statpot{'p20MA'}=-0.183;
    $statpot{'p20MR'}=-0.100;
    $statpot{'p20MN'}=-0.051;
    $statpot{'p20MD'}=-0.086;
    $statpot{'p20MC'}=-0.328;
    $statpot{'p20MQ'}=-0.052;
    $statpot{'p20ME'}=0.091;
    $statpot{'p20MG'}=-0.050;
    $statpot{'p20MH'}=-0.000;
    $statpot{'p20MI'}=-0.104;
    $statpot{'p20ML'}=-0.068;
    $statpot{'p20MK'}=0.050;
    $statpot{'p20MM'}=-0.295;
    $statpot{'p20MF'}=-0.146;
    $statpot{'p20MP'}=-0.012;
    $statpot{'p20MS'}=-0.159;
    $statpot{'p20MT'}=-0.068;
    $statpot{'p20MW'}=-0.170;
    $statpot{'p20MY'}=-0.128;
    $statpot{'p20MV'}=-0.131;
    $statpot{'p20FA'}=-0.081;
    $statpot{'p20FR'}=-0.045;
    $statpot{'p20FN'}=-0.062;
    $statpot{'p20FD'}=-0.006;
    $statpot{'p20FC'}=-0.067;
    $statpot{'p20FQ'}=-0.083;
    $statpot{'p20FE'}=0.112;
    $statpot{'p20FG'}=-0.031;
    $statpot{'p20FH'}=-0.051;
    $statpot{'p20FI'}=-0.050;
    $statpot{'p20FL'}=-0.068;
    $statpot{'p20FK'}=0.033;
    $statpot{'p20FM'}=-0.146;
    $statpot{'p20FF'}=-0.158;
    $statpot{'p20FP'}=0.055;
    $statpot{'p20FS'}=-0.087;
    $statpot{'p20FT'}=-0.060;
    $statpot{'p20FW'}=-0.108;
    $statpot{'p20FY'}=-0.101;
    $statpot{'p20FV'}=-0.060;
    $statpot{'p20PA'}=-0.007;
    $statpot{'p20PR'}=0.114;
    $statpot{'p20PN'}=0.019;
    $statpot{'p20PD'}=0.057;
    $statpot{'p20PC'}=-0.146;
    $statpot{'p20PQ'}=0.108;
    $statpot{'p20PE'}=0.110;
    $statpot{'p20PG'}=0.073;
    $statpot{'p20PH'}=-0.017;
    $statpot{'p20PI'}=-0.047;
    $statpot{'p20PL'}=-0.002;
    $statpot{'p20PK'}=0.138;
    $statpot{'p20PM'}=-0.012;
    $statpot{'p20PF'}=0.055;
    $statpot{'p20PP'}=0.097;
    $statpot{'p20PS'}=0.013;
    $statpot{'p20PT'}=-0.021;
    $statpot{'p20PW'}=0.106;
    $statpot{'p20PY'}=0.040;
    $statpot{'p20PV'}=-0.045;
    $statpot{'p20SA'}=-0.011;
    $statpot{'p20SR'}=0.038;
    $statpot{'p20SN'}=-0.061;
    $statpot{'p20SD'}=0.040;
    $statpot{'p20SC'}=-0.012;
    $statpot{'p20SQ'}=-0.013;
    $statpot{'p20SE'}=0.105;
    $statpot{'p20SG'}=0.027;
    $statpot{'p20SH'}=-0.048;
    $statpot{'p20SI'}=-0.083;
    $statpot{'p20SL'}=-0.064;
    $statpot{'p20SK'}=0.049;
    $statpot{'p20SM'}=-0.159;
    $statpot{'p20SF'}=-0.087;
    $statpot{'p20SP'}=0.013;
    $statpot{'p20SS'}=-0.007;
    $statpot{'p20ST'}=-0.043;
    $statpot{'p20SW'}=-0.062;
    $statpot{'p20SY'}=-0.081;
    $statpot{'p20SV'}=-0.120;
    $statpot{'p20TA'}=-0.059;
    $statpot{'p20TR'}=-0.016;
    $statpot{'p20TN'}=-0.022;
    $statpot{'p20TD'}=0.031;
    $statpot{'p20TC'}=-0.079;
    $statpot{'p20TQ'}=-0.012;
    $statpot{'p20TE'}=0.072;
    $statpot{'p20TG'}=0.043;
    $statpot{'p20TH'}=-0.030;
    $statpot{'p20TI'}=-0.116;
    $statpot{'p20TL'}=-0.056;
    $statpot{'p20TK'}=0.009;
    $statpot{'p20TM'}=-0.068;
    $statpot{'p20TF'}=-0.060;
    $statpot{'p20TP'}=-0.021;
    $statpot{'p20TS'}=-0.043;
    $statpot{'p20TT'}=-0.105;
    $statpot{'p20TW'}=-0.120;
    $statpot{'p20TY'}=-0.117;
    $statpot{'p20TV'}=-0.064;
    $statpot{'p20WA'}=-0.050;
    $statpot{'p20WR'}=-0.044;
    $statpot{'p20WN'}=0.005;
    $statpot{'p20WD'}=0.083;
    $statpot{'p20WC'}=-0.035;
    $statpot{'p20WQ'}=-0.006;
    $statpot{'p20WE'}=0.068;
    $statpot{'p20WG'}=0.059;
    $statpot{'p20WH'}=-0.174;
    $statpot{'p20WI'}=-0.071;
    $statpot{'p20WL'}=-0.088;
    $statpot{'p20WK'}=0.190;
    $statpot{'p20WM'}=-0.170;
    $statpot{'p20WF'}=-0.108;
    $statpot{'p20WP'}=0.106;
    $statpot{'p20WS'}=-0.062;
    $statpot{'p20WT'}=-0.120;
    $statpot{'p20WW'}=-0.253;
    $statpot{'p20WY'}=-0.183;
    $statpot{'p20WV'}=-0.167;
    $statpot{'p20YA'}=-0.103;
    $statpot{'p20YR'}=0.000;
    $statpot{'p20YN'}=-0.141;
    $statpot{'p20YD'}=-0.044;
    $statpot{'p20YC'}=-0.045;
    $statpot{'p20YQ'}=0.043;
    $statpot{'p20YE'}=0.071;
    $statpot{'p20YG'}=-0.054;
    $statpot{'p20YH'}=-0.028;
    $statpot{'p20YI'}=-0.054;
    $statpot{'p20YL'}=-0.070;
    $statpot{'p20YK'}=0.074;
    $statpot{'p20YM'}=-0.128;
    $statpot{'p20YF'}=-0.101;
    $statpot{'p20YP'}=0.040;
    $statpot{'p20YS'}=-0.081;
    $statpot{'p20YT'}=-0.117;
    $statpot{'p20YW'}=-0.183;
    $statpot{'p20YY'}=-0.158;
    $statpot{'p20YV'}=-0.077;
    $statpot{'p20VA'}=-0.030;
    $statpot{'p20VR'}=0.002;
    $statpot{'p20VN'}=-0.118;
    $statpot{'p20VD'}=-0.049;
    $statpot{'p20VC'}=-0.141;
    $statpot{'p20VQ'}=-0.047;
    $statpot{'p20VE'}=0.046;
    $statpot{'p20VG'}=0.021;
    $statpot{'p20VH'}=-0.115;
    $statpot{'p20VI'}=-0.068;
    $statpot{'p20VL'}=-0.048;
    $statpot{'p20VK'}=0.012;
    $statpot{'p20VM'}=-0.131;
    $statpot{'p20VF'}=-0.060;
    $statpot{'p20VP'}=-0.045;
    $statpot{'p20VS'}=-0.120;
    $statpot{'p20VT'}=-0.064;
    $statpot{'p20VW'}=-0.167;
    $statpot{'p20VY'}=-0.077;
    $statpot{'p20VV'}=-0.065;
    $statpot{'f20AA'}=-0.067;
    $statpot{'f20AR'}=-0.001;
    $statpot{'f20AN'}=0.010;
    $statpot{'f20AD'}=0.137;
    $statpot{'f20AC'}=-0.212;
    $statpot{'f20AQ'}=-0.012;
    $statpot{'f20AE'}=0.131;
    $statpot{'f20AG'}=0.042;
    $statpot{'f20AH'}=-0.131;
    $statpot{'f20AI'}=-0.154;
    $statpot{'f20AL'}=-0.160;
    $statpot{'f20AK'}=0.112;
    $statpot{'f20AM'}=-0.238;
    $statpot{'f20AF'}=-0.227;
    $statpot{'f20AP'}=-0.015;
    $statpot{'f20AS'}=-0.049;
    $statpot{'f20AT'}=-0.060;
    $statpot{'f20AW'}=-0.126;
    $statpot{'f20AY'}=-0.173;
    $statpot{'f20AV'}=-0.137;
    $statpot{'f20RA'}=0.061;
    $statpot{'f20RR'}=0.172;
    $statpot{'f20RN'}=0.206;
    $statpot{'f20RD'}=0.222;
    $statpot{'f20RC'}=-0.113;
    $statpot{'f20RQ'}=0.097;
    $statpot{'f20RE'}=0.296;
    $statpot{'f20RG'}=0.253;
    $statpot{'f20RH'}=0.072;
    $statpot{'f20RI'}=-0.127;
    $statpot{'f20RL'}=0.008;
    $statpot{'f20RK'}=0.307;
    $statpot{'f20RM'}=-0.084;
    $statpot{'f20RF'}=-0.152;
    $statpot{'f20RP'}=0.301;
    $statpot{'f20RS'}=0.064;
    $statpot{'f20RT'}=0.133;
    $statpot{'f20RW'}=-0.080;
    $statpot{'f20RY'}=-0.092;
    $statpot{'f20RV'}=-0.019;
    $statpot{'f20NA'}=0.090;
    $statpot{'f20NR'}=0.172;
    $statpot{'f20NN'}=0.321;
    $statpot{'f20ND'}=0.345;
    $statpot{'f20NC'}=0.034;
    $statpot{'f20NQ'}=0.222;
    $statpot{'f20NE'}=0.250;
    $statpot{'f20NG'}=0.228;
    $statpot{'f20NH'}=0.196;
    $statpot{'f20NI'}=-0.001;
    $statpot{'f20NL'}=-0.066;
    $statpot{'f20NK'}=0.470;
    $statpot{'f20NM'}=0.011;
    $statpot{'f20NF'}=0.011;
    $statpot{'f20NP'}=0.350;
    $statpot{'f20NS'}=0.269;
    $statpot{'f20NT'}=0.254;
    $statpot{'f20NW'}=-0.131;
    $statpot{'f20NY'}=0.007;
    $statpot{'f20NV'}=-0.004;
    $statpot{'f20DA'}=0.254;
    $statpot{'f20DR'}=0.249;
    $statpot{'f20DN'}=0.411;
    $statpot{'f20DD'}=0.547;
    $statpot{'f20DC'}=0.072;
    $statpot{'f20DQ'}=0.363;
    $statpot{'f20DE'}=0.510;
    $statpot{'f20DG'}=0.426;
    $statpot{'f20DH'}=0.264;
    $statpot{'f20DI'}=0.173;
    $statpot{'f20DL'}=0.124;
    $statpot{'f20DK'}=0.546;
    $statpot{'f20DM'}=0.092;
    $statpot{'f20DF'}=0.070;
    $statpot{'f20DP'}=0.360;
    $statpot{'f20DS'}=0.434;
    $statpot{'f20DT'}=0.203;
    $statpot{'f20DW'}=0.073;
    $statpot{'f20DY'}=0.066;
    $statpot{'f20DV'}=0.127;
    $statpot{'f20CA'}=-0.323;
    $statpot{'f20CR'}=-0.297;
    $statpot{'f20CN'}=-0.255;
    $statpot{'f20CD'}=-0.198;
    $statpot{'f20CC'}=-0.446;
    $statpot{'f20CQ'}=-0.143;
    $statpot{'f20CE'}=-0.061;
    $statpot{'f20CG'}=-0.239;
    $statpot{'f20CH'}=-0.176;
    $statpot{'f20CI'}=-0.275;
    $statpot{'f20CL'}=-0.280;
    $statpot{'f20CK'}=-0.018;
    $statpot{'f20CM'}=-0.484;
    $statpot{'f20CF'}=-0.444;
    $statpot{'f20CP'}=-0.222;
    $statpot{'f20CS'}=-0.284;
    $statpot{'f20CT'}=-0.250;
    $statpot{'f20CW'}=-0.360;
    $statpot{'f20CY'}=-0.430;
    $statpot{'f20CV'}=-0.485;
    $statpot{'f20QA'}=0.097;
    $statpot{'f20QR'}=0.118;
    $statpot{'f20QN'}=0.173;
    $statpot{'f20QD'}=0.410;
    $statpot{'f20QC'}=0.019;
    $statpot{'f20QQ'}=0.466;
    $statpot{'f20QE'}=0.417;
    $statpot{'f20QG'}=0.247;
    $statpot{'f20QH'}=0.031;
    $statpot{'f20QI'}=0.012;
    $statpot{'f20QL'}=-0.038;
    $statpot{'f20QK'}=0.445;
    $statpot{'f20QM'}=0.136;
    $statpot{'f20QF'}=-0.113;
    $statpot{'f20QP'}=0.254;
    $statpot{'f20QS'}=0.168;
    $statpot{'f20QT'}=0.160;
    $statpot{'f20QW'}=-0.004;
    $statpot{'f20QY'}=0.015;
    $statpot{'f20QV'}=0.051;
    $statpot{'f20EA'}=0.266;
    $statpot{'f20ER'}=0.417;
    $statpot{'f20EN'}=0.302;
    $statpot{'f20ED'}=0.536;
    $statpot{'f20EC'}=0.193;
    $statpot{'f20EQ'}=0.520;
    $statpot{'f20EE'}=0.555;
    $statpot{'f20EG'}=0.480;
    $statpot{'f20EH'}=0.335;
    $statpot{'f20EI'}=0.213;
    $statpot{'f20EL'}=0.181;
    $statpot{'f20EK'}=0.526;
    $statpot{'f20EM'}=0.167;
    $statpot{'f20EF'}=0.201;
    $statpot{'f20EP'}=0.381;
    $statpot{'f20ES'}=0.385;
    $statpot{'f20ET'}=0.359;
    $statpot{'f20EW'}=0.323;
    $statpot{'f20EY'}=0.308;
    $statpot{'f20EV'}=0.228;
    $statpot{'f20GA'}=0.093;
    $statpot{'f20GR'}=0.233;
    $statpot{'f20GN'}=0.250;
    $statpot{'f20GD'}=0.343;
    $statpot{'f20GC'}=-0.098;
    $statpot{'f20GQ'}=0.216;
    $statpot{'f20GE'}=0.351;
    $statpot{'f20GG'}=0.253;
    $statpot{'f20GH'}=0.172;
    $statpot{'f20GI'}=0.021;
    $statpot{'f20GL'}=0.012;
    $statpot{'f20GK'}=0.335;
    $statpot{'f20GM'}=-0.102;
    $statpot{'f20GF'}=-0.022;
    $statpot{'f20GP'}=0.195;
    $statpot{'f20GS'}=0.138;
    $statpot{'f20GT'}=0.100;
    $statpot{'f20GW'}=-0.060;
    $statpot{'f20GY'}=-0.030;
    $statpot{'f20GV'}=0.012;
    $statpot{'f20HA'}=-0.075;
    $statpot{'f20HR'}=0.003;
    $statpot{'f20HN'}=0.097;
    $statpot{'f20HD'}=0.175;
    $statpot{'f20HC'}=-0.087;
    $statpot{'f20HQ'}=-0.025;
    $statpot{'f20HE'}=0.200;
    $statpot{'f20HG'}=0.085;
    $statpot{'f20HH'}=-0.092;
    $statpot{'f20HI'}=-0.204;
    $statpot{'f20HL'}=-0.215;
    $statpot{'f20HK'}=0.124;
    $statpot{'f20HM'}=-0.372;
    $statpot{'f20HF'}=-0.146;
    $statpot{'f20HP'}=0.139;
    $statpot{'f20HS'}=-0.039;
    $statpot{'f20HT'}=-0.073;
    $statpot{'f20HW'}=-0.269;
    $statpot{'f20HY'}=-0.343;
    $statpot{'f20HV'}=-0.184;
    $statpot{'f20IA'}=-0.215;
    $statpot{'f20IR'}=-0.188;
    $statpot{'f20IN'}=-0.157;
    $statpot{'f20ID'}=-0.084;
    $statpot{'f20IC'}=-0.322;
    $statpot{'f20IQ'}=-0.162;
    $statpot{'f20IE'}=0.003;
    $statpot{'f20IG'}=-0.128;
    $statpot{'f20IH'}=-0.248;
    $statpot{'f20II'}=-0.277;
    $statpot{'f20IL'}=-0.257;
    $statpot{'f20IK'}=-0.032;
    $statpot{'f20IM'}=-0.352;
    $statpot{'f20IF'}=-0.322;
    $statpot{'f20IP'}=-0.174;
    $statpot{'f20IS'}=-0.187;
    $statpot{'f20IT'}=-0.214;
    $statpot{'f20IW'}=-0.385;
    $statpot{'f20IY'}=-0.303;
    $statpot{'f20IV'}=-0.206;
    $statpot{'f20LA'}=-0.210;
    $statpot{'f20LR'}=-0.140;
    $statpot{'f20LN'}=-0.203;
    $statpot{'f20LD'}=-0.141;
    $statpot{'f20LC'}=-0.291;
    $statpot{'f20LQ'}=-0.123;
    $statpot{'f20LE'}=0.045;
    $statpot{'f20LG'}=-0.137;
    $statpot{'f20LH'}=-0.299;
    $statpot{'f20LI'}=-0.261;
    $statpot{'f20LL'}=-0.267;
    $statpot{'f20LK'}=-0.017;
    $statpot{'f20LM'}=-0.280;
    $statpot{'f20LF'}=-0.361;
    $statpot{'f20LP'}=-0.110;
    $statpot{'f20LS'}=-0.264;
    $statpot{'f20LT'}=-0.217;
    $statpot{'f20LW'}=-0.359;
    $statpot{'f20LY'}=-0.336;
    $statpot{'f20LV'}=-0.213;
    $statpot{'f20KA'}=0.257;
    $statpot{'f20KR'}=0.512;
    $statpot{'f20KN'}=0.556;
    $statpot{'f20KD'}=0.488;
    $statpot{'f20KC'}=0.092;
    $statpot{'f20KQ'}=0.465;
    $statpot{'f20KE'}=0.550;
    $statpot{'f20KG'}=0.458;
    $statpot{'f20KH'}=0.279;
    $statpot{'f20KI'}=0.245;
    $statpot{'f20KL'}=0.243;
    $statpot{'f20KK'}=0.637;
    $statpot{'f20KM'}=0.309;
    $statpot{'f20KF'}=0.138;
    $statpot{'f20KP'}=0.546;
    $statpot{'f20KS'}=0.384;
    $statpot{'f20KT'}=0.303;
    $statpot{'f20KW'}=0.192;
    $statpot{'f20KY'}=0.128;
    $statpot{'f20KV'}=0.237;
    $statpot{'f20MA'}=-0.328;
    $statpot{'f20MR'}=-0.173;
    $statpot{'f20MN'}=-0.102;
    $statpot{'f20MD'}=-0.092;
    $statpot{'f20MC'}=-0.408;
    $statpot{'f20MQ'}=0.045;
    $statpot{'f20ME'}=-0.070;
    $statpot{'f20MG'}=-0.228;
    $statpot{'f20MH'}=-0.380;
    $statpot{'f20MI'}=-0.337;
    $statpot{'f20ML'}=-0.274;
    $statpot{'f20MK'}=0.038;
    $statpot{'f20MM'}=-0.286;
    $statpot{'f20MF'}=-0.440;
    $statpot{'f20MP'}=-0.229;
    $statpot{'f20MS'}=-0.215;
    $statpot{'f20MT'}=-0.340;
    $statpot{'f20MW'}=-0.197;
    $statpot{'f20MY'}=-0.379;
    $statpot{'f20MV'}=-0.274;
    $statpot{'f20FA'}=-0.243;
    $statpot{'f20FR'}=-0.225;
    $statpot{'f20FN'}=-0.238;
    $statpot{'f20FD'}=-0.076;
    $statpot{'f20FC'}=-0.453;
    $statpot{'f20FQ'}=-0.265;
    $statpot{'f20FE'}=0.039;
    $statpot{'f20FG'}=-0.200;
    $statpot{'f20FH'}=-0.270;
    $statpot{'f20FI'}=-0.331;
    $statpot{'f20FL'}=-0.371;
    $statpot{'f20FK'}=-0.059;
    $statpot{'f20FM'}=-0.534;
    $statpot{'f20FF'}=-0.444;
    $statpot{'f20FP'}=-0.257;
    $statpot{'f20FS'}=-0.296;
    $statpot{'f20FT'}=-0.209;
    $statpot{'f20FW'}=-0.349;
    $statpot{'f20FY'}=-0.512;
    $statpot{'f20FV'}=-0.310;
    $statpot{'f20PA'}=0.076;
    $statpot{'f20PR'}=0.334;
    $statpot{'f20PN'}=0.447;
    $statpot{'f20PD'}=0.326;
    $statpot{'f20PC'}=-0.030;
    $statpot{'f20PQ'}=0.326;
    $statpot{'f20PE'}=0.381;
    $statpot{'f20PG'}=0.283;
    $statpot{'f20PH'}=0.217;
    $statpot{'f20PI'}=0.078;
    $statpot{'f20PL'}=0.119;
    $statpot{'f20PK'}=0.425;
    $statpot{'f20PM'}=-0.096;
    $statpot{'f20PF'}=-0.002;
    $statpot{'f20PP'}=0.379;
    $statpot{'f20PS'}=0.170;
    $statpot{'f20PT'}=0.174;
    $statpot{'f20PW'}=0.149;
    $statpot{'f20PY'}=0.121;
    $statpot{'f20PV'}=0.061;
    $statpot{'f20SA'}=0.077;
    $statpot{'f20SR'}=0.079;
    $statpot{'f20SN'}=0.225;
    $statpot{'f20SD'}=0.343;
    $statpot{'f20SC'}=-0.079;
    $statpot{'f20SQ'}=0.221;
    $statpot{'f20SE'}=0.250;
    $statpot{'f20SG'}=0.140;
    $statpot{'f20SH'}=0.012;
    $statpot{'f20SI'}=-0.086;
    $statpot{'f20SL'}=-0.089;
    $statpot{'f20SK'}=0.317;
    $statpot{'f20SM'}=-0.008;
    $statpot{'f20SF'}=-0.107;
    $statpot{'f20SP'}=0.108;
    $statpot{'f20SS'}=0.130;
    $statpot{'f20ST'}=0.065;
    $statpot{'f20SW'}=-0.046;
    $statpot{'f20SY'}=-0.078;
    $statpot{'f20SV'}=-0.070;
    $statpot{'f20TA'}=0.017;
    $statpot{'f20TR'}=0.117;
    $statpot{'f20TN'}=0.185;
    $statpot{'f20TD'}=0.158;
    $statpot{'f20TC'}=-0.069;
    $statpot{'f20TQ'}=0.144;
    $statpot{'f20TE'}=0.263;
    $statpot{'f20TG'}=0.048;
    $statpot{'f20TH'}=-0.078;
    $statpot{'f20TI'}=-0.021;
    $statpot{'f20TL'}=-0.053;
    $statpot{'f20TK'}=0.223;
    $statpot{'f20TM'}=-0.185;
    $statpot{'f20TF'}=-0.067;
    $statpot{'f20TP'}=0.122;
    $statpot{'f20TS'}=0.047;
    $statpot{'f20TT'}=0.103;
    $statpot{'f20TW'}=-0.052;
    $statpot{'f20TY'}=-0.103;
    $statpot{'f20TV'}=-0.017;
    $statpot{'f20WA'}=-0.206;
    $statpot{'f20WR'}=-0.144;
    $statpot{'f20WN'}=-0.171;
    $statpot{'f20WD'}=-0.129;
    $statpot{'f20WC'}=-0.533;
    $statpot{'f20WQ'}=-0.056;
    $statpot{'f20WE'}=0.094;
    $statpot{'f20WG'}=-0.105;
    $statpot{'f20WH'}=-0.253;
    $statpot{'f20WI'}=-0.289;
    $statpot{'f20WL'}=-0.338;
    $statpot{'f20WK'}=-0.042;
    $statpot{'f20WM'}=-0.249;
    $statpot{'f20WF'}=-0.388;
    $statpot{'f20WP'}=-0.076;
    $statpot{'f20WS'}=-0.161;
    $statpot{'f20WT'}=-0.110;
    $statpot{'f20WW'}=-0.376;
    $statpot{'f20WY'}=-0.508;
    $statpot{'f20WV'}=-0.339;
    $statpot{'f20YA'}=-0.243;
    $statpot{'f20YR'}=-0.156;
    $statpot{'f20YN'}=-0.133;
    $statpot{'f20YD'}=-0.067;
    $statpot{'f20YC'}=-0.503;
    $statpot{'f20YQ'}=-0.136;
    $statpot{'f20YE'}=0.102;
    $statpot{'f20YG'}=-0.116;
    $statpot{'f20YH'}=-0.371;
    $statpot{'f20YI'}=-0.251;
    $statpot{'f20YL'}=-0.299;
    $statpot{'f20YK'}=-0.051;
    $statpot{'f20YM'}=-0.382;
    $statpot{'f20YF'}=-0.451;
    $statpot{'f20YP'}=-0.101;
    $statpot{'f20YS'}=-0.178;
    $statpot{'f20YT'}=-0.209;
    $statpot{'f20YW'}=-0.493;
    $statpot{'f20YY'}=-0.264;
    $statpot{'f20YV'}=-0.284;
    $statpot{'f20VA'}=-0.162;
    $statpot{'f20VR'}=-0.167;
    $statpot{'f20VN'}=-0.139;
    $statpot{'f20VD'}=-0.098;
    $statpot{'f20VC'}=-0.415;
    $statpot{'f20VQ'}=-0.063;
    $statpot{'f20VE'}=0.063;
    $statpot{'f20VG'}=-0.078;
    $statpot{'f20VH'}=-0.277;
    $statpot{'f20VI'}=-0.220;
    $statpot{'f20VL'}=-0.196;
    $statpot{'f20VK'}=0.025;
    $statpot{'f20VM'}=-0.257;
    $statpot{'f20VF'}=-0.323;
    $statpot{'f20VP'}=-0.064;
    $statpot{'f20VS'}=-0.181;
    $statpot{'f20VT'}=-0.083;
    $statpot{'f20VW'}=-0.351;
    $statpot{'f20VY'}=-0.275;
    $statpot{'f20VV'}=-0.238;
    $statpot{'a20AA'}=0.008;
    $statpot{'a20AR'}=-0.006;
    $statpot{'a20AN'}=-0.110;
    $statpot{'a20AD'}=0.004;
    $statpot{'a20AC'}=-0.018;
    $statpot{'a20AQ'}=0.038;
    $statpot{'a20AE'}=0.023;
    $statpot{'a20AG'}=0.016;
    $statpot{'a20AH'}=-0.041;
    $statpot{'a20AI'}=-0.033;
    $statpot{'a20AL'}=0.103;
    $statpot{'a20AK'}=-0.004;
    $statpot{'a20AM'}=-0.014;
    $statpot{'a20AF'}=0.119;
    $statpot{'a20AP'}=-0.049;
    $statpot{'a20AS'}=0.008;
    $statpot{'a20AT'}=-0.011;
    $statpot{'a20AW'}=0.083;
    $statpot{'a20AY'}=0.052;
    $statpot{'a20AV'}=-0.002;
    $statpot{'a20RA'}=-0.063;
    $statpot{'a20RR'}=-0.083;
    $statpot{'a20RN'}=-0.127;
    $statpot{'a20RD'}=-0.080;
    $statpot{'a20RC'}=-0.163;
    $statpot{'a20RQ'}=0.002;
    $statpot{'a20RE'}=0.020;
    $statpot{'a20RG'}=0.014;
    $statpot{'a20RH'}=-0.086;
    $statpot{'a20RI'}=-0.060;
    $statpot{'a20RL'}=-0.059;
    $statpot{'a20RK'}=-0.045;
    $statpot{'a20RM'}=-0.176;
    $statpot{'a20RF'}=0.011;
    $statpot{'a20RP'}=-0.037;
    $statpot{'a20RS'}=-0.215;
    $statpot{'a20RT'}=-0.106;
    $statpot{'a20RW'}=-0.097;
    $statpot{'a20RY'}=-0.032;
    $statpot{'a20RV'}=-0.160;
    $statpot{'a20NA'}=-0.172;
    $statpot{'a20NR'}=-0.105;
    $statpot{'a20NN'}=-0.043;
    $statpot{'a20ND'}=-0.003;
    $statpot{'a20NC'}=-0.197;
    $statpot{'a20NQ'}=-0.102;
    $statpot{'a20NE'}=-0.072;
    $statpot{'a20NG'}=-0.007;
    $statpot{'a20NH'}=-0.123;
    $statpot{'a20NI'}=-0.163;
    $statpot{'a20NL'}=-0.075;
    $statpot{'a20NK'}=0.006;
    $statpot{'a20NM'}=-0.081;
    $statpot{'a20NF'}=-0.100;
    $statpot{'a20NP'}=0.019;
    $statpot{'a20NS'}=-0.072;
    $statpot{'a20NT'}=-0.077;
    $statpot{'a20NW'}=-0.080;
    $statpot{'a20NY'}=-0.103;
    $statpot{'a20NV'}=-0.157;
    $statpot{'a20DA'}=-0.086;
    $statpot{'a20DR'}=-0.099;
    $statpot{'a20DN'}=-0.044;
    $statpot{'a20DD'}=-0.039;
    $statpot{'a20DC'}=-0.121;
    $statpot{'a20DQ'}=0.001;
    $statpot{'a20DE'}=0.007;
    $statpot{'a20DG'}=-0.026;
    $statpot{'a20DH'}=-0.079;
    $statpot{'a20DI'}=-0.167;
    $statpot{'a20DL'}=-0.109;
    $statpot{'a20DK'}=-0.004;
    $statpot{'a20DM'}=-0.086;
    $statpot{'a20DF'}=-0.164;
    $statpot{'a20DP'}=0.025;
    $statpot{'a20DS'}=-0.146;
    $statpot{'a20DT'}=-0.124;
    $statpot{'a20DW'}=-0.188;
    $statpot{'a20DY'}=-0.067;
    $statpot{'a20DV'}=-0.199;
    $statpot{'a20CA'}=0.125;
    $statpot{'a20CR'}=0.026;
    $statpot{'a20CN'}=0.069;
    $statpot{'a20CD'}=0.139;
    $statpot{'a20CC'}=0.580;
    $statpot{'a20CQ'}=-0.050;
    $statpot{'a20CE'}=0.087;
    $statpot{'a20CG'}=0.063;
    $statpot{'a20CH'}=0.177;
    $statpot{'a20CI'}=0.127;
    $statpot{'a20CL'}=0.226;
    $statpot{'a20CK'}=-0.109;
    $statpot{'a20CM'}=0.065;
    $statpot{'a20CF'}=0.219;
    $statpot{'a20CP'}=0.010;
    $statpot{'a20CS'}=0.082;
    $statpot{'a20CT'}=0.069;
    $statpot{'a20CW'}=0.066;
    $statpot{'a20CY'}=0.184;
    $statpot{'a20CV'}=0.264;
    $statpot{'a20QA'}=-0.062;
    $statpot{'a20QR'}=-0.015;
    $statpot{'a20QN'}=-0.069;
    $statpot{'a20QD'}=-0.029;
    $statpot{'a20QC'}=-0.187;
    $statpot{'a20QQ'}=0.084;
    $statpot{'a20QE'}=-0.002;
    $statpot{'a20QG'}=-0.040;
    $statpot{'a20QH'}=-0.140;
    $statpot{'a20QI'}=-0.069;
    $statpot{'a20QL'}=0.040;
    $statpot{'a20QK'}=-0.022;
    $statpot{'a20QM'}=-0.012;
    $statpot{'a20QF'}=-0.115;
    $statpot{'a20QP'}=-0.036;
    $statpot{'a20QS'}=-0.030;
    $statpot{'a20QT'}=-0.041;
    $statpot{'a20QW'}=-0.019;
    $statpot{'a20QY'}=-0.051;
    $statpot{'a20QV'}=-0.111;
    $statpot{'a20EA'}=-0.084;
    $statpot{'a20ER'}=-0.060;
    $statpot{'a20EN'}=-0.106;
    $statpot{'a20ED'}=-0.009;
    $statpot{'a20EC'}=-0.129;
    $statpot{'a20EQ'}=-0.061;
    $statpot{'a20EE'}=0.054;
    $statpot{'a20EG'}=-0.040;
    $statpot{'a20EH'}=-0.189;
    $statpot{'a20EI'}=-0.075;
    $statpot{'a20EL'}=-0.046;
    $statpot{'a20EK'}=0.082;
    $statpot{'a20EM'}=-0.174;
    $statpot{'a20EF'}=-0.056;
    $statpot{'a20EP'}=-0.033;
    $statpot{'a20ES'}=-0.114;
    $statpot{'a20ET'}=-0.183;
    $statpot{'a20EW'}=-0.026;
    $statpot{'a20EY'}=-0.027;
    $statpot{'a20EV'}=-0.114;
    $statpot{'a20GA'}=-0.031;
    $statpot{'a20GR'}=0.030;
    $statpot{'a20GN'}=-0.022;
    $statpot{'a20GD'}=0.027;
    $statpot{'a20GC'}=-0.086;
    $statpot{'a20GQ'}=-0.017;
    $statpot{'a20GE'}=0.044;
    $statpot{'a20GG'}=0.112;
    $statpot{'a20GH'}=-0.069;
    $statpot{'a20GI'}=0.005;
    $statpot{'a20GL'}=-0.013;
    $statpot{'a20GK'}=0.083;
    $statpot{'a20GM'}=-0.122;
    $statpot{'a20GF'}=0.011;
    $statpot{'a20GP'}=-0.036;
    $statpot{'a20GS'}=-0.062;
    $statpot{'a20GT'}=-0.083;
    $statpot{'a20GW'}=0.036;
    $statpot{'a20GY'}=0.035;
    $statpot{'a20GV'}=-0.087;
    $statpot{'a20HA'}=-0.097;
    $statpot{'a20HR'}=-0.026;
    $statpot{'a20HN'}=-0.052;
    $statpot{'a20HD'}=-0.014;
    $statpot{'a20HC'}=0.073;
    $statpot{'a20HQ'}=-0.094;
    $statpot{'a20HE'}=-0.105;
    $statpot{'a20HG'}=0.000;
    $statpot{'a20HH'}=0.055;
    $statpot{'a20HI'}=0.014;
    $statpot{'a20HL'}=0.021;
    $statpot{'a20HK'}=-0.086;
    $statpot{'a20HM'}=-0.059;
    $statpot{'a20HF'}=0.092;
    $statpot{'a20HP'}=-0.123;
    $statpot{'a20HS'}=-0.158;
    $statpot{'a20HT'}=-0.138;
    $statpot{'a20HW'}=0.012;
    $statpot{'a20HY'}=-0.035;
    $statpot{'a20HV'}=-0.126;
    $statpot{'a20IA'}=0.040;
    $statpot{'a20IR'}=0.007;
    $statpot{'a20IN'}=-0.021;
    $statpot{'a20ID'}=0.052;
    $statpot{'a20IC'}=0.196;
    $statpot{'a20IQ'}=0.113;
    $statpot{'a20IE'}=0.110;
    $statpot{'a20IG'}=0.169;
    $statpot{'a20IH'}=0.069;
    $statpot{'a20II'}=0.186;
    $statpot{'a20IL'}=0.221;
    $statpot{'a20IK'}=-0.006;
    $statpot{'a20IM'}=0.184;
    $statpot{'a20IF'}=0.217;
    $statpot{'a20IP'}=0.007;
    $statpot{'a20IS'}=0.032;
    $statpot{'a20IT'}=0.161;
    $statpot{'a20IW'}=0.133;
    $statpot{'a20IY'}=0.121;
    $statpot{'a20IV'}=0.123;
    $statpot{'a20LA'}=0.171;
    $statpot{'a20LR'}=0.097;
    $statpot{'a20LN'}=0.070;
    $statpot{'a20LD'}=0.151;
    $statpot{'a20LC'}=0.245;
    $statpot{'a20LQ'}=0.135;
    $statpot{'a20LE'}=0.072;
    $statpot{'a20LG'}=0.151;
    $statpot{'a20LH'}=0.133;
    $statpot{'a20LI'}=0.228;
    $statpot{'a20LL'}=0.218;
    $statpot{'a20LK'}=0.149;
    $statpot{'a20LM'}=0.269;
    $statpot{'a20LF'}=0.173;
    $statpot{'a20LP'}=0.002;
    $statpot{'a20LS'}=0.201;
    $statpot{'a20LT'}=0.076;
    $statpot{'a20LW'}=0.289;
    $statpot{'a20LY'}=0.201;
    $statpot{'a20LV'}=0.200;
    $statpot{'a20KA'}=-0.115;
    $statpot{'a20KR'}=-0.161;
    $statpot{'a20KN'}=-0.040;
    $statpot{'a20KD'}=0.029;
    $statpot{'a20KC'}=-0.191;
    $statpot{'a20KQ'}=-0.034;
    $statpot{'a20KE'}=0.068;
    $statpot{'a20KG'}=0.001;
    $statpot{'a20KH'}=-0.189;
    $statpot{'a20KI'}=-0.215;
    $statpot{'a20KL'}=-0.078;
    $statpot{'a20KK'}=-0.013;
    $statpot{'a20KM'}=-0.210;
    $statpot{'a20KF'}=-0.133;
    $statpot{'a20KP'}=-0.048;
    $statpot{'a20KS'}=-0.100;
    $statpot{'a20KT'}=-0.085;
    $statpot{'a20KW'}=-0.157;
    $statpot{'a20KY'}=-0.180;
    $statpot{'a20KV'}=-0.132;
    $statpot{'a20MA'}=0.112;
    $statpot{'a20MR'}=-0.090;
    $statpot{'a20MN'}=0.027;
    $statpot{'a20MD'}=0.091;
    $statpot{'a20MC'}=-0.046;
    $statpot{'a20MQ'}=0.070;
    $statpot{'a20ME'}=0.030;
    $statpot{'a20MG'}=0.016;
    $statpot{'a20MH'}=-0.047;
    $statpot{'a20MI'}=0.157;
    $statpot{'a20ML'}=0.259;
    $statpot{'a20MK'}=-0.015;
    $statpot{'a20MM'}=-0.021;
    $statpot{'a20MF'}=0.101;
    $statpot{'a20MP'}=-0.051;
    $statpot{'a20MS'}=-0.045;
    $statpot{'a20MT'}=0.010;
    $statpot{'a20MW'}=0.047;
    $statpot{'a20MY'}=0.165;
    $statpot{'a20MV'}=0.034;
    $statpot{'a20FA'}=0.141;
    $statpot{'a20FR'}=0.098;
    $statpot{'a20FN'}=0.163;
    $statpot{'a20FD'}=-0.040;
    $statpot{'a20FC'}=0.237;
    $statpot{'a20FQ'}=0.051;
    $statpot{'a20FE'}=0.084;
    $statpot{'a20FG'}=0.223;
    $statpot{'a20FH'}=0.262;
    $statpot{'a20FI'}=0.230;
    $statpot{'a20FL'}=0.188;
    $statpot{'a20FK'}=0.036;
    $statpot{'a20FM'}=0.276;
    $statpot{'a20FF'}=0.176;
    $statpot{'a20FP'}=-0.009;
    $statpot{'a20FS'}=0.123;
    $statpot{'a20FT'}=0.117;
    $statpot{'a20FW'}=0.211;
    $statpot{'a20FY'}=0.212;
    $statpot{'a20FV'}=0.123;
    $statpot{'a20PA'}=-0.128;
    $statpot{'a20PR'}=-0.060;
    $statpot{'a20PN'}=-0.041;
    $statpot{'a20PD'}=0.049;
    $statpot{'a20PC'}=-0.173;
    $statpot{'a20PQ'}=-0.084;
    $statpot{'a20PE'}=-0.033;
    $statpot{'a20PG'}=-0.100;
    $statpot{'a20PH'}=-0.176;
    $statpot{'a20PI'}=-0.222;
    $statpot{'a20PL'}=-0.198;
    $statpot{'a20PK'}=0.022;
    $statpot{'a20PM'}=-0.187;
    $statpot{'a20PF'}=-0.251;
    $statpot{'a20PP'}=0.009;
    $statpot{'a20PS'}=-0.072;
    $statpot{'a20PT'}=-0.062;
    $statpot{'a20PW'}=-0.182;
    $statpot{'a20PY'}=-0.141;
    $statpot{'a20PV'}=-0.130;
    $statpot{'a20SA'}=-0.106;
    $statpot{'a20SR'}=-0.226;
    $statpot{'a20SN'}=-0.043;
    $statpot{'a20SD'}=-0.095;
    $statpot{'a20SC'}=-0.131;
    $statpot{'a20SQ'}=-0.067;
    $statpot{'a20SE'}=-0.027;
    $statpot{'a20SG'}=-0.064;
    $statpot{'a20SH'}=-0.198;
    $statpot{'a20SI'}=-0.074;
    $statpot{'a20SL'}=-0.014;
    $statpot{'a20SK'}=-0.060;
    $statpot{'a20SM'}=-0.236;
    $statpot{'a20SF'}=-0.093;
    $statpot{'a20SP'}=-0.024;
    $statpot{'a20SS'}=-0.118;
    $statpot{'a20ST'}=-0.158;
    $statpot{'a20SW'}=0.073;
    $statpot{'a20SY'}=-0.035;
    $statpot{'a20SV'}=-0.143;
    $statpot{'a20TA'}=-0.084;
    $statpot{'a20TR'}=-0.095;
    $statpot{'a20TN'}=-0.029;
    $statpot{'a20TD'}=-0.092;
    $statpot{'a20TC'}=-0.117;
    $statpot{'a20TQ'}=-0.029;
    $statpot{'a20TE'}=-0.126;
    $statpot{'a20TG'}=-0.041;
    $statpot{'a20TH'}=-0.133;
    $statpot{'a20TI'}=-0.055;
    $statpot{'a20TL'}=-0.101;
    $statpot{'a20TK'}=-0.031;
    $statpot{'a20TM'}=-0.169;
    $statpot{'a20TF'}=-0.040;
    $statpot{'a20TP'}=-0.022;
    $statpot{'a20TS'}=-0.144;
    $statpot{'a20TT'}=-0.098;
    $statpot{'a20TW'}=-0.119;
    $statpot{'a20TY'}=-0.078;
    $statpot{'a20TV'}=-0.045;
    $statpot{'a20WA'}=0.185;
    $statpot{'a20WR'}=-0.035;
    $statpot{'a20WN'}=-0.040;
    $statpot{'a20WD'}=-0.017;
    $statpot{'a20WC'}=0.362;
    $statpot{'a20WQ'}=0.031;
    $statpot{'a20WE'}=0.161;
    $statpot{'a20WG'}=0.084;
    $statpot{'a20WH'}=-0.009;
    $statpot{'a20WI'}=-0.000;
    $statpot{'a20WL'}=0.253;
    $statpot{'a20WK'}=0.031;
    $statpot{'a20WM'}=0.114;
    $statpot{'a20WF'}=0.278;
    $statpot{'a20WP'}=0.005;
    $statpot{'a20WS'}=0.206;
    $statpot{'a20WT'}=-0.067;
    $statpot{'a20WW'}=-0.004;
    $statpot{'a20WY'}=0.131;
    $statpot{'a20WV'}=0.075;
    $statpot{'a20YA'}=0.146;
    $statpot{'a20YR'}=0.037;
    $statpot{'a20YN'}=0.029;
    $statpot{'a20YD'}=0.059;
    $statpot{'a20YC'}=0.315;
    $statpot{'a20YQ'}=0.104;
    $statpot{'a20YE'}=0.144;
    $statpot{'a20YG'}=0.129;
    $statpot{'a20YH'}=0.002;
    $statpot{'a20YI'}=0.051;
    $statpot{'a20YL'}=0.142;
    $statpot{'a20YK'}=-0.035;
    $statpot{'a20YM'}=0.169;
    $statpot{'a20YF'}=0.103;
    $statpot{'a20YP'}=0.062;
    $statpot{'a20YS'}=0.072;
    $statpot{'a20YT'}=0.036;
    $statpot{'a20YW'}=0.105;
    $statpot{'a20YY'}=0.164;
    $statpot{'a20YV'}=0.030;
    $statpot{'a20VA'}=0.027;
    $statpot{'a20VR'}=-0.017;
    $statpot{'a20VN'}=-0.036;
    $statpot{'a20VD'}=-0.010;
    $statpot{'a20VC'}=0.140;
    $statpot{'a20VQ'}=-0.009;
    $statpot{'a20VE'}=0.018;
    $statpot{'a20VG'}=-0.002;
    $statpot{'a20VH'}=-0.024;
    $statpot{'a20VI'}=0.142;
    $statpot{'a20VL'}=0.176;
    $statpot{'a20VK'}=0.034;
    $statpot{'a20VM'}=0.011;
    $statpot{'a20VF'}=0.143;
    $statpot{'a20VP'}=-0.018;
    $statpot{'a20VS'}=-0.036;
    $statpot{'a20VT'}=0.019;
    $statpot{'a20VW'}=0.091;
    $statpot{'a20VY'}=0.018;
    $statpot{'a20VV'}=0.047;
    $statpot{'p21AA'}=-0.039;
    $statpot{'p21AR'}=-0.040;
    $statpot{'p21AN'}=-0.026;
    $statpot{'p21AD'}=0.066;
    $statpot{'p21AC'}=-0.131;
    $statpot{'p21AQ'}=-0.070;
    $statpot{'p21AE'}=0.073;
    $statpot{'p21AG'}=0.043;
    $statpot{'p21AH'}=-0.015;
    $statpot{'p21AI'}=-0.029;
    $statpot{'p21AL'}=-0.023;
    $statpot{'p21AK'}=0.036;
    $statpot{'p21AM'}=-0.160;
    $statpot{'p21AF'}=-0.082;
    $statpot{'p21AP'}=-0.023;
    $statpot{'p21AS'}=-0.049;
    $statpot{'p21AT'}=-0.092;
    $statpot{'p21AW'}=-0.064;
    $statpot{'p21AY'}=-0.072;
    $statpot{'p21AV'}=-0.056;
    $statpot{'p21RA'}=-0.040;
    $statpot{'p21RR'}=0.040;
    $statpot{'p21RN'}=0.103;
    $statpot{'p21RD'}=0.133;
    $statpot{'p21RC'}=-0.042;
    $statpot{'p21RQ'}=-0.001;
    $statpot{'p21RE'}=0.073;
    $statpot{'p21RG'}=0.069;
    $statpot{'p21RH'}=-0.045;
    $statpot{'p21RI'}=-0.055;
    $statpot{'p21RL'}=0.000;
    $statpot{'p21RK'}=0.079;
    $statpot{'p21RM'}=-0.050;
    $statpot{'p21RF'}=-0.138;
    $statpot{'p21RP'}=0.061;
    $statpot{'p21RS'}=0.022;
    $statpot{'p21RT'}=-0.009;
    $statpot{'p21RW'}=0.044;
    $statpot{'p21RY'}=-0.086;
    $statpot{'p21RV'}=-0.016;
    $statpot{'p21NA'}=-0.026;
    $statpot{'p21NR'}=0.103;
    $statpot{'p21NN'}=0.076;
    $statpot{'p21ND'}=0.065;
    $statpot{'p21NC'}=-0.135;
    $statpot{'p21NQ'}=-0.014;
    $statpot{'p21NE'}=0.075;
    $statpot{'p21NG'}=0.038;
    $statpot{'p21NH'}=-0.084;
    $statpot{'p21NI'}=-0.062;
    $statpot{'p21NL'}=-0.030;
    $statpot{'p21NK'}=0.142;
    $statpot{'p21NM'}=-0.090;
    $statpot{'p21NF'}=-0.134;
    $statpot{'p21NP'}=0.019;
    $statpot{'p21NS'}=0.005;
    $statpot{'p21NT'}=0.018;
    $statpot{'p21NW'}=-0.124;
    $statpot{'p21NY'}=-0.046;
    $statpot{'p21NV'}=-0.033;
    $statpot{'p21DA'}=0.066;
    $statpot{'p21DR'}=0.133;
    $statpot{'p21DN'}=0.065;
    $statpot{'p21DD'}=0.040;
    $statpot{'p21DC'}=-0.024;
    $statpot{'p21DQ'}=0.042;
    $statpot{'p21DE'}=0.132;
    $statpot{'p21DG'}=0.157;
    $statpot{'p21DH'}=0.068;
    $statpot{'p21DI'}=0.030;
    $statpot{'p21DL'}=-0.016;
    $statpot{'p21DK'}=0.123;
    $statpot{'p21DM'}=-0.062;
    $statpot{'p21DF'}=0.007;
    $statpot{'p21DP'}=0.068;
    $statpot{'p21DS'}=0.018;
    $statpot{'p21DT'}=-0.011;
    $statpot{'p21DW'}=0.041;
    $statpot{'p21DY'}=-0.002;
    $statpot{'p21DV'}=0.003;
    $statpot{'p21CA'}=-0.131;
    $statpot{'p21CR'}=-0.042;
    $statpot{'p21CN'}=-0.135;
    $statpot{'p21CD'}=-0.024;
    $statpot{'p21CC'}=0.104;
    $statpot{'p21CQ'}=-0.097;
    $statpot{'p21CE'}=-0.057;
    $statpot{'p21CG'}=0.029;
    $statpot{'p21CH'}=-0.087;
    $statpot{'p21CI'}=-0.094;
    $statpot{'p21CL'}=-0.087;
    $statpot{'p21CK'}=-0.044;
    $statpot{'p21CM'}=-0.172;
    $statpot{'p21CF'}=-0.016;
    $statpot{'p21CP'}=-0.047;
    $statpot{'p21CS'}=-0.036;
    $statpot{'p21CT'}=-0.033;
    $statpot{'p21CW'}=-0.194;
    $statpot{'p21CY'}=-0.270;
    $statpot{'p21CV'}=-0.043;
    $statpot{'p21QA'}=-0.070;
    $statpot{'p21QR'}=-0.001;
    $statpot{'p21QN'}=-0.014;
    $statpot{'p21QD'}=0.042;
    $statpot{'p21QC'}=-0.097;
    $statpot{'p21QQ'}=0.082;
    $statpot{'p21QE'}=0.145;
    $statpot{'p21QG'}=0.063;
    $statpot{'p21QH'}=0.044;
    $statpot{'p21QI'}=0.007;
    $statpot{'p21QL'}=0.010;
    $statpot{'p21QK'}=0.132;
    $statpot{'p21QM'}=-0.001;
    $statpot{'p21QF'}=-0.077;
    $statpot{'p21QP'}=0.005;
    $statpot{'p21QS'}=0.032;
    $statpot{'p21QT'}=0.001;
    $statpot{'p21QW'}=-0.016;
    $statpot{'p21QY'}=-0.048;
    $statpot{'p21QV'}=-0.043;
    $statpot{'p21EA'}=0.073;
    $statpot{'p21ER'}=0.073;
    $statpot{'p21EN'}=0.075;
    $statpot{'p21ED'}=0.132;
    $statpot{'p21EC'}=-0.057;
    $statpot{'p21EQ'}=0.145;
    $statpot{'p21EE'}=0.215;
    $statpot{'p21EG'}=0.067;
    $statpot{'p21EH'}=0.072;
    $statpot{'p21EI'}=0.042;
    $statpot{'p21EL'}=0.039;
    $statpot{'p21EK'}=0.183;
    $statpot{'p21EM'}=0.069;
    $statpot{'p21EF'}=0.021;
    $statpot{'p21EP'}=0.068;
    $statpot{'p21ES'}=0.057;
    $statpot{'p21ET'}=0.086;
    $statpot{'p21EW'}=-0.062;
    $statpot{'p21EY'}=0.056;
    $statpot{'p21EV'}=0.032;
    $statpot{'p21GA'}=0.043;
    $statpot{'p21GR'}=0.069;
    $statpot{'p21GN'}=0.038;
    $statpot{'p21GD'}=0.157;
    $statpot{'p21GC'}=0.029;
    $statpot{'p21GQ'}=0.063;
    $statpot{'p21GE'}=0.067;
    $statpot{'p21GG'}=0.183;
    $statpot{'p21GH'}=0.039;
    $statpot{'p21GI'}=0.052;
    $statpot{'p21GL'}=0.023;
    $statpot{'p21GK'}=0.084;
    $statpot{'p21GM'}=-0.007;
    $statpot{'p21GF'}=0.010;
    $statpot{'p21GP'}=0.082;
    $statpot{'p21GS'}=0.048;
    $statpot{'p21GT'}=0.060;
    $statpot{'p21GW'}=0.098;
    $statpot{'p21GY'}=0.015;
    $statpot{'p21GV'}=0.032;
    $statpot{'p21HA'}=-0.015;
    $statpot{'p21HR'}=-0.045;
    $statpot{'p21HN'}=-0.084;
    $statpot{'p21HD'}=0.068;
    $statpot{'p21HC'}=-0.087;
    $statpot{'p21HQ'}=0.044;
    $statpot{'p21HE'}=0.072;
    $statpot{'p21HG'}=0.039;
    $statpot{'p21HH'}=-0.154;
    $statpot{'p21HI'}=-0.100;
    $statpot{'p21HL'}=-0.089;
    $statpot{'p21HK'}=0.032;
    $statpot{'p21HM'}=-0.259;
    $statpot{'p21HF'}=0.014;
    $statpot{'p21HP'}=-0.028;
    $statpot{'p21HS'}=-0.059;
    $statpot{'p21HT'}=-0.065;
    $statpot{'p21HW'}=-0.069;
    $statpot{'p21HY'}=-0.106;
    $statpot{'p21HV'}=-0.146;
    $statpot{'p21IA'}=-0.029;
    $statpot{'p21IR'}=-0.055;
    $statpot{'p21IN'}=-0.062;
    $statpot{'p21ID'}=0.030;
    $statpot{'p21IC'}=-0.094;
    $statpot{'p21IQ'}=0.007;
    $statpot{'p21IE'}=0.042;
    $statpot{'p21IG'}=0.052;
    $statpot{'p21IH'}=-0.100;
    $statpot{'p21II'}=0.007;
    $statpot{'p21IL'}=0.017;
    $statpot{'p21IK'}=0.046;
    $statpot{'p21IM'}=-0.072;
    $statpot{'p21IF'}=-0.065;
    $statpot{'p21IP'}=0.003;
    $statpot{'p21IS'}=-0.065;
    $statpot{'p21IT'}=-0.035;
    $statpot{'p21IW'}=-0.078;
    $statpot{'p21IY'}=-0.131;
    $statpot{'p21IV'}=-0.033;
    $statpot{'p21LA'}=-0.023;
    $statpot{'p21LR'}=0.000;
    $statpot{'p21LN'}=-0.030;
    $statpot{'p21LD'}=-0.016;
    $statpot{'p21LC'}=-0.087;
    $statpot{'p21LQ'}=0.010;
    $statpot{'p21LE'}=0.039;
    $statpot{'p21LG'}=0.023;
    $statpot{'p21LH'}=-0.089;
    $statpot{'p21LI'}=0.017;
    $statpot{'p21LL'}=0.010;
    $statpot{'p21LK'}=0.080;
    $statpot{'p21LM'}=-0.082;
    $statpot{'p21LF'}=-0.040;
    $statpot{'p21LP'}=-0.001;
    $statpot{'p21LS'}=-0.076;
    $statpot{'p21LT'}=-0.055;
    $statpot{'p21LW'}=-0.060;
    $statpot{'p21LY'}=-0.089;
    $statpot{'p21LV'}=-0.001;
    $statpot{'p21KA'}=0.036;
    $statpot{'p21KR'}=0.079;
    $statpot{'p21KN'}=0.142;
    $statpot{'p21KD'}=0.123;
    $statpot{'p21KC'}=-0.044;
    $statpot{'p21KQ'}=0.132;
    $statpot{'p21KE'}=0.183;
    $statpot{'p21KG'}=0.084;
    $statpot{'p21KH'}=0.032;
    $statpot{'p21KI'}=0.046;
    $statpot{'p21KL'}=0.080;
    $statpot{'p21KK'}=0.188;
    $statpot{'p21KM'}=0.086;
    $statpot{'p21KF'}=0.085;
    $statpot{'p21KP'}=0.037;
    $statpot{'p21KS'}=0.063;
    $statpot{'p21KT'}=0.083;
    $statpot{'p21KW'}=0.043;
    $statpot{'p21KY'}=0.034;
    $statpot{'p21KV'}=0.072;
    $statpot{'p21MA'}=-0.160;
    $statpot{'p21MR'}=-0.050;
    $statpot{'p21MN'}=-0.090;
    $statpot{'p21MD'}=-0.062;
    $statpot{'p21MC'}=-0.172;
    $statpot{'p21MQ'}=-0.001;
    $statpot{'p21ME'}=0.069;
    $statpot{'p21MG'}=-0.007;
    $statpot{'p21MH'}=-0.259;
    $statpot{'p21MI'}=-0.072;
    $statpot{'p21ML'}=-0.082;
    $statpot{'p21MK'}=0.086;
    $statpot{'p21MM'}=-0.127;
    $statpot{'p21MF'}=-0.001;
    $statpot{'p21MP'}=-0.065;
    $statpot{'p21MS'}=-0.207;
    $statpot{'p21MT'}=-0.128;
    $statpot{'p21MW'}=-0.039;
    $statpot{'p21MY'}=-0.208;
    $statpot{'p21MV'}=-0.126;
    $statpot{'p21FA'}=-0.082;
    $statpot{'p21FR'}=-0.138;
    $statpot{'p21FN'}=-0.134;
    $statpot{'p21FD'}=0.007;
    $statpot{'p21FC'}=-0.016;
    $statpot{'p21FQ'}=-0.077;
    $statpot{'p21FE'}=0.021;
    $statpot{'p21FG'}=0.010;
    $statpot{'p21FH'}=0.014;
    $statpot{'p21FI'}=-0.065;
    $statpot{'p21FL'}=-0.040;
    $statpot{'p21FK'}=0.085;
    $statpot{'p21FM'}=-0.001;
    $statpot{'p21FF'}=-0.062;
    $statpot{'p21FP'}=-0.096;
    $statpot{'p21FS'}=-0.079;
    $statpot{'p21FT'}=-0.091;
    $statpot{'p21FW'}=-0.144;
    $statpot{'p21FY'}=-0.152;
    $statpot{'p21FV'}=-0.048;
    $statpot{'p21PA'}=-0.023;
    $statpot{'p21PR'}=0.061;
    $statpot{'p21PN'}=0.019;
    $statpot{'p21PD'}=0.068;
    $statpot{'p21PC'}=-0.047;
    $statpot{'p21PQ'}=0.005;
    $statpot{'p21PE'}=0.068;
    $statpot{'p21PG'}=0.082;
    $statpot{'p21PH'}=-0.028;
    $statpot{'p21PI'}=0.003;
    $statpot{'p21PL'}=-0.001;
    $statpot{'p21PK'}=0.037;
    $statpot{'p21PM'}=-0.065;
    $statpot{'p21PF'}=-0.096;
    $statpot{'p21PP'}=0.106;
    $statpot{'p21PS'}=-0.030;
    $statpot{'p21PT'}=-0.034;
    $statpot{'p21PW'}=-0.057;
    $statpot{'p21PY'}=-0.064;
    $statpot{'p21PV'}=-0.056;
    $statpot{'p21SA'}=-0.049;
    $statpot{'p21SR'}=0.022;
    $statpot{'p21SN'}=0.005;
    $statpot{'p21SD'}=0.018;
    $statpot{'p21SC'}=-0.036;
    $statpot{'p21SQ'}=0.032;
    $statpot{'p21SE'}=0.057;
    $statpot{'p21SG'}=0.048;
    $statpot{'p21SH'}=-0.059;
    $statpot{'p21SI'}=-0.065;
    $statpot{'p21SL'}=-0.076;
    $statpot{'p21SK'}=0.063;
    $statpot{'p21SM'}=-0.207;
    $statpot{'p21SF'}=-0.079;
    $statpot{'p21SP'}=-0.030;
    $statpot{'p21SS'}=-0.022;
    $statpot{'p21ST'}=-0.045;
    $statpot{'p21SW'}=-0.076;
    $statpot{'p21SY'}=-0.035;
    $statpot{'p21SV'}=-0.104;
    $statpot{'p21TA'}=-0.092;
    $statpot{'p21TR'}=-0.009;
    $statpot{'p21TN'}=0.018;
    $statpot{'p21TD'}=-0.011;
    $statpot{'p21TC'}=-0.033;
    $statpot{'p21TQ'}=0.001;
    $statpot{'p21TE'}=0.086;
    $statpot{'p21TG'}=0.060;
    $statpot{'p21TH'}=-0.065;
    $statpot{'p21TI'}=-0.035;
    $statpot{'p21TL'}=-0.055;
    $statpot{'p21TK'}=0.083;
    $statpot{'p21TM'}=-0.128;
    $statpot{'p21TF'}=-0.091;
    $statpot{'p21TP'}=-0.034;
    $statpot{'p21TS'}=-0.045;
    $statpot{'p21TT'}=0.044;
    $statpot{'p21TW'}=-0.004;
    $statpot{'p21TY'}=-0.028;
    $statpot{'p21TV'}=-0.052;
    $statpot{'p21WA'}=-0.064;
    $statpot{'p21WR'}=0.044;
    $statpot{'p21WN'}=-0.124;
    $statpot{'p21WD'}=0.041;
    $statpot{'p21WC'}=-0.194;
    $statpot{'p21WQ'}=-0.016;
    $statpot{'p21WE'}=-0.062;
    $statpot{'p21WG'}=0.098;
    $statpot{'p21WH'}=-0.069;
    $statpot{'p21WI'}=-0.078;
    $statpot{'p21WL'}=-0.060;
    $statpot{'p21WK'}=0.043;
    $statpot{'p21WM'}=-0.039;
    $statpot{'p21WF'}=-0.144;
    $statpot{'p21WP'}=-0.057;
    $statpot{'p21WS'}=-0.076;
    $statpot{'p21WT'}=-0.004;
    $statpot{'p21WW'}=-0.060;
    $statpot{'p21WY'}=-0.228;
    $statpot{'p21WV'}=-0.071;
    $statpot{'p21YA'}=-0.072;
    $statpot{'p21YR'}=-0.086;
    $statpot{'p21YN'}=-0.046;
    $statpot{'p21YD'}=-0.002;
    $statpot{'p21YC'}=-0.270;
    $statpot{'p21YQ'}=-0.048;
    $statpot{'p21YE'}=0.056;
    $statpot{'p21YG'}=0.015;
    $statpot{'p21YH'}=-0.106;
    $statpot{'p21YI'}=-0.131;
    $statpot{'p21YL'}=-0.089;
    $statpot{'p21YK'}=0.034;
    $statpot{'p21YM'}=-0.208;
    $statpot{'p21YF'}=-0.152;
    $statpot{'p21YP'}=-0.064;
    $statpot{'p21YS'}=-0.035;
    $statpot{'p21YT'}=-0.028;
    $statpot{'p21YW'}=-0.228;
    $statpot{'p21YY'}=-0.081;
    $statpot{'p21YV'}=-0.100;
    $statpot{'p21VA'}=-0.056;
    $statpot{'p21VR'}=-0.016;
    $statpot{'p21VN'}=-0.033;
    $statpot{'p21VD'}=0.003;
    $statpot{'p21VC'}=-0.043;
    $statpot{'p21VQ'}=-0.043;
    $statpot{'p21VE'}=0.032;
    $statpot{'p21VG'}=0.032;
    $statpot{'p21VH'}=-0.146;
    $statpot{'p21VI'}=-0.033;
    $statpot{'p21VL'}=-0.001;
    $statpot{'p21VK'}=0.072;
    $statpot{'p21VM'}=-0.126;
    $statpot{'p21VF'}=-0.048;
    $statpot{'p21VP'}=-0.056;
    $statpot{'p21VS'}=-0.104;
    $statpot{'p21VT'}=-0.052;
    $statpot{'p21VW'}=-0.071;
    $statpot{'p21VY'}=-0.100;
    $statpot{'p21VV'}=-0.044;
    $statpot{'f21AA'}=-0.054;
    $statpot{'f21AR'}=-0.007;
    $statpot{'f21AN'}=-0.022;
    $statpot{'f21AD'}=0.090;
    $statpot{'f21AC'}=-0.299;
    $statpot{'f21AQ'}=-0.021;
    $statpot{'f21AE'}=0.186;
    $statpot{'f21AG'}=-0.033;
    $statpot{'f21AH'}=-0.246;
    $statpot{'f21AI'}=-0.171;
    $statpot{'f21AL'}=-0.089;
    $statpot{'f21AK'}=0.093;
    $statpot{'f21AM'}=-0.165;
    $statpot{'f21AF'}=-0.157;
    $statpot{'f21AP'}=-0.014;
    $statpot{'f21AS'}=-0.061;
    $statpot{'f21AT'}=-0.042;
    $statpot{'f21AW'}=-0.227;
    $statpot{'f21AY'}=-0.171;
    $statpot{'f21AV'}=-0.125;
    $statpot{'f21RA'}=0.085;
    $statpot{'f21RR'}=0.177;
    $statpot{'f21RN'}=0.089;
    $statpot{'f21RD'}=0.251;
    $statpot{'f21RC'}=-0.057;
    $statpot{'f21RQ'}=0.142;
    $statpot{'f21RE'}=0.362;
    $statpot{'f21RG'}=0.206;
    $statpot{'f21RH'}=0.012;
    $statpot{'f21RI'}=-0.008;
    $statpot{'f21RL'}=-0.053;
    $statpot{'f21RK'}=0.278;
    $statpot{'f21RM'}=-0.121;
    $statpot{'f21RF'}=-0.181;
    $statpot{'f21RP'}=0.309;
    $statpot{'f21RS'}=0.061;
    $statpot{'f21RT'}=0.104;
    $statpot{'f21RW'}=0.028;
    $statpot{'f21RY'}=-0.100;
    $statpot{'f21RV'}=0.056;
    $statpot{'f21NA'}=0.075;
    $statpot{'f21NR'}=0.115;
    $statpot{'f21NN'}=0.280;
    $statpot{'f21ND'}=0.379;
    $statpot{'f21NC'}=-0.010;
    $statpot{'f21NQ'}=0.251;
    $statpot{'f21NE'}=0.286;
    $statpot{'f21NG'}=0.208;
    $statpot{'f21NH'}=0.152;
    $statpot{'f21NI'}=-0.014;
    $statpot{'f21NL'}=-0.034;
    $statpot{'f21NK'}=0.346;
    $statpot{'f21NM'}=-0.087;
    $statpot{'f21NF'}=0.055;
    $statpot{'f21NP'}=0.256;
    $statpot{'f21NS'}=0.213;
    $statpot{'f21NT'}=0.155;
    $statpot{'f21NW'}=-0.065;
    $statpot{'f21NY'}=-0.147;
    $statpot{'f21NV'}=-0.018;
    $statpot{'f21DA'}=0.247;
    $statpot{'f21DR'}=0.286;
    $statpot{'f21DN'}=0.425;
    $statpot{'f21DD'}=0.398;
    $statpot{'f21DC'}=0.231;
    $statpot{'f21DQ'}=0.313;
    $statpot{'f21DE'}=0.565;
    $statpot{'f21DG'}=0.425;
    $statpot{'f21DH'}=0.252;
    $statpot{'f21DI'}=0.150;
    $statpot{'f21DL'}=0.068;
    $statpot{'f21DK'}=0.491;
    $statpot{'f21DM'}=0.234;
    $statpot{'f21DF'}=0.154;
    $statpot{'f21DP'}=0.403;
    $statpot{'f21DS'}=0.338;
    $statpot{'f21DT'}=0.267;
    $statpot{'f21DW'}=0.164;
    $statpot{'f21DY'}=0.146;
    $statpot{'f21DV'}=0.163;
    $statpot{'f21CA'}=-0.280;
    $statpot{'f21CR'}=-0.252;
    $statpot{'f21CN'}=-0.313;
    $statpot{'f21CD'}=-0.035;
    $statpot{'f21CC'}=-0.481;
    $statpot{'f21CQ'}=-0.205;
    $statpot{'f21CE'}=-0.086;
    $statpot{'f21CG'}=-0.216;
    $statpot{'f21CH'}=-0.391;
    $statpot{'f21CI'}=-0.331;
    $statpot{'f21CL'}=-0.305;
    $statpot{'f21CK'}=-0.135;
    $statpot{'f21CM'}=-0.389;
    $statpot{'f21CF'}=-0.290;
    $statpot{'f21CP'}=-0.123;
    $statpot{'f21CS'}=-0.294;
    $statpot{'f21CT'}=-0.237;
    $statpot{'f21CW'}=-0.432;
    $statpot{'f21CY'}=-0.487;
    $statpot{'f21CV'}=-0.425;
    $statpot{'f21QA'}=0.080;
    $statpot{'f21QR'}=0.190;
    $statpot{'f21QN'}=0.215;
    $statpot{'f21QD'}=0.227;
    $statpot{'f21QC'}=-0.123;
    $statpot{'f21QQ'}=0.204;
    $statpot{'f21QE'}=0.314;
    $statpot{'f21QG'}=0.196;
    $statpot{'f21QH'}=-0.048;
    $statpot{'f21QI'}=-0.066;
    $statpot{'f21QL'}=0.057;
    $statpot{'f21QK'}=0.322;
    $statpot{'f21QM'}=0.035;
    $statpot{'f21QF'}=-0.130;
    $statpot{'f21QP'}=0.297;
    $statpot{'f21QS'}=0.156;
    $statpot{'f21QT'}=0.116;
    $statpot{'f21QW'}=-0.163;
    $statpot{'f21QY'}=-0.000;
    $statpot{'f21QV'}=0.025;
    $statpot{'f21EA'}=0.353;
    $statpot{'f21ER'}=0.393;
    $statpot{'f21EN'}=0.390;
    $statpot{'f21ED'}=0.526;
    $statpot{'f21EC'}=0.159;
    $statpot{'f21EQ'}=0.413;
    $statpot{'f21EE'}=0.651;
    $statpot{'f21EG'}=0.390;
    $statpot{'f21EH'}=0.186;
    $statpot{'f21EI'}=0.217;
    $statpot{'f21EL'}=0.236;
    $statpot{'f21EK'}=0.537;
    $statpot{'f21EM'}=0.199;
    $statpot{'f21EF'}=0.142;
    $statpot{'f21EP'}=0.380;
    $statpot{'f21ES'}=0.323;
    $statpot{'f21ET'}=0.336;
    $statpot{'f21EW'}=0.124;
    $statpot{'f21EY'}=0.224;
    $statpot{'f21EV'}=0.269;
    $statpot{'f21GA'}=0.080;
    $statpot{'f21GR'}=0.177;
    $statpot{'f21GN'}=0.225;
    $statpot{'f21GD'}=0.309;
    $statpot{'f21GC'}=-0.086;
    $statpot{'f21GQ'}=0.208;
    $statpot{'f21GE'}=0.288;
    $statpot{'f21GG'}=0.214;
    $statpot{'f21GH'}=0.071;
    $statpot{'f21GI'}=0.081;
    $statpot{'f21GL'}=0.013;
    $statpot{'f21GK'}=0.321;
    $statpot{'f21GM'}=-0.051;
    $statpot{'f21GF'}=0.027;
    $statpot{'f21GP'}=0.255;
    $statpot{'f21GS'}=0.118;
    $statpot{'f21GT'}=0.134;
    $statpot{'f21GW'}=-0.067;
    $statpot{'f21GY'}=-0.008;
    $statpot{'f21GV'}=0.020;
    $statpot{'f21HA'}=-0.227;
    $statpot{'f21HR'}=-0.021;
    $statpot{'f21HN'}=0.047;
    $statpot{'f21HD'}=0.117;
    $statpot{'f21HC'}=-0.225;
    $statpot{'f21HQ'}=-0.100;
    $statpot{'f21HE'}=0.163;
    $statpot{'f21HG'}=-0.073;
    $statpot{'f21HH'}=0.024;
    $statpot{'f21HI'}=-0.246;
    $statpot{'f21HL'}=-0.184;
    $statpot{'f21HK'}=0.145;
    $statpot{'f21HM'}=-0.144;
    $statpot{'f21HF'}=-0.213;
    $statpot{'f21HP'}=-0.001;
    $statpot{'f21HS'}=0.011;
    $statpot{'f21HT'}=-0.059;
    $statpot{'f21HW'}=-0.159;
    $statpot{'f21HY'}=-0.214;
    $statpot{'f21HV'}=-0.217;
    $statpot{'f21IA'}=-0.239;
    $statpot{'f21IR'}=-0.140;
    $statpot{'f21IN'}=-0.172;
    $statpot{'f21ID'}=-0.092;
    $statpot{'f21IC'}=-0.314;
    $statpot{'f21IQ'}=-0.196;
    $statpot{'f21IE'}=-0.034;
    $statpot{'f21IG'}=-0.110;
    $statpot{'f21IH'}=-0.326;
    $statpot{'f21II'}=-0.254;
    $statpot{'f21IL'}=-0.303;
    $statpot{'f21IK'}=0.031;
    $statpot{'f21IM'}=-0.185;
    $statpot{'f21IF'}=-0.324;
    $statpot{'f21IP'}=-0.196;
    $statpot{'f21IS'}=-0.189;
    $statpot{'f21IT'}=-0.205;
    $statpot{'f21IW'}=-0.388;
    $statpot{'f21IY'}=-0.295;
    $statpot{'f21IV'}=-0.277;
    $statpot{'f21LA'}=-0.163;
    $statpot{'f21LR'}=-0.171;
    $statpot{'f21LN'}=-0.216;
    $statpot{'f21LD'}=-0.176;
    $statpot{'f21LC'}=-0.324;
    $statpot{'f21LQ'}=-0.062;
    $statpot{'f21LE'}=0.018;
    $statpot{'f21LG'}=-0.129;
    $statpot{'f21LH'}=-0.246;
    $statpot{'f21LI'}=-0.266;
    $statpot{'f21LL'}=-0.205;
    $statpot{'f21LK'}=-0.030;
    $statpot{'f21LM'}=-0.305;
    $statpot{'f21LF'}=-0.307;
    $statpot{'f21LP'}=-0.150;
    $statpot{'f21LS'}=-0.206;
    $statpot{'f21LT'}=-0.147;
    $statpot{'f21LW'}=-0.410;
    $statpot{'f21LY'}=-0.345;
    $statpot{'f21LV'}=-0.172;
    $statpot{'f21KA'}=0.265;
    $statpot{'f21KR'}=0.439;
    $statpot{'f21KN'}=0.454;
    $statpot{'f21KD'}=0.572;
    $statpot{'f21KC'}=0.039;
    $statpot{'f21KQ'}=0.278;
    $statpot{'f21KE'}=0.519;
    $statpot{'f21KG'}=0.423;
    $statpot{'f21KH'}=0.262;
    $statpot{'f21KI'}=0.253;
    $statpot{'f21KL'}=0.199;
    $statpot{'f21KK'}=0.601;
    $statpot{'f21KM'}=0.279;
    $statpot{'f21KF'}=0.108;
    $statpot{'f21KP'}=0.482;
    $statpot{'f21KS'}=0.369;
    $statpot{'f21KT'}=0.345;
    $statpot{'f21KW'}=0.191;
    $statpot{'f21KY'}=0.133;
    $statpot{'f21KV'}=0.264;
    $statpot{'f21MA'}=-0.222;
    $statpot{'f21MR'}=-0.164;
    $statpot{'f21MN'}=-0.272;
    $statpot{'f21MD'}=-0.015;
    $statpot{'f21MC'}=-0.324;
    $statpot{'f21MQ'}=-0.150;
    $statpot{'f21ME'}=0.054;
    $statpot{'f21MG'}=-0.180;
    $statpot{'f21MH'}=-0.220;
    $statpot{'f21MI'}=-0.237;
    $statpot{'f21ML'}=-0.291;
    $statpot{'f21MK'}=0.036;
    $statpot{'f21MM'}=-0.207;
    $statpot{'f21MF'}=-0.198;
    $statpot{'f21MP'}=-0.224;
    $statpot{'f21MS'}=-0.221;
    $statpot{'f21MT'}=-0.130;
    $statpot{'f21MW'}=-0.304;
    $statpot{'f21MY'}=-0.419;
    $statpot{'f21MV'}=-0.353;
    $statpot{'f21FA'}=-0.249;
    $statpot{'f21FR'}=-0.308;
    $statpot{'f21FN'}=-0.150;
    $statpot{'f21FD'}=-0.117;
    $statpot{'f21FC'}=-0.252;
    $statpot{'f21FQ'}=-0.320;
    $statpot{'f21FE'}=-0.116;
    $statpot{'f21FG'}=-0.131;
    $statpot{'f21FH'}=-0.384;
    $statpot{'f21FI'}=-0.319;
    $statpot{'f21FL'}=-0.315;
    $statpot{'f21FK'}=-0.071;
    $statpot{'f21FM'}=-0.247;
    $statpot{'f21FF'}=-0.381;
    $statpot{'f21FP'}=-0.187;
    $statpot{'f21FS'}=-0.280;
    $statpot{'f21FT'}=-0.210;
    $statpot{'f21FW'}=-0.473;
    $statpot{'f21FY'}=-0.408;
    $statpot{'f21FV'}=-0.330;
    $statpot{'f21PA'}=0.094;
    $statpot{'f21PR'}=0.311;
    $statpot{'f21PN'}=0.192;
    $statpot{'f21PD'}=0.360;
    $statpot{'f21PC'}=-0.028;
    $statpot{'f21PQ'}=0.284;
    $statpot{'f21PE'}=0.347;
    $statpot{'f21PG'}=0.356;
    $statpot{'f21PH'}=0.115;
    $statpot{'f21PI'}=0.016;
    $statpot{'f21PL'}=0.057;
    $statpot{'f21PK'}=0.389;
    $statpot{'f21PM'}=-0.152;
    $statpot{'f21PF'}=0.084;
    $statpot{'f21PP'}=0.293;
    $statpot{'f21PS'}=0.172;
    $statpot{'f21PT'}=0.246;
    $statpot{'f21PW'}=0.137;
    $statpot{'f21PY'}=-0.029;
    $statpot{'f21PV'}=0.057;
    $statpot{'f21SA'}=0.025;
    $statpot{'f21SR'}=0.057;
    $statpot{'f21SN'}=0.215;
    $statpot{'f21SD'}=0.170;
    $statpot{'f21SC'}=-0.147;
    $statpot{'f21SQ'}=0.204;
    $statpot{'f21SE'}=0.279;
    $statpot{'f21SG'}=0.117;
    $statpot{'f21SH'}=-0.041;
    $statpot{'f21SI'}=-0.022;
    $statpot{'f21SL'}=-0.018;
    $statpot{'f21SK'}=0.259;
    $statpot{'f21SM'}=-0.161;
    $statpot{'f21SF'}=-0.137;
    $statpot{'f21SP'}=0.084;
    $statpot{'f21SS'}=0.190;
    $statpot{'f21ST'}=0.152;
    $statpot{'f21SW'}=0.008;
    $statpot{'f21SY'}=-0.078;
    $statpot{'f21SV'}=0.022;
    $statpot{'f21TA'}=-0.010;
    $statpot{'f21TR'}=0.065;
    $statpot{'f21TN'}=0.139;
    $statpot{'f21TD'}=0.123;
    $statpot{'f21TC'}=-0.112;
    $statpot{'f21TQ'}=0.013;
    $statpot{'f21TE'}=0.235;
    $statpot{'f21TG'}=0.091;
    $statpot{'f21TH'}=-0.076;
    $statpot{'f21TI'}=-0.079;
    $statpot{'f21TL'}=-0.028;
    $statpot{'f21TK'}=0.212;
    $statpot{'f21TM'}=-0.033;
    $statpot{'f21TF'}=-0.102;
    $statpot{'f21TP'}=0.129;
    $statpot{'f21TS'}=0.117;
    $statpot{'f21TT'}=0.009;
    $statpot{'f21TW'}=-0.108;
    $statpot{'f21TY'}=-0.059;
    $statpot{'f21TV'}=-0.047;
    $statpot{'f21WA'}=-0.202;
    $statpot{'f21WR'}=-0.026;
    $statpot{'f21WN'}=-0.176;
    $statpot{'f21WD'}=-0.070;
    $statpot{'f21WC'}=-0.472;
    $statpot{'f21WQ'}=-0.237;
    $statpot{'f21WE'}=0.082;
    $statpot{'f21WG'}=-0.231;
    $statpot{'f21WH'}=-0.207;
    $statpot{'f21WI'}=-0.320;
    $statpot{'f21WL'}=-0.353;
    $statpot{'f21WK'}=0.011;
    $statpot{'f21WM'}=-0.339;
    $statpot{'f21WF'}=-0.439;
    $statpot{'f21WP'}=-0.132;
    $statpot{'f21WS'}=-0.062;
    $statpot{'f21WT'}=-0.222;
    $statpot{'f21WW'}=-0.406;
    $statpot{'f21WY'}=-0.465;
    $statpot{'f21WV'}=-0.256;
    $statpot{'f21YA'}=-0.227;
    $statpot{'f21YR'}=-0.109;
    $statpot{'f21YN'}=-0.201;
    $statpot{'f21YD'}=-0.111;
    $statpot{'f21YC'}=-0.557;
    $statpot{'f21YQ'}=-0.116;
    $statpot{'f21YE'}=0.042;
    $statpot{'f21YG'}=-0.175;
    $statpot{'f21YH'}=-0.331;
    $statpot{'f21YI'}=-0.305;
    $statpot{'f21YL'}=-0.334;
    $statpot{'f21YK'}=-0.020;
    $statpot{'f21YM'}=-0.453;
    $statpot{'f21YF'}=-0.347;
    $statpot{'f21YP'}=-0.160;
    $statpot{'f21YS'}=-0.247;
    $statpot{'f21YT'}=-0.190;
    $statpot{'f21YW'}=-0.485;
    $statpot{'f21YY'}=-0.330;
    $statpot{'f21YV'}=-0.221;
    $statpot{'f21VA'}=-0.153;
    $statpot{'f21VR'}=-0.073;
    $statpot{'f21VN'}=-0.146;
    $statpot{'f21VD'}=-0.031;
    $statpot{'f21VC'}=-0.415;
    $statpot{'f21VQ'}=-0.088;
    $statpot{'f21VE'}=0.080;
    $statpot{'f21VG'}=-0.096;
    $statpot{'f21VH'}=-0.298;
    $statpot{'f21VI'}=-0.257;
    $statpot{'f21VL'}=-0.158;
    $statpot{'f21VK'}=0.044;
    $statpot{'f21VM'}=-0.303;
    $statpot{'f21VF'}=-0.296;
    $statpot{'f21VP'}=-0.103;
    $statpot{'f21VS'}=-0.144;
    $statpot{'f21VT'}=-0.149;
    $statpot{'f21VW'}=-0.238;
    $statpot{'f21VY'}=-0.190;
    $statpot{'f21VV'}=-0.152;
    $statpot{'a21AA'}=0.027;
    $statpot{'a21AR'}=0.024;
    $statpot{'a21AN'}=-0.019;
    $statpot{'a21AD'}=0.028;
    $statpot{'a21AC'}=0.076;
    $statpot{'a21AQ'}=0.073;
    $statpot{'a21AE'}=0.065;
    $statpot{'a21AG'}=0.050;
    $statpot{'a21AH'}=-0.023;
    $statpot{'a21AI'}=0.058;
    $statpot{'a21AL'}=0.117;
    $statpot{'a21AK'}=-0.021;
    $statpot{'a21AM'}=0.054;
    $statpot{'a21AF'}=0.033;
    $statpot{'a21AP'}=-0.044;
    $statpot{'a21AS'}=0.027;
    $statpot{'a21AT'}=-0.092;
    $statpot{'a21AW'}=0.028;
    $statpot{'a21AY'}=0.036;
    $statpot{'a21AV'}=0.023;
    $statpot{'a21RA'}=-0.062;
    $statpot{'a21RR'}=-0.101;
    $statpot{'a21RN'}=-0.118;
    $statpot{'a21RD'}=-0.042;
    $statpot{'a21RC'}=-0.157;
    $statpot{'a21RQ'}=-0.133;
    $statpot{'a21RE'}=0.030;
    $statpot{'a21RG'}=-0.053;
    $statpot{'a21RH'}=-0.097;
    $statpot{'a21RI'}=-0.099;
    $statpot{'a21RL'}=0.033;
    $statpot{'a21RK'}=-0.050;
    $statpot{'a21RM'}=-0.055;
    $statpot{'a21RF'}=-0.098;
    $statpot{'a21RP'}=-0.096;
    $statpot{'a21RS'}=-0.160;
    $statpot{'a21RT'}=-0.203;
    $statpot{'a21RW'}=0.044;
    $statpot{'a21RY'}=-0.006;
    $statpot{'a21RV'}=-0.063;
    $statpot{'a21NA'}=-0.104;
    $statpot{'a21NR'}=-0.137;
    $statpot{'a21NN'}=0.072;
    $statpot{'a21ND'}=0.010;
    $statpot{'a21NC'}=-0.252;
    $statpot{'a21NQ'}=-0.042;
    $statpot{'a21NE'}=-0.039;
    $statpot{'a21NG'}=0.012;
    $statpot{'a21NH'}=-0.134;
    $statpot{'a21NI'}=-0.116;
    $statpot{'a21NL'}=-0.077;
    $statpot{'a21NK'}=-0.018;
    $statpot{'a21NM'}=-0.188;
    $statpot{'a21NF'}=-0.116;
    $statpot{'a21NP'}=0.004;
    $statpot{'a21NS'}=-0.127;
    $statpot{'a21NT'}=-0.153;
    $statpot{'a21NW'}=-0.126;
    $statpot{'a21NY'}=-0.049;
    $statpot{'a21NV'}=-0.061;
    $statpot{'a21DA'}=-0.097;
    $statpot{'a21DR'}=-0.067;
    $statpot{'a21DN'}=-0.019;
    $statpot{'a21DD'}=-0.198;
    $statpot{'a21DC'}=-0.225;
    $statpot{'a21DQ'}=-0.095;
    $statpot{'a21DE'}=-0.015;
    $statpot{'a21DG'}=-0.106;
    $statpot{'a21DH'}=-0.193;
    $statpot{'a21DI'}=-0.162;
    $statpot{'a21DL'}=-0.152;
    $statpot{'a21DK'}=0.032;
    $statpot{'a21DM'}=-0.170;
    $statpot{'a21DF'}=-0.174;
    $statpot{'a21DP'}=-0.150;
    $statpot{'a21DS'}=-0.132;
    $statpot{'a21DT'}=-0.194;
    $statpot{'a21DW'}=-0.116;
    $statpot{'a21DY'}=-0.147;
    $statpot{'a21DV'}=-0.185;
    $statpot{'a21CA'}=0.051;
    $statpot{'a21CR'}=0.042;
    $statpot{'a21CN'}=0.033;
    $statpot{'a21CD'}=-0.031;
    $statpot{'a21CC'}=0.158;
    $statpot{'a21CQ'}=0.057;
    $statpot{'a21CE'}=0.017;
    $statpot{'a21CG'}=0.056;
    $statpot{'a21CH'}=0.048;
    $statpot{'a21CI'}=0.195;
    $statpot{'a21CL'}=0.196;
    $statpot{'a21CK'}=-0.040;
    $statpot{'a21CM'}=0.150;
    $statpot{'a21CF'}=0.161;
    $statpot{'a21CP'}=-0.054;
    $statpot{'a21CS'}=0.167;
    $statpot{'a21CT'}=0.043;
    $statpot{'a21CW'}=0.042;
    $statpot{'a21CY'}=0.070;
    $statpot{'a21CV'}=0.049;
    $statpot{'a21QA'}=-0.026;
    $statpot{'a21QR'}=-0.167;
    $statpot{'a21QN'}=-0.017;
    $statpot{'a21QD'}=-0.037;
    $statpot{'a21QC'}=-0.032;
    $statpot{'a21QQ'}=0.003;
    $statpot{'a21QE'}=-0.047;
    $statpot{'a21QG'}=-0.001;
    $statpot{'a21QH'}=-0.234;
    $statpot{'a21QI'}=-0.017;
    $statpot{'a21QL'}=-0.073;
    $statpot{'a21QK'}=-0.030;
    $statpot{'a21QM'}=-0.100;
    $statpot{'a21QF'}=-0.098;
    $statpot{'a21QP'}=-0.058;
    $statpot{'a21QS'}=-0.033;
    $statpot{'a21QT'}=-0.133;
    $statpot{'a21QW'}=-0.038;
    $statpot{'a21QY'}=-0.028;
    $statpot{'a21QV'}=-0.047;
    $statpot{'a21EA'}=-0.063;
    $statpot{'a21ER'}=0.009;
    $statpot{'a21EN'}=-0.105;
    $statpot{'a21ED'}=0.006;
    $statpot{'a21EC'}=-0.188;
    $statpot{'a21EQ'}=-0.108;
    $statpot{'a21EE'}=-0.016;
    $statpot{'a21EG'}=-0.070;
    $statpot{'a21EH'}=-0.047;
    $statpot{'a21EI'}=-0.110;
    $statpot{'a21EL'}=-0.071;
    $statpot{'a21EK'}=0.016;
    $statpot{'a21EM'}=-0.110;
    $statpot{'a21EF'}=-0.126;
    $statpot{'a21EP'}=-0.115;
    $statpot{'a21ES'}=-0.066;
    $statpot{'a21ET'}=-0.174;
    $statpot{'a21EW'}=-0.032;
    $statpot{'a21EY'}=-0.042;
    $statpot{'a21EV'}=-0.123;
    $statpot{'a21GA'}=-0.057;
    $statpot{'a21GR'}=-0.029;
    $statpot{'a21GN'}=-0.000;
    $statpot{'a21GD'}=-0.034;
    $statpot{'a21GC'}=-0.081;
    $statpot{'a21GQ'}=-0.009;
    $statpot{'a21GE'}=-0.001;
    $statpot{'a21GG'}=0.089;
    $statpot{'a21GH'}=-0.131;
    $statpot{'a21GI'}=-0.075;
    $statpot{'a21GL'}=0.004;
    $statpot{'a21GK'}=0.043;
    $statpot{'a21GM'}=-0.079;
    $statpot{'a21GF'}=-0.020;
    $statpot{'a21GP'}=-0.025;
    $statpot{'a21GS'}=-0.176;
    $statpot{'a21GT'}=-0.089;
    $statpot{'a21GW'}=-0.052;
    $statpot{'a21GY'}=-0.085;
    $statpot{'a21GV'}=-0.057;
    $statpot{'a21HA'}=-0.046;
    $statpot{'a21HR'}=-0.068;
    $statpot{'a21HN'}=-0.053;
    $statpot{'a21HD'}=-0.101;
    $statpot{'a21HC'}=-0.149;
    $statpot{'a21HQ'}=-0.192;
    $statpot{'a21HE'}=-0.029;
    $statpot{'a21HG'}=-0.003;
    $statpot{'a21HH'}=-0.052;
    $statpot{'a21HI'}=0.006;
    $statpot{'a21HL'}=0.026;
    $statpot{'a21HK'}=-0.057;
    $statpot{'a21HM'}=-0.023;
    $statpot{'a21HF'}=-0.109;
    $statpot{'a21HP'}=0.012;
    $statpot{'a21HS'}=-0.121;
    $statpot{'a21HT'}=-0.129;
    $statpot{'a21HW'}=0.149;
    $statpot{'a21HY'}=-0.068;
    $statpot{'a21HV'}=-0.092;
    $statpot{'a21IA'}=0.150;
    $statpot{'a21IR'}=0.034;
    $statpot{'a21IN'}=0.040;
    $statpot{'a21ID'}=0.051;
    $statpot{'a21IC'}=0.170;
    $statpot{'a21IQ'}=0.132;
    $statpot{'a21IE'}=0.114;
    $statpot{'a21IG'}=0.117;
    $statpot{'a21IH'}=0.113;
    $statpot{'a21II'}=0.159;
    $statpot{'a21IL'}=0.183;
    $statpot{'a21IK'}=0.061;
    $statpot{'a21IM'}=0.055;
    $statpot{'a21IF'}=0.310;
    $statpot{'a21IP'}=0.006;
    $statpot{'a21IS'}=0.125;
    $statpot{'a21IT'}=0.067;
    $statpot{'a21IW'}=0.165;
    $statpot{'a21IY'}=0.215;
    $statpot{'a21IV'}=0.224;
    $statpot{'a21LA'}=0.216;
    $statpot{'a21LR'}=0.175;
    $statpot{'a21LN'}=0.119;
    $statpot{'a21LD'}=0.088;
    $statpot{'a21LC'}=0.229;
    $statpot{'a21LQ'}=0.039;
    $statpot{'a21LE'}=0.121;
    $statpot{'a21LG'}=0.162;
    $statpot{'a21LH'}=0.105;
    $statpot{'a21LI'}=0.127;
    $statpot{'a21LL'}=0.331;
    $statpot{'a21LK'}=0.141;
    $statpot{'a21LM'}=0.156;
    $statpot{'a21LF'}=0.259;
    $statpot{'a21LP'}=-0.048;
    $statpot{'a21LS'}=0.088;
    $statpot{'a21LT'}=0.127;
    $statpot{'a21LW'}=0.086;
    $statpot{'a21LY'}=0.229;
    $statpot{'a21LV'}=0.211;
    $statpot{'a21KA'}=-0.151;
    $statpot{'a21KR'}=-0.147;
    $statpot{'a21KN'}=-0.081;
    $statpot{'a21KD'}=-0.013;
    $statpot{'a21KC'}=-0.189;
    $statpot{'a21KQ'}=-0.000;
    $statpot{'a21KE'}=0.027;
    $statpot{'a21KG'}=-0.026;
    $statpot{'a21KH'}=-0.140;
    $statpot{'a21KI'}=-0.118;
    $statpot{'a21KL'}=-0.068;
    $statpot{'a21KK'}=0.040;
    $statpot{'a21KM'}=-0.119;
    $statpot{'a21KF'}=-0.079;
    $statpot{'a21KP'}=-0.107;
    $statpot{'a21KS'}=-0.169;
    $statpot{'a21KT'}=-0.165;
    $statpot{'a21KW'}=-0.071;
    $statpot{'a21KY'}=-0.102;
    $statpot{'a21KV'}=-0.122;
    $statpot{'a21MA'}=0.131;
    $statpot{'a21MR'}=-0.008;
    $statpot{'a21MN'}=0.005;
    $statpot{'a21MD'}=0.032;
    $statpot{'a21MC'}=0.051;
    $statpot{'a21MQ'}=0.087;
    $statpot{'a21ME'}=0.009;
    $statpot{'a21MG'}=0.063;
    $statpot{'a21MH'}=0.066;
    $statpot{'a21MI'}=0.126;
    $statpot{'a21ML'}=0.133;
    $statpot{'a21MK'}=0.076;
    $statpot{'a21MM'}=0.079;
    $statpot{'a21MF'}=0.303;
    $statpot{'a21MP'}=-0.081;
    $statpot{'a21MS'}=0.017;
    $statpot{'a21MT'}=0.042;
    $statpot{'a21MW'}=0.073;
    $statpot{'a21MY'}=0.097;
    $statpot{'a21MV'}=0.174;
    $statpot{'a21FA'}=0.155;
    $statpot{'a21FR'}=0.054;
    $statpot{'a21FN'}=0.079;
    $statpot{'a21FD'}=0.066;
    $statpot{'a21FC'}=0.109;
    $statpot{'a21FQ'}=0.128;
    $statpot{'a21FE'}=0.119;
    $statpot{'a21FG'}=0.150;
    $statpot{'a21FH'}=0.107;
    $statpot{'a21FI'}=0.301;
    $statpot{'a21FL'}=0.272;
    $statpot{'a21FK'}=0.087;
    $statpot{'a21FM'}=0.386;
    $statpot{'a21FF'}=0.256;
    $statpot{'a21FP'}=0.011;
    $statpot{'a21FS'}=0.073;
    $statpot{'a21FT'}=0.117;
    $statpot{'a21FW'}=0.273;
    $statpot{'a21FY'}=0.317;
    $statpot{'a21FV'}=0.190;
    $statpot{'a21PA'}=-0.138;
    $statpot{'a21PR'}=-0.097;
    $statpot{'a21PN'}=0.053;
    $statpot{'a21PD'}=-0.125;
    $statpot{'a21PC'}=-0.139;
    $statpot{'a21PQ'}=-0.049;
    $statpot{'a21PE'}=-0.095;
    $statpot{'a21PG'}=-0.095;
    $statpot{'a21PH'}=-0.089;
    $statpot{'a21PI'}=-0.199;
    $statpot{'a21PL'}=-0.232;
    $statpot{'a21PK'}=-0.054;
    $statpot{'a21PM'}=-0.157;
    $statpot{'a21PF'}=-0.236;
    $statpot{'a21PP'}=-0.116;
    $statpot{'a21PS'}=-0.215;
    $statpot{'a21PT'}=-0.182;
    $statpot{'a21PW'}=-0.253;
    $statpot{'a21PY'}=-0.099;
    $statpot{'a21PV'}=-0.209;
    $statpot{'a21SA'}=-0.057;
    $statpot{'a21SR'}=-0.157;
    $statpot{'a21SN'}=-0.128;
    $statpot{'a21SD'}=-0.019;
    $statpot{'a21SC'}=-0.012;
    $statpot{'a21SQ'}=-0.069;
    $statpot{'a21SE'}=-0.036;
    $statpot{'a21SG'}=-0.176;
    $statpot{'a21SH'}=-0.076;
    $statpot{'a21SI'}=-0.058;
    $statpot{'a21SL'}=-0.110;
    $statpot{'a21SK'}=-0.104;
    $statpot{'a21SM'}=-0.052;
    $statpot{'a21SF'}=-0.089;
    $statpot{'a21SP'}=-0.154;
    $statpot{'a21SS'}=-0.083;
    $statpot{'a21ST'}=-0.164;
    $statpot{'a21SW'}=-0.152;
    $statpot{'a21SY'}=-0.130;
    $statpot{'a21SV'}=-0.163;
    $statpot{'a21TA'}=-0.121;
    $statpot{'a21TR'}=-0.175;
    $statpot{'a21TN'}=-0.142;
    $statpot{'a21TD'}=-0.097;
    $statpot{'a21TC'}=-0.090;
    $statpot{'a21TQ'}=-0.050;
    $statpot{'a21TE'}=-0.111;
    $statpot{'a21TG'}=-0.055;
    $statpot{'a21TH'}=-0.114;
    $statpot{'a21TI'}=-0.073;
    $statpot{'a21TL'}=-0.005;
    $statpot{'a21TK'}=-0.082;
    $statpot{'a21TM'}=-0.059;
    $statpot{'a21TF'}=-0.008;
    $statpot{'a21TP'}=-0.101;
    $statpot{'a21TS'}=-0.140;
    $statpot{'a21TT'}=-0.193;
    $statpot{'a21TW'}=-0.126;
    $statpot{'a21TY'}=-0.101;
    $statpot{'a21TV'}=-0.039;
    $statpot{'a21WA'}=-0.002;
    $statpot{'a21WR'}=0.099;
    $statpot{'a21WN'}=-0.020;
    $statpot{'a21WD'}=0.089;
    $statpot{'a21WC'}=0.099;
    $statpot{'a21WQ'}=0.047;
    $statpot{'a21WE'}=0.003;
    $statpot{'a21WG'}=0.132;
    $statpot{'a21WH'}=0.214;
    $statpot{'a21WI'}=0.062;
    $statpot{'a21WL'}=0.003;
    $statpot{'a21WK'}=0.080;
    $statpot{'a21WM'}=0.123;
    $statpot{'a21WF'}=0.211;
    $statpot{'a21WP'}=-0.035;
    $statpot{'a21WS'}=-0.093;
    $statpot{'a21WT'}=-0.011;
    $statpot{'a21WW'}=0.034;
    $statpot{'a21WY'}=0.188;
    $statpot{'a21WV'}=0.228;
    $statpot{'a21YA'}=0.108;
    $statpot{'a21YR'}=0.004;
    $statpot{'a21YN'}=0.009;
    $statpot{'a21YD'}=0.086;
    $statpot{'a21YC'}=0.190;
    $statpot{'a21YQ'}=0.092;
    $statpot{'a21YE'}=0.120;
    $statpot{'a21YG'}=0.090;
    $statpot{'a21YH'}=0.078;
    $statpot{'a21YI'}=0.232;
    $statpot{'a21YL'}=0.212;
    $statpot{'a21YK'}=0.030;
    $statpot{'a21YM'}=0.156;
    $statpot{'a21YF'}=0.210;
    $statpot{'a21YP'}=0.035;
    $statpot{'a21YS'}=0.049;
    $statpot{'a21YT'}=0.034;
    $statpot{'a21YW'}=0.224;
    $statpot{'a21YY'}=0.210;
    $statpot{'a21YV'}=0.184;
    $statpot{'a21VA'}=0.056;
    $statpot{'a21VR'}=0.065;
    $statpot{'a21VN'}=0.070;
    $statpot{'a21VD'}=-0.027;
    $statpot{'a21VC'}=0.035;
    $statpot{'a21VQ'}=0.066;
    $statpot{'a21VE'}=0.025;
    $statpot{'a21VG'}=0.059;
    $statpot{'a21VH'}=0.004;
    $statpot{'a21VI'}=0.194;
    $statpot{'a21VL'}=0.192;
    $statpot{'a21VK'}=0.053;
    $statpot{'a21VM'}=0.096;
    $statpot{'a21VF'}=0.138;
    $statpot{'a21VP'}=-0.070;
    $statpot{'a21VS'}=-0.010;
    $statpot{'a21VT'}=0.071;
    $statpot{'a21VW'}=0.203;
    $statpot{'a21VY'}=0.142;
    $statpot{'a21VV'}=0.121;
    $statpot{'p22AA'}=-0.051;
    $statpot{'p22AR'}=-0.030;
    $statpot{'p22AN'}=0.020;
    $statpot{'p22AD'}=-0.004;
    $statpot{'p22AC'}=-0.099;
    $statpot{'p22AQ'}=-0.030;
    $statpot{'p22AE'}=0.052;
    $statpot{'p22AG'}=0.058;
    $statpot{'p22AH'}=-0.020;
    $statpot{'p22AI'}=-0.032;
    $statpot{'p22AL'}=0.006;
    $statpot{'p22AK'}=0.103;
    $statpot{'p22AM'}=-0.064;
    $statpot{'p22AF'}=-0.107;
    $statpot{'p22AP'}=-0.063;
    $statpot{'p22AS'}=-0.067;
    $statpot{'p22AT'}=-0.077;
    $statpot{'p22AW'}=-0.054;
    $statpot{'p22AY'}=-0.111;
    $statpot{'p22AV'}=-0.049;
    $statpot{'p22RA'}=-0.030;
    $statpot{'p22RR'}=0.049;
    $statpot{'p22RN'}=-0.037;
    $statpot{'p22RD'}=0.060;
    $statpot{'p22RC'}=-0.056;
    $statpot{'p22RQ'}=0.074;
    $statpot{'p22RE'}=0.067;
    $statpot{'p22RG'}=0.060;
    $statpot{'p22RH'}=-0.003;
    $statpot{'p22RI'}=-0.014;
    $statpot{'p22RL'}=-0.011;
    $statpot{'p22RK'}=0.087;
    $statpot{'p22RM'}=-0.093;
    $statpot{'p22RF'}=-0.063;
    $statpot{'p22RP'}=0.018;
    $statpot{'p22RS'}=-0.002;
    $statpot{'p22RT'}=-0.048;
    $statpot{'p22RW'}=0.033;
    $statpot{'p22RY'}=-0.036;
    $statpot{'p22RV'}=-0.004;
    $statpot{'p22NA'}=0.020;
    $statpot{'p22NR'}=-0.037;
    $statpot{'p22NN'}=0.158;
    $statpot{'p22ND'}=0.045;
    $statpot{'p22NC'}=0.082;
    $statpot{'p22NQ'}=0.028;
    $statpot{'p22NE'}=0.080;
    $statpot{'p22NG'}=0.060;
    $statpot{'p22NH'}=0.012;
    $statpot{'p22NI'}=-0.103;
    $statpot{'p22NL'}=-0.029;
    $statpot{'p22NK'}=0.077;
    $statpot{'p22NM'}=-0.107;
    $statpot{'p22NF'}=-0.083;
    $statpot{'p22NP'}=-0.018;
    $statpot{'p22NS'}=0.016;
    $statpot{'p22NT'}=-0.019;
    $statpot{'p22NW'}=-0.128;
    $statpot{'p22NY'}=-0.086;
    $statpot{'p22NV'}=-0.064;
    $statpot{'p22DA'}=-0.004;
    $statpot{'p22DR'}=0.060;
    $statpot{'p22DN'}=0.045;
    $statpot{'p22DD'}=0.049;
    $statpot{'p22DC'}=-0.026;
    $statpot{'p22DQ'}=0.066;
    $statpot{'p22DE'}=0.089;
    $statpot{'p22DG'}=0.098;
    $statpot{'p22DH'}=-0.044;
    $statpot{'p22DI'}=-0.021;
    $statpot{'p22DL'}=0.006;
    $statpot{'p22DK'}=0.118;
    $statpot{'p22DM'}=-0.039;
    $statpot{'p22DF'}=-0.030;
    $statpot{'p22DP'}=0.081;
    $statpot{'p22DS'}=0.036;
    $statpot{'p22DT'}=-0.010;
    $statpot{'p22DW'}=0.025;
    $statpot{'p22DY'}=0.003;
    $statpot{'p22DV'}=0.013;
    $statpot{'p22CA'}=-0.099;
    $statpot{'p22CR'}=-0.056;
    $statpot{'p22CN'}=0.082;
    $statpot{'p22CD'}=-0.026;
    $statpot{'p22CC'}=-0.065;
    $statpot{'p22CQ'}=-0.142;
    $statpot{'p22CE'}=0.029;
    $statpot{'p22CG'}=0.057;
    $statpot{'p22CH'}=-0.068;
    $statpot{'p22CI'}=-0.141;
    $statpot{'p22CL'}=-0.092;
    $statpot{'p22CK'}=-0.041;
    $statpot{'p22CM'}=0.215;
    $statpot{'p22CF'}=0.056;
    $statpot{'p22CP'}=-0.064;
    $statpot{'p22CS'}=-0.105;
    $statpot{'p22CT'}=0.051;
    $statpot{'p22CW'}=0.018;
    $statpot{'p22CY'}=-0.142;
    $statpot{'p22CV'}=-0.012;
    $statpot{'p22QA'}=-0.030;
    $statpot{'p22QR'}=0.074;
    $statpot{'p22QN'}=0.028;
    $statpot{'p22QD'}=0.066;
    $statpot{'p22QC'}=-0.142;
    $statpot{'p22QQ'}=-0.024;
    $statpot{'p22QE'}=0.099;
    $statpot{'p22QG'}=0.057;
    $statpot{'p22QH'}=-0.051;
    $statpot{'p22QI'}=-0.064;
    $statpot{'p22QL'}=-0.022;
    $statpot{'p22QK'}=0.123;
    $statpot{'p22QM'}=-0.095;
    $statpot{'p22QF'}=-0.066;
    $statpot{'p22QP'}=0.003;
    $statpot{'p22QS'}=0.063;
    $statpot{'p22QT'}=0.031;
    $statpot{'p22QW'}=-0.018;
    $statpot{'p22QY'}=-0.072;
    $statpot{'p22QV'}=-0.060;
    $statpot{'p22EA'}=0.052;
    $statpot{'p22ER'}=0.067;
    $statpot{'p22EN'}=0.080;
    $statpot{'p22ED'}=0.089;
    $statpot{'p22EC'}=0.029;
    $statpot{'p22EQ'}=0.099;
    $statpot{'p22EE'}=0.174;
    $statpot{'p22EG'}=0.120;
    $statpot{'p22EH'}=0.054;
    $statpot{'p22EI'}=0.112;
    $statpot{'p22EL'}=0.070;
    $statpot{'p22EK'}=0.139;
    $statpot{'p22EM'}=0.009;
    $statpot{'p22EF'}=0.009;
    $statpot{'p22EP'}=0.088;
    $statpot{'p22ES'}=0.062;
    $statpot{'p22ET'}=0.038;
    $statpot{'p22EW'}=0.024;
    $statpot{'p22EY'}=0.030;
    $statpot{'p22EV'}=0.028;
    $statpot{'p22GA'}=0.058;
    $statpot{'p22GR'}=0.060;
    $statpot{'p22GN'}=0.060;
    $statpot{'p22GD'}=0.098;
    $statpot{'p22GC'}=0.057;
    $statpot{'p22GQ'}=0.057;
    $statpot{'p22GE'}=0.120;
    $statpot{'p22GG'}=0.158;
    $statpot{'p22GH'}=0.038;
    $statpot{'p22GI'}=0.053;
    $statpot{'p22GL'}=0.050;
    $statpot{'p22GK'}=0.134;
    $statpot{'p22GM'}=-0.037;
    $statpot{'p22GF'}=0.017;
    $statpot{'p22GP'}=0.031;
    $statpot{'p22GS'}=0.087;
    $statpot{'p22GT'}=0.028;
    $statpot{'p22GW'}=0.074;
    $statpot{'p22GY'}=-0.044;
    $statpot{'p22GV'}=0.032;
    $statpot{'p22HA'}=-0.020;
    $statpot{'p22HR'}=-0.003;
    $statpot{'p22HN'}=0.012;
    $statpot{'p22HD'}=-0.044;
    $statpot{'p22HC'}=-0.068;
    $statpot{'p22HQ'}=-0.051;
    $statpot{'p22HE'}=0.054;
    $statpot{'p22HG'}=0.038;
    $statpot{'p22HH'}=0.104;
    $statpot{'p22HI'}=-0.022;
    $statpot{'p22HL'}=-0.104;
    $statpot{'p22HK'}=0.080;
    $statpot{'p22HM'}=-0.050;
    $statpot{'p22HF'}=-0.107;
    $statpot{'p22HP'}=0.003;
    $statpot{'p22HS'}=-0.070;
    $statpot{'p22HT'}=-0.047;
    $statpot{'p22HW'}=-0.008;
    $statpot{'p22HY'}=-0.054;
    $statpot{'p22HV'}=-0.140;
    $statpot{'p22IA'}=-0.032;
    $statpot{'p22IR'}=-0.014;
    $statpot{'p22IN'}=-0.103;
    $statpot{'p22ID'}=-0.021;
    $statpot{'p22IC'}=-0.141;
    $statpot{'p22IQ'}=-0.064;
    $statpot{'p22IE'}=0.112;
    $statpot{'p22IG'}=0.053;
    $statpot{'p22IH'}=-0.022;
    $statpot{'p22II'}=0.005;
    $statpot{'p22IL'}=-0.009;
    $statpot{'p22IK'}=0.061;
    $statpot{'p22IM'}=-0.082;
    $statpot{'p22IF'}=-0.018;
    $statpot{'p22IP'}=0.022;
    $statpot{'p22IS'}=-0.044;
    $statpot{'p22IT'}=-0.044;
    $statpot{'p22IW'}=-0.032;
    $statpot{'p22IY'}=-0.121;
    $statpot{'p22IV'}=-0.008;
    $statpot{'p22LA'}=0.006;
    $statpot{'p22LR'}=-0.011;
    $statpot{'p22LN'}=-0.029;
    $statpot{'p22LD'}=0.006;
    $statpot{'p22LC'}=-0.092;
    $statpot{'p22LQ'}=-0.022;
    $statpot{'p22LE'}=0.070;
    $statpot{'p22LG'}=0.050;
    $statpot{'p22LH'}=-0.104;
    $statpot{'p22LI'}=-0.009;
    $statpot{'p22LL'}=-0.015;
    $statpot{'p22LK'}=0.038;
    $statpot{'p22LM'}=-0.064;
    $statpot{'p22LF'}=0.003;
    $statpot{'p22LP'}=0.026;
    $statpot{'p22LS'}=-0.069;
    $statpot{'p22LT'}=-0.022;
    $statpot{'p22LW'}=-0.060;
    $statpot{'p22LY'}=-0.152;
    $statpot{'p22LV'}=-0.018;
    $statpot{'p22KA'}=0.103;
    $statpot{'p22KR'}=0.087;
    $statpot{'p22KN'}=0.077;
    $statpot{'p22KD'}=0.118;
    $statpot{'p22KC'}=-0.041;
    $statpot{'p22KQ'}=0.123;
    $statpot{'p22KE'}=0.139;
    $statpot{'p22KG'}=0.134;
    $statpot{'p22KH'}=0.080;
    $statpot{'p22KI'}=0.061;
    $statpot{'p22KL'}=0.038;
    $statpot{'p22KK'}=0.172;
    $statpot{'p22KM'}=-0.076;
    $statpot{'p22KF'}=-0.034;
    $statpot{'p22KP'}=0.045;
    $statpot{'p22KS'}=0.052;
    $statpot{'p22KT'}=0.026;
    $statpot{'p22KW'}=-0.043;
    $statpot{'p22KY'}=-0.011;
    $statpot{'p22KV'}=0.074;
    $statpot{'p22MA'}=-0.064;
    $statpot{'p22MR'}=-0.093;
    $statpot{'p22MN'}=-0.107;
    $statpot{'p22MD'}=-0.039;
    $statpot{'p22MC'}=0.215;
    $statpot{'p22MQ'}=-0.095;
    $statpot{'p22ME'}=0.009;
    $statpot{'p22MG'}=-0.037;
    $statpot{'p22MH'}=-0.050;
    $statpot{'p22MI'}=-0.082;
    $statpot{'p22ML'}=-0.064;
    $statpot{'p22MK'}=-0.076;
    $statpot{'p22MM'}=-0.003;
    $statpot{'p22MF'}=-0.071;
    $statpot{'p22MP'}=-0.033;
    $statpot{'p22MS'}=-0.061;
    $statpot{'p22MT'}=-0.071;
    $statpot{'p22MW'}=-0.122;
    $statpot{'p22MY'}=-0.108;
    $statpot{'p22MV'}=-0.113;
    $statpot{'p22FA'}=-0.107;
    $statpot{'p22FR'}=-0.063;
    $statpot{'p22FN'}=-0.083;
    $statpot{'p22FD'}=-0.030;
    $statpot{'p22FC'}=0.056;
    $statpot{'p22FQ'}=-0.066;
    $statpot{'p22FE'}=0.009;
    $statpot{'p22FG'}=0.017;
    $statpot{'p22FH'}=-0.107;
    $statpot{'p22FI'}=-0.018;
    $statpot{'p22FL'}=0.003;
    $statpot{'p22FK'}=-0.034;
    $statpot{'p22FM'}=-0.071;
    $statpot{'p22FF'}=-0.079;
    $statpot{'p22FP'}=-0.017;
    $statpot{'p22FS'}=-0.098;
    $statpot{'p22FT'}=-0.046;
    $statpot{'p22FW'}=-0.097;
    $statpot{'p22FY'}=-0.060;
    $statpot{'p22FV'}=-0.051;
    $statpot{'p22PA'}=-0.063;
    $statpot{'p22PR'}=0.018;
    $statpot{'p22PN'}=-0.018;
    $statpot{'p22PD'}=0.081;
    $statpot{'p22PC'}=-0.064;
    $statpot{'p22PQ'}=0.003;
    $statpot{'p22PE'}=0.088;
    $statpot{'p22PG'}=0.031;
    $statpot{'p22PH'}=0.003;
    $statpot{'p22PI'}=0.022;
    $statpot{'p22PL'}=0.026;
    $statpot{'p22PK'}=0.045;
    $statpot{'p22PM'}=-0.033;
    $statpot{'p22PF'}=-0.017;
    $statpot{'p22PP'}=0.124;
    $statpot{'p22PS'}=0.015;
    $statpot{'p22PT'}=-0.024;
    $statpot{'p22PW'}=0.074;
    $statpot{'p22PY'}=-0.083;
    $statpot{'p22PV'}=-0.037;
    $statpot{'p22SA'}=-0.067;
    $statpot{'p22SR'}=-0.002;
    $statpot{'p22SN'}=0.016;
    $statpot{'p22SD'}=0.036;
    $statpot{'p22SC'}=-0.105;
    $statpot{'p22SQ'}=0.063;
    $statpot{'p22SE'}=0.062;
    $statpot{'p22SG'}=0.087;
    $statpot{'p22SH'}=-0.070;
    $statpot{'p22SI'}=-0.044;
    $statpot{'p22SL'}=-0.069;
    $statpot{'p22SK'}=0.052;
    $statpot{'p22SM'}=-0.061;
    $statpot{'p22SF'}=-0.098;
    $statpot{'p22SP'}=0.015;
    $statpot{'p22SS'}=-0.082;
    $statpot{'p22ST'}=-0.025;
    $statpot{'p22SW'}=-0.060;
    $statpot{'p22SY'}=-0.127;
    $statpot{'p22SV'}=-0.073;
    $statpot{'p22TA'}=-0.077;
    $statpot{'p22TR'}=-0.048;
    $statpot{'p22TN'}=-0.019;
    $statpot{'p22TD'}=-0.010;
    $statpot{'p22TC'}=0.051;
    $statpot{'p22TQ'}=0.031;
    $statpot{'p22TE'}=0.038;
    $statpot{'p22TG'}=0.028;
    $statpot{'p22TH'}=-0.047;
    $statpot{'p22TI'}=-0.044;
    $statpot{'p22TL'}=-0.022;
    $statpot{'p22TK'}=0.026;
    $statpot{'p22TM'}=-0.071;
    $statpot{'p22TF'}=-0.046;
    $statpot{'p22TP'}=-0.024;
    $statpot{'p22TS'}=-0.025;
    $statpot{'p22TT'}=0.041;
    $statpot{'p22TW'}=-0.075;
    $statpot{'p22TY'}=-0.137;
    $statpot{'p22TV'}=0.001;
    $statpot{'p22WA'}=-0.054;
    $statpot{'p22WR'}=0.033;
    $statpot{'p22WN'}=-0.128;
    $statpot{'p22WD'}=0.025;
    $statpot{'p22WC'}=0.018;
    $statpot{'p22WQ'}=-0.018;
    $statpot{'p22WE'}=0.024;
    $statpot{'p22WG'}=0.074;
    $statpot{'p22WH'}=-0.008;
    $statpot{'p22WI'}=-0.032;
    $statpot{'p22WL'}=-0.060;
    $statpot{'p22WK'}=-0.043;
    $statpot{'p22WM'}=-0.122;
    $statpot{'p22WF'}=-0.097;
    $statpot{'p22WP'}=0.074;
    $statpot{'p22WS'}=-0.060;
    $statpot{'p22WT'}=-0.075;
    $statpot{'p22WW'}=-0.153;
    $statpot{'p22WY'}=-0.202;
    $statpot{'p22WV'}=-0.051;
    $statpot{'p22YA'}=-0.111;
    $statpot{'p22YR'}=-0.036;
    $statpot{'p22YN'}=-0.086;
    $statpot{'p22YD'}=0.003;
    $statpot{'p22YC'}=-0.142;
    $statpot{'p22YQ'}=-0.072;
    $statpot{'p22YE'}=0.030;
    $statpot{'p22YG'}=-0.044;
    $statpot{'p22YH'}=-0.054;
    $statpot{'p22YI'}=-0.121;
    $statpot{'p22YL'}=-0.152;
    $statpot{'p22YK'}=-0.011;
    $statpot{'p22YM'}=-0.108;
    $statpot{'p22YF'}=-0.060;
    $statpot{'p22YP'}=-0.083;
    $statpot{'p22YS'}=-0.127;
    $statpot{'p22YT'}=-0.137;
    $statpot{'p22YW'}=-0.202;
    $statpot{'p22YY'}=-0.090;
    $statpot{'p22YV'}=-0.161;
    $statpot{'p22VA'}=-0.049;
    $statpot{'p22VR'}=-0.004;
    $statpot{'p22VN'}=-0.064;
    $statpot{'p22VD'}=0.013;
    $statpot{'p22VC'}=-0.012;
    $statpot{'p22VQ'}=-0.060;
    $statpot{'p22VE'}=0.028;
    $statpot{'p22VG'}=0.032;
    $statpot{'p22VH'}=-0.140;
    $statpot{'p22VI'}=-0.008;
    $statpot{'p22VL'}=-0.018;
    $statpot{'p22VK'}=0.074;
    $statpot{'p22VM'}=-0.113;
    $statpot{'p22VF'}=-0.051;
    $statpot{'p22VP'}=-0.037;
    $statpot{'p22VS'}=-0.073;
    $statpot{'p22VT'}=0.001;
    $statpot{'p22VW'}=-0.051;
    $statpot{'p22VY'}=-0.161;
    $statpot{'p22VV'}=0.019;
    $statpot{'f22AA'}=-0.100;
    $statpot{'f22AR'}=0.097;
    $statpot{'f22AN'}=-0.103;
    $statpot{'f22AD'}=0.096;
    $statpot{'f22AC'}=-0.255;
    $statpot{'f22AQ'}=0.019;
    $statpot{'f22AE'}=0.208;
    $statpot{'f22AG'}=0.036;
    $statpot{'f22AH'}=-0.092;
    $statpot{'f22AI'}=-0.111;
    $statpot{'f22AL'}=-0.088;
    $statpot{'f22AK'}=0.085;
    $statpot{'f22AM'}=-0.169;
    $statpot{'f22AF'}=-0.161;
    $statpot{'f22AP'}=-0.064;
    $statpot{'f22AS'}=-0.001;
    $statpot{'f22AT'}=-0.056;
    $statpot{'f22AW'}=-0.179;
    $statpot{'f22AY'}=-0.205;
    $statpot{'f22AV'}=-0.119;
    $statpot{'f22RA'}=0.134;
    $statpot{'f22RR'}=0.161;
    $statpot{'f22RN'}=0.204;
    $statpot{'f22RD'}=0.227;
    $statpot{'f22RC'}=0.000;
    $statpot{'f22RQ'}=0.137;
    $statpot{'f22RE'}=0.363;
    $statpot{'f22RG'}=0.214;
    $statpot{'f22RH'}=0.039;
    $statpot{'f22RI'}=0.045;
    $statpot{'f22RL'}=0.005;
    $statpot{'f22RK'}=0.253;
    $statpot{'f22RM'}=-0.022;
    $statpot{'f22RF'}=-0.004;
    $statpot{'f22RP'}=0.298;
    $statpot{'f22RS'}=0.207;
    $statpot{'f22RT'}=0.186;
    $statpot{'f22RW'}=-0.014;
    $statpot{'f22RY'}=-0.050;
    $statpot{'f22RV'}=-0.003;
    $statpot{'f22NA'}=0.042;
    $statpot{'f22NR'}=0.170;
    $statpot{'f22NN'}=0.184;
    $statpot{'f22ND'}=0.280;
    $statpot{'f22NC'}=0.028;
    $statpot{'f22NQ'}=0.173;
    $statpot{'f22NE'}=0.366;
    $statpot{'f22NG'}=0.238;
    $statpot{'f22NH'}=0.083;
    $statpot{'f22NI'}=-0.012;
    $statpot{'f22NL'}=-0.068;
    $statpot{'f22NK'}=0.352;
    $statpot{'f22NM'}=-0.035;
    $statpot{'f22NF'}=-0.007;
    $statpot{'f22NP'}=0.293;
    $statpot{'f22NS'}=0.236;
    $statpot{'f22NT'}=0.115;
    $statpot{'f22NW'}=0.026;
    $statpot{'f22NY'}=0.081;
    $statpot{'f22NV'}=0.035;
    $statpot{'f22DA'}=0.253;
    $statpot{'f22DR'}=0.321;
    $statpot{'f22DN'}=0.337;
    $statpot{'f22DD'}=0.479;
    $statpot{'f22DC'}=0.079;
    $statpot{'f22DQ'}=0.264;
    $statpot{'f22DE'}=0.411;
    $statpot{'f22DG'}=0.337;
    $statpot{'f22DH'}=0.180;
    $statpot{'f22DI'}=0.075;
    $statpot{'f22DL'}=0.107;
    $statpot{'f22DK'}=0.589;
    $statpot{'f22DM'}=0.082;
    $statpot{'f22DF'}=0.018;
    $statpot{'f22DP'}=0.309;
    $statpot{'f22DS'}=0.259;
    $statpot{'f22DT'}=0.217;
    $statpot{'f22DW'}=0.217;
    $statpot{'f22DY'}=0.130;
    $statpot{'f22DV'}=0.177;
    $statpot{'f22CA'}=-0.292;
    $statpot{'f22CR'}=-0.189;
    $statpot{'f22CN'}=-0.233;
    $statpot{'f22CD'}=-0.067;
    $statpot{'f22CC'}=-0.502;
    $statpot{'f22CQ'}=-0.029;
    $statpot{'f22CE'}=-0.034;
    $statpot{'f22CG'}=-0.036;
    $statpot{'f22CH'}=-0.299;
    $statpot{'f22CI'}=-0.464;
    $statpot{'f22CL'}=-0.385;
    $statpot{'f22CK'}=-0.091;
    $statpot{'f22CM'}=-0.396;
    $statpot{'f22CF'}=-0.381;
    $statpot{'f22CP'}=-0.167;
    $statpot{'f22CS'}=-0.174;
    $statpot{'f22CT'}=-0.259;
    $statpot{'f22CW'}=-0.144;
    $statpot{'f22CY'}=-0.506;
    $statpot{'f22CV'}=-0.318;
    $statpot{'f22QA'}=0.108;
    $statpot{'f22QR'}=0.133;
    $statpot{'f22QN'}=0.131;
    $statpot{'f22QD'}=0.172;
    $statpot{'f22QC'}=0.055;
    $statpot{'f22QQ'}=0.158;
    $statpot{'f22QE'}=0.401;
    $statpot{'f22QG'}=0.172;
    $statpot{'f22QH'}=-0.019;
    $statpot{'f22QI'}=0.026;
    $statpot{'f22QL'}=-0.022;
    $statpot{'f22QK'}=0.306;
    $statpot{'f22QM'}=-0.150;
    $statpot{'f22QF'}=-0.055;
    $statpot{'f22QP'}=0.231;
    $statpot{'f22QS'}=0.089;
    $statpot{'f22QT'}=0.103;
    $statpot{'f22QW'}=-0.114;
    $statpot{'f22QY'}=-0.030;
    $statpot{'f22QV'}=0.004;
    $statpot{'f22EA'}=0.286;
    $statpot{'f22ER'}=0.443;
    $statpot{'f22EN'}=0.375;
    $statpot{'f22ED'}=0.440;
    $statpot{'f22EC'}=0.117;
    $statpot{'f22EQ'}=0.493;
    $statpot{'f22EE'}=0.523;
    $statpot{'f22EG'}=0.363;
    $statpot{'f22EH'}=0.195;
    $statpot{'f22EI'}=0.062;
    $statpot{'f22EL'}=0.215;
    $statpot{'f22EK'}=0.512;
    $statpot{'f22EM'}=0.136;
    $statpot{'f22EF'}=0.156;
    $statpot{'f22EP'}=0.463;
    $statpot{'f22ES'}=0.337;
    $statpot{'f22ET'}=0.312;
    $statpot{'f22EW'}=0.056;
    $statpot{'f22EY'}=0.205;
    $statpot{'f22EV'}=0.227;
    $statpot{'f22GA'}=0.084;
    $statpot{'f22GR'}=0.192;
    $statpot{'f22GN'}=0.160;
    $statpot{'f22GD'}=0.243;
    $statpot{'f22GC'}=0.037;
    $statpot{'f22GQ'}=0.170;
    $statpot{'f22GE'}=0.334;
    $statpot{'f22GG'}=0.271;
    $statpot{'f22GH'}=0.001;
    $statpot{'f22GI'}=0.022;
    $statpot{'f22GL'}=0.013;
    $statpot{'f22GK'}=0.296;
    $statpot{'f22GM'}=-0.088;
    $statpot{'f22GF'}=-0.042;
    $statpot{'f22GP'}=0.234;
    $statpot{'f22GS'}=0.187;
    $statpot{'f22GT'}=0.140;
    $statpot{'f22GW'}=0.042;
    $statpot{'f22GY'}=0.046;
    $statpot{'f22GV'}=0.072;
    $statpot{'f22HA'}=-0.082;
    $statpot{'f22HR'}=-0.017;
    $statpot{'f22HN'}=-0.031;
    $statpot{'f22HD'}=0.105;
    $statpot{'f22HC'}=-0.287;
    $statpot{'f22HQ'}=-0.125;
    $statpot{'f22HE'}=0.022;
    $statpot{'f22HG'}=-0.027;
    $statpot{'f22HH'}=-0.110;
    $statpot{'f22HI'}=-0.154;
    $statpot{'f22HL'}=-0.196;
    $statpot{'f22HK'}=0.182;
    $statpot{'f22HM'}=-0.314;
    $statpot{'f22HF'}=-0.188;
    $statpot{'f22HP'}=-0.013;
    $statpot{'f22HS'}=-0.171;
    $statpot{'f22HT'}=-0.111;
    $statpot{'f22HW'}=-0.241;
    $statpot{'f22HY'}=-0.223;
    $statpot{'f22HV'}=-0.072;
    $statpot{'f22IA'}=-0.187;
    $statpot{'f22IR'}=-0.169;
    $statpot{'f22IN'}=-0.199;
    $statpot{'f22ID'}=-0.126;
    $statpot{'f22IC'}=-0.528;
    $statpot{'f22IQ'}=-0.063;
    $statpot{'f22IE'}=-0.129;
    $statpot{'f22IG'}=-0.137;
    $statpot{'f22IH'}=-0.272;
    $statpot{'f22II'}=-0.236;
    $statpot{'f22IL'}=-0.303;
    $statpot{'f22IK'}=0.004;
    $statpot{'f22IM'}=-0.342;
    $statpot{'f22IF'}=-0.345;
    $statpot{'f22IP'}=-0.126;
    $statpot{'f22IS'}=-0.275;
    $statpot{'f22IT'}=-0.135;
    $statpot{'f22IW'}=-0.395;
    $statpot{'f22IY'}=-0.277;
    $statpot{'f22IV'}=-0.253;
    $statpot{'f22LA'}=-0.174;
    $statpot{'f22LR'}=-0.098;
    $statpot{'f22LN'}=-0.245;
    $statpot{'f22LD'}=-0.135;
    $statpot{'f22LC'}=-0.365;
    $statpot{'f22LQ'}=-0.179;
    $statpot{'f22LE'}=-0.012;
    $statpot{'f22LG'}=-0.126;
    $statpot{'f22LH'}=-0.208;
    $statpot{'f22LI'}=-0.287;
    $statpot{'f22LL'}=-0.183;
    $statpot{'f22LK'}=-0.016;
    $statpot{'f22LM'}=-0.284;
    $statpot{'f22LF'}=-0.295;
    $statpot{'f22LP'}=-0.181;
    $statpot{'f22LS'}=-0.199;
    $statpot{'f22LT'}=-0.255;
    $statpot{'f22LW'}=-0.321;
    $statpot{'f22LY'}=-0.231;
    $statpot{'f22LV'}=-0.175;
    $statpot{'f22KA'}=0.261;
    $statpot{'f22KR'}=0.370;
    $statpot{'f22KN'}=0.472;
    $statpot{'f22KD'}=0.585;
    $statpot{'f22KC'}=0.081;
    $statpot{'f22KQ'}=0.394;
    $statpot{'f22KE'}=0.569;
    $statpot{'f22KG'}=0.387;
    $statpot{'f22KH'}=0.365;
    $statpot{'f22KI'}=0.270;
    $statpot{'f22KL'}=0.215;
    $statpot{'f22KK'}=0.633;
    $statpot{'f22KM'}=0.232;
    $statpot{'f22KF'}=0.183;
    $statpot{'f22KP'}=0.450;
    $statpot{'f22KS'}=0.364;
    $statpot{'f22KT'}=0.389;
    $statpot{'f22KW'}=0.110;
    $statpot{'f22KY'}=0.181;
    $statpot{'f22KV'}=0.243;
    $statpot{'f22MA'}=-0.218;
    $statpot{'f22MR'}=-0.077;
    $statpot{'f22MN'}=-0.226;
    $statpot{'f22MD'}=-0.116;
    $statpot{'f22MC'}=-0.364;
    $statpot{'f22MQ'}=-0.243;
    $statpot{'f22ME'}=-0.104;
    $statpot{'f22MG'}=-0.223;
    $statpot{'f22MH'}=-0.362;
    $statpot{'f22MI'}=-0.331;
    $statpot{'f22ML'}=-0.233;
    $statpot{'f22MK'}=0.006;
    $statpot{'f22MM'}=-0.232;
    $statpot{'f22MF'}=-0.527;
    $statpot{'f22MP'}=-0.197;
    $statpot{'f22MS'}=-0.250;
    $statpot{'f22MT'}=-0.282;
    $statpot{'f22MW'}=-0.531;
    $statpot{'f22MY'}=-0.327;
    $statpot{'f22MV'}=-0.293;
    $statpot{'f22FA'}=-0.298;
    $statpot{'f22FR'}=-0.187;
    $statpot{'f22FN'}=-0.208;
    $statpot{'f22FD'}=-0.196;
    $statpot{'f22FC'}=-0.384;
    $statpot{'f22FQ'}=-0.241;
    $statpot{'f22FE'}=0.022;
    $statpot{'f22FG'}=-0.211;
    $statpot{'f22FH'}=-0.338;
    $statpot{'f22FI'}=-0.332;
    $statpot{'f22FL'}=-0.314;
    $statpot{'f22FK'}=-0.054;
    $statpot{'f22FM'}=-0.433;
    $statpot{'f22FF'}=-0.455;
    $statpot{'f22FP'}=-0.117;
    $statpot{'f22FS'}=-0.307;
    $statpot{'f22FT'}=-0.307;
    $statpot{'f22FW'}=-0.466;
    $statpot{'f22FY'}=-0.415;
    $statpot{'f22FV'}=-0.291;
    $statpot{'f22PA'}=0.043;
    $statpot{'f22PR'}=0.292;
    $statpot{'f22PN'}=0.280;
    $statpot{'f22PD'}=0.320;
    $statpot{'f22PC'}=-0.044;
    $statpot{'f22PQ'}=0.252;
    $statpot{'f22PE'}=0.366;
    $statpot{'f22PG'}=0.297;
    $statpot{'f22PH'}=0.078;
    $statpot{'f22PI'}=0.021;
    $statpot{'f22PL'}=0.028;
    $statpot{'f22PK'}=0.482;
    $statpot{'f22PM'}=0.076;
    $statpot{'f22PF'}=0.052;
    $statpot{'f22PP'}=0.398;
    $statpot{'f22PS'}=0.218;
    $statpot{'f22PT'}=0.232;
    $statpot{'f22PW'}=0.112;
    $statpot{'f22PY'}=0.046;
    $statpot{'f22PV'}=0.126;
    $statpot{'f22SA'}=0.018;
    $statpot{'f22SR'}=0.182;
    $statpot{'f22SN'}=0.154;
    $statpot{'f22SD'}=0.220;
    $statpot{'f22SC'}=-0.069;
    $statpot{'f22SQ'}=0.137;
    $statpot{'f22SE'}=0.262;
    $statpot{'f22SG'}=0.201;
    $statpot{'f22SH'}=-0.071;
    $statpot{'f22SI'}=-0.168;
    $statpot{'f22SL'}=-0.058;
    $statpot{'f22SK'}=0.347;
    $statpot{'f22SM'}=-0.093;
    $statpot{'f22SF'}=-0.163;
    $statpot{'f22SP'}=0.169;
    $statpot{'f22SS'}=0.127;
    $statpot{'f22ST'}=0.003;
    $statpot{'f22SW'}=-0.120;
    $statpot{'f22SY'}=-0.030;
    $statpot{'f22SV'}=-0.078;
    $statpot{'f22TA'}=0.032;
    $statpot{'f22TR'}=0.103;
    $statpot{'f22TN'}=0.101;
    $statpot{'f22TD'}=0.205;
    $statpot{'f22TC'}=-0.021;
    $statpot{'f22TQ'}=0.073;
    $statpot{'f22TE'}=0.257;
    $statpot{'f22TG'}=0.158;
    $statpot{'f22TH'}=-0.064;
    $statpot{'f22TI'}=0.010;
    $statpot{'f22TL'}=-0.088;
    $statpot{'f22TK'}=0.296;
    $statpot{'f22TM'}=-0.175;
    $statpot{'f22TF'}=-0.156;
    $statpot{'f22TP'}=0.142;
    $statpot{'f22TS'}=0.045;
    $statpot{'f22TT'}=0.038;
    $statpot{'f22TW'}=-0.021;
    $statpot{'f22TY'}=-0.061;
    $statpot{'f22TV'}=0.013;
    $statpot{'f22WA'}=-0.206;
    $statpot{'f22WR'}=-0.166;
    $statpot{'f22WN'}=-0.069;
    $statpot{'f22WD'}=0.033;
    $statpot{'f22WC'}=-0.318;
    $statpot{'f22WQ'}=-0.199;
    $statpot{'f22WE'}=-0.043;
    $statpot{'f22WG'}=-0.033;
    $statpot{'f22WH'}=-0.187;
    $statpot{'f22WI'}=-0.385;
    $statpot{'f22WL'}=-0.310;
    $statpot{'f22WK'}=0.027;
    $statpot{'f22WM'}=-0.667;
    $statpot{'f22WF'}=-0.430;
    $statpot{'f22WP'}=-0.134;
    $statpot{'f22WS'}=-0.299;
    $statpot{'f22WT'}=-0.230;
    $statpot{'f22WW'}=-0.420;
    $statpot{'f22WY'}=-0.390;
    $statpot{'f22WV'}=-0.305;
    $statpot{'f22YA'}=-0.281;
    $statpot{'f22YR'}=-0.154;
    $statpot{'f22YN'}=-0.155;
    $statpot{'f22YD'}=-0.096;
    $statpot{'f22YC'}=-0.522;
    $statpot{'f22YQ'}=-0.113;
    $statpot{'f22YE'}=0.046;
    $statpot{'f22YG'}=-0.171;
    $statpot{'f22YH'}=-0.146;
    $statpot{'f22YI'}=-0.228;
    $statpot{'f22YL'}=-0.229;
    $statpot{'f22YK'}=-0.009;
    $statpot{'f22YM'}=-0.313;
    $statpot{'f22YF'}=-0.403;
    $statpot{'f22YP'}=-0.138;
    $statpot{'f22YS'}=-0.180;
    $statpot{'f22YT'}=-0.253;
    $statpot{'f22YW'}=-0.343;
    $statpot{'f22YY'}=-0.322;
    $statpot{'f22YV'}=-0.273;
    $statpot{'f22VA'}=-0.119;
    $statpot{'f22VR'}=-0.093;
    $statpot{'f22VN'}=-0.100;
    $statpot{'f22VD'}=0.022;
    $statpot{'f22VC'}=-0.313;
    $statpot{'f22VQ'}=-0.180;
    $statpot{'f22VE'}=0.006;
    $statpot{'f22VG'}=-0.059;
    $statpot{'f22VH'}=-0.146;
    $statpot{'f22VI'}=-0.192;
    $statpot{'f22VL'}=-0.155;
    $statpot{'f22VK'}=0.029;
    $statpot{'f22VM'}=-0.288;
    $statpot{'f22VF'}=-0.300;
    $statpot{'f22VP'}=-0.071;
    $statpot{'f22VS'}=-0.171;
    $statpot{'f22VT'}=-0.141;
    $statpot{'f22VW'}=-0.264;
    $statpot{'f22VY'}=-0.255;
    $statpot{'f22VV'}=-0.101;
    $statpot{'a22AA'}=0.030;
    $statpot{'a22AR'}=-0.052;
    $statpot{'a22AN'}=-0.024;
    $statpot{'a22AD'}=-0.028;
    $statpot{'a22AC'}=-0.117;
    $statpot{'a22AQ'}=0.006;
    $statpot{'a22AE'}=0.017;
    $statpot{'a22AG'}=0.023;
    $statpot{'a22AH'}=-0.013;
    $statpot{'a22AI'}=0.045;
    $statpot{'a22AL'}=0.043;
    $statpot{'a22AK'}=0.010;
    $statpot{'a22AM'}=0.013;
    $statpot{'a22AF'}=-0.004;
    $statpot{'a22AP'}=-0.090;
    $statpot{'a22AS'}=-0.035;
    $statpot{'a22AT'}=0.041;
    $statpot{'a22AW'}=0.037;
    $statpot{'a22AY'}=-0.066;
    $statpot{'a22AV'}=0.060;
    $statpot{'a22RA'}=-0.083;
    $statpot{'a22RR'}=-0.212;
    $statpot{'a22RN'}=-0.172;
    $statpot{'a22RD'}=-0.104;
    $statpot{'a22RC'}=-0.196;
    $statpot{'a22RQ'}=-0.101;
    $statpot{'a22RE'}=0.004;
    $statpot{'a22RG'}=-0.070;
    $statpot{'a22RH'}=-0.164;
    $statpot{'a22RI'}=-0.126;
    $statpot{'a22RL'}=0.032;
    $statpot{'a22RK'}=-0.104;
    $statpot{'a22RM'}=-0.075;
    $statpot{'a22RF'}=-0.073;
    $statpot{'a22RP'}=-0.054;
    $statpot{'a22RS'}=-0.100;
    $statpot{'a22RT'}=-0.173;
    $statpot{'a22RW'}=-0.069;
    $statpot{'a22RY'}=-0.098;
    $statpot{'a22RV'}=-0.053;
    $statpot{'a22NA'}=-0.153;
    $statpot{'a22NR'}=-0.149;
    $statpot{'a22NN'}=-0.179;
    $statpot{'a22ND'}=-0.055;
    $statpot{'a22NC'}=-0.155;
    $statpot{'a22NQ'}=-0.125;
    $statpot{'a22NE'}=-0.125;
    $statpot{'a22NG'}=-0.076;
    $statpot{'a22NH'}=-0.177;
    $statpot{'a22NI'}=-0.089;
    $statpot{'a22NL'}=-0.060;
    $statpot{'a22NK'}=-0.081;
    $statpot{'a22NM'}=-0.187;
    $statpot{'a22NF'}=-0.101;
    $statpot{'a22NP'}=-0.173;
    $statpot{'a22NS'}=-0.173;
    $statpot{'a22NT'}=-0.103;
    $statpot{'a22NW'}=0.008;
    $statpot{'a22NY'}=-0.090;
    $statpot{'a22NV'}=-0.085;
    $statpot{'a22DA'}=-0.145;
    $statpot{'a22DR'}=-0.163;
    $statpot{'a22DN'}=-0.090;
    $statpot{'a22DD'}=-0.060;
    $statpot{'a22DC'}=-0.148;
    $statpot{'a22DQ'}=-0.127;
    $statpot{'a22DE'}=-0.072;
    $statpot{'a22DG'}=-0.131;
    $statpot{'a22DH'}=-0.152;
    $statpot{'a22DI'}=-0.107;
    $statpot{'a22DL'}=-0.105;
    $statpot{'a22DK'}=-0.016;
    $statpot{'a22DM'}=-0.180;
    $statpot{'a22DF'}=-0.210;
    $statpot{'a22DP'}=-0.142;
    $statpot{'a22DS'}=-0.122;
    $statpot{'a22DT'}=-0.153;
    $statpot{'a22DW'}=-0.120;
    $statpot{'a22DY'}=-0.145;
    $statpot{'a22DV'}=-0.129;
    $statpot{'a22CA'}=-0.076;
    $statpot{'a22CR'}=-0.027;
    $statpot{'a22CN'}=0.090;
    $statpot{'a22CD'}=-0.029;
    $statpot{'a22CC'}=0.237;
    $statpot{'a22CQ'}=0.130;
    $statpot{'a22CE'}=0.061;
    $statpot{'a22CG'}=0.018;
    $statpot{'a22CH'}=0.016;
    $statpot{'a22CI'}=0.023;
    $statpot{'a22CL'}=0.156;
    $statpot{'a22CK'}=0.022;
    $statpot{'a22CM'}=0.136;
    $statpot{'a22CF'}=0.140;
    $statpot{'a22CP'}=-0.136;
    $statpot{'a22CS'}=0.065;
    $statpot{'a22CT'}=0.266;
    $statpot{'a22CW'}=0.019;
    $statpot{'a22CY'}=0.184;
    $statpot{'a22CV'}=0.083;
    $statpot{'a22QA'}=-0.072;
    $statpot{'a22QR'}=-0.099;
    $statpot{'a22QN'}=-0.096;
    $statpot{'a22QD'}=-0.065;
    $statpot{'a22QC'}=0.050;
    $statpot{'a22QQ'}=0.039;
    $statpot{'a22QE'}=-0.022;
    $statpot{'a22QG'}=-0.016;
    $statpot{'a22QH'}=-0.206;
    $statpot{'a22QI'}=0.018;
    $statpot{'a22QL'}=-0.013;
    $statpot{'a22QK'}=-0.020;
    $statpot{'a22QM'}=-0.018;
    $statpot{'a22QF'}=-0.038;
    $statpot{'a22QP'}=-0.038;
    $statpot{'a22QS'}=-0.113;
    $statpot{'a22QT'}=-0.105;
    $statpot{'a22QW'}=-0.067;
    $statpot{'a22QY'}=-0.082;
    $statpot{'a22QV'}=-0.094;
    $statpot{'a22EA'}=-0.043;
    $statpot{'a22ER'}=-0.046;
    $statpot{'a22EN'}=-0.131;
    $statpot{'a22ED'}=-0.089;
    $statpot{'a22EC'}=-0.073;
    $statpot{'a22EQ'}=-0.075;
    $statpot{'a22EE'}=-0.003;
    $statpot{'a22EG'}=-0.045;
    $statpot{'a22EH'}=-0.142;
    $statpot{'a22EI'}=-0.114;
    $statpot{'a22EL'}=-0.038;
    $statpot{'a22EK'}=-0.041;
    $statpot{'a22EM'}=-0.203;
    $statpot{'a22EF'}=-0.117;
    $statpot{'a22EP'}=-0.133;
    $statpot{'a22ES'}=-0.192;
    $statpot{'a22ET'}=-0.121;
    $statpot{'a22EW'}=-0.082;
    $statpot{'a22EY'}=-0.067;
    $statpot{'a22EV'}=-0.196;
    $statpot{'a22GA'}=-0.021;
    $statpot{'a22GR'}=-0.053;
    $statpot{'a22GN'}=-0.019;
    $statpot{'a22GD'}=-0.070;
    $statpot{'a22GC'}=-0.047;
    $statpot{'a22GQ'}=-0.014;
    $statpot{'a22GE'}=-0.024;
    $statpot{'a22GG'}=0.002;
    $statpot{'a22GH'}=-0.064;
    $statpot{'a22GI'}=-0.058;
    $statpot{'a22GL'}=-0.006;
    $statpot{'a22GK'}=0.068;
    $statpot{'a22GM'}=-0.077;
    $statpot{'a22GF'}=-0.060;
    $statpot{'a22GP'}=-0.110;
    $statpot{'a22GS'}=-0.071;
    $statpot{'a22GT'}=-0.015;
    $statpot{'a22GW'}=0.066;
    $statpot{'a22GY'}=-0.084;
    $statpot{'a22GV'}=-0.081;
    $statpot{'a22HA'}=-0.023;
    $statpot{'a22HR'}=-0.118;
    $statpot{'a22HN'}=-0.088;
    $statpot{'a22HD'}=-0.098;
    $statpot{'a22HC'}=0.001;
    $statpot{'a22HQ'}=-0.116;
    $statpot{'a22HE'}=-0.005;
    $statpot{'a22HG'}=-0.038;
    $statpot{'a22HH'}=-0.080;
    $statpot{'a22HI'}=0.056;
    $statpot{'a22HL'}=0.085;
    $statpot{'a22HK'}=-0.046;
    $statpot{'a22HM'}=0.021;
    $statpot{'a22HF'}=-0.068;
    $statpot{'a22HP'}=-0.142;
    $statpot{'a22HS'}=0.016;
    $statpot{'a22HT'}=0.020;
    $statpot{'a22HW'}=0.256;
    $statpot{'a22HY'}=0.192;
    $statpot{'a22HV'}=-0.069;
    $statpot{'a22IA'}=0.139;
    $statpot{'a22IR'}=0.090;
    $statpot{'a22IN'}=0.105;
    $statpot{'a22ID'}=0.086;
    $statpot{'a22IC'}=0.125;
    $statpot{'a22IQ'}=0.109;
    $statpot{'a22IE'}=0.073;
    $statpot{'a22IG'}=0.106;
    $statpot{'a22IH'}=0.213;
    $statpot{'a22II'}=0.356;
    $statpot{'a22IL'}=0.307;
    $statpot{'a22IK'}=0.082;
    $statpot{'a22IM'}=0.215;
    $statpot{'a22IF'}=0.242;
    $statpot{'a22IP'}=0.018;
    $statpot{'a22IS'}=0.099;
    $statpot{'a22IT'}=0.158;
    $statpot{'a22IW'}=0.354;
    $statpot{'a22IY'}=0.203;
    $statpot{'a22IV'}=0.247;
    $statpot{'a22LA'}=0.150;
    $statpot{'a22LR'}=0.145;
    $statpot{'a22LN'}=0.139;
    $statpot{'a22LD'}=0.130;
    $statpot{'a22LC'}=0.126;
    $statpot{'a22LQ'}=0.163;
    $statpot{'a22LE'}=0.173;
    $statpot{'a22LG'}=0.145;
    $statpot{'a22LH'}=0.101;
    $statpot{'a22LI'}=0.279;
    $statpot{'a22LL'}=0.264;
    $statpot{'a22LK'}=0.190;
    $statpot{'a22LM'}=0.275;
    $statpot{'a22LF'}=0.270;
    $statpot{'a22LP'}=0.035;
    $statpot{'a22LS'}=0.124;
    $statpot{'a22LT'}=0.173;
    $statpot{'a22LW'}=0.137;
    $statpot{'a22LY'}=0.296;
    $statpot{'a22LV'}=0.208;
    $statpot{'a22KA'}=-0.125;
    $statpot{'a22KR'}=-0.175;
    $statpot{'a22KN'}=-0.146;
    $statpot{'a22KD'}=-0.014;
    $statpot{'a22KC'}=-0.126;
    $statpot{'a22KQ'}=-0.074;
    $statpot{'a22KE'}=-0.071;
    $statpot{'a22KG'}=0.004;
    $statpot{'a22KH'}=-0.162;
    $statpot{'a22KI'}=-0.132;
    $statpot{'a22KL'}=-0.024;
    $statpot{'a22KK'}=-0.022;
    $statpot{'a22KM'}=-0.203;
    $statpot{'a22KF'}=-0.126;
    $statpot{'a22KP'}=-0.068;
    $statpot{'a22KS'}=-0.106;
    $statpot{'a22KT'}=-0.090;
    $statpot{'a22KW'}=-0.135;
    $statpot{'a22KY'}=-0.066;
    $statpot{'a22KV'}=-0.146;
    $statpot{'a22MA'}=0.075;
    $statpot{'a22MR'}=-0.021;
    $statpot{'a22MN'}=0.001;
    $statpot{'a22MD'}=-0.004;
    $statpot{'a22MC'}=0.085;
    $statpot{'a22MQ'}=0.095;
    $statpot{'a22ME'}=0.006;
    $statpot{'a22MG'}=0.076;
    $statpot{'a22MH'}=0.089;
    $statpot{'a22MI'}=0.196;
    $statpot{'a22ML'}=0.192;
    $statpot{'a22MK'}=-0.032;
    $statpot{'a22MM'}=0.270;
    $statpot{'a22MF'}=0.239;
    $statpot{'a22MP'}=-0.090;
    $statpot{'a22MS'}=0.118;
    $statpot{'a22MT'}=0.050;
    $statpot{'a22MW'}=0.037;
    $statpot{'a22MY'}=0.057;
    $statpot{'a22MV'}=0.146;
    $statpot{'a22FA'}=0.178;
    $statpot{'a22FR'}=0.123;
    $statpot{'a22FN'}=0.107;
    $statpot{'a22FD'}=-0.013;
    $statpot{'a22FC'}=0.143;
    $statpot{'a22FQ'}=0.176;
    $statpot{'a22FE'}=-0.007;
    $statpot{'a22FG'}=0.128;
    $statpot{'a22FH'}=0.120;
    $statpot{'a22FI'}=0.220;
    $statpot{'a22FL'}=0.304;
    $statpot{'a22FK'}=0.076;
    $statpot{'a22FM'}=0.065;
    $statpot{'a22FF'}=0.406;
    $statpot{'a22FP'}=-0.013;
    $statpot{'a22FS'}=0.077;
    $statpot{'a22FT'}=0.074;
    $statpot{'a22FW'}=0.284;
    $statpot{'a22FY'}=0.206;
    $statpot{'a22FV'}=0.188;
    $statpot{'a22PA'}=-0.184;
    $statpot{'a22PR'}=-0.049;
    $statpot{'a22PN'}=-0.166;
    $statpot{'a22PD'}=-0.149;
    $statpot{'a22PC'}=-0.239;
    $statpot{'a22PQ'}=-0.052;
    $statpot{'a22PE'}=-0.077;
    $statpot{'a22PG'}=-0.152;
    $statpot{'a22PH'}=-0.213;
    $statpot{'a22PI'}=-0.124;
    $statpot{'a22PL'}=-0.168;
    $statpot{'a22PK'}=-0.085;
    $statpot{'a22PM'}=-0.321;
    $statpot{'a22PF'}=-0.165;
    $statpot{'a22PP'}=-0.077;
    $statpot{'a22PS'}=-0.172;
    $statpot{'a22PT'}=-0.205;
    $statpot{'a22PW'}=-0.166;
    $statpot{'a22PY'}=-0.195;
    $statpot{'a22PV'}=-0.141;
    $statpot{'a22SA'}=-0.052;
    $statpot{'a22SR'}=-0.083;
    $statpot{'a22SN'}=-0.120;
    $statpot{'a22SD'}=-0.096;
    $statpot{'a22SC'}=-0.041;
    $statpot{'a22SQ'}=-0.147;
    $statpot{'a22SE'}=-0.147;
    $statpot{'a22SG'}=-0.081;
    $statpot{'a22SH'}=-0.086;
    $statpot{'a22SI'}=-0.031;
    $statpot{'a22SL'}=-0.034;
    $statpot{'a22SK'}=-0.096;
    $statpot{'a22SM'}=-0.065;
    $statpot{'a22SF'}=-0.090;
    $statpot{'a22SP'}=-0.139;
    $statpot{'a22SS'}=-0.100;
    $statpot{'a22ST'}=-0.134;
    $statpot{'a22SW'}=-0.168;
    $statpot{'a22SY'}=-0.110;
    $statpot{'a22SV'}=-0.127;
    $statpot{'a22TA'}=-0.044;
    $statpot{'a22TR'}=-0.115;
    $statpot{'a22TN'}=-0.093;
    $statpot{'a22TD'}=-0.146;
    $statpot{'a22TC'}=-0.009;
    $statpot{'a22TQ'}=-0.082;
    $statpot{'a22TE'}=-0.086;
    $statpot{'a22TG'}=-0.030;
    $statpot{'a22TH'}=-0.027;
    $statpot{'a22TI'}=-0.000;
    $statpot{'a22TL'}=-0.027;
    $statpot{'a22TK'}=-0.032;
    $statpot{'a22TM'}=-0.077;
    $statpot{'a22TF'}=-0.100;
    $statpot{'a22TP'}=-0.145;
    $statpot{'a22TS'}=-0.167;
    $statpot{'a22TT'}=-0.178;
    $statpot{'a22TW'}=-0.141;
    $statpot{'a22TY'}=-0.145;
    $statpot{'a22TV'}=-0.025;
    $statpot{'a22WA'}=0.069;
    $statpot{'a22WR'}=0.087;
    $statpot{'a22WN'}=0.100;
    $statpot{'a22WD'}=0.023;
    $statpot{'a22WC'}=0.228;
    $statpot{'a22WQ'}=0.021;
    $statpot{'a22WE'}=0.007;
    $statpot{'a22WG'}=0.141;
    $statpot{'a22WH'}=0.181;
    $statpot{'a22WI'}=0.332;
    $statpot{'a22WL'}=0.119;
    $statpot{'a22WK'}=-0.071;
    $statpot{'a22WM'}=0.315;
    $statpot{'a22WF'}=0.219;
    $statpot{'a22WP'}=0.054;
    $statpot{'a22WS'}=0.016;
    $statpot{'a22WT'}=0.063;
    $statpot{'a22WW'}=0.097;
    $statpot{'a22WY'}=0.221;
    $statpot{'a22WV'}=0.331;
    $statpot{'a22YA'}=0.026;
    $statpot{'a22YR'}=0.006;
    $statpot{'a22YN'}=0.142;
    $statpot{'a22YD'}=0.054;
    $statpot{'a22YC'}=0.212;
    $statpot{'a22YQ'}=-0.002;
    $statpot{'a22YE'}=0.068;
    $statpot{'a22YG'}=0.140;
    $statpot{'a22YH'}=0.093;
    $statpot{'a22YI'}=0.132;
    $statpot{'a22YL'}=0.293;
    $statpot{'a22YK'}=0.102;
    $statpot{'a22YM'}=0.039;
    $statpot{'a22YF'}=0.185;
    $statpot{'a22YP'}=-0.030;
    $statpot{'a22YS'}=0.038;
    $statpot{'a22YT'}=0.054;
    $statpot{'a22YW'}=0.146;
    $statpot{'a22YY'}=0.162;
    $statpot{'a22YV'}=0.144;
    $statpot{'a22VA'}=0.060;
    $statpot{'a22VR'}=0.037;
    $statpot{'a22VN'}=0.042;
    $statpot{'a22VD'}=-0.005;
    $statpot{'a22VC'}=0.076;
    $statpot{'a22VQ'}=0.096;
    $statpot{'a22VE'}=-0.025;
    $statpot{'a22VG'}=0.040;
    $statpot{'a22VH'}=0.006;
    $statpot{'a22VI'}=0.158;
    $statpot{'a22VL'}=0.181;
    $statpot{'a22VK'}=0.020;
    $statpot{'a22VM'}=0.139;
    $statpot{'a22VF'}=0.202;
    $statpot{'a22VP'}=0.034;
    $statpot{'a22VS'}=-0.036;
    $statpot{'a22VT'}=0.138;
    $statpot{'a22VW'}=0.264;
    $statpot{'a22VY'}=0.119;
    $statpot{'a22VV'}=0.170;
    $statpot{'p23AA'}=-0.010;
    $statpot{'p23AR'}=0.004;
    $statpot{'p23AN'}=-0.024;
    $statpot{'p23AD'}=-0.004;
    $statpot{'p23AC'}=-0.134;
    $statpot{'p23AQ'}=-0.014;
    $statpot{'p23AE'}=0.037;
    $statpot{'p23AG'}=0.056;
    $statpot{'p23AH'}=-0.023;
    $statpot{'p23AI'}=-0.043;
    $statpot{'p23AL'}=-0.033;
    $statpot{'p23AK'}=0.059;
    $statpot{'p23AM'}=-0.131;
    $statpot{'p23AF'}=-0.058;
    $statpot{'p23AP'}=-0.042;
    $statpot{'p23AS'}=-0.071;
    $statpot{'p23AT'}=-0.035;
    $statpot{'p23AW'}=-0.179;
    $statpot{'p23AY'}=-0.077;
    $statpot{'p23AV'}=-0.042;
    $statpot{'p23RA'}=0.004;
    $statpot{'p23RR'}=0.041;
    $statpot{'p23RN'}=-0.041;
    $statpot{'p23RD'}=0.044;
    $statpot{'p23RC'}=-0.067;
    $statpot{'p23RQ'}=-0.017;
    $statpot{'p23RE'}=0.078;
    $statpot{'p23RG'}=0.038;
    $statpot{'p23RH'}=-0.015;
    $statpot{'p23RI'}=-0.035;
    $statpot{'p23RL'}=-0.019;
    $statpot{'p23RK'}=0.114;
    $statpot{'p23RM'}=-0.018;
    $statpot{'p23RF'}=-0.083;
    $statpot{'p23RP'}=0.026;
    $statpot{'p23RS'}=0.014;
    $statpot{'p23RT'}=-0.033;
    $statpot{'p23RW'}=0.032;
    $statpot{'p23RY'}=-0.056;
    $statpot{'p23RV'}=-0.023;
    $statpot{'p23NA'}=-0.024;
    $statpot{'p23NR'}=-0.041;
    $statpot{'p23NN'}=0.062;
    $statpot{'p23ND'}=0.026;
    $statpot{'p23NC'}=0.125;
    $statpot{'p23NQ'}=0.035;
    $statpot{'p23NE'}=0.125;
    $statpot{'p23NG'}=0.066;
    $statpot{'p23NH'}=0.066;
    $statpot{'p23NI'}=-0.040;
    $statpot{'p23NL'}=-0.038;
    $statpot{'p23NK'}=0.048;
    $statpot{'p23NM'}=-0.085;
    $statpot{'p23NF'}=-0.087;
    $statpot{'p23NP'}=0.028;
    $statpot{'p23NS'}=-0.022;
    $statpot{'p23NT'}=-0.002;
    $statpot{'p23NW'}=-0.092;
    $statpot{'p23NY'}=-0.072;
    $statpot{'p23NV'}=-0.037;
    $statpot{'p23DA'}=-0.004;
    $statpot{'p23DR'}=0.044;
    $statpot{'p23DN'}=0.026;
    $statpot{'p23DD'}=0.077;
    $statpot{'p23DC'}=-0.011;
    $statpot{'p23DQ'}=0.050;
    $statpot{'p23DE'}=0.134;
    $statpot{'p23DG'}=0.129;
    $statpot{'p23DH'}=0.049;
    $statpot{'p23DI'}=0.081;
    $statpot{'p23DL'}=-0.005;
    $statpot{'p23DK'}=0.108;
    $statpot{'p23DM'}=-0.038;
    $statpot{'p23DF'}=0.005;
    $statpot{'p23DP'}=0.018;
    $statpot{'p23DS'}=-0.036;
    $statpot{'p23DT'}=-0.009;
    $statpot{'p23DW'}=0.042;
    $statpot{'p23DY'}=0.046;
    $statpot{'p23DV'}=-0.028;
    $statpot{'p23CA'}=-0.134;
    $statpot{'p23CR'}=-0.067;
    $statpot{'p23CN'}=0.125;
    $statpot{'p23CD'}=-0.011;
    $statpot{'p23CC'}=0.225;
    $statpot{'p23CQ'}=-0.001;
    $statpot{'p23CE'}=-0.073;
    $statpot{'p23CG'}=0.037;
    $statpot{'p23CH'}=-0.190;
    $statpot{'p23CI'}=-0.156;
    $statpot{'p23CL'}=-0.040;
    $statpot{'p23CK'}=0.064;
    $statpot{'p23CM'}=-0.096;
    $statpot{'p23CF'}=-0.070;
    $statpot{'p23CP'}=-0.105;
    $statpot{'p23CS'}=-0.023;
    $statpot{'p23CT'}=-0.081;
    $statpot{'p23CW'}=0.086;
    $statpot{'p23CY'}=-0.046;
    $statpot{'p23CV'}=0.013;
    $statpot{'p23QA'}=-0.014;
    $statpot{'p23QR'}=-0.017;
    $statpot{'p23QN'}=0.035;
    $statpot{'p23QD'}=0.050;
    $statpot{'p23QC'}=-0.001;
    $statpot{'p23QQ'}=0.020;
    $statpot{'p23QE'}=0.147;
    $statpot{'p23QG'}=0.094;
    $statpot{'p23QH'}=0.035;
    $statpot{'p23QI'}=0.033;
    $statpot{'p23QL'}=-0.024;
    $statpot{'p23QK'}=0.076;
    $statpot{'p23QM'}=-0.098;
    $statpot{'p23QF'}=-0.046;
    $statpot{'p23QP'}=-0.000;
    $statpot{'p23QS'}=-0.021;
    $statpot{'p23QT'}=-0.073;
    $statpot{'p23QW'}=-0.077;
    $statpot{'p23QY'}=-0.073;
    $statpot{'p23QV'}=-0.024;
    $statpot{'p23EA'}=0.037;
    $statpot{'p23ER'}=0.078;
    $statpot{'p23EN'}=0.125;
    $statpot{'p23ED'}=0.134;
    $statpot{'p23EC'}=-0.073;
    $statpot{'p23EQ'}=0.147;
    $statpot{'p23EE'}=0.144;
    $statpot{'p23EG'}=0.122;
    $statpot{'p23EH'}=0.041;
    $statpot{'p23EI'}=0.053;
    $statpot{'p23EL'}=0.046;
    $statpot{'p23EK'}=0.168;
    $statpot{'p23EM'}=-0.058;
    $statpot{'p23EF'}=0.018;
    $statpot{'p23EP'}=0.039;
    $statpot{'p23ES'}=0.021;
    $statpot{'p23ET'}=0.023;
    $statpot{'p23EW'}=-0.024;
    $statpot{'p23EY'}=0.048;
    $statpot{'p23EV'}=0.063;
    $statpot{'p23GA'}=0.056;
    $statpot{'p23GR'}=0.038;
    $statpot{'p23GN'}=0.066;
    $statpot{'p23GD'}=0.129;
    $statpot{'p23GC'}=0.037;
    $statpot{'p23GQ'}=0.094;
    $statpot{'p23GE'}=0.122;
    $statpot{'p23GG'}=0.130;
    $statpot{'p23GH'}=-0.030;
    $statpot{'p23GI'}=0.028;
    $statpot{'p23GL'}=0.074;
    $statpot{'p23GK'}=0.095;
    $statpot{'p23GM'}=0.045;
    $statpot{'p23GF'}=0.022;
    $statpot{'p23GP'}=0.075;
    $statpot{'p23GS'}=0.020;
    $statpot{'p23GT'}=0.056;
    $statpot{'p23GW'}=0.028;
    $statpot{'p23GY'}=0.048;
    $statpot{'p23GV'}=0.040;
    $statpot{'p23HA'}=-0.023;
    $statpot{'p23HR'}=-0.015;
    $statpot{'p23HN'}=0.066;
    $statpot{'p23HD'}=0.049;
    $statpot{'p23HC'}=-0.190;
    $statpot{'p23HQ'}=0.035;
    $statpot{'p23HE'}=0.041;
    $statpot{'p23HG'}=-0.030;
    $statpot{'p23HH'}=-0.048;
    $statpot{'p23HI'}=-0.100;
    $statpot{'p23HL'}=-0.069;
    $statpot{'p23HK'}=0.061;
    $statpot{'p23HM'}=-0.090;
    $statpot{'p23HF'}=-0.158;
    $statpot{'p23HP'}=-0.035;
    $statpot{'p23HS'}=-0.046;
    $statpot{'p23HT'}=-0.061;
    $statpot{'p23HW'}=-0.017;
    $statpot{'p23HY'}=-0.069;
    $statpot{'p23HV'}=-0.095;
    $statpot{'p23IA'}=-0.043;
    $statpot{'p23IR'}=-0.035;
    $statpot{'p23IN'}=-0.040;
    $statpot{'p23ID'}=0.081;
    $statpot{'p23IC'}=-0.156;
    $statpot{'p23IQ'}=0.033;
    $statpot{'p23IE'}=0.053;
    $statpot{'p23IG'}=0.028;
    $statpot{'p23IH'}=-0.100;
    $statpot{'p23II'}=0.009;
    $statpot{'p23IL'}=-0.019;
    $statpot{'p23IK'}=0.061;
    $statpot{'p23IM'}=-0.058;
    $statpot{'p23IF'}=-0.026;
    $statpot{'p23IP'}=-0.037;
    $statpot{'p23IS'}=-0.096;
    $statpot{'p23IT'}=-0.051;
    $statpot{'p23IW'}=-0.112;
    $statpot{'p23IY'}=-0.075;
    $statpot{'p23IV'}=-0.003;
    $statpot{'p23LA'}=-0.033;
    $statpot{'p23LR'}=-0.019;
    $statpot{'p23LN'}=-0.038;
    $statpot{'p23LD'}=-0.005;
    $statpot{'p23LC'}=-0.040;
    $statpot{'p23LQ'}=-0.024;
    $statpot{'p23LE'}=0.046;
    $statpot{'p23LG'}=0.074;
    $statpot{'p23LH'}=-0.069;
    $statpot{'p23LI'}=-0.019;
    $statpot{'p23LL'}=0.038;
    $statpot{'p23LK'}=0.056;
    $statpot{'p23LM'}=-0.024;
    $statpot{'p23LF'}=0.003;
    $statpot{'p23LP'}=0.024;
    $statpot{'p23LS'}=-0.039;
    $statpot{'p23LT'}=-0.042;
    $statpot{'p23LW'}=-0.078;
    $statpot{'p23LY'}=-0.155;
    $statpot{'p23LV'}=-0.003;
    $statpot{'p23KA'}=0.059;
    $statpot{'p23KR'}=0.114;
    $statpot{'p23KN'}=0.048;
    $statpot{'p23KD'}=0.108;
    $statpot{'p23KC'}=0.064;
    $statpot{'p23KQ'}=0.076;
    $statpot{'p23KE'}=0.168;
    $statpot{'p23KG'}=0.095;
    $statpot{'p23KH'}=0.061;
    $statpot{'p23KI'}=0.061;
    $statpot{'p23KL'}=0.056;
    $statpot{'p23KK'}=0.143;
    $statpot{'p23KM'}=-0.013;
    $statpot{'p23KF'}=0.031;
    $statpot{'p23KP'}=0.090;
    $statpot{'p23KS'}=0.037;
    $statpot{'p23KT'}=0.056;
    $statpot{'p23KW'}=-0.043;
    $statpot{'p23KY'}=0.025;
    $statpot{'p23KV'}=0.058;
    $statpot{'p23MA'}=-0.131;
    $statpot{'p23MR'}=-0.018;
    $statpot{'p23MN'}=-0.085;
    $statpot{'p23MD'}=-0.038;
    $statpot{'p23MC'}=-0.096;
    $statpot{'p23MQ'}=-0.098;
    $statpot{'p23ME'}=-0.058;
    $statpot{'p23MG'}=0.045;
    $statpot{'p23MH'}=-0.090;
    $statpot{'p23MI'}=-0.058;
    $statpot{'p23ML'}=-0.024;
    $statpot{'p23MK'}=-0.013;
    $statpot{'p23MM'}=0.037;
    $statpot{'p23MF'}=-0.061;
    $statpot{'p23MP'}=-0.020;
    $statpot{'p23MS'}=-0.117;
    $statpot{'p23MT'}=-0.054;
    $statpot{'p23MW'}=-0.085;
    $statpot{'p23MY'}=-0.077;
    $statpot{'p23MV'}=-0.093;
    $statpot{'p23FA'}=-0.058;
    $statpot{'p23FR'}=-0.083;
    $statpot{'p23FN'}=-0.087;
    $statpot{'p23FD'}=0.005;
    $statpot{'p23FC'}=-0.070;
    $statpot{'p23FQ'}=-0.046;
    $statpot{'p23FE'}=0.018;
    $statpot{'p23FG'}=0.022;
    $statpot{'p23FH'}=-0.158;
    $statpot{'p23FI'}=-0.026;
    $statpot{'p23FL'}=0.003;
    $statpot{'p23FK'}=0.031;
    $statpot{'p23FM'}=-0.061;
    $statpot{'p23FF'}=-0.044;
    $statpot{'p23FP'}=-0.037;
    $statpot{'p23FS'}=-0.150;
    $statpot{'p23FT'}=-0.040;
    $statpot{'p23FW'}=-0.088;
    $statpot{'p23FY'}=-0.052;
    $statpot{'p23FV'}=-0.014;
    $statpot{'p23PA'}=-0.042;
    $statpot{'p23PR'}=0.026;
    $statpot{'p23PN'}=0.028;
    $statpot{'p23PD'}=0.018;
    $statpot{'p23PC'}=-0.105;
    $statpot{'p23PQ'}=-0.000;
    $statpot{'p23PE'}=0.039;
    $statpot{'p23PG'}=0.075;
    $statpot{'p23PH'}=-0.035;
    $statpot{'p23PI'}=-0.037;
    $statpot{'p23PL'}=0.024;
    $statpot{'p23PK'}=0.090;
    $statpot{'p23PM'}=-0.020;
    $statpot{'p23PF'}=-0.037;
    $statpot{'p23PP'}=0.013;
    $statpot{'p23PS'}=0.003;
    $statpot{'p23PT'}=-0.045;
    $statpot{'p23PW'}=-0.024;
    $statpot{'p23PY'}=-0.036;
    $statpot{'p23PV'}=-0.071;
    $statpot{'p23SA'}=-0.071;
    $statpot{'p23SR'}=0.014;
    $statpot{'p23SN'}=-0.022;
    $statpot{'p23SD'}=-0.036;
    $statpot{'p23SC'}=-0.023;
    $statpot{'p23SQ'}=-0.021;
    $statpot{'p23SE'}=0.021;
    $statpot{'p23SG'}=0.020;
    $statpot{'p23SH'}=-0.046;
    $statpot{'p23SI'}=-0.096;
    $statpot{'p23SL'}=-0.039;
    $statpot{'p23SK'}=0.037;
    $statpot{'p23SM'}=-0.117;
    $statpot{'p23SF'}=-0.150;
    $statpot{'p23SP'}=0.003;
    $statpot{'p23SS'}=-0.031;
    $statpot{'p23ST'}=-0.026;
    $statpot{'p23SW'}=-0.093;
    $statpot{'p23SY'}=-0.109;
    $statpot{'p23SV'}=-0.043;
    $statpot{'p23TA'}=-0.035;
    $statpot{'p23TR'}=-0.033;
    $statpot{'p23TN'}=-0.002;
    $statpot{'p23TD'}=-0.009;
    $statpot{'p23TC'}=-0.081;
    $statpot{'p23TQ'}=-0.073;
    $statpot{'p23TE'}=0.023;
    $statpot{'p23TG'}=0.056;
    $statpot{'p23TH'}=-0.061;
    $statpot{'p23TI'}=-0.051;
    $statpot{'p23TL'}=-0.042;
    $statpot{'p23TK'}=0.056;
    $statpot{'p23TM'}=-0.054;
    $statpot{'p23TF'}=-0.040;
    $statpot{'p23TP'}=-0.045;
    $statpot{'p23TS'}=-0.026;
    $statpot{'p23TT'}=0.001;
    $statpot{'p23TW'}=-0.048;
    $statpot{'p23TY'}=-0.064;
    $statpot{'p23TV'}=-0.059;
    $statpot{'p23WA'}=-0.179;
    $statpot{'p23WR'}=0.032;
    $statpot{'p23WN'}=-0.092;
    $statpot{'p23WD'}=0.042;
    $statpot{'p23WC'}=0.086;
    $statpot{'p23WQ'}=-0.077;
    $statpot{'p23WE'}=-0.024;
    $statpot{'p23WG'}=0.028;
    $statpot{'p23WH'}=-0.017;
    $statpot{'p23WI'}=-0.112;
    $statpot{'p23WL'}=-0.078;
    $statpot{'p23WK'}=-0.043;
    $statpot{'p23WM'}=-0.085;
    $statpot{'p23WF'}=-0.088;
    $statpot{'p23WP'}=-0.024;
    $statpot{'p23WS'}=-0.093;
    $statpot{'p23WT'}=-0.048;
    $statpot{'p23WW'}=-0.338;
    $statpot{'p23WY'}=-0.127;
    $statpot{'p23WV'}=-0.071;
    $statpot{'p23YA'}=-0.077;
    $statpot{'p23YR'}=-0.056;
    $statpot{'p23YN'}=-0.072;
    $statpot{'p23YD'}=0.046;
    $statpot{'p23YC'}=-0.046;
    $statpot{'p23YQ'}=-0.073;
    $statpot{'p23YE'}=0.048;
    $statpot{'p23YG'}=0.048;
    $statpot{'p23YH'}=-0.069;
    $statpot{'p23YI'}=-0.075;
    $statpot{'p23YL'}=-0.155;
    $statpot{'p23YK'}=0.025;
    $statpot{'p23YM'}=-0.077;
    $statpot{'p23YF'}=-0.052;
    $statpot{'p23YP'}=-0.036;
    $statpot{'p23YS'}=-0.109;
    $statpot{'p23YT'}=-0.064;
    $statpot{'p23YW'}=-0.127;
    $statpot{'p23YY'}=-0.037;
    $statpot{'p23YV'}=-0.093;
    $statpot{'p23VA'}=-0.042;
    $statpot{'p23VR'}=-0.023;
    $statpot{'p23VN'}=-0.037;
    $statpot{'p23VD'}=-0.028;
    $statpot{'p23VC'}=0.013;
    $statpot{'p23VQ'}=-0.024;
    $statpot{'p23VE'}=0.063;
    $statpot{'p23VG'}=0.040;
    $statpot{'p23VH'}=-0.095;
    $statpot{'p23VI'}=-0.003;
    $statpot{'p23VL'}=-0.003;
    $statpot{'p23VK'}=0.058;
    $statpot{'p23VM'}=-0.093;
    $statpot{'p23VF'}=-0.014;
    $statpot{'p23VP'}=-0.071;
    $statpot{'p23VS'}=-0.043;
    $statpot{'p23VT'}=-0.059;
    $statpot{'p23VW'}=-0.071;
    $statpot{'p23VY'}=-0.093;
    $statpot{'p23VV'}=0.054;
    $statpot{'f23AA'}=-0.096;
    $statpot{'f23AR'}=0.043;
    $statpot{'f23AN'}=0.002;
    $statpot{'f23AD'}=0.039;
    $statpot{'f23AC'}=-0.306;
    $statpot{'f23AQ'}=0.089;
    $statpot{'f23AE'}=0.130;
    $statpot{'f23AG'}=-0.049;
    $statpot{'f23AH'}=-0.106;
    $statpot{'f23AI'}=-0.135;
    $statpot{'f23AL'}=-0.118;
    $statpot{'f23AK'}=0.143;
    $statpot{'f23AM'}=-0.164;
    $statpot{'f23AF'}=-0.226;
    $statpot{'f23AP'}=-0.034;
    $statpot{'f23AS'}=-0.077;
    $statpot{'f23AT'}=-0.084;
    $statpot{'f23AW'}=-0.189;
    $statpot{'f23AY'}=-0.146;
    $statpot{'f23AV'}=-0.098;
    $statpot{'f23RA'}=0.093;
    $statpot{'f23RR'}=0.190;
    $statpot{'f23RN'}=0.119;
    $statpot{'f23RD'}=0.246;
    $statpot{'f23RC'}=0.115;
    $statpot{'f23RQ'}=0.078;
    $statpot{'f23RE'}=0.262;
    $statpot{'f23RG'}=0.199;
    $statpot{'f23RH'}=0.068;
    $statpot{'f23RI'}=-0.048;
    $statpot{'f23RL'}=-0.047;
    $statpot{'f23RK'}=0.301;
    $statpot{'f23RM'}=-0.024;
    $statpot{'f23RF'}=-0.069;
    $statpot{'f23RP'}=0.310;
    $statpot{'f23RS'}=0.119;
    $statpot{'f23RT'}=0.001;
    $statpot{'f23RW'}=-0.066;
    $statpot{'f23RY'}=-0.073;
    $statpot{'f23RV'}=-0.046;
    $statpot{'f23NA'}=0.035;
    $statpot{'f23NR'}=0.127;
    $statpot{'f23NN'}=0.051;
    $statpot{'f23ND'}=0.360;
    $statpot{'f23NC'}=-0.093;
    $statpot{'f23NQ'}=0.136;
    $statpot{'f23NE'}=0.276;
    $statpot{'f23NG'}=0.197;
    $statpot{'f23NH'}=0.015;
    $statpot{'f23NI'}=0.043;
    $statpot{'f23NL'}=0.017;
    $statpot{'f23NK'}=0.290;
    $statpot{'f23NM'}=-0.137;
    $statpot{'f23NF'}=-0.020;
    $statpot{'f23NP'}=0.209;
    $statpot{'f23NS'}=0.122;
    $statpot{'f23NT'}=0.126;
    $statpot{'f23NW'}=0.031;
    $statpot{'f23NY'}=-0.029;
    $statpot{'f23NV'}=-0.044;
    $statpot{'f23DA'}=0.183;
    $statpot{'f23DR'}=0.432;
    $statpot{'f23DN'}=0.354;
    $statpot{'f23DD'}=0.353;
    $statpot{'f23DC'}=0.236;
    $statpot{'f23DQ'}=0.214;
    $statpot{'f23DE'}=0.397;
    $statpot{'f23DG'}=0.335;
    $statpot{'f23DH'}=0.121;
    $statpot{'f23DI'}=0.106;
    $statpot{'f23DL'}=0.160;
    $statpot{'f23DK'}=0.468;
    $statpot{'f23DM'}=0.138;
    $statpot{'f23DF'}=0.073;
    $statpot{'f23DP'}=0.364;
    $statpot{'f23DS'}=0.189;
    $statpot{'f23DT'}=0.286;
    $statpot{'f23DW'}=0.057;
    $statpot{'f23DY'}=0.132;
    $statpot{'f23DV'}=0.219;
    $statpot{'f23CA'}=-0.360;
    $statpot{'f23CR'}=-0.120;
    $statpot{'f23CN'}=-0.170;
    $statpot{'f23CD'}=0.026;
    $statpot{'f23CC'}=-0.319;
    $statpot{'f23CQ'}=-0.212;
    $statpot{'f23CE'}=-0.176;
    $statpot{'f23CG'}=-0.161;
    $statpot{'f23CH'}=-0.396;
    $statpot{'f23CI'}=-0.198;
    $statpot{'f23CL'}=-0.421;
    $statpot{'f23CK'}=-0.166;
    $statpot{'f23CM'}=-0.335;
    $statpot{'f23CF'}=-0.423;
    $statpot{'f23CP'}=-0.110;
    $statpot{'f23CS'}=-0.217;
    $statpot{'f23CT'}=-0.204;
    $statpot{'f23CW'}=-0.328;
    $statpot{'f23CY'}=-0.263;
    $statpot{'f23CV'}=-0.367;
    $statpot{'f23QA'}=0.122;
    $statpot{'f23QR'}=0.059;
    $statpot{'f23QN'}=0.168;
    $statpot{'f23QD'}=0.177;
    $statpot{'f23QC'}=-0.143;
    $statpot{'f23QQ'}=0.029;
    $statpot{'f23QE'}=0.371;
    $statpot{'f23QG'}=0.155;
    $statpot{'f23QH'}=0.100;
    $statpot{'f23QI'}=0.009;
    $statpot{'f23QL'}=-0.023;
    $statpot{'f23QK'}=0.316;
    $statpot{'f23QM'}=0.062;
    $statpot{'f23QF'}=0.000;
    $statpot{'f23QP'}=0.422;
    $statpot{'f23QS'}=0.193;
    $statpot{'f23QT'}=0.072;
    $statpot{'f23QW'}=0.145;
    $statpot{'f23QY'}=-0.084;
    $statpot{'f23QV'}=0.083;
    $statpot{'f23EA'}=0.211;
    $statpot{'f23ER'}=0.397;
    $statpot{'f23EN'}=0.399;
    $statpot{'f23ED'}=0.442;
    $statpot{'f23EC'}=0.014;
    $statpot{'f23EQ'}=0.421;
    $statpot{'f23EE'}=0.553;
    $statpot{'f23EG'}=0.401;
    $statpot{'f23EH'}=0.261;
    $statpot{'f23EI'}=0.227;
    $statpot{'f23EL'}=0.234;
    $statpot{'f23EK'}=0.604;
    $statpot{'f23EM'}=0.122;
    $statpot{'f23EF'}=0.097;
    $statpot{'f23EP'}=0.449;
    $statpot{'f23ES'}=0.319;
    $statpot{'f23ET'}=0.288;
    $statpot{'f23EW'}=-0.001;
    $statpot{'f23EY'}=0.113;
    $statpot{'f23EV'}=0.179;
    $statpot{'f23GA'}=0.034;
    $statpot{'f23GR'}=0.206;
    $statpot{'f23GN'}=0.227;
    $statpot{'f23GD'}=0.293;
    $statpot{'f23GC'}=-0.015;
    $statpot{'f23GQ'}=0.127;
    $statpot{'f23GE'}=0.324;
    $statpot{'f23GG'}=0.265;
    $statpot{'f23GH'}=0.002;
    $statpot{'f23GI'}=0.007;
    $statpot{'f23GL'}=0.037;
    $statpot{'f23GK'}=0.364;
    $statpot{'f23GM'}=0.005;
    $statpot{'f23GF'}=-0.046;
    $statpot{'f23GP'}=0.207;
    $statpot{'f23GS'}=0.158;
    $statpot{'f23GT'}=0.124;
    $statpot{'f23GW'}=0.006;
    $statpot{'f23GY'}=0.006;
    $statpot{'f23GV'}=0.045;
    $statpot{'f23HA'}=-0.047;
    $statpot{'f23HR'}=-0.134;
    $statpot{'f23HN'}=-0.031;
    $statpot{'f23HD'}=0.062;
    $statpot{'f23HC'}=-0.241;
    $statpot{'f23HQ'}=0.025;
    $statpot{'f23HE'}=0.128;
    $statpot{'f23HG'}=0.020;
    $statpot{'f23HH'}=-0.137;
    $statpot{'f23HI'}=-0.251;
    $statpot{'f23HL'}=-0.167;
    $statpot{'f23HK'}=0.135;
    $statpot{'f23HM'}=-0.106;
    $statpot{'f23HF'}=-0.132;
    $statpot{'f23HP'}=0.163;
    $statpot{'f23HS'}=-0.073;
    $statpot{'f23HT'}=-0.120;
    $statpot{'f23HW'}=-0.117;
    $statpot{'f23HY'}=-0.293;
    $statpot{'f23HV'}=-0.120;
    $statpot{'f23IA'}=-0.247;
    $statpot{'f23IR'}=-0.167;
    $statpot{'f23IN'}=-0.116;
    $statpot{'f23ID'}=-0.089;
    $statpot{'f23IC'}=-0.219;
    $statpot{'f23IQ'}=-0.127;
    $statpot{'f23IE'}=0.053;
    $statpot{'f23IG'}=-0.132;
    $statpot{'f23IH'}=-0.311;
    $statpot{'f23II'}=-0.219;
    $statpot{'f23IL'}=-0.224;
    $statpot{'f23IK'}=-0.026;
    $statpot{'f23IM'}=-0.300;
    $statpot{'f23IF'}=-0.275;
    $statpot{'f23IP'}=-0.158;
    $statpot{'f23IS'}=-0.216;
    $statpot{'f23IT'}=-0.204;
    $statpot{'f23IW'}=-0.293;
    $statpot{'f23IY'}=-0.274;
    $statpot{'f23IV'}=-0.206;
    $statpot{'f23LA'}=-0.194;
    $statpot{'f23LR'}=-0.151;
    $statpot{'f23LN'}=-0.205;
    $statpot{'f23LD'}=-0.062;
    $statpot{'f23LC'}=-0.405;
    $statpot{'f23LQ'}=-0.138;
    $statpot{'f23LE'}=0.017;
    $statpot{'f23LG'}=-0.103;
    $statpot{'f23LH'}=-0.265;
    $statpot{'f23LI'}=-0.243;
    $statpot{'f23LL'}=-0.170;
    $statpot{'f23LK'}=0.019;
    $statpot{'f23LM'}=-0.356;
    $statpot{'f23LF'}=-0.269;
    $statpot{'f23LP'}=-0.106;
    $statpot{'f23LS'}=-0.181;
    $statpot{'f23LT'}=-0.225;
    $statpot{'f23LW'}=-0.356;
    $statpot{'f23LY'}=-0.247;
    $statpot{'f23LV'}=-0.190;
    $statpot{'f23KA'}=0.274;
    $statpot{'f23KR'}=0.329;
    $statpot{'f23KN'}=0.362;
    $statpot{'f23KD'}=0.438;
    $statpot{'f23KC'}=0.019;
    $statpot{'f23KQ'}=0.419;
    $statpot{'f23KE'}=0.635;
    $statpot{'f23KG'}=0.475;
    $statpot{'f23KH'}=0.231;
    $statpot{'f23KI'}=0.169;
    $statpot{'f23KL'}=0.225;
    $statpot{'f23KK'}=0.634;
    $statpot{'f23KM'}=0.194;
    $statpot{'f23KF'}=0.097;
    $statpot{'f23KP'}=0.501;
    $statpot{'f23KS'}=0.298;
    $statpot{'f23KT'}=0.328;
    $statpot{'f23KW'}=0.289;
    $statpot{'f23KY'}=0.096;
    $statpot{'f23KV'}=0.160;
    $statpot{'f23MA'}=-0.242;
    $statpot{'f23MR'}=-0.117;
    $statpot{'f23MN'}=-0.341;
    $statpot{'f23MD'}=-0.094;
    $statpot{'f23MC'}=-0.398;
    $statpot{'f23MQ'}=-0.158;
    $statpot{'f23ME'}=-0.005;
    $statpot{'f23MG'}=-0.157;
    $statpot{'f23MH'}=-0.235;
    $statpot{'f23MI'}=-0.295;
    $statpot{'f23ML'}=-0.276;
    $statpot{'f23MK'}=0.000;
    $statpot{'f23MM'}=-0.404;
    $statpot{'f23MF'}=-0.331;
    $statpot{'f23MP'}=-0.213;
    $statpot{'f23MS'}=-0.210;
    $statpot{'f23MT'}=-0.233;
    $statpot{'f23MW'}=-0.341;
    $statpot{'f23MY'}=-0.374;
    $statpot{'f23MV'}=-0.278;
    $statpot{'f23FA'}=-0.278;
    $statpot{'f23FR'}=-0.212;
    $statpot{'f23FN'}=-0.180;
    $statpot{'f23FD'}=-0.134;
    $statpot{'f23FC'}=-0.331;
    $statpot{'f23FQ'}=-0.092;
    $statpot{'f23FE'}=-0.186;
    $statpot{'f23FG'}=-0.189;
    $statpot{'f23FH'}=-0.320;
    $statpot{'f23FI'}=-0.298;
    $statpot{'f23FL'}=-0.261;
    $statpot{'f23FK'}=-0.088;
    $statpot{'f23FM'}=-0.337;
    $statpot{'f23FF'}=-0.372;
    $statpot{'f23FP'}=-0.159;
    $statpot{'f23FS'}=-0.201;
    $statpot{'f23FT'}=-0.274;
    $statpot{'f23FW'}=-0.239;
    $statpot{'f23FY'}=-0.387;
    $statpot{'f23FV'}=-0.274;
    $statpot{'f23PA'}=0.073;
    $statpot{'f23PR'}=0.239;
    $statpot{'f23PN'}=0.262;
    $statpot{'f23PD'}=0.336;
    $statpot{'f23PC'}=0.043;
    $statpot{'f23PQ'}=0.322;
    $statpot{'f23PE'}=0.399;
    $statpot{'f23PG'}=0.306;
    $statpot{'f23PH'}=0.297;
    $statpot{'f23PI'}=0.004;
    $statpot{'f23PL'}=0.120;
    $statpot{'f23PK'}=0.514;
    $statpot{'f23PM'}=-0.070;
    $statpot{'f23PF'}=0.105;
    $statpot{'f23PP'}=0.406;
    $statpot{'f23PS'}=0.225;
    $statpot{'f23PT'}=0.188;
    $statpot{'f23PW'}=-0.007;
    $statpot{'f23PY'}=0.175;
    $statpot{'f23PV'}=0.196;
    $statpot{'f23SA'}=0.032;
    $statpot{'f23SR'}=0.061;
    $statpot{'f23SN'}=0.100;
    $statpot{'f23SD'}=0.194;
    $statpot{'f23SC'}=-0.070;
    $statpot{'f23SQ'}=0.181;
    $statpot{'f23SE'}=0.225;
    $statpot{'f23SG'}=0.157;
    $statpot{'f23SH'}=0.059;
    $statpot{'f23SI'}=-0.063;
    $statpot{'f23SL'}=-0.053;
    $statpot{'f23SK'}=0.216;
    $statpot{'f23SM'}=-0.038;
    $statpot{'f23SF'}=-0.063;
    $statpot{'f23SP'}=0.109;
    $statpot{'f23SS'}=0.142;
    $statpot{'f23ST'}=0.189;
    $statpot{'f23SW'}=-0.035;
    $statpot{'f23SY'}=-0.148;
    $statpot{'f23SV'}=-0.009;
    $statpot{'f23TA'}=-0.018;
    $statpot{'f23TR'}=-0.010;
    $statpot{'f23TN'}=0.098;
    $statpot{'f23TD'}=0.169;
    $statpot{'f23TC'}=-0.076;
    $statpot{'f23TQ'}=0.016;
    $statpot{'f23TE'}=0.233;
    $statpot{'f23TG'}=0.145;
    $statpot{'f23TH'}=-0.080;
    $statpot{'f23TI'}=-0.070;
    $statpot{'f23TL'}=-0.091;
    $statpot{'f23TK'}=0.306;
    $statpot{'f23TM'}=-0.123;
    $statpot{'f23TF'}=-0.137;
    $statpot{'f23TP'}=0.148;
    $statpot{'f23TS'}=0.121;
    $statpot{'f23TT'}=0.053;
    $statpot{'f23TW'}=-0.026;
    $statpot{'f23TY'}=-0.109;
    $statpot{'f23TV'}=-0.039;
    $statpot{'f23WA'}=-0.236;
    $statpot{'f23WR'}=-0.166;
    $statpot{'f23WN'}=-0.138;
    $statpot{'f23WD'}=-0.136;
    $statpot{'f23WC'}=-0.201;
    $statpot{'f23WQ'}=0.038;
    $statpot{'f23WE'}=-0.104;
    $statpot{'f23WG'}=-0.177;
    $statpot{'f23WH'}=-0.104;
    $statpot{'f23WI'}=-0.347;
    $statpot{'f23WL'}=-0.289;
    $statpot{'f23WK'}=0.055;
    $statpot{'f23WM'}=-0.426;
    $statpot{'f23WF'}=-0.216;
    $statpot{'f23WP'}=-0.145;
    $statpot{'f23WS'}=-0.182;
    $statpot{'f23WT'}=-0.165;
    $statpot{'f23WW'}=-0.297;
    $statpot{'f23WY'}=-0.279;
    $statpot{'f23WV'}=-0.360;
    $statpot{'f23YA'}=-0.223;
    $statpot{'f23YR'}=-0.173;
    $statpot{'f23YN'}=-0.143;
    $statpot{'f23YD'}=-0.053;
    $statpot{'f23YC'}=-0.297;
    $statpot{'f23YQ'}=-0.160;
    $statpot{'f23YE'}=-0.075;
    $statpot{'f23YG'}=-0.134;
    $statpot{'f23YH'}=-0.350;
    $statpot{'f23YI'}=-0.343;
    $statpot{'f23YL'}=-0.255;
    $statpot{'f23YK'}=-0.101;
    $statpot{'f23YM'}=-0.415;
    $statpot{'f23YF'}=-0.358;
    $statpot{'f23YP'}=-0.009;
    $statpot{'f23YS'}=-0.252;
    $statpot{'f23YT'}=-0.163;
    $statpot{'f23YW'}=-0.278;
    $statpot{'f23YY'}=-0.253;
    $statpot{'f23YV'}=-0.232;
    $statpot{'f23VA'}=-0.140;
    $statpot{'f23VR'}=-0.125;
    $statpot{'f23VN'}=-0.177;
    $statpot{'f23VD'}=-0.015;
    $statpot{'f23VC'}=-0.356;
    $statpot{'f23VQ'}=-0.084;
    $statpot{'f23VE'}=-0.016;
    $statpot{'f23VG'}=-0.080;
    $statpot{'f23VH'}=-0.209;
    $statpot{'f23VI'}=-0.162;
    $statpot{'f23VL'}=-0.178;
    $statpot{'f23VK'}=0.022;
    $statpot{'f23VM'}=-0.241;
    $statpot{'f23VF'}=-0.247;
    $statpot{'f23VP'}=-0.025;
    $statpot{'f23VS'}=-0.144;
    $statpot{'f23VT'}=-0.192;
    $statpot{'f23VW'}=-0.297;
    $statpot{'f23VY'}=-0.247;
    $statpot{'f23VV'}=-0.207;
    $statpot{'a23AA'}=0.069;
    $statpot{'a23AR'}=-0.015;
    $statpot{'a23AN'}=-0.058;
    $statpot{'a23AD'}=-0.026;
    $statpot{'a23AC'}=0.057;
    $statpot{'a23AQ'}=0.030;
    $statpot{'a23AE'}=0.012;
    $statpot{'a23AG'}=0.084;
    $statpot{'a23AH'}=0.029;
    $statpot{'a23AI'}=0.051;
    $statpot{'a23AL'}=0.083;
    $statpot{'a23AK'}=0.010;
    $statpot{'a23AM'}=-0.019;
    $statpot{'a23AF'}=0.096;
    $statpot{'a23AP'}=-0.015;
    $statpot{'a23AS'}=0.009;
    $statpot{'a23AT'}=-0.023;
    $statpot{'a23AW'}=0.026;
    $statpot{'a23AY'}=0.063;
    $statpot{'a23AV'}=0.009;
    $statpot{'a23RA'}=-0.059;
    $statpot{'a23RR'}=-0.051;
    $statpot{'a23RN'}=-0.139;
    $statpot{'a23RD'}=-0.083;
    $statpot{'a23RC'}=-0.113;
    $statpot{'a23RQ'}=-0.068;
    $statpot{'a23RE'}=-0.012;
    $statpot{'a23RG'}=-0.107;
    $statpot{'a23RH'}=-0.186;
    $statpot{'a23RI'}=-0.071;
    $statpot{'a23RL'}=0.011;
    $statpot{'a23RK'}=-0.104;
    $statpot{'a23RM'}=-0.065;
    $statpot{'a23RF'}=-0.073;
    $statpot{'a23RP'}=-0.129;
    $statpot{'a23RS'}=-0.135;
    $statpot{'a23RT'}=-0.177;
    $statpot{'a23RW'}=-0.127;
    $statpot{'a23RY'}=-0.062;
    $statpot{'a23RV'}=-0.056;
    $statpot{'a23NA'}=-0.086;
    $statpot{'a23NR'}=-0.144;
    $statpot{'a23NN'}=-0.103;
    $statpot{'a23ND'}=-0.090;
    $statpot{'a23NC'}=-0.105;
    $statpot{'a23NQ'}=-0.111;
    $statpot{'a23NE'}=-0.077;
    $statpot{'a23NG'}=-0.072;
    $statpot{'a23NH'}=-0.011;
    $statpot{'a23NI'}=-0.145;
    $statpot{'a23NL'}=-0.159;
    $statpot{'a23NK'}=-0.099;
    $statpot{'a23NM'}=-0.145;
    $statpot{'a23NF'}=-0.046;
    $statpot{'a23NP'}=-0.141;
    $statpot{'a23NS'}=-0.103;
    $statpot{'a23NT'}=-0.133;
    $statpot{'a23NW'}=-0.340;
    $statpot{'a23NY'}=-0.136;
    $statpot{'a23NV'}=-0.142;
    $statpot{'a23DA'}=-0.139;
    $statpot{'a23DR'}=-0.192;
    $statpot{'a23DN'}=-0.087;
    $statpot{'a23DD'}=-0.097;
    $statpot{'a23DC'}=-0.249;
    $statpot{'a23DQ'}=-0.113;
    $statpot{'a23DE'}=-0.133;
    $statpot{'a23DG'}=-0.088;
    $statpot{'a23DH'}=-0.231;
    $statpot{'a23DI'}=-0.114;
    $statpot{'a23DL'}=-0.102;
    $statpot{'a23DK'}=-0.106;
    $statpot{'a23DM'}=-0.097;
    $statpot{'a23DF'}=-0.153;
    $statpot{'a23DP'}=-0.163;
    $statpot{'a23DS'}=-0.200;
    $statpot{'a23DT'}=-0.216;
    $statpot{'a23DW'}=-0.160;
    $statpot{'a23DY'}=-0.060;
    $statpot{'a23DV'}=-0.184;
    $statpot{'a23CA'}=0.130;
    $statpot{'a23CR'}=0.094;
    $statpot{'a23CN'}=-0.034;
    $statpot{'a23CD'}=-0.112;
    $statpot{'a23CC'}=0.006;
    $statpot{'a23CQ'}=-0.035;
    $statpot{'a23CE'}=-0.079;
    $statpot{'a23CG'}=0.168;
    $statpot{'a23CH'}=0.345;
    $statpot{'a23CI'}=0.177;
    $statpot{'a23CL'}=0.253;
    $statpot{'a23CK'}=0.036;
    $statpot{'a23CM'}=0.089;
    $statpot{'a23CF'}=0.280;
    $statpot{'a23CP'}=-0.018;
    $statpot{'a23CS'}=0.009;
    $statpot{'a23CT'}=0.059;
    $statpot{'a23CW'}=0.273;
    $statpot{'a23CY'}=0.118;
    $statpot{'a23CV'}=0.055;
    $statpot{'a23QA'}=0.001;
    $statpot{'a23QR'}=-0.052;
    $statpot{'a23QN'}=-0.133;
    $statpot{'a23QD'}=-0.088;
    $statpot{'a23QC'}=-0.103;
    $statpot{'a23QQ'}=-0.045;
    $statpot{'a23QE'}=-0.158;
    $statpot{'a23QG'}=-0.086;
    $statpot{'a23QH'}=-0.014;
    $statpot{'a23QI'}=-0.060;
    $statpot{'a23QL'}=-0.041;
    $statpot{'a23QK'}=-0.002;
    $statpot{'a23QM'}=-0.024;
    $statpot{'a23QF'}=0.058;
    $statpot{'a23QP'}=-0.171;
    $statpot{'a23QS'}=-0.092;
    $statpot{'a23QT'}=-0.062;
    $statpot{'a23QW'}=0.019;
    $statpot{'a23QY'}=-0.013;
    $statpot{'a23QV'}=-0.101;
    $statpot{'a23EA'}=-0.053;
    $statpot{'a23ER'}=-0.100;
    $statpot{'a23EN'}=-0.150;
    $statpot{'a23ED'}=-0.157;
    $statpot{'a23EC'}=-0.240;
    $statpot{'a23EQ'}=-0.185;
    $statpot{'a23EE'}=0.092;
    $statpot{'a23EG'}=-0.127;
    $statpot{'a23EH'}=-0.233;
    $statpot{'a23EI'}=-0.086;
    $statpot{'a23EL'}=-0.069;
    $statpot{'a23EK'}=-0.030;
    $statpot{'a23EM'}=-0.143;
    $statpot{'a23EF'}=-0.205;
    $statpot{'a23EP'}=-0.099;
    $statpot{'a23ES'}=-0.179;
    $statpot{'a23ET'}=-0.149;
    $statpot{'a23EW'}=-0.070;
    $statpot{'a23EY'}=-0.095;
    $statpot{'a23EV'}=-0.151;
    $statpot{'a23GA'}=0.000;
    $statpot{'a23GR'}=-0.111;
    $statpot{'a23GN'}=-0.091;
    $statpot{'a23GD'}=-0.061;
    $statpot{'a23GC'}=0.013;
    $statpot{'a23GQ'}=-0.064;
    $statpot{'a23GE'}=-0.079;
    $statpot{'a23GG'}=0.004;
    $statpot{'a23GH'}=-0.131;
    $statpot{'a23GI'}=0.013;
    $statpot{'a23GL'}=-0.041;
    $statpot{'a23GK'}=-0.008;
    $statpot{'a23GM'}=-0.055;
    $statpot{'a23GF'}=-0.034;
    $statpot{'a23GP'}=-0.049;
    $statpot{'a23GS'}=-0.061;
    $statpot{'a23GT'}=-0.076;
    $statpot{'a23GW'}=-0.051;
    $statpot{'a23GY'}=0.066;
    $statpot{'a23GV'}=-0.038;
    $statpot{'a23HA'}=-0.032;
    $statpot{'a23HR'}=-0.008;
    $statpot{'a23HN'}=0.032;
    $statpot{'a23HD'}=-0.191;
    $statpot{'a23HC'}=0.110;
    $statpot{'a23HQ'}=0.051;
    $statpot{'a23HE'}=-0.148;
    $statpot{'a23HG'}=-0.145;
    $statpot{'a23HH'}=0.073;
    $statpot{'a23HI'}=-0.036;
    $statpot{'a23HL'}=0.025;
    $statpot{'a23HK'}=-0.039;
    $statpot{'a23HM'}=-0.066;
    $statpot{'a23HF'}=-0.034;
    $statpot{'a23HP'}=-0.098;
    $statpot{'a23HS'}=-0.129;
    $statpot{'a23HT'}=-0.092;
    $statpot{'a23HW'}=0.309;
    $statpot{'a23HY'}=0.053;
    $statpot{'a23HV'}=0.003;
    $statpot{'a23IA'}=0.198;
    $statpot{'a23IR'}=0.054;
    $statpot{'a23IN'}=-0.005;
    $statpot{'a23ID'}=0.060;
    $statpot{'a23IC'}=0.208;
    $statpot{'a23IQ'}=0.074;
    $statpot{'a23IE'}=0.055;
    $statpot{'a23IG'}=0.166;
    $statpot{'a23IH'}=0.037;
    $statpot{'a23II'}=0.277;
    $statpot{'a23IL'}=0.261;
    $statpot{'a23IK'}=0.137;
    $statpot{'a23IM'}=0.138;
    $statpot{'a23IF'}=0.341;
    $statpot{'a23IP'}=-0.056;
    $statpot{'a23IS'}=0.142;
    $statpot{'a23IT'}=0.168;
    $statpot{'a23IW'}=0.124;
    $statpot{'a23IY'}=0.170;
    $statpot{'a23IV'}=0.289;
    $statpot{'a23LA'}=0.181;
    $statpot{'a23LR'}=0.128;
    $statpot{'a23LN'}=0.053;
    $statpot{'a23LD'}=0.096;
    $statpot{'a23LC'}=0.225;
    $statpot{'a23LQ'}=0.077;
    $statpot{'a23LE'}=0.119;
    $statpot{'a23LG'}=0.099;
    $statpot{'a23LH'}=0.148;
    $statpot{'a23LI'}=0.292;
    $statpot{'a23LL'}=0.300;
    $statpot{'a23LK'}=0.104;
    $statpot{'a23LM'}=0.353;
    $statpot{'a23LF'}=0.295;
    $statpot{'a23LP'}=0.044;
    $statpot{'a23LS'}=0.106;
    $statpot{'a23LT'}=0.140;
    $statpot{'a23LW'}=0.314;
    $statpot{'a23LY'}=0.204;
    $statpot{'a23LV'}=0.199;
    $statpot{'a23KA'}=-0.087;
    $statpot{'a23KR'}=-0.121;
    $statpot{'a23KN'}=-0.141;
    $statpot{'a23KD'}=-0.090;
    $statpot{'a23KC'}=-0.132;
    $statpot{'a23KQ'}=-0.065;
    $statpot{'a23KE'}=-0.044;
    $statpot{'a23KG'}=-0.075;
    $statpot{'a23KH'}=-0.108;
    $statpot{'a23KI'}=-0.039;
    $statpot{'a23KL'}=-0.069;
    $statpot{'a23KK'}=0.032;
    $statpot{'a23KM'}=-0.152;
    $statpot{'a23KF'}=-0.045;
    $statpot{'a23KP'}=-0.102;
    $statpot{'a23KS'}=-0.132;
    $statpot{'a23KT'}=-0.154;
    $statpot{'a23KW'}=-0.019;
    $statpot{'a23KY'}=-0.085;
    $statpot{'a23KV'}=-0.119;
    $statpot{'a23MA'}=0.076;
    $statpot{'a23MR'}=0.028;
    $statpot{'a23MN'}=0.088;
    $statpot{'a23MD'}=0.120;
    $statpot{'a23MC'}=0.185;
    $statpot{'a23MQ'}=0.211;
    $statpot{'a23ME'}=-0.038;
    $statpot{'a23MG'}=0.117;
    $statpot{'a23MH'}=0.078;
    $statpot{'a23MI'}=0.131;
    $statpot{'a23ML'}=0.216;
    $statpot{'a23MK'}=0.001;
    $statpot{'a23MM'}=0.151;
    $statpot{'a23MF'}=0.090;
    $statpot{'a23MP'}=0.116;
    $statpot{'a23MS'}=0.145;
    $statpot{'a23MT'}=-0.049;
    $statpot{'a23MW'}=0.206;
    $statpot{'a23MY'}=0.094;
    $statpot{'a23MV'}=0.097;
    $statpot{'a23FA'}=0.167;
    $statpot{'a23FR'}=0.083;
    $statpot{'a23FN'}=0.120;
    $statpot{'a23FD'}=0.034;
    $statpot{'a23FC'}=0.137;
    $statpot{'a23FQ'}=0.156;
    $statpot{'a23FE'}=0.055;
    $statpot{'a23FG'}=0.122;
    $statpot{'a23FH'}=0.200;
    $statpot{'a23FI'}=0.381;
    $statpot{'a23FL'}=0.281;
    $statpot{'a23FK'}=0.131;
    $statpot{'a23FM'}=0.099;
    $statpot{'a23FF'}=0.290;
    $statpot{'a23FP'}=0.133;
    $statpot{'a23FS'}=0.084;
    $statpot{'a23FT'}=0.100;
    $statpot{'a23FW'}=0.361;
    $statpot{'a23FY'}=0.162;
    $statpot{'a23FV'}=0.304;
    $statpot{'a23PA'}=-0.110;
    $statpot{'a23PR'}=-0.082;
    $statpot{'a23PN'}=-0.175;
    $statpot{'a23PD'}=-0.148;
    $statpot{'a23PC'}=-0.149;
    $statpot{'a23PQ'}=-0.116;
    $statpot{'a23PE'}=-0.069;
    $statpot{'a23PG'}=-0.117;
    $statpot{'a23PH'}=-0.185;
    $statpot{'a23PI'}=-0.202;
    $statpot{'a23PL'}=-0.158;
    $statpot{'a23PK'}=-0.109;
    $statpot{'a23PM'}=-0.046;
    $statpot{'a23PF'}=-0.124;
    $statpot{'a23PP'}=-0.090;
    $statpot{'a23PS'}=-0.212;
    $statpot{'a23PT'}=-0.194;
    $statpot{'a23PW'}=-0.144;
    $statpot{'a23PY'}=-0.164;
    $statpot{'a23PV'}=-0.142;
    $statpot{'a23SA'}=-0.092;
    $statpot{'a23SR'}=-0.091;
    $statpot{'a23SN'}=-0.087;
    $statpot{'a23SD'}=-0.204;
    $statpot{'a23SC'}=-0.129;
    $statpot{'a23SQ'}=-0.083;
    $statpot{'a23SE'}=-0.122;
    $statpot{'a23SG'}=-0.061;
    $statpot{'a23SH'}=-0.230;
    $statpot{'a23SI'}=-0.030;
    $statpot{'a23SL'}=-0.032;
    $statpot{'a23SK'}=-0.081;
    $statpot{'a23SM'}=-0.046;
    $statpot{'a23SF'}=-0.061;
    $statpot{'a23SP'}=-0.137;
    $statpot{'a23SS'}=-0.184;
    $statpot{'a23ST'}=-0.184;
    $statpot{'a23SW'}=-0.074;
    $statpot{'a23SY'}=-0.088;
    $statpot{'a23SV'}=-0.080;
    $statpot{'a23TA'}=-0.085;
    $statpot{'a23TR'}=-0.168;
    $statpot{'a23TN'}=-0.114;
    $statpot{'a23TD'}=-0.144;
    $statpot{'a23TC'}=-0.069;
    $statpot{'a23TQ'}=-0.015;
    $statpot{'a23TE'}=-0.114;
    $statpot{'a23TG'}=-0.093;
    $statpot{'a23TH'}=-0.129;
    $statpot{'a23TI'}=0.012;
    $statpot{'a23TL'}=-0.015;
    $statpot{'a23TK'}=-0.141;
    $statpot{'a23TM'}=-0.160;
    $statpot{'a23TF'}=-0.057;
    $statpot{'a23TP'}=-0.167;
    $statpot{'a23TS'}=-0.139;
    $statpot{'a23TT'}=-0.159;
    $statpot{'a23TW'}=0.020;
    $statpot{'a23TY'}=-0.002;
    $statpot{'a23TV'}=-0.067;
    $statpot{'a23WA'}=0.082;
    $statpot{'a23WR'}=-0.032;
    $statpot{'a23WN'}=-0.220;
    $statpot{'a23WD'}=0.008;
    $statpot{'a23WC'}=0.100;
    $statpot{'a23WQ'}=0.113;
    $statpot{'a23WE'}=0.028;
    $statpot{'a23WG'}=0.137;
    $statpot{'a23WH'}=0.291;
    $statpot{'a23WI'}=0.205;
    $statpot{'a23WL'}=0.202;
    $statpot{'a23WK'}=0.172;
    $statpot{'a23WM'}=0.357;
    $statpot{'a23WF'}=0.324;
    $statpot{'a23WP'}=-0.017;
    $statpot{'a23WS'}=0.071;
    $statpot{'a23WT'}=0.169;
    $statpot{'a23WW'}=0.240;
    $statpot{'a23WY'}=0.408;
    $statpot{'a23WV'}=0.229;
    $statpot{'a23YA'}=0.162;
    $statpot{'a23YR'}=0.044;
    $statpot{'a23YN'}=-0.032;
    $statpot{'a23YD'}=0.109;
    $statpot{'a23YC'}=0.164;
    $statpot{'a23YQ'}=0.068;
    $statpot{'a23YE'}=0.079;
    $statpot{'a23YG'}=0.227;
    $statpot{'a23YH'}=0.134;
    $statpot{'a23YI'}=0.278;
    $statpot{'a23YL'}=0.216;
    $statpot{'a23YK'}=0.097;
    $statpot{'a23YM'}=0.160;
    $statpot{'a23YF'}=0.117;
    $statpot{'a23YP'}=-0.018;
    $statpot{'a23YS'}=0.023;
    $statpot{'a23YT'}=0.057;
    $statpot{'a23YW'}=0.407;
    $statpot{'a23YY'}=0.235;
    $statpot{'a23YV'}=0.153;
    $statpot{'a23VA'}=0.057;
    $statpot{'a23VR'}=0.025;
    $statpot{'a23VN'}=-0.017;
    $statpot{'a23VD'}=-0.004;
    $statpot{'a23VC'}=0.041;
    $statpot{'a23VQ'}=0.050;
    $statpot{'a23VE'}=0.008;
    $statpot{'a23VG'}=0.084;
    $statpot{'a23VH'}=0.106;
    $statpot{'a23VI'}=0.224;
    $statpot{'a23VL'}=0.183;
    $statpot{'a23VK'}=-0.009;
    $statpot{'a23VM'}=0.048;
    $statpot{'a23VF'}=0.263;
    $statpot{'a23VP'}=0.042;
    $statpot{'a23VS'}=0.053;
    $statpot{'a23VT'}=0.095;
    $statpot{'a23VW'}=0.136;
    $statpot{'a23VY'}=0.175;
    $statpot{'a23VV'}=0.122;
    $statpot{'p24AA'}=-0.006;
    $statpot{'p24AR'}=-0.035;
    $statpot{'p24AN'}=-0.027;
    $statpot{'p24AD'}=-0.048;
    $statpot{'p24AC'}=0.026;
    $statpot{'p24AQ'}=-0.021;
    $statpot{'p24AE'}=-0.058;
    $statpot{'p24AG'}=0.068;
    $statpot{'p24AH'}=-0.007;
    $statpot{'p24AI'}=0.021;
    $statpot{'p24AL'}=0.009;
    $statpot{'p24AK'}=-0.057;
    $statpot{'p24AM'}=0.025;
    $statpot{'p24AF'}=0.019;
    $statpot{'p24AP'}=-0.035;
    $statpot{'p24AS'}=-0.013;
    $statpot{'p24AT'}=-0.009;
    $statpot{'p24AW'}=0.011;
    $statpot{'p24AY'}=0.014;
    $statpot{'p24AV'}=0.012;
    $statpot{'p24RA'}=-0.035;
    $statpot{'p24RR'}=-0.043;
    $statpot{'p24RN'}=-0.035;
    $statpot{'p24RD'}=-0.056;
    $statpot{'p24RC'}=0.005;
    $statpot{'p24RQ'}=-0.037;
    $statpot{'p24RE'}=-0.060;
    $statpot{'p24RG'}=0.051;
    $statpot{'p24RH'}=-0.016;
    $statpot{'p24RI'}=0.009;
    $statpot{'p24RL'}=-0.019;
    $statpot{'p24RK'}=-0.073;
    $statpot{'p24RM'}=-0.002;
    $statpot{'p24RF'}=-0.002;
    $statpot{'p24RP'}=-0.053;
    $statpot{'p24RS'}=-0.046;
    $statpot{'p24RT'}=-0.028;
    $statpot{'p24RW'}=-0.019;
    $statpot{'p24RY'}=-0.001;
    $statpot{'p24RV'}=-0.011;
    $statpot{'p24NA'}=-0.027;
    $statpot{'p24NR'}=-0.035;
    $statpot{'p24NN'}=-0.046;
    $statpot{'p24ND'}=-0.055;
    $statpot{'p24NC'}=-0.005;
    $statpot{'p24NQ'}=-0.047;
    $statpot{'p24NE'}=-0.068;
    $statpot{'p24NG'}=0.056;
    $statpot{'p24NH'}=-0.012;
    $statpot{'p24NI'}=0.013;
    $statpot{'p24NL'}=-0.011;
    $statpot{'p24NK'}=-0.068;
    $statpot{'p24NM'}=0.001;
    $statpot{'p24NF'}=0.001;
    $statpot{'p24NP'}=-0.040;
    $statpot{'p24NS'}=-0.028;
    $statpot{'p24NT'}=-0.038;
    $statpot{'p24NW'}=-0.001;
    $statpot{'p24NY'}=-0.006;
    $statpot{'p24NV'}=-0.004;
    $statpot{'p24DA'}=-0.048;
    $statpot{'p24DR'}=-0.056;
    $statpot{'p24DN'}=-0.055;
    $statpot{'p24DD'}=-0.065;
    $statpot{'p24DC'}=-0.032;
    $statpot{'p24DQ'}=-0.054;
    $statpot{'p24DE'}=-0.080;
    $statpot{'p24DG'}=0.033;
    $statpot{'p24DH'}=-0.042;
    $statpot{'p24DI'}=-0.028;
    $statpot{'p24DL'}=-0.034;
    $statpot{'p24DK'}=-0.067;
    $statpot{'p24DM'}=-0.037;
    $statpot{'p24DF'}=-0.022;
    $statpot{'p24DP'}=-0.061;
    $statpot{'p24DS'}=-0.054;
    $statpot{'p24DT'}=-0.050;
    $statpot{'p24DW'}=-0.033;
    $statpot{'p24DY'}=-0.029;
    $statpot{'p24DV'}=-0.039;
    $statpot{'p24CA'}=0.026;
    $statpot{'p24CR'}=0.005;
    $statpot{'p24CN'}=-0.005;
    $statpot{'p24CD'}=-0.032;
    $statpot{'p24CC'}=0.098;
    $statpot{'p24CQ'}=0.018;
    $statpot{'p24CE'}=-0.041;
    $statpot{'p24CG'}=0.106;
    $statpot{'p24CH'}=0.032;
    $statpot{'p24CI'}=0.062;
    $statpot{'p24CL'}=0.066;
    $statpot{'p24CK'}=-0.054;
    $statpot{'p24CM'}=0.079;
    $statpot{'p24CF'}=0.082;
    $statpot{'p24CP'}=0.001;
    $statpot{'p24CS'}=0.016;
    $statpot{'p24CT'}=0.028;
    $statpot{'p24CW'}=0.083;
    $statpot{'p24CY'}=0.077;
    $statpot{'p24CV'}=0.044;
    $statpot{'p24QA'}=-0.021;
    $statpot{'p24QR'}=-0.037;
    $statpot{'p24QN'}=-0.047;
    $statpot{'p24QD'}=-0.054;
    $statpot{'p24QC'}=0.018;
    $statpot{'p24QQ'}=-0.028;
    $statpot{'p24QE'}=-0.071;
    $statpot{'p24QG'}=0.051;
    $statpot{'p24QH'}=-0.028;
    $statpot{'p24QI'}=-0.001;
    $statpot{'p24QL'}=-0.008;
    $statpot{'p24QK'}=-0.071;
    $statpot{'p24QM'}=-0.006;
    $statpot{'p24QF'}=0.006;
    $statpot{'p24QP'}=-0.049;
    $statpot{'p24QS'}=-0.037;
    $statpot{'p24QT'}=-0.026;
    $statpot{'p24QW'}=0.000;
    $statpot{'p24QY'}=-0.001;
    $statpot{'p24QV'}=-0.010;
    $statpot{'p24EA'}=-0.058;
    $statpot{'p24ER'}=-0.060;
    $statpot{'p24EN'}=-0.068;
    $statpot{'p24ED'}=-0.080;
    $statpot{'p24EC'}=-0.041;
    $statpot{'p24EQ'}=-0.071;
    $statpot{'p24EE'}=-0.073;
    $statpot{'p24EG'}=0.026;
    $statpot{'p24EH'}=-0.065;
    $statpot{'p24EI'}=-0.040;
    $statpot{'p24EL'}=-0.048;
    $statpot{'p24EK'}=-0.068;
    $statpot{'p24EM'}=-0.045;
    $statpot{'p24EF'}=-0.044;
    $statpot{'p24EP'}=-0.062;
    $statpot{'p24ES'}=-0.059;
    $statpot{'p24ET'}=-0.054;
    $statpot{'p24EW'}=-0.041;
    $statpot{'p24EY'}=-0.040;
    $statpot{'p24EV'}=-0.048;
    $statpot{'p24GA'}=0.068;
    $statpot{'p24GR'}=0.051;
    $statpot{'p24GN'}=0.056;
    $statpot{'p24GD'}=0.033;
    $statpot{'p24GC'}=0.106;
    $statpot{'p24GQ'}=0.051;
    $statpot{'p24GE'}=0.026;
    $statpot{'p24GG'}=0.166;
    $statpot{'p24GH'}=0.079;
    $statpot{'p24GI'}=0.090;
    $statpot{'p24GL'}=0.078;
    $statpot{'p24GK'}=0.022;
    $statpot{'p24GM'}=0.100;
    $statpot{'p24GF'}=0.097;
    $statpot{'p24GP'}=0.057;
    $statpot{'p24GS'}=0.068;
    $statpot{'p24GT'}=0.073;
    $statpot{'p24GW'}=0.088;
    $statpot{'p24GY'}=0.083;
    $statpot{'p24GV'}=0.085;
    $statpot{'p24HA'}=-0.007;
    $statpot{'p24HR'}=-0.016;
    $statpot{'p24HN'}=-0.012;
    $statpot{'p24HD'}=-0.042;
    $statpot{'p24HC'}=0.032;
    $statpot{'p24HQ'}=-0.028;
    $statpot{'p24HE'}=-0.065;
    $statpot{'p24HG'}=0.079;
    $statpot{'p24HH'}=0.023;
    $statpot{'p24HI'}=0.044;
    $statpot{'p24HL'}=0.027;
    $statpot{'p24HK'}=-0.050;
    $statpot{'p24HM'}=0.063;
    $statpot{'p24HF'}=0.052;
    $statpot{'p24HP'}=-0.025;
    $statpot{'p24HS'}=-0.008;
    $statpot{'p24HT'}=0.007;
    $statpot{'p24HW'}=0.044;
    $statpot{'p24HY'}=0.046;
    $statpot{'p24HV'}=0.030;
    $statpot{'p24IA'}=0.021;
    $statpot{'p24IR'}=0.009;
    $statpot{'p24IN'}=0.013;
    $statpot{'p24ID'}=-0.028;
    $statpot{'p24IC'}=0.062;
    $statpot{'p24IQ'}=-0.001;
    $statpot{'p24IE'}=-0.040;
    $statpot{'p24IG'}=0.090;
    $statpot{'p24IH'}=0.044;
    $statpot{'p24II'}=0.064;
    $statpot{'p24IL'}=0.052;
    $statpot{'p24IK'}=-0.030;
    $statpot{'p24IM'}=0.064;
    $statpot{'p24IF'}=0.071;
    $statpot{'p24IP'}=-0.007;
    $statpot{'p24IS'}=0.014;
    $statpot{'p24IT'}=0.026;
    $statpot{'p24IW'}=0.074;
    $statpot{'p24IY'}=0.070;
    $statpot{'p24IV'}=0.047;
    $statpot{'p24LA'}=0.009;
    $statpot{'p24LR'}=-0.019;
    $statpot{'p24LN'}=-0.011;
    $statpot{'p24LD'}=-0.034;
    $statpot{'p24LC'}=0.066;
    $statpot{'p24LQ'}=-0.008;
    $statpot{'p24LE'}=-0.048;
    $statpot{'p24LG'}=0.078;
    $statpot{'p24LH'}=0.027;
    $statpot{'p24LI'}=0.052;
    $statpot{'p24LL'}=0.046;
    $statpot{'p24LK'}=-0.045;
    $statpot{'p24LM'}=0.042;
    $statpot{'p24LF'}=0.060;
    $statpot{'p24LP'}=-0.026;
    $statpot{'p24LS'}=0.001;
    $statpot{'p24LT'}=0.008;
    $statpot{'p24LW'}=0.056;
    $statpot{'p24LY'}=0.050;
    $statpot{'p24LV'}=0.031;
    $statpot{'p24KA'}=-0.057;
    $statpot{'p24KR'}=-0.073;
    $statpot{'p24KN'}=-0.068;
    $statpot{'p24KD'}=-0.067;
    $statpot{'p24KC'}=-0.054;
    $statpot{'p24KQ'}=-0.071;
    $statpot{'p24KE'}=-0.068;
    $statpot{'p24KG'}=0.022;
    $statpot{'p24KH'}=-0.050;
    $statpot{'p24KI'}=-0.030;
    $statpot{'p24KL'}=-0.045;
    $statpot{'p24KK'}=-0.067;
    $statpot{'p24KM'}=-0.041;
    $statpot{'p24KF'}=-0.039;
    $statpot{'p24KP'}=-0.063;
    $statpot{'p24KS'}=-0.064;
    $statpot{'p24KT'}=-0.050;
    $statpot{'p24KW'}=-0.046;
    $statpot{'p24KY'}=-0.050;
    $statpot{'p24KV'}=-0.046;
    $statpot{'p24MA'}=0.025;
    $statpot{'p24MR'}=-0.002;
    $statpot{'p24MN'}=0.001;
    $statpot{'p24MD'}=-0.037;
    $statpot{'p24MC'}=0.079;
    $statpot{'p24MQ'}=-0.006;
    $statpot{'p24ME'}=-0.045;
    $statpot{'p24MG'}=0.100;
    $statpot{'p24MH'}=0.063;
    $statpot{'p24MI'}=0.064;
    $statpot{'p24ML'}=0.042;
    $statpot{'p24MK'}=-0.041;
    $statpot{'p24MM'}=0.080;
    $statpot{'p24MF'}=0.088;
    $statpot{'p24MP'}=-0.012;
    $statpot{'p24MS'}=0.018;
    $statpot{'p24MT'}=0.021;
    $statpot{'p24MW'}=0.085;
    $statpot{'p24MY'}=0.068;
    $statpot{'p24MV'}=0.042;
    $statpot{'p24FA'}=0.019;
    $statpot{'p24FR'}=-0.002;
    $statpot{'p24FN'}=0.001;
    $statpot{'p24FD'}=-0.022;
    $statpot{'p24FC'}=0.082;
    $statpot{'p24FQ'}=0.006;
    $statpot{'p24FE'}=-0.044;
    $statpot{'p24FG'}=0.097;
    $statpot{'p24FH'}=0.052;
    $statpot{'p24FI'}=0.071;
    $statpot{'p24FL'}=0.060;
    $statpot{'p24FK'}=-0.039;
    $statpot{'p24FM'}=0.088;
    $statpot{'p24FF'}=0.120;
    $statpot{'p24FP'}=-0.011;
    $statpot{'p24FS'}=0.026;
    $statpot{'p24FT'}=0.018;
    $statpot{'p24FW'}=0.090;
    $statpot{'p24FY'}=0.086;
    $statpot{'p24FV'}=0.058;
    $statpot{'p24PA'}=-0.035;
    $statpot{'p24PR'}=-0.053;
    $statpot{'p24PN'}=-0.040;
    $statpot{'p24PD'}=-0.061;
    $statpot{'p24PC'}=0.001;
    $statpot{'p24PQ'}=-0.049;
    $statpot{'p24PE'}=-0.062;
    $statpot{'p24PG'}=0.057;
    $statpot{'p24PH'}=-0.025;
    $statpot{'p24PI'}=-0.007;
    $statpot{'p24PL'}=-0.026;
    $statpot{'p24PK'}=-0.063;
    $statpot{'p24PM'}=-0.012;
    $statpot{'p24PF'}=-0.011;
    $statpot{'p24PP'}=-0.038;
    $statpot{'p24PS'}=-0.037;
    $statpot{'p24PT'}=-0.029;
    $statpot{'p24PW'}=-0.019;
    $statpot{'p24PY'}=-0.005;
    $statpot{'p24PV'}=-0.017;
    $statpot{'p24SA'}=-0.013;
    $statpot{'p24SR'}=-0.046;
    $statpot{'p24SN'}=-0.028;
    $statpot{'p24SD'}=-0.054;
    $statpot{'p24SC'}=0.016;
    $statpot{'p24SQ'}=-0.037;
    $statpot{'p24SE'}=-0.059;
    $statpot{'p24SG'}=0.068;
    $statpot{'p24SH'}=-0.008;
    $statpot{'p24SI'}=0.014;
    $statpot{'p24SL'}=0.001;
    $statpot{'p24SK'}=-0.064;
    $statpot{'p24SM'}=0.018;
    $statpot{'p24SF'}=0.026;
    $statpot{'p24SP'}=-0.037;
    $statpot{'p24SS'}=-0.020;
    $statpot{'p24ST'}=-0.019;
    $statpot{'p24SW'}=-0.000;
    $statpot{'p24SY'}=-0.000;
    $statpot{'p24SV'}=-0.002;
    $statpot{'p24TA'}=-0.009;
    $statpot{'p24TR'}=-0.028;
    $statpot{'p24TN'}=-0.038;
    $statpot{'p24TD'}=-0.050;
    $statpot{'p24TC'}=0.028;
    $statpot{'p24TQ'}=-0.026;
    $statpot{'p24TE'}=-0.054;
    $statpot{'p24TG'}=0.073;
    $statpot{'p24TH'}=0.007;
    $statpot{'p24TI'}=0.026;
    $statpot{'p24TL'}=0.008;
    $statpot{'p24TK'}=-0.050;
    $statpot{'p24TM'}=0.021;
    $statpot{'p24TF'}=0.018;
    $statpot{'p24TP'}=-0.029;
    $statpot{'p24TS'}=-0.019;
    $statpot{'p24TT'}=-0.001;
    $statpot{'p24TW'}=0.006;
    $statpot{'p24TY'}=0.015;
    $statpot{'p24TV'}=0.002;
    $statpot{'p24WA'}=0.011;
    $statpot{'p24WR'}=-0.019;
    $statpot{'p24WN'}=-0.001;
    $statpot{'p24WD'}=-0.033;
    $statpot{'p24WC'}=0.083;
    $statpot{'p24WQ'}=0.000;
    $statpot{'p24WE'}=-0.041;
    $statpot{'p24WG'}=0.088;
    $statpot{'p24WH'}=0.044;
    $statpot{'p24WI'}=0.074;
    $statpot{'p24WL'}=0.056;
    $statpot{'p24WK'}=-0.046;
    $statpot{'p24WM'}=0.085;
    $statpot{'p24WF'}=0.090;
    $statpot{'p24WP'}=-0.019;
    $statpot{'p24WS'}=-0.000;
    $statpot{'p24WT'}=0.006;
    $statpot{'p24WW'}=0.103;
    $statpot{'p24WY'}=0.075;
    $statpot{'p24WV'}=0.047;
    $statpot{'p24YA'}=0.014;
    $statpot{'p24YR'}=-0.001;
    $statpot{'p24YN'}=-0.006;
    $statpot{'p24YD'}=-0.029;
    $statpot{'p24YC'}=0.077;
    $statpot{'p24YQ'}=-0.001;
    $statpot{'p24YE'}=-0.040;
    $statpot{'p24YG'}=0.083;
    $statpot{'p24YH'}=0.046;
    $statpot{'p24YI'}=0.070;
    $statpot{'p24YL'}=0.050;
    $statpot{'p24YK'}=-0.050;
    $statpot{'p24YM'}=0.068;
    $statpot{'p24YF'}=0.086;
    $statpot{'p24YP'}=-0.005;
    $statpot{'p24YS'}=-0.000;
    $statpot{'p24YT'}=0.015;
    $statpot{'p24YW'}=0.075;
    $statpot{'p24YY'}=0.064;
    $statpot{'p24YV'}=0.041;
    $statpot{'p24VA'}=0.012;
    $statpot{'p24VR'}=-0.011;
    $statpot{'p24VN'}=-0.004;
    $statpot{'p24VD'}=-0.039;
    $statpot{'p24VC'}=0.044;
    $statpot{'p24VQ'}=-0.010;
    $statpot{'p24VE'}=-0.048;
    $statpot{'p24VG'}=0.085;
    $statpot{'p24VH'}=0.030;
    $statpot{'p24VI'}=0.047;
    $statpot{'p24VL'}=0.031;
    $statpot{'p24VK'}=-0.046;
    $statpot{'p24VM'}=0.042;
    $statpot{'p24VF'}=0.058;
    $statpot{'p24VP'}=-0.017;
    $statpot{'p24VS'}=-0.002;
    $statpot{'p24VT'}=0.002;
    $statpot{'p24VW'}=0.047;
    $statpot{'p24VY'}=0.041;
    $statpot{'p24VV'}=0.035;
    $statpot{'f24AA'}=-0.098;
    $statpot{'f24AR'}=-0.049;
    $statpot{'f24AN'}=-0.008;
    $statpot{'f24AD'}=-0.008;
    $statpot{'f24AC'}=-0.083;
    $statpot{'f24AQ'}=-0.038;
    $statpot{'f24AE'}=0.024;
    $statpot{'f24AG'}=0.051;
    $statpot{'f24AH'}=-0.046;
    $statpot{'f24AI'}=-0.129;
    $statpot{'f24AL'}=-0.135;
    $statpot{'f24AK'}=-0.010;
    $statpot{'f24AM'}=-0.125;
    $statpot{'f24AF'}=-0.166;
    $statpot{'f24AP'}=0.014;
    $statpot{'f24AS'}=-0.020;
    $statpot{'f24AT'}=-0.025;
    $statpot{'f24AW'}=-0.110;
    $statpot{'f24AY'}=-0.103;
    $statpot{'f24AV'}=-0.103;
    $statpot{'f24RA'}=0.041;
    $statpot{'f24RR'}=0.091;
    $statpot{'f24RN'}=0.097;
    $statpot{'f24RD'}=0.157;
    $statpot{'f24RC'}=0.058;
    $statpot{'f24RQ'}=0.089;
    $statpot{'f24RE'}=0.166;
    $statpot{'f24RG'}=0.217;
    $statpot{'f24RH'}=0.052;
    $statpot{'f24RI'}=-0.003;
    $statpot{'f24RL'}=-0.004;
    $statpot{'f24RK'}=0.133;
    $statpot{'f24RM'}=0.032;
    $statpot{'f24RF'}=-0.035;
    $statpot{'f24RP'}=0.175;
    $statpot{'f24RS'}=0.109;
    $statpot{'f24RT'}=0.083;
    $statpot{'f24RW'}=-0.007;
    $statpot{'f24RY'}=0.011;
    $statpot{'f24RV'}=0.034;
    $statpot{'f24NA'}=0.073;
    $statpot{'f24NR'}=0.118;
    $statpot{'f24NN'}=0.154;
    $statpot{'f24ND'}=0.171;
    $statpot{'f24NC'}=0.058;
    $statpot{'f24NQ'}=0.120;
    $statpot{'f24NE'}=0.165;
    $statpot{'f24NG'}=0.222;
    $statpot{'f24NH'}=0.096;
    $statpot{'f24NI'}=0.035;
    $statpot{'f24NL'}=0.005;
    $statpot{'f24NK'}=0.154;
    $statpot{'f24NM'}=0.068;
    $statpot{'f24NF'}=0.017;
    $statpot{'f24NP'}=0.157;
    $statpot{'f24NS'}=0.146;
    $statpot{'f24NT'}=0.136;
    $statpot{'f24NW'}=0.029;
    $statpot{'f24NY'}=0.028;
    $statpot{'f24NV'}=0.040;
    $statpot{'f24DA'}=0.111;
    $statpot{'f24DR'}=0.243;
    $statpot{'f24DN'}=0.243;
    $statpot{'f24DD'}=0.234;
    $statpot{'f24DC'}=0.146;
    $statpot{'f24DQ'}=0.165;
    $statpot{'f24DE'}=0.281;
    $statpot{'f24DG'}=0.294;
    $statpot{'f24DH'}=0.196;
    $statpot{'f24DI'}=0.088;
    $statpot{'f24DL'}=0.072;
    $statpot{'f24DK'}=0.225;
    $statpot{'f24DM'}=0.115;
    $statpot{'f24DF'}=0.085;
    $statpot{'f24DP'}=0.245;
    $statpot{'f24DS'}=0.218;
    $statpot{'f24DT'}=0.207;
    $statpot{'f24DW'}=0.139;
    $statpot{'f24DY'}=0.115;
    $statpot{'f24DV'}=0.127;
    $statpot{'f24CA'}=-0.090;
    $statpot{'f24CR'}=-0.075;
    $statpot{'f24CN'}=-0.114;
    $statpot{'f24CD'}=-0.054;
    $statpot{'f24CC'}=-0.158;
    $statpot{'f24CQ'}=-0.037;
    $statpot{'f24CE'}=-0.033;
    $statpot{'f24CG'}=0.004;
    $statpot{'f24CH'}=-0.129;
    $statpot{'f24CI'}=-0.153;
    $statpot{'f24CL'}=-0.175;
    $statpot{'f24CK'}=-0.056;
    $statpot{'f24CM'}=-0.089;
    $statpot{'f24CF'}=-0.204;
    $statpot{'f24CP'}=-0.012;
    $statpot{'f24CS'}=-0.074;
    $statpot{'f24CT'}=-0.067;
    $statpot{'f24CW'}=-0.204;
    $statpot{'f24CY'}=-0.197;
    $statpot{'f24CV'}=-0.091;
    $statpot{'f24QA'}=0.018;
    $statpot{'f24QR'}=0.096;
    $statpot{'f24QN'}=0.114;
    $statpot{'f24QD'}=0.111;
    $statpot{'f24QC'}=0.039;
    $statpot{'f24QQ'}=0.059;
    $statpot{'f24QE'}=0.171;
    $statpot{'f24QG'}=0.171;
    $statpot{'f24QH'}=0.070;
    $statpot{'f24QI'}=-0.018;
    $statpot{'f24QL'}=-0.006;
    $statpot{'f24QK'}=0.097;
    $statpot{'f24QM'}=-0.009;
    $statpot{'f24QF'}=-0.034;
    $statpot{'f24QP'}=0.140;
    $statpot{'f24QS'}=0.124;
    $statpot{'f24QT'}=0.103;
    $statpot{'f24QW'}=-0.029;
    $statpot{'f24QY'}=-0.011;
    $statpot{'f24QV'}=0.007;
    $statpot{'f24EA'}=0.264;
    $statpot{'f24ER'}=0.288;
    $statpot{'f24EN'}=0.295;
    $statpot{'f24ED'}=0.327;
    $statpot{'f24EC'}=0.221;
    $statpot{'f24EQ'}=0.320;
    $statpot{'f24EE'}=0.389;
    $statpot{'f24EG'}=0.410;
    $statpot{'f24EH'}=0.275;
    $statpot{'f24EI'}=0.205;
    $statpot{'f24EL'}=0.187;
    $statpot{'f24EK'}=0.365;
    $statpot{'f24EM'}=0.222;
    $statpot{'f24EF'}=0.139;
    $statpot{'f24EP'}=0.378;
    $statpot{'f24ES'}=0.301;
    $statpot{'f24ET'}=0.295;
    $statpot{'f24EW'}=0.172;
    $statpot{'f24EY'}=0.202;
    $statpot{'f24EV'}=0.227;
    $statpot{'f24GA'}=0.114;
    $statpot{'f24GR'}=0.184;
    $statpot{'f24GN'}=0.186;
    $statpot{'f24GD'}=0.211;
    $statpot{'f24GC'}=0.094;
    $statpot{'f24GQ'}=0.161;
    $statpot{'f24GE'}=0.245;
    $statpot{'f24GG'}=0.245;
    $statpot{'f24GH'}=0.190;
    $statpot{'f24GI'}=0.087;
    $statpot{'f24GL'}=0.063;
    $statpot{'f24GK'}=0.202;
    $statpot{'f24GM'}=0.103;
    $statpot{'f24GF'}=0.064;
    $statpot{'f24GP'}=0.233;
    $statpot{'f24GS'}=0.179;
    $statpot{'f24GT'}=0.169;
    $statpot{'f24GW'}=0.083;
    $statpot{'f24GY'}=0.112;
    $statpot{'f24GV'}=0.098;
    $statpot{'f24HA'}=-0.032;
    $statpot{'f24HR'}=-0.028;
    $statpot{'f24HN'}=0.021;
    $statpot{'f24HD'}=0.062;
    $statpot{'f24HC'}=-0.053;
    $statpot{'f24HQ'}=0.036;
    $statpot{'f24HE'}=0.083;
    $statpot{'f24HG'}=0.133;
    $statpot{'f24HH'}=-0.022;
    $statpot{'f24HI'}=-0.107;
    $statpot{'f24HL'}=-0.105;
    $statpot{'f24HK'}=0.018;
    $statpot{'f24HM'}=-0.049;
    $statpot{'f24HF'}=-0.100;
    $statpot{'f24HP'}=0.065;
    $statpot{'f24HS'}=0.035;
    $statpot{'f24HT'}=0.025;
    $statpot{'f24HW'}=-0.103;
    $statpot{'f24HY'}=-0.058;
    $statpot{'f24HV'}=-0.030;
    $statpot{'f24IA'}=-0.210;
    $statpot{'f24IR'}=-0.158;
    $statpot{'f24IN'}=-0.140;
    $statpot{'f24ID'}=-0.138;
    $statpot{'f24IC'}=-0.206;
    $statpot{'f24IQ'}=-0.164;
    $statpot{'f24IE'}=-0.090;
    $statpot{'f24IG'}=-0.059;
    $statpot{'f24IH'}=-0.187;
    $statpot{'f24II'}=-0.253;
    $statpot{'f24IL'}=-0.254;
    $statpot{'f24IK'}=-0.129;
    $statpot{'f24IM'}=-0.242;
    $statpot{'f24IF'}=-0.257;
    $statpot{'f24IP'}=-0.123;
    $statpot{'f24IS'}=-0.147;
    $statpot{'f24IT'}=-0.164;
    $statpot{'f24IW'}=-0.254;
    $statpot{'f24IY'}=-0.246;
    $statpot{'f24IV'}=-0.217;
    $statpot{'f24LA'}=-0.194;
    $statpot{'f24LR'}=-0.160;
    $statpot{'f24LN'}=-0.168;
    $statpot{'f24LD'}=-0.132;
    $statpot{'f24LC'}=-0.234;
    $statpot{'f24LQ'}=-0.138;
    $statpot{'f24LE'}=-0.102;
    $statpot{'f24LG'}=-0.064;
    $statpot{'f24LH'}=-0.173;
    $statpot{'f24LI'}=-0.243;
    $statpot{'f24LL'}=-0.241;
    $statpot{'f24LK'}=-0.132;
    $statpot{'f24LM'}=-0.224;
    $statpot{'f24LF'}=-0.277;
    $statpot{'f24LP'}=-0.113;
    $statpot{'f24LS'}=-0.160;
    $statpot{'f24LT'}=-0.136;
    $statpot{'f24LW'}=-0.251;
    $statpot{'f24LY'}=-0.216;
    $statpot{'f24LV'}=-0.206;
    $statpot{'f24KA'}=0.143;
    $statpot{'f24KR'}=0.241;
    $statpot{'f24KN'}=0.247;
    $statpot{'f24KD'}=0.259;
    $statpot{'f24KC'}=0.153;
    $statpot{'f24KQ'}=0.187;
    $statpot{'f24KE'}=0.303;
    $statpot{'f24KG'}=0.302;
    $statpot{'f24KH'}=0.169;
    $statpot{'f24KI'}=0.099;
    $statpot{'f24KL'}=0.084;
    $statpot{'f24KK'}=0.239;
    $statpot{'f24KM'}=0.105;
    $statpot{'f24KF'}=0.089;
    $statpot{'f24KP'}=0.275;
    $statpot{'f24KS'}=0.239;
    $statpot{'f24KT'}=0.226;
    $statpot{'f24KW'}=0.145;
    $statpot{'f24KY'}=0.150;
    $statpot{'f24KV'}=0.138;
    $statpot{'f24MA'}=-0.196;
    $statpot{'f24MR'}=-0.124;
    $statpot{'f24MN'}=-0.114;
    $statpot{'f24MD'}=-0.105;
    $statpot{'f24MC'}=-0.128;
    $statpot{'f24MQ'}=-0.146;
    $statpot{'f24ME'}=-0.068;
    $statpot{'f24MG'}=-0.029;
    $statpot{'f24MH'}=-0.146;
    $statpot{'f24MI'}=-0.231;
    $statpot{'f24ML'}=-0.225;
    $statpot{'f24MK'}=-0.120;
    $statpot{'f24MM'}=-0.237;
    $statpot{'f24MF'}=-0.253;
    $statpot{'f24MP'}=-0.086;
    $statpot{'f24MS'}=-0.111;
    $statpot{'f24MT'}=-0.132;
    $statpot{'f24MW'}=-0.195;
    $statpot{'f24MY'}=-0.205;
    $statpot{'f24MV'}=-0.179;
    $statpot{'f24FA'}=-0.276;
    $statpot{'f24FR'}=-0.222;
    $statpot{'f24FN'}=-0.180;
    $statpot{'f24FD'}=-0.178;
    $statpot{'f24FC'}=-0.267;
    $statpot{'f24FQ'}=-0.222;
    $statpot{'f24FE'}=-0.166;
    $statpot{'f24FG'}=-0.121;
    $statpot{'f24FH'}=-0.228;
    $statpot{'f24FI'}=-0.290;
    $statpot{'f24FL'}=-0.310;
    $statpot{'f24FK'}=-0.184;
    $statpot{'f24FM'}=-0.305;
    $statpot{'f24FF'}=-0.311;
    $statpot{'f24FP'}=-0.189;
    $statpot{'f24FS'}=-0.192;
    $statpot{'f24FT'}=-0.207;
    $statpot{'f24FW'}=-0.261;
    $statpot{'f24FY'}=-0.278;
    $statpot{'f24FV'}=-0.287;
    $statpot{'f24PA'}=0.146;
    $statpot{'f24PR'}=0.232;
    $statpot{'f24PN'}=0.197;
    $statpot{'f24PD'}=0.231;
    $statpot{'f24PC'}=0.155;
    $statpot{'f24PQ'}=0.214;
    $statpot{'f24PE'}=0.271;
    $statpot{'f24PG'}=0.299;
    $statpot{'f24PH'}=0.189;
    $statpot{'f24PI'}=0.073;
    $statpot{'f24PL'}=0.109;
    $statpot{'f24PK'}=0.224;
    $statpot{'f24PM'}=0.123;
    $statpot{'f24PF'}=0.066;
    $statpot{'f24PP'}=0.266;
    $statpot{'f24PS'}=0.217;
    $statpot{'f24PT'}=0.197;
    $statpot{'f24PW'}=0.062;
    $statpot{'f24PY'}=0.115;
    $statpot{'f24PV'}=0.131;
    $statpot{'f24SA'}=0.058;
    $statpot{'f24SR'}=0.082;
    $statpot{'f24SN'}=0.126;
    $statpot{'f24SD'}=0.159;
    $statpot{'f24SC'}=0.035;
    $statpot{'f24SQ'}=0.143;
    $statpot{'f24SE'}=0.149;
    $statpot{'f24SG'}=0.200;
    $statpot{'f24SH'}=0.113;
    $statpot{'f24SI'}=0.010;
    $statpot{'f24SL'}=-0.007;
    $statpot{'f24SK'}=0.140;
    $statpot{'f24SM'}=0.022;
    $statpot{'f24SF'}=-0.010;
    $statpot{'f24SP'}=0.150;
    $statpot{'f24SS'}=0.113;
    $statpot{'f24ST'}=0.136;
    $statpot{'f24SW'}=0.015;
    $statpot{'f24SY'}=0.030;
    $statpot{'f24SV'}=0.040;
    $statpot{'f24TA'}=0.032;
    $statpot{'f24TR'}=0.049;
    $statpot{'f24TN'}=0.097;
    $statpot{'f24TD'}=0.116;
    $statpot{'f24TC'}=0.026;
    $statpot{'f24TQ'}=0.120;
    $statpot{'f24TE'}=0.113;
    $statpot{'f24TG'}=0.169;
    $statpot{'f24TH'}=0.092;
    $statpot{'f24TI'}=-0.025;
    $statpot{'f24TL'}=-0.012;
    $statpot{'f24TK'}=0.105;
    $statpot{'f24TM'}=-0.003;
    $statpot{'f24TF'}=-0.057;
    $statpot{'f24TP'}=0.121;
    $statpot{'f24TS'}=0.098;
    $statpot{'f24TT'}=0.086;
    $statpot{'f24TW'}=0.004;
    $statpot{'f24TY'}=0.018;
    $statpot{'f24TV'}=0.003;
    $statpot{'f24WA'}=-0.199;
    $statpot{'f24WR'}=-0.174;
    $statpot{'f24WN'}=-0.144;
    $statpot{'f24WD'}=-0.112;
    $statpot{'f24WC'}=-0.235;
    $statpot{'f24WQ'}=-0.185;
    $statpot{'f24WE'}=-0.079;
    $statpot{'f24WG'}=-0.063;
    $statpot{'f24WH'}=-0.218;
    $statpot{'f24WI'}=-0.251;
    $statpot{'f24WL'}=-0.274;
    $statpot{'f24WK'}=-0.132;
    $statpot{'f24WM'}=-0.212;
    $statpot{'f24WF'}=-0.246;
    $statpot{'f24WP'}=-0.140;
    $statpot{'f24WS'}=-0.141;
    $statpot{'f24WT'}=-0.137;
    $statpot{'f24WW'}=-0.271;
    $statpot{'f24WY'}=-0.243;
    $statpot{'f24WV'}=-0.221;
    $statpot{'f24YA'}=-0.135;
    $statpot{'f24YR'}=-0.126;
    $statpot{'f24YN'}=-0.128;
    $statpot{'f24YD'}=-0.085;
    $statpot{'f24YC'}=-0.182;
    $statpot{'f24YQ'}=-0.123;
    $statpot{'f24YE'}=-0.063;
    $statpot{'f24YG'}=-0.011;
    $statpot{'f24YH'}=-0.122;
    $statpot{'f24YI'}=-0.203;
    $statpot{'f24YL'}=-0.194;
    $statpot{'f24YK'}=-0.073;
    $statpot{'f24YM'}=-0.170;
    $statpot{'f24YF'}=-0.225;
    $statpot{'f24YP'}=-0.074;
    $statpot{'f24YS'}=-0.102;
    $statpot{'f24YT'}=-0.097;
    $statpot{'f24YW'}=-0.224;
    $statpot{'f24YY'}=-0.196;
    $statpot{'f24YV'}=-0.163;
    $statpot{'f24VA'}=-0.125;
    $statpot{'f24VR'}=-0.093;
    $statpot{'f24VN'}=-0.097;
    $statpot{'f24VD'}=-0.056;
    $statpot{'f24VC'}=-0.091;
    $statpot{'f24VQ'}=-0.073;
    $statpot{'f24VE'}=-0.016;
    $statpot{'f24VG'}=0.008;
    $statpot{'f24VH'}=-0.088;
    $statpot{'f24VI'}=-0.175;
    $statpot{'f24VL'}=-0.169;
    $statpot{'f24VK'}=-0.058;
    $statpot{'f24VM'}=-0.140;
    $statpot{'f24VF'}=-0.229;
    $statpot{'f24VP'}=-0.039;
    $statpot{'f24VS'}=-0.068;
    $statpot{'f24VT'}=-0.078;
    $statpot{'f24VW'}=-0.187;
    $statpot{'f24VY'}=-0.162;
    $statpot{'f24VV'}=-0.160;
    $statpot{'a24AA'}=0.056;
    $statpot{'a24AR'}=-0.019;
    $statpot{'a24AN'}=-0.037;
    $statpot{'a24AD'}=-0.087;
    $statpot{'a24AC'}=0.154;
    $statpot{'a24AQ'}=-0.030;
    $statpot{'a24AE'}=-0.119;
    $statpot{'a24AG'}=0.091;
    $statpot{'a24AH'}=0.052;
    $statpot{'a24AI'}=0.162;
    $statpot{'a24AL'}=0.140;
    $statpot{'a24AK'}=-0.081;
    $statpot{'a24AM'}=0.163;
    $statpot{'a24AF'}=0.207;
    $statpot{'a24AP'}=-0.065;
    $statpot{'a24AS'}=-0.023;
    $statpot{'a24AT'}=-0.003;
    $statpot{'a24AW'}=0.133;
    $statpot{'a24AY'}=0.133;
    $statpot{'a24AV'}=0.116;
    $statpot{'a24RA'}=-0.089;
    $statpot{'a24RR'}=-0.194;
    $statpot{'a24RN'}=-0.151;
    $statpot{'a24RD'}=-0.215;
    $statpot{'a24RC'}=-0.033;
    $statpot{'a24RQ'}=-0.168;
    $statpot{'a24RE'}=-0.240;
    $statpot{'a24RG'}=-0.083;
    $statpot{'a24RH'}=-0.091;
    $statpot{'a24RI'}=0.028;
    $statpot{'a24RL'}=0.004;
    $statpot{'a24RK'}=-0.208;
    $statpot{'a24RM'}=-0.006;
    $statpot{'a24RF'}=0.076;
    $statpot{'a24RP'}=-0.234;
    $statpot{'a24RS'}=-0.140;
    $statpot{'a24RT'}=-0.127;
    $statpot{'a24RW'}=0.023;
    $statpot{'a24RY'}=0.007;
    $statpot{'a24RV'}=-0.040;
    $statpot{'a24NA'}=-0.095;
    $statpot{'a24NR'}=-0.163;
    $statpot{'a24NN'}=-0.212;
    $statpot{'a24ND'}=-0.261;
    $statpot{'a24NC'}=-0.050;
    $statpot{'a24NQ'}=-0.185;
    $statpot{'a24NE'}=-0.248;
    $statpot{'a24NG'}=-0.081;
    $statpot{'a24NH'}=-0.075;
    $statpot{'a24NI'}=0.022;
    $statpot{'a24NL'}=0.023;
    $statpot{'a24NK'}=-0.253;
    $statpot{'a24NM'}=0.003;
    $statpot{'a24NF'}=0.039;
    $statpot{'a24NP'}=-0.213;
    $statpot{'a24NS'}=-0.180;
    $statpot{'a24NT'}=-0.152;
    $statpot{'a24NW'}=0.014;
    $statpot{'a24NY'}=0.009;
    $statpot{'a24NV'}=-0.033;
    $statpot{'a24DA'}=-0.167;
    $statpot{'a24DR'}=-0.259;
    $statpot{'a24DN'}=-0.295;
    $statpot{'a24DD'}=-0.322;
    $statpot{'a24DC'}=-0.101;
    $statpot{'a24DQ'}=-0.233;
    $statpot{'a24DE'}=-0.343;
    $statpot{'a24DG'}=-0.170;
    $statpot{'a24DH'}=-0.188;
    $statpot{'a24DI'}=-0.073;
    $statpot{'a24DL'}=-0.080;
    $statpot{'a24DK'}=-0.309;
    $statpot{'a24DM'}=-0.099;
    $statpot{'a24DF'}=-0.064;
    $statpot{'a24DP'}=-0.294;
    $statpot{'a24DS'}=-0.252;
    $statpot{'a24DT'}=-0.221;
    $statpot{'a24DW'}=-0.101;
    $statpot{'a24DY'}=-0.103;
    $statpot{'a24DV'}=-0.115;
    $statpot{'a24CA'}=0.161;
    $statpot{'a24CR'}=0.071;
    $statpot{'a24CN'}=0.084;
    $statpot{'a24CD'}=0.039;
    $statpot{'a24CC'}=0.260;
    $statpot{'a24CQ'}=0.062;
    $statpot{'a24CE'}=-0.014;
    $statpot{'a24CG'}=0.218;
    $statpot{'a24CH'}=0.250;
    $statpot{'a24CI'}=0.335;
    $statpot{'a24CL'}=0.266;
    $statpot{'a24CK'}=0.010;
    $statpot{'a24CM'}=0.233;
    $statpot{'a24CF'}=0.419;
    $statpot{'a24CP'}=0.065;
    $statpot{'a24CS'}=0.078;
    $statpot{'a24CT'}=0.111;
    $statpot{'a24CW'}=0.412;
    $statpot{'a24CY'}=0.342;
    $statpot{'a24CV'}=0.237;
    $statpot{'a24QA'}=-0.074;
    $statpot{'a24QR'}=-0.172;
    $statpot{'a24QN'}=-0.182;
    $statpot{'a24QD'}=-0.203;
    $statpot{'a24QC'}=0.003;
    $statpot{'a24QQ'}=-0.169;
    $statpot{'a24QE'}=-0.246;
    $statpot{'a24QG'}=-0.048;
    $statpot{'a24QH'}=-0.083;
    $statpot{'a24QI'}=0.050;
    $statpot{'a24QL'}=0.010;
    $statpot{'a24QK'}=-0.203;
    $statpot{'a24QM'}=0.016;
    $statpot{'a24QF'}=0.056;
    $statpot{'a24QP'}=-0.194;
    $statpot{'a24QS'}=-0.167;
    $statpot{'a24QT'}=-0.124;
    $statpot{'a24QW'}=0.023;
    $statpot{'a24QY'}=0.016;
    $statpot{'a24QV'}=-0.009;
    $statpot{'a24EA'}=-0.259;
    $statpot{'a24ER'}=-0.300;
    $statpot{'a24EN'}=-0.309;
    $statpot{'a24ED'}=-0.362;
    $statpot{'a24EC'}=-0.177;
    $statpot{'a24EQ'}=-0.316;
    $statpot{'a24EE'}=-0.399;
    $statpot{'a24EG'}=-0.218;
    $statpot{'a24EH'}=-0.241;
    $statpot{'a24EI'}=-0.175;
    $statpot{'a24EL'}=-0.176;
    $statpot{'a24EK'}=-0.367;
    $statpot{'a24EM'}=-0.189;
    $statpot{'a24EF'}=-0.133;
    $statpot{'a24EP'}=-0.357;
    $statpot{'a24ES'}=-0.296;
    $statpot{'a24ET'}=-0.285;
    $statpot{'a24EW'}=-0.142;
    $statpot{'a24EY'}=-0.194;
    $statpot{'a24EV'}=-0.203;
    $statpot{'a24GA'}=0.041;
    $statpot{'a24GR'}=-0.062;
    $statpot{'a24GN'}=-0.060;
    $statpot{'a24GD'}=-0.125;
    $statpot{'a24GC'}=0.140;
    $statpot{'a24GQ'}=-0.041;
    $statpot{'a24GE'}=-0.139;
    $statpot{'a24GG'}=0.074;
    $statpot{'a24GH'}=0.024;
    $statpot{'a24GI'}=0.148;
    $statpot{'a24GL'}=0.132;
    $statpot{'a24GK'}=-0.120;
    $statpot{'a24GM'}=0.116;
    $statpot{'a24GF'}=0.169;
    $statpot{'a24GP'}=-0.098;
    $statpot{'a24GS'}=-0.026;
    $statpot{'a24GT'}=-0.011;
    $statpot{'a24GW'}=0.126;
    $statpot{'a24GY'}=0.116;
    $statpot{'a24GV'}=0.109;
    $statpot{'a24HA'}=0.040;
    $statpot{'a24HR'}=-0.033;
    $statpot{'a24HN'}=-0.024;
    $statpot{'a24HD'}=-0.108;
    $statpot{'a24HC'}=0.172;
    $statpot{'a24HQ'}=-0.060;
    $statpot{'a24HE'}=-0.136;
    $statpot{'a24HG'}=0.063;
    $statpot{'a24HH'}=0.059;
    $statpot{'a24HI'}=0.218;
    $statpot{'a24HL'}=0.179;
    $statpot{'a24HK'}=-0.123;
    $statpot{'a24HM'}=0.127;
    $statpot{'a24HF'}=0.214;
    $statpot{'a24HP'}=-0.084;
    $statpot{'a24HS'}=-0.019;
    $statpot{'a24HT'}=-0.012;
    $statpot{'a24HW'}=0.163;
    $statpot{'a24HY'}=0.148;
    $statpot{'a24HV'}=0.105;
    $statpot{'a24IA'}=0.257;
    $statpot{'a24IR'}=0.176;
    $statpot{'a24IN'}=0.178;
    $statpot{'a24ID'}=0.113;
    $statpot{'a24IC'}=0.407;
    $statpot{'a24IQ'}=0.195;
    $statpot{'a24IE'}=0.030;
    $statpot{'a24IG'}=0.290;
    $statpot{'a24IH'}=0.313;
    $statpot{'a24II'}=0.370;
    $statpot{'a24IL'}=0.379;
    $statpot{'a24IK'}=0.079;
    $statpot{'a24IM'}=0.397;
    $statpot{'a24IF'}=0.428;
    $statpot{'a24IP'}=0.128;
    $statpot{'a24IS'}=0.200;
    $statpot{'a24IT'}=0.222;
    $statpot{'a24IW'}=0.417;
    $statpot{'a24IY'}=0.396;
    $statpot{'a24IV'}=0.338;
    $statpot{'a24LA'}=0.207;
    $statpot{'a24LR'}=0.152;
    $statpot{'a24LN'}=0.183;
    $statpot{'a24LD'}=0.089;
    $statpot{'a24LC'}=0.342;
    $statpot{'a24LQ'}=0.132;
    $statpot{'a24LE'}=0.030;
    $statpot{'a24LG'}=0.255;
    $statpot{'a24LH'}=0.254;
    $statpot{'a24LI'}=0.362;
    $statpot{'a24LL'}=0.297;
    $statpot{'a24LK'}=0.068;
    $statpot{'a24LM'}=0.339;
    $statpot{'a24LF'}=0.421;
    $statpot{'a24LP'}=0.091;
    $statpot{'a24LS'}=0.185;
    $statpot{'a24LT'}=0.177;
    $statpot{'a24LW'}=0.367;
    $statpot{'a24LY'}=0.320;
    $statpot{'a24LV'}=0.288;
    $statpot{'a24KA'}=-0.183;
    $statpot{'a24KR'}=-0.264;
    $statpot{'a24KN'}=-0.297;
    $statpot{'a24KD'}=-0.324;
    $statpot{'a24KC'}=-0.132;
    $statpot{'a24KQ'}=-0.253;
    $statpot{'a24KE'}=-0.343;
    $statpot{'a24KG'}=-0.173;
    $statpot{'a24KH'}=-0.214;
    $statpot{'a24KI'}=-0.101;
    $statpot{'a24KL'}=-0.104;
    $statpot{'a24KK'}=-0.351;
    $statpot{'a24KM'}=-0.125;
    $statpot{'a24KF'}=-0.088;
    $statpot{'a24KP'}=-0.312;
    $statpot{'a24KS'}=-0.264;
    $statpot{'a24KT'}=-0.254;
    $statpot{'a24KW'}=-0.142;
    $statpot{'a24KY'}=-0.128;
    $statpot{'a24KV'}=-0.134;
    $statpot{'a24MA'}=0.248;
    $statpot{'a24MR'}=0.135;
    $statpot{'a24MN'}=0.162;
    $statpot{'a24MD'}=0.075;
    $statpot{'a24MC'}=0.278;
    $statpot{'a24MQ'}=0.146;
    $statpot{'a24ME'}=0.009;
    $statpot{'a24MG'}=0.239;
    $statpot{'a24MH'}=0.229;
    $statpot{'a24MI'}=0.382;
    $statpot{'a24ML'}=0.341;
    $statpot{'a24MK'}=0.051;
    $statpot{'a24MM'}=0.326;
    $statpot{'a24MF'}=0.385;
    $statpot{'a24MP'}=0.089;
    $statpot{'a24MS'}=0.146;
    $statpot{'a24MT'}=0.201;
    $statpot{'a24MW'}=0.355;
    $statpot{'a24MY'}=0.384;
    $statpot{'a24MV'}=0.291;
    $statpot{'a24FA'}=0.352;
    $statpot{'a24FR'}=0.275;
    $statpot{'a24FN'}=0.225;
    $statpot{'a24FD'}=0.161;
    $statpot{'a24FC'}=0.515;
    $statpot{'a24FQ'}=0.249;
    $statpot{'a24FE'}=0.107;
    $statpot{'a24FG'}=0.362;
    $statpot{'a24FH'}=0.371;
    $statpot{'a24FI'}=0.481;
    $statpot{'a24FL'}=0.474;
    $statpot{'a24FK'}=0.139;
    $statpot{'a24FM'}=0.468;
    $statpot{'a24FF'}=0.515;
    $statpot{'a24FP'}=0.197;
    $statpot{'a24FS'}=0.261;
    $statpot{'a24FT'}=0.305;
    $statpot{'a24FW'}=0.493;
    $statpot{'a24FY'}=0.484;
    $statpot{'a24FV'}=0.423;
    $statpot{'a24PA'}=-0.156;
    $statpot{'a24PR'}=-0.263;
    $statpot{'a24PN'}=-0.234;
    $statpot{'a24PD'}=-0.287;
    $statpot{'a24PC'}=-0.056;
    $statpot{'a24PQ'}=-0.234;
    $statpot{'a24PE'}=-0.313;
    $statpot{'a24PG'}=-0.135;
    $statpot{'a24PH'}=-0.161;
    $statpot{'a24PI'}=-0.039;
    $statpot{'a24PL'}=-0.089;
    $statpot{'a24PK'}=-0.288;
    $statpot{'a24PM'}=-0.079;
    $statpot{'a24PF'}=-0.035;
    $statpot{'a24PP'}=-0.307;
    $statpot{'a24PS'}=-0.225;
    $statpot{'a24PT'}=-0.191;
    $statpot{'a24PW'}=-0.056;
    $statpot{'a24PY'}=-0.090;
    $statpot{'a24PV'}=-0.106;
    $statpot{'a24SA'}=-0.081;
    $statpot{'a24SR'}=-0.123;
    $statpot{'a24SN'}=-0.169;
    $statpot{'a24SD'}=-0.222;
    $statpot{'a24SC'}=-0.008;
    $statpot{'a24SQ'}=-0.178;
    $statpot{'a24SE'}=-0.223;
    $statpot{'a24SG'}=-0.039;
    $statpot{'a24SH'}=-0.073;
    $statpot{'a24SI'}=0.052;
    $statpot{'a24SL'}=0.039;
    $statpot{'a24SK'}=-0.214;
    $statpot{'a24SM'}=0.026;
    $statpot{'a24SF'}=0.080;
    $statpot{'a24SP'}=-0.190;
    $statpot{'a24SS'}=-0.156;
    $statpot{'a24ST'}=-0.138;
    $statpot{'a24SW'}=0.038;
    $statpot{'a24SY'}=0.023;
    $statpot{'a24SV'}=0.003;
    $statpot{'a24TA'}=-0.047;
    $statpot{'a24TR'}=-0.105;
    $statpot{'a24TN'}=-0.129;
    $statpot{'a24TD'}=-0.171;
    $statpot{'a24TC'}=0.033;
    $statpot{'a24TQ'}=-0.135;
    $statpot{'a24TE'}=-0.193;
    $statpot{'a24TG'}=-0.011;
    $statpot{'a24TH'}=-0.060;
    $statpot{'a24TI'}=0.081;
    $statpot{'a24TL'}=0.057;
    $statpot{'a24TK'}=-0.189;
    $statpot{'a24TM'}=0.072;
    $statpot{'a24TF'}=0.139;
    $statpot{'a24TP'}=-0.147;
    $statpot{'a24TS'}=-0.115;
    $statpot{'a24TT'}=-0.126;
    $statpot{'a24TW'}=0.048;
    $statpot{'a24TY'}=0.028;
    $statpot{'a24TV'}=0.040;
    $statpot{'a24WA'}=0.231;
    $statpot{'a24WR'}=0.182;
    $statpot{'a24WN'}=0.163;
    $statpot{'a24WD'}=0.088;
    $statpot{'a24WC'}=0.453;
    $statpot{'a24WQ'}=0.172;
    $statpot{'a24WE'}=0.036;
    $statpot{'a24WG'}=0.261;
    $statpot{'a24WH'}=0.293;
    $statpot{'a24WI'}=0.412;
    $statpot{'a24WL'}=0.401;
    $statpot{'a24WK'}=0.061;
    $statpot{'a24WM'}=0.379;
    $statpot{'a24WF'}=0.470;
    $statpot{'a24WP'}=0.115;
    $statpot{'a24WS'}=0.177;
    $statpot{'a24WT'}=0.176;
    $statpot{'a24WW'}=0.426;
    $statpot{'a24WY'}=0.437;
    $statpot{'a24WV'}=0.327;
    $statpot{'a24YA'}=0.166;
    $statpot{'a24YR'}=0.130;
    $statpot{'a24YN'}=0.143;
    $statpot{'a24YD'}=0.047;
    $statpot{'a24YC'}=0.322;
    $statpot{'a24YQ'}=0.117;
    $statpot{'a24YE'}=-0.019;
    $statpot{'a24YG'}=0.224;
    $statpot{'a24YH'}=0.213;
    $statpot{'a24YI'}=0.335;
    $statpot{'a24YL'}=0.292;
    $statpot{'a24YK'}=0.030;
    $statpot{'a24YM'}=0.335;
    $statpot{'a24YF'}=0.403;
    $statpot{'a24YP'}=0.055;
    $statpot{'a24YS'}=0.136;
    $statpot{'a24YT'}=0.129;
    $statpot{'a24YW'}=0.410;
    $statpot{'a24YY'}=0.291;
    $statpot{'a24YV'}=0.252;
    $statpot{'a24VA'}=0.139;
    $statpot{'a24VR'}=0.067;
    $statpot{'a24VN'}=0.078;
    $statpot{'a24VD'}=0.020;
    $statpot{'a24VC'}=0.237;
    $statpot{'a24VQ'}=0.059;
    $statpot{'a24VE'}=-0.049;
    $statpot{'a24VG'}=0.187;
    $statpot{'a24VH'}=0.161;
    $statpot{'a24VI'}=0.283;
    $statpot{'a24VL'}=0.240;
    $statpot{'a24VK'}=0.005;
    $statpot{'a24VM'}=0.243;
    $statpot{'a24VF'}=0.336;
    $statpot{'a24VP'}=0.020;
    $statpot{'a24VS'}=0.092;
    $statpot{'a24VT'}=0.111;
    $statpot{'a24VW'}=0.282;
    $statpot{'a24VY'}=0.252;
    $statpot{'a24VV'}=0.203;

    return %statpot;

}


=head1 AUTHOR

Fiserlab Members , C<< <andras at fiserlab.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-. at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc StatisticalPotential


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=.>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/.>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/.>

=item * Search CPAN

L<http://search.cpan.org/dist/./>

=back



=head1 LICENSE AND COPYRIGHT
Copyright 2015 Fiserlab Members .

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


=cut

1; # End of StatisticalPotential
